from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32MP1 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32MP131AAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131AAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131AAEx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131AAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131AAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131AAFx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131AAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131AAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131AAGx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131CAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131CAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131CAEx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131CAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131CAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131CAFx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131CAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131CAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131CAGx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131DAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131DAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131DAEx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131DAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131DAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131DAFx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131DAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131DAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131DAGx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131FAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131FAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131FAEx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131FAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131FAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131FAFx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP131FAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP131FAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP131', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp131f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP131FAGx\n\nArm Cortex-A7 STM32MP1 STM32MP131', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133AAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133AAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133AAEx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133AAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133AAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133AAFx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133AAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133AAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133AAGx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133CAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133CAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133CAEx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133CAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133CAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133CAFx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133CAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133CAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133CAGx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133DAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133DAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133DAEx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133DAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133DAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133DAFx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133DAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133DAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133DAGx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133FAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133FAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133FAEx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133FAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133FAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133FAFx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP133FAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP133FAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP133', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp133f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP133FAGx\n\nArm Cortex-A7 STM32MP1 STM32MP133', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135AAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135AAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135AAEx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135AAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135AAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135AAFx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135AAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135AAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135AAGx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135CAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135CAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135CAEx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135CAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135CAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135CAFx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135CAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135CAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135CAGx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135DAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135DAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135DAEx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135DAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135DAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135DAFx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135DAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135DAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135DAGx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135FAEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135FAEx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:LFBGA-289_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135FAEx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135FAFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135FAFx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm'], 'footprint':'Package_BGA:ST_TFBGA-320_11x11mm_Layout21x21_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135FAFx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='AA19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='C16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D19',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K19',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R19',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T18',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='U19',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='U5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='V2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='V20',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='W1',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W15',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='W4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='Y12',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y15',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='Y19',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP135FAGx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP135FAGx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm'], 'footprint':'Package_BGA:TFBGA-289_9x9mm_Layout17x17_P0.5mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP135', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp135f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP135FAGx\n\nArm Cortex-A7 STM32MP1 STM32MP135', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDSD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VDDSD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDCPU',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K11',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PWR_CPU_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='T6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U15',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='U6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='U7',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='USB_DM2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151AAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151AAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151AAAx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151AABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151AABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151AABx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151AACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151AACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151AACx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151AADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151AADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151AADx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151CAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151CAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151CAAx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151CABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151CABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151CABx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151CACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151CACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151CACx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151CADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151CADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151CADx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151DAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151DAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151DAAx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151DABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151DABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151DABx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151DACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151DACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151DACx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151DADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151DADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151DADx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151FAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151FAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151FAAx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151FABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151FABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151FABx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151FACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151FACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151FACx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP151FADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP151FADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP151', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp151f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP151FADx\n\nArm Cortex-A7 STM32MP1 STM32MP151', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153AAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153AAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153AAAx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153AABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153AABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153AABx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153AACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153AACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153AACx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153AADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153AADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153AADx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153CAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153CAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153CAAx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153CABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153CABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153CABx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153CACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153CACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153CACx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153CADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153CADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153CADx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153DAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153DAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153DAAx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153DABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153DABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153DABx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153DACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153DACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153DACx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153DADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153DADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153DADx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153FAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153FAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153FAAx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153FABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153FABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153FABx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153FACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153FACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153FACx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B16',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B17',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B18',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP153FADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP153FADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP153', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp153f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP153FADx\n\nArm Cortex-A7 STM32MP1 STM32MP153', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B13',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C13',name='VDD_Unused',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157AAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157AAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157AAAx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157AABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157AABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157AABx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157AACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157AACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157AACx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157AADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157AADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157AADx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157CAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157CAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157CAAx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157CABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157CABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157CABx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157CACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157CACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157CACx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157CADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157CADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157CADx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157DAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157DAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157DAAx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157DABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157DABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157DABx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157DACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157DACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157DACx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157DADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157DADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157d.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157DADx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157FAAx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157FAAx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-448_18x18mm_Layout22x22_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157FAAx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA14',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA17',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB13',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB14',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB15',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AB17',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB19',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C21',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D19',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F21',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L21',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P21',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='P6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R20',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='T18',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='U10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U21',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='V10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V17',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='V18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='Y14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y19',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='Y2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y21',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y4',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y8',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157FABx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157FABx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm'], 'footprint':'Package_BGA:ST_LFBGA-354_16x16mm_Layout19x19_P0.8mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157FABx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C18',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E17',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD_PLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H17',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VSS_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VDD_PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='L16',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='T1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U7',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V13',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VSS_USBHS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V16',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='W12',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='W13',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W9',name='PF9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157FACx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157FACx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-361_12x12mm_Layout23x23_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157FACx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B7',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D1',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E2',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSS_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VDD_ANA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J8',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='DDR_DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='DDR_DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AA12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='VDD3V3_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA16',name='VSS_USBHS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA17',name='VDD3V3_USBFS',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='DDR_DQM3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='DDR_DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='DDR_DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='AB16',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='DDR_DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='DDR_DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='DDR_DQS3P',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='DDR_DQS3N',func=pin_types.BIDIR,unit=1),
            Pin(num='AB3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='AB7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AB8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='AB9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='DDR_DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='DDR_DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AC3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='AC5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='DDR_DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='DDR_DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='DDR_DQS2N',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='C18',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='C19',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C22',name='DDR_DQS2P',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='DDR_DQM2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='DDR_DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='DDR_DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='DDR_DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='DDR_DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F22',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PZ4',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PZ3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PZ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PZ5',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PZ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PZ2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K22',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='M20',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P22',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='R20',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='ANA0',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='ANA1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V22',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W4',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='DDR_DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='DDR_DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32MP157FADx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32MP157FADx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm'], 'footprint':'Package_BGA:ST_TFBGA-257_10x10mm_Layout19x19_P0.5mmP0.65mm', 'keywords':'Arm Cortex-A7 STM32MP1 STM32MP157', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32mp157f.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32MP1.kicad_sym\nSTM32MP157FADx\n\nArm Cortex-A7 STM32MP1 STM32MP157', 'pins':[
            Pin(num='1A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='1A2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='1A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='1A4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='1A5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='1A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1A7',name='VDD1V2_DSI_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1A8',name='DDR_ZQ',func=pin_types.BIDIR,unit=1),
            Pin(num='1A9',name='DDR_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='1B1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='1B2',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='1B3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='1B5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1B6',name='VDDA1V8_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='1B7',name='VDD1V2_DSI_PHY',func=pin_types.PWRIN,unit=1),
            Pin(num='1B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1B9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1C1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='1C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='1C3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1C8',name='DDR_DTO1',func=pin_types.BIDIR,unit=1),
            Pin(num='1C9',name='DDR_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='1D1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='1D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D3',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1D7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1D8',name='DDR_DTO0',func=pin_types.BIDIR,unit=1),
            Pin(num='1D9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1E1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='1E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E4',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1E8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1E9',name='DDR_RASN',func=pin_types.BIDIR,unit=1),
            Pin(num='1F1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='1F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1F4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F5',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1F7',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1F8',name='DDR_ATO',func=pin_types.BIDIR,unit=1),
            Pin(num='1F9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='1G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G6',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1G8',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='1G9',name='DDR_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='1H1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='1H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H5',name='VDDA1V8_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H7',name='VDD3V3_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='1H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1H9',name='VDDQ_DDR',func=pin_types.PWRIN,unit=1),
            Pin(num='1J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='1J2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='1J3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1J4',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='1J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='1J6',name='VDDA1V1_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='1J7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='1J8',name='USB_RREF',func=pin_types.BIDIR,unit=1),
            Pin(num='1J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='DDR_DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='DDR_DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='NJTRST',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='DDR_DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='DDR_DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='DDR_DQS0N',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='DDR_DQS0P',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VDD_DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='DDR_RESETN',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='DDR_DQM0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='DDR_DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='DDR_DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D18',name='DDR_DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='DDR_DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='DDR_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='DDR_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='DDR_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F19',name='DDR_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G18',name='DDR_A0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='DDR_BA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='BOOT2',func=pin_types.INPUT,unit=1),
            Pin(num='H17',name='DDR_BA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='DDR_ODT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='J17',name='DDR_CSN',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='DDR_WEN',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='DDR_CASN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NRST_CORE',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='PWR_LP',func=pin_types.OUTPUT,unit=1),
            Pin(num='K17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='DDR_CLKN',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='PDR_ON_CORE',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='BOOT1',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DDR_CLKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='DDR_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PDR_ON',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DDR_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='DDR_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='DDR_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PWR_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='DDR_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='DDR_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='DDR_CKE',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='DDR_BA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='DDR_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='DDR_DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='DDR_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='DDR_DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='DDR_DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='BYPASS_REG1V8',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='DDR_DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='DDR_DQS1N',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='DDR_DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='USB_DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='USB_DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='OTG_VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='DDR_DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='DDR_DQM1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='DDR_DQS1P',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='USB_DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W14',name='USB_DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='DDR_VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='DDR_DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='DDR_DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PG9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])