from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

FPGA_Xilinx_Virtex5 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'XC5VFX100T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX100T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX100T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A15',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A16',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AH23',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AH24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ14',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ19',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ20',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ21',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ22',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK13',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK14',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK16',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK18',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK19',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK21',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK22',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK24',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL13',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL14',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL15',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL19',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL20',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL21',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN17',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='B15',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B16',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B17',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C14',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C15',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C17',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D14',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D15',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D16',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D17',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D19',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D20',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D21',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D22',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E14',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E16',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E17',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E21',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E23',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E24',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F14',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F15',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F18',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A6',name='MGTRXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A7',name='MGTRXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A8',name='MGTRXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A9',name='MGTRXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AL7',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AM7',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN10',name='MGTTXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN5',name='MGTTXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN6',name='MGTTXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN9',name='MGTTXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP6',name='MGTRXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP7',name='MGTRXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP8',name='MGTRXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP9',name='MGTRXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='B10',name='MGTTXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B5',name='MGTTXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B6',name='MGTTXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B9',name='MGTTXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='C8',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D8',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM10',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM5',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM6',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM9',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=14),
            Pin(num='C10',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C5',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C6',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C9',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=14),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=14),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=16),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=17)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B32', 'J22', 'L20', 'H12', 'K22', 'N34', 'R33', 'E32', 'V31', 'F33', 'H22', 'J32', 'K23', 'L21', 'D32', 'F34', 'H23', 'J34', 'K32', 'L33', 'R32', 'D13', 'D34', 'H32', 'K12', 'K33', 'L34', 'R34', 'E34', 'U31', 'C33', 'G22', 'H33', 'K13', 'K34', 'M32', 'T34', 'B33', 'C34', 'G23', 'H34', 'K14', 'L14', 'M33', 'P32', 'U33', 'C32', 'G32', 'J12', 'K16', 'L15', 'N32', 'R30', 'G14', 'P34', 'E33', 'G33', 'J15', 'K21', 'A33', 'L16', 'N33', 'T33', 'T27', 'U32']},{'label': 'uB', 'num': 2, 'pin_nums': ['N6', 'N7', 'AJ34', 'F5', 'AE34', 'N8', 'E7', 'AB29', 'P10', 'AE33', 'P5', 'P6', 'P7', 'E6', 'P9', 'AJ32', 'AP32', 'AA34', 'AN32', 'R11', 'AE32', 'R6', 'R7', 'AN34', 'AN33', 'R8', 'AA33', 'AA32', 'AD34', 'AH34', 'R9', 'T10', 'AM32', 'AL34', 'T11', 'T6', 'AD32', 'T7', 'AH33', 'T8', 'AL33', 'T9', 'AM33', 'AC34', 'U10', 'F6', 'U7', 'G5', 'AH32', 'V32', 'G6', 'AK34', 'G7', 'V33', 'AC33', 'H5', 'V34', 'H7', 'W28', 'J5', 'J6', 'W32', 'AG33', 'J7', 'AC32', 'AK33', 'W34', 'K6', 'Y32', 'K7', 'L4', 'Y33', 'L5', 'Y34', 'AG32', 'AB33', 'L6', 'M5', 'AK32', 'M6', 'M7', 'AF33', 'M9', 'AB32', 'AF34', 'N5']},{'label': 'uC', 'num': 3, 'pin_nums': ['AB31', 'V24', 'J31', 'AC29', 'V25', 'K29', 'AC30', 'K31', 'V27', 'AD29', 'V28', 'L29', 'AD30', 'L30', 'V29', 'AD31', 'V30', 'L31', 'AD33', 'L32', 'W24', 'AE29', 'M29', 'W25', 'AE30', 'M30', 'W26', 'AE31', 'M31', 'W27', 'J30', 'AF29', 'N29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'Y28', 'P33', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'U30']},{'label': 'uD', 'num': 4, 'pin_nums': ['J26', 'W6', 'J27', 'AE6', 'W7', 'AE7', 'J28', 'W8', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AG7', 'L24', 'Y8', 'AH5', 'L25', 'Y9', 'AH7', 'L26', 'AJ6', 'L28', 'AJ7', 'M25', 'AK6', 'M26', 'AK7', 'M27', 'E26', 'M28', 'E27', 'N24', 'E28', 'N25', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'AD7', 'J24', 'W10', 'AD6', 'J25', 'W11']},{'label': 'uE', 'num': 5, 'pin_nums': ['M8', 'B12', 'E11', 'AE17', 'AF16', 'F8', 'H11', 'K8', 'N10', 'AF15', 'AE16', 'B13', 'E12', 'F9', 'H8', 'A13', 'AE19', 'AF20', 'K9', 'E10', 'N9', 'F13', 'AD19', 'AE21', 'AF21', 'C12', 'E13', 'G10', 'H10', 'H9', 'K11', 'L10', 'AE22', 'AD20', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'D11', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AM19']},{'label': 'uF', 'num': 6, 'pin_nums': ['AD11', 'Y24', 'AH27', 'AD24', 'AH28', 'AD25', 'AH8', 'AD26', 'AH9', 'AD27', 'AJ10', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AE24', 'AJ26', 'AE26', 'AJ27', 'AE27', 'AJ28', 'AE28', 'AJ29', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AH25', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AG11', 'AB8', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AP14']},{'label': 'uG', 'num': 7, 'pin_nums': ['B27', 'AM31', 'B28', 'A18', 'AN18', 'B30', 'A19', 'AN19', 'B31', 'A20', 'AN20', 'C18', 'A21', 'AN22', 'C19', 'A23', 'AN23', 'C20', 'A24', 'AN24', 'C22', 'A25', 'AN25', 'C23', 'A26', 'AN26', 'C24', 'A28', 'AN27', 'C25', 'A29', 'AN28', 'C26', 'A30', 'AN29', 'C27', 'A31', 'AN30', 'C28', 'AK25', 'AP19', 'C29', 'AL22', 'AP20', 'C30', 'AL24', 'AP21', 'D25', 'AL25', 'AP22', 'D26', 'AL26', 'AP24', 'D27', 'AL28', 'AP25', 'D29', 'AL29', 'AP26', 'D30', 'AL30', 'AP27', 'D31', 'AL31', 'AP29', 'F27', 'AM18', 'AP30', 'G24', 'AM20', 'AP31', 'AM21', 'B18', 'AM22', 'B20', 'AM23', 'B21', 'AM25', 'B22', 'AM26', 'B23', 'AM27', 'AM30', 'B25', 'AM28', 'B26']},{'label': 'uH', 'num': 8, 'pin_nums': ['K19', 'J14', 'AE18', 'AG18', 'AH17', 'G15', 'J16', 'L18', 'AF18', 'AH18', 'G16', 'AG20', 'H14', 'J17', 'L19', 'AF19', 'AH19', 'AG21', 'H13', 'J19', 'AH15', 'AG13', 'AG22', 'AH20', 'H15', 'J20', 'AG14', 'H17', 'AH12', 'AH22', 'H18', 'J21', 'AG15', 'AH13', 'AL12', 'H19', 'K17', 'AG16', 'AH14', 'D23', 'H20', 'K18', 'AG17', 'E20']},{'label': 'uI', 'num': 9, 'pin_nums': ['AL14', 'D22', 'D24', 'AL15', 'AL16', 'E14', 'A14', 'E16', 'AL18', 'A15', 'AL19', 'E17', 'A16', 'AL20', 'E18', 'AH23', 'E19', 'AL21', 'AH24', 'AL23', 'E21', 'AJ12', 'AM15', 'E22', 'AJ14', 'AM16', 'E23', 'AJ15', 'AM17', 'E24', 'AJ16', 'AN15', 'F14', 'AJ17', 'AN16', 'F15', 'AJ18', 'AN17', 'F16', 'AJ19', 'AP15', 'F17', 'AJ20', 'AP16', 'F18', 'AJ21', 'AP17', 'F19', 'AJ22', 'B15', 'F20', 'AJ24', 'B16', 'F21', 'AK12', 'B17', 'F23', 'AK13', 'B19', 'F24', 'AK14', 'C14', 'G17', 'AK15', 'C15', 'G18', 'AK16', 'C16', 'G20', 'AK17', 'C17', 'G21', 'AK18', 'D14', 'AK19', 'D15', 'AK21', 'D16', 'AK22', 'D17', 'AK23', 'D19', 'AK24', 'D20', 'AL13', 'D21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['P1', 'W1', 'AA1', 'W2', 'P3', 'AB1', 'Y1', 'P4', 'AB2', 'R1', 'Y3', 'AC2', 'T1', 'Y4', 'M2', 'T2', 'N1', 'U2', 'N2', 'V2']},{'label': 'uK', 'num': 11, 'pin_nums': ['AE2', 'F2', 'K2', 'AF1', 'G1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4', 'AD2', 'AH2', 'J1', 'AE1', 'AJ2', 'K1']},{'label': 'uL', 'num': 12, 'pin_nums': ['C1', 'AL5', 'AM1', 'D1', 'A2', 'AN3', 'D2', 'A3', 'AN4', 'D4', 'AK2', 'AP2', 'E2', 'AL1', 'AP3', 'E4', 'AL2', 'B3', 'AL4', 'B4']},{'label': 'uM', 'num': 13, 'pin_nums': ['A8', 'AP6', 'C8', 'A9', 'D8', 'AP7', 'AL7', 'AP8', 'AM7', 'AP9', 'AN10', 'B10', 'AN5', 'B5', 'A6', 'AN6', 'B6', 'A7', 'B9', 'AN9']},{'label': 'uN', 'num': 14, 'pin_nums': ['AE3', 'AL3', 'D3', 'J4', 'AM9', 'U3', 'AG3', 'AL8', 'C10', 'D5', 'K3', 'V3', 'AG4', 'AM10', 'C3', 'D7', 'V4', 'L3', 'AA3', 'AH3', 'AM3', 'C4', 'E3', 'M3', 'V5', 'AA4', 'AJ3', 'AM4', 'C5', 'F3', 'N3', 'W3', 'AB3', 'AJ4', 'AM5', 'C6', 'F4', 'R3', 'AC3', 'AK3', 'AM6', 'C7', 'G3', 'R4', 'AD3', 'AK5', 'AM8', 'C9', 'J3', 'T3']},{'label': 'uO', 'num': 15, 'pin_nums': ['M15', 'U18', 'M22', 'AC15', 'M23', 'V17', 'AC22', 'AD14', 'N14', 'V18', 'N15', 'W17', 'AD15', 'AD21', 'N22', 'W18', 'AA22', 'AD22', 'N23', 'AB15', 'AD23', 'P15', 'AC14', 'U17']},{'label': 'uP', 'num': 16, 'pin_nums': ['L27', 'T18', 'AB11', 'L7', 'F12', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'T20', 'AB17', 'F32', 'M12', 'E5', 'P2', 'T21', 'AB19', 'F7', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'G29', 'M16', 'P22', 'T4', 'AC16', 'G34', 'M17', 'P23', 'T5', 'AC18', 'G4', 'M18', 'P28', 'U12', 'AC20', 'G9', 'M19', 'P8', 'U14', 'AD13', 'H16', 'M20', 'R10', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'R15', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'R17', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'P17', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20']},{'label': 'uQ', 'num': 17, 'pin_nums': ['V20', 'AE20', 'AA13', 'V22', 'AM14', 'AE25', 'AA15', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AE5', 'AA19', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'AN11', 'W19', 'AA23', 'AF2', 'AN2', 'W21', 'AA27', 'AF22', 'AN21', 'W23', 'AA7', 'AF27', 'AN31', 'W33', 'AB12', 'AF32', 'AN7', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14', 'AB22', 'AG34', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AE15', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AL9']}] }),
        Part(**{ 'name':'XC5VFX100T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX100T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX100T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=9),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=9),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=9),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=10),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=10),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=10),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=10),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=11),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=11),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=11),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=12),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=12),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=12),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=12),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=12),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=12),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=12),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=12),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=12),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=12),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=12),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=13),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=13),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=13),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=13),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=13),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=13),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=13),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=13),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=13),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=13),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=13),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=13),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=14),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=14),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=14),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=14),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=14),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=14),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=14),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=14),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=14),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=14),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=14),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=15),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=15),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=15),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=15),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=15),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=15),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=15),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=15),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=15),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=15),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=15),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=15),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=15),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=15),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=15),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=15),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=15),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=15),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=15),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=15),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=15),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=15),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=15),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=15),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=15),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=15),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=15),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=15),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=15),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=15),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=15),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=15),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=15),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=15),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=15),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=15),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=15),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=15),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=15),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=15),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=15),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=15),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=15),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=15),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=15),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=15),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=15),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=15),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=15),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=15),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=16),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=16),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=16),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=16),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=16),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=16),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=16),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=16),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=16),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=16),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=17),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=17),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=17),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=17),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=17),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=18)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['M41', 'P25', 'N28', 'AA39', 'V41', 'Y41', 'J41', 'AA38', 'M42', 'N29', 'P26', 'J42', 'T40', 'W40', 'Y42', 'AA41', 'K42', 'N13', 'N30', 'P27', 'T41', 'W41', 'AA37', 'AA42', 'L40', 'N14', 'N40', 'P28', 'T42', 'W42', 'F13', 'L41', 'N15', 'N41', 'P40', 'F41', 'L42', 'U41', 'Y37', 'F42', 'M13', 'N16', 'P13', 'P41', 'U42', 'Y38', 'G41', 'AA40', 'M14', 'N25', 'P17', 'P42', 'G42', 'R42', 'V37', 'Y39', 'M16', 'H41', 'N26', 'P18', 'R40', 'M29', 'V40', 'Y40', 'J14']},{'label': 'uB', 'num': 2, 'pin_nums': ['AC40', 'W5', 'AU41', 'AC41', 'W6', 'AU42', 'AD39', 'AV41', 'W7', 'AD40', 'W8', 'G6', 'AD41', 'H5', 'Y10', 'AD42', 'Y7', 'H6', 'AE36', 'J5', 'Y8', 'AE40', 'J6', 'Y9', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AT42', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AA6', 'AK42', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AA9', 'AL42', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'AR42', 'V8', 'AC38', 'AT41', 'W10', 'AC39', 'W11']},{'label': 'uC', 'num': 3, 'pin_nums': ['J38', 'J40', 'AJ37', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'L39', 'AK41', 'M38', 'AL37', 'M39', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'G38', 'W37', 'AG39', 'G39', 'W38', 'AG40', 'H38', 'Y34', 'AH37', 'AH39', 'H39', 'Y35', 'AH38', 'H40']},{'label': 'uD', 'num': 4, 'pin_nums': ['AG6', 'AB11', 'M37', 'AG7', 'AB6', 'N35', 'AB7', 'AH4', 'N36', 'AH5', 'AB8', 'P35', 'AB9', 'AH6', 'P36', 'AJ5', 'AC10', 'R34', 'AC5', 'AJ6', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'AD5', 'E37', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'F37', 'AD8', 'V35', 'AG4', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'AE7', 'H36', 'Y33', 'AE8', 'J35', 'AE9', 'J36', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'AG10', 'L38', 'AA32', 'M36']},{'label': 'uE', 'num': 5, 'pin_nums': ['H8', 'AL14', 'E9', 'AK12', 'AN14', 'L8', 'P8', 'T9', 'AK13', 'AL29', 'AP13', 'F5', 'P9', 'U11', 'H9', 'L9', 'AK14', 'AL30', 'AR26', 'F6', 'J7', 'M7', 'R6', 'T11', 'U8', 'AK15', 'AM13', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AK27', 'AM14', 'D7', 'F9', 'K7', 'M9', 'R8', 'V10', 'AK28', 'AM28', 'E5', 'G7', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'AK29', 'AM29', 'E7', 'G8', 'K9', 'N9', 'T10', 'V9', 'AJ30', 'AK30', 'AN13', 'E8', 'P7', 'G9', 'L7']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE35', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AG36', 'E33', 'P31', 'AH34', 'E34', 'P32', 'AH35', 'E35', 'P33', 'AH36', 'E36', 'R32', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AT37', 'AU38', 'M31', 'AE34', 'AU37', 'M32']},{'label': 'uG', 'num': 7, 'pin_nums': ['E6', 'AN33', 'P10', 'AP31', 'F10', 'P11', 'AP32', 'F11', 'P12', 'F12', 'AP33', 'R10', 'AP39', 'F14', 'F15', 'AR32', 'E15', 'AR33', 'G10', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'K10', 'AJ32', 'AV34', 'K12', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31', 'N11']},{'label': 'uH', 'num': 8, 'pin_nums': ['AN6', 'AJ8', 'AG9', 'AL8', 'AR7', 'E26', 'K28', 'L29', 'AH10', 'AK10', 'AL9', 'AN8', 'AR8', 'H27', 'K29', 'L30', 'AH11', 'AK11', 'AM6', 'AN9', 'AT5', 'J15', 'K30', 'M17', 'AH7', 'AK8', 'AM7', 'AP5', 'AT6', 'J16', 'L14', 'M26', 'AH8', 'AK9', 'AM8', 'AP6', 'AT7', 'J17', 'L15', 'M27', 'AG11', 'AH9', 'AL10', 'AM9', 'AP7', 'AU6', 'J30', 'L16', 'M28', 'AG12', 'AJ10', 'AL6', 'AN4', 'AP8', 'AV5', 'K15', 'L17', 'AG8', 'AJ11', 'AL7', 'AN5', 'AR5', 'AV6', 'K17', 'L27']},{'label': 'uI', 'num': 9, 'pin_nums': ['G18', 'H29', 'AN15', 'AL16', 'AP28', 'F16', 'G27', 'H30', 'K19', 'K24', 'L26', 'M18', 'F17', 'G28', 'J18', 'AL17', 'AN16', 'AP30', 'K25', 'M19', 'AP27', 'AL26', 'AN28', 'AR16', 'F23', 'G29', 'J25', 'K27', 'M24', 'AL27', 'AN29', 'AT13', 'F27', 'H16', 'J26', 'L19', 'N18', 'AM16', 'AN30', 'B25', 'F29', 'H18', 'J27', 'L20', 'N19', 'AM17', 'AP15', 'C22', 'G16', 'H26', 'J28', 'L24', 'N20', 'AK17', 'AM26', 'AP16', 'E17', 'G17', 'H28', 'K18', 'L25', 'AL15', 'P20', 'AM27', 'E18']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AR19', 'AK18', 'AP17', 'AT17', 'AM19', 'AU29', 'AK19', 'AM24', 'AP18', 'AR27', 'AT19', 'AW24', 'AK24', 'AN18', 'AP25', 'AR28', 'AT23', 'AY21', 'AK25', 'AN19', 'AP26', 'AR29', 'AT26', 'AL19', 'AN20', 'AR14', 'AR30', 'AT27', 'AL24', 'AN24', 'AR15', 'AT14', 'AT29', 'AL25', 'AN25', 'AR17', 'AT15', 'AT30', 'AM18', 'AN26', 'AR18', 'AT16', 'AU28']},{'label': 'uK', 'num': 11, 'pin_nums': ['AD3', 'U2', 'AD4', 'V1', 'AE1', 'V3', 'AA2', 'AF1', 'V4', 'AB2', 'AF2', 'W1', 'AC1', 'AG2', 'Y1', 'AC2', 'T2', 'Y2', 'AD1', 'U1']},{'label': 'uL', 'num': 12, 'pin_nums': ['AN2', 'P1', 'AJ1', 'AH2', 'AM2', 'AJ2', 'K2', 'P2', 'AK1', 'L1', 'R2', 'AK3', 'L2', 'AK4', 'M1', 'AL1', 'M3', 'AM1', 'M4', 'N1']},{'label': 'uM', 'num': 13, 'pin_nums': ['AT3', 'E2', 'F1', 'AT4', 'AU1', 'F3', 'AV1', 'F4', 'AP2', 'AV2', 'G1', 'AR1', 'AW2', 'H1', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2']},{'label': 'uN', 'num': 14, 'pin_nums': ['A2', 'B5', 'BB4', 'A3', 'B6', 'BB5', 'A4', 'BA1', 'C3', 'A5', 'BA2', 'C4', 'AW4', 'BA5', 'AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3']},{'label': 'uO', 'num': 15, 'pin_nums': ['G3', 'P3', 'AL4', 'AC3', 'AW3', 'C2', 'G4', 'R3', 'C5', 'H3', 'T3', 'AE3', 'AM3', 'AW5', 'AE4', 'AN3', 'AY1', 'C6', 'J3', 'AV3', 'U3', 'AF3', 'AP3', 'AY2', 'D3', 'K3', 'W3', 'AR3', 'AA3', 'AG3', 'AY3', 'D4', 'L3', 'W4', 'AA5', 'AH3', 'AU3', 'AY5', 'D5', 'N3', 'Y3', 'AU4', 'AB3', 'AJ3', 'AY6', 'E3', 'N4', 'AB4', 'AL3', 'C1']},{'label': 'uP', 'num': 16, 'pin_nums': ['AA22', 'P15', 'AB21', 'AH16', 'R14', 'AB22', 'AH29', 'R15', 'AC21', 'AH30', 'R29', 'AC22', 'AJ15', 'R30', 'AG29', 'AJ16', 'T14', 'AG30', 'AH15', 'AJ28', 'T30', 'AA21', 'AH14', 'AL28']},{'label': 'uQ', 'num': 17, 'pin_nums': ['M20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'B16', 'AE28', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'AB17', 'G35', 'M35', 'R23', 'V25', 'AB27', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'B40', 'AF21', 'H4', 'N2', 'B10', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'J9', 'P16', 'T23', 'W30', 'A19', 'AD13', 'AG20', 'D17', 'K11', 'P19', 'T25', 'Y13', 'A23', 'AD15', 'AG22', 'D24', 'K16', 'P21', 'T27', 'Y15', 'A28', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'Y17', 'A33', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'Y19', 'A38', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'U14', 'Y21', 'AA12', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'U16', 'Y22', 'AA14', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'Y23', 'AA16', 'AD27', 'AH19', 'E21', 'L13', 'P34', 'U20', 'Y25', 'AD29', 'AA18', 'AH21', 'E31', 'L18', 'P4', 'U22', 'Y27', 'AA20', 'AD31', 'AH23', 'E4', 'L23', 'R11', 'U24', 'Y29', 'AA24', 'AE12', 'AH25', 'E41', 'L28', 'R12', 'U26', 'Y31', 'AA26', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'R20', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'M2', 'R19', 'V17', 'AE24', 'G15']},{'label': 'uR', 'num': 18, 'pin_nums': ['AJ29', 'AW6', 'W27', 'U15', 'AA25', 'AD12', 'AF28', 'AJ39', 'AP24', 'AW8', 'W29', 'U17', 'AD14', 'AA27', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AF8', 'AK2', 'AR11', 'BA10', 'U25', 'W9', 'AB10', 'AD20', 'AG13', 'AK21', 'AR21', 'BA15', 'U27', 'Y11', 'AB12', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'Y12', 'AB14', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'Y14', 'AB16', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'Y16', 'AB18', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'Y18', 'AB20', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'Y20', 'AB24', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'V14', 'Y24', 'AB26', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'Y26', 'AB28', 'AE13', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'Y28', 'AB30', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'Y30', 'AE17', 'AB40', 'AH12', 'AM10', 'AU15', 'BB30', 'V20', 'Y36', 'AB5', 'AE19', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'Y4', 'AC11', 'AE2', 'AA23', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'Y6', 'AC13', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AE29', 'AH32', 'AM5', 'AV32', 'T20', 'V42', 'AE31', 'AC25', 'AH42', 'AN12', 'AC7', 'AV4', 'T22', 'W13', 'AC27', 'AE41', 'AJ13', 'AN17', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'AA13', 'W19', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'AA15', 'W2', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'AA17', 'W21', 'AC4', 'AF22', 'AJ25', 'AN42', 'AP14', 'AW29', 'T8', 'AA19', 'W23', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AF26']}] }),
        Part(**{ 'name':'XC5VFX130T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX130T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX130T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L2P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A31',name='IO_L2N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A32',name='IO_L3P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A34',name='IO_L7P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A35',name='IO_L7N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A36',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A37',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A39',name='IO_L15P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A40',name='IO_L15N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A41',name='IO_L16P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B31',name='IO_L1N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B32',name='IO_L3N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B33',name='IO_L4P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B34',name='IO_L6N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='B36',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B37',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B38',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B39',name='IO_L14P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B41',name='IO_L16N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B42',name='IO_L17P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C30',name='IO_L1P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C31',name='IO_L0N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C33',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C34',name='IO_L6P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C35',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C36',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C38',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C39',name='IO_L13P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C40',name='IO_L13N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C41',name='IO_L17N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D31',name='IO_L0P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D32',name='IO_L5P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D33',name='IO_L5N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D35',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D36',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D38',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D40',name='IO_L18P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D41',name='IO_L18N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D42',name='IO_L19N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='E42',name='IO_L19P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW31',name='IO_L19N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW32',name='IO_L15N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW33',name='IO_L15P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW35',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW36',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW37',name='IO_L6N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW38',name='IO_L7P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW40',name='IO_L1N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW41',name='IO_L1P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW42',name='IO_L0N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY30',name='IO_L19P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY32',name='IO_L16P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY33',name='IO_L14P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY34',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY35',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY37',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY38',name='IO_L6P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY39',name='IO_L7N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY40',name='IO_L2P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY42',name='IO_L0P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA30',name='IO_L18P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA31',name='IO_L18N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA32',name='IO_L16N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA34',name='IO_L13N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA35',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA36',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA37',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA39',name='IO_L5N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA40',name='IO_L4P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA41',name='IO_L2N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA42',name='IO_L3P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB31',name='IO_L17N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB32',name='IO_L17P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB33',name='IO_L13P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB34',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB36',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB37',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB38',name='IO_L5P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB39',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB41',name='IO_L3N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=10),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=10),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=10),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=10),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=10),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=10),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=10),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=10),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=10),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=10),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='D18',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=11),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=11),
            Pin(num='E20',name='IO_L14P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='E22',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='E23',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F19',name='IO_L16P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F20',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F21',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F24',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F25',name='IO_L17N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='F26',name='IO_L17P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='G19',name='IO_L16N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=11),
            Pin(num='G21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='G22',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='G23',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=11),
            Pin(num='G24',name='IO_L15P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='G26',name='IO_L19N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=11),
            Pin(num='H19',name='IO_L18P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='H20',name='IO_L18N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='H21',name='IO_L4P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='H23',name='IO_L13N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='H24',name='IO_L15N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='H25',name='IO_L19P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='J20',name='IO_L5P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='J21',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=11),
            Pin(num='J22',name='IO_L7N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='J23',name='IO_L13P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='K20',name='IO_L5N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='K22',name='IO_L7P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='K23',name='IO_L6N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='L21',name='IO_L1N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='L22',name='IO_L6P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='M21',name='IO_L1P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='M22',name='IO_L0N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='M23',name='IO_L0P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='N21',name='IO_L3N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='N22',name='IO_L3P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='N23',name='IO_L2N_7',func=pin_types.BIDIR,unit=11),
            Pin(num='N24',name='IO_L2P_7',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ21',name='IO_L2N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AJ22',name='IO_L2P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AK20',name='IO_L3P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AK22',name='IO_L1N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AK23',name='IO_L1P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AL20',name='IO_L3N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AL21',name='IO_L0P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AL22',name='IO_L0N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AM21',name='IO_L19N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AM22',name='IO_L16P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AM23',name='IO_L16N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AN21',name='IO_L19P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AN23',name='IO_L17P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=12),
            Pin(num='AP20',name='IO_L18P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AP21',name='IO_L18N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AP22',name='IO_L14N_VREF_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AP23',name='IO_L17N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AR20',name='IO_L7P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AR22',name='IO_L15P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AR23',name='IO_L14P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AR24',name='IO_L8N_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AR25',name='IO_L6P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AT20',name='IO_L7N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AT21',name='IO_L9N_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AT22',name='IO_L15N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AT24',name='IO_L8P_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AT25',name='IO_L6N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU18',name='IO_L5N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU19',name='IO_L5P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=12),
            Pin(num='AU21',name='IO_L9P_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU22',name='IO_L12N_VRP_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU23',name='IO_L12P_VRN_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU24',name='IO_L11P_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU26',name='IO_L4P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AU27',name='IO_L4N_VREF_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=12),
            Pin(num='AV20',name='IO_L10N_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AV21',name='IO_L10P_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AV23',name='IO_L13P_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AV24',name='IO_L13N_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AV25',name='IO_L11N_CC_8',func=pin_types.BIDIR,unit=12),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=13),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=13),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=13),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=13),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=13),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=13),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=13),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=13),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=13),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=13),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=13),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=13),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=14),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=14),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=14),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=14),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=14),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=14),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=14),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=14),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=14),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=14),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=15),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=15),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=15),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=16),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=16),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=16),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=16),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=16),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=16),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=16),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=16),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=16),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=16),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=16),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=16),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=16),
            Pin(num='A10',name='MGTRXN0_128',func=pin_types.BIDIR,unit=17),
            Pin(num='A11',name='MGTRXP0_128',func=pin_types.BIDIR,unit=17),
            Pin(num='A8',name='MGTRXP1_128',func=pin_types.BIDIR,unit=17),
            Pin(num='A9',name='MGTRXN1_128',func=pin_types.BIDIR,unit=17),
            Pin(num='AW9',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=17),
            Pin(num='AY9',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=17),
            Pin(num='B11',name='MGTTXN0_128',func=pin_types.BIDIR,unit=17),
            Pin(num='B12',name='MGTTXP0_128',func=pin_types.BIDIR,unit=17),
            Pin(num='B7',name='MGTTXP1_128',func=pin_types.BIDIR,unit=17),
            Pin(num='B8',name='MGTTXN1_128',func=pin_types.BIDIR,unit=17),
            Pin(num='BA11',name='MGTTXN1_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BA12',name='MGTTXP1_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BA7',name='MGTTXP0_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BA8',name='MGTTXN0_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BB10',name='MGTRXN1_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BB11',name='MGTRXP1_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BB8',name='MGTRXP0_130',func=pin_types.BIDIR,unit=17),
            Pin(num='BB9',name='MGTRXN0_130',func=pin_types.BIDIR,unit=17),
            Pin(num='C10',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=17),
            Pin(num='D10',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=17),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=18),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY11',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY12',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY7',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY8',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=18),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C11',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=18),
            Pin(num='C12',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C7',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=18),
            Pin(num='C8',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=18),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=18),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=18),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=20),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=21)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N16', 'P13', 'F42', 'M13', 'U42', 'Y38', 'AA40', 'G41', 'M14', 'N25', 'P17', 'P42', 'V37', 'Y39', 'G42', 'M16', 'N26', 'P18', 'H41', 'R40', 'V40', 'Y40', 'M29', 'F41', 'J14', 'L42', 'N28', 'P25', 'M41', 'R42', 'V41', 'Y41', 'J41', 'AA39', 'M42', 'N29', 'P26', 'T40', 'W40', 'Y42', 'J42', 'AA41', 'N13', 'N30', 'P27', 'K42', 'T41', 'W41', 'AA42', 'L40', 'N14', 'N40', 'P28', 'P41', 'T42', 'W42', 'F13', 'L41', 'N15', 'N41', 'P40', 'AA37', 'U41', 'Y37', 'AA38']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB42', 'V8', 'AR42', 'AC38', 'W10', 'AT41', 'AC39', 'AT42', 'W11', 'AC40', 'W5', 'AU41', 'AC41', 'AU42', 'W6', 'AD39', 'W7', 'AV41', 'AD40', 'G6', 'W8', 'AD41', 'Y10', 'H5', 'AD42', 'H6', 'Y7', 'AE36', 'J5', 'Y8', 'AE40', 'J6', 'Y9', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AB41', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AK42', 'AA6', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AA9', 'AL42', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AP42', 'V7']},{'label': 'uC', 'num': 3, 'pin_nums': ['H38', 'Y34', 'H39', 'AH37', 'Y35', 'AH38', 'H40', 'AH39', 'J38', 'AJ37', 'J40', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'L39', 'AK41', 'M38', 'AL37', 'M39', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'AG40', 'G38', 'W37', 'AG39', 'G39', 'W38']},{'label': 'uD', 'num': 4, 'pin_nums': ['AF7', 'AF9', 'L37', 'AG10', 'L38', 'AA32', 'AG4', 'M36', 'AG6', 'AB11', 'M37', 'AB6', 'AG7', 'N35', 'AH4', 'AB7', 'N36', 'AB8', 'AH5', 'P35', 'AH6', 'AB9', 'P36', 'AC10', 'AJ5', 'R34', 'AC5', 'AJ6', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'E37', 'AD5', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'H36', 'AE7', 'Y33', 'AE8', 'J35', 'AE9', 'J36', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'L36']},{'label': 'uE', 'num': 5, 'pin_nums': ['G7', 'E5', 'AK28', 'AM28', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'AK29', 'AM29', 'E7', 'N9', 'T10', 'V9', 'G8', 'K9', 'AJ30', 'AK30', 'AN13', 'E8', 'G9', 'L7', 'P7', 'R8', 'T11', 'V10', 'AK12', 'AL14', 'AN14', 'E9', 'H8', 'L8', 'P8', 'T9', 'AK13', 'AL29', 'AP13', 'F5', 'H9', 'L9', 'P9', 'U11', 'AK14', 'AL30', 'AR26', 'F6', 'J7', 'M7', 'R6', 'U8', 'AK15', 'AM13', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AK27', 'AM14', 'D7', 'F9', 'M9', 'K7']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE32', 'L34', 'AE33', 'AT37', 'M31', 'AE34', 'AU37', 'M32', 'AE35', 'AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AG36', 'E33', 'P31', 'AH34', 'E34', 'P32', 'AH35', 'E35', 'P33', 'AH36', 'E36', 'R32', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'AT36', 'L31', 'AD33', 'AR38', 'L32']},{'label': 'uG', 'num': 7, 'pin_nums': ['E13', 'AM32', 'M12', 'E14', 'AM33', 'N10', 'AN31', 'E15', 'N11', 'E6', 'AN33', 'P10', 'AP31', 'F10', 'P11', 'F11', 'AP32', 'P12', 'AP33', 'F12', 'R10', 'AP39', 'F14', 'AR32', 'F15', 'AR33', 'G10', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'E12', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'K10', 'AJ32', 'AV34', 'K12', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'L11', 'D13', 'AL32', 'E10', 'L12', 'AM31', 'M11']},{'label': 'uH', 'num': 8, 'pin_nums': ['AK8', 'B34', 'AK9', 'B35', 'AL10', 'B36', 'AL6', 'B37', 'AL7', 'B38', 'AL8', 'B39', 'AL9', 'B41', 'AM6', 'B42', 'A30', 'AM7', 'C30', 'A31', 'AM8', 'C31', 'A32', 'AM9', 'C33', 'A34', 'AN4', 'C34', 'A35', 'AN5', 'C35', 'A36', 'AN6', 'C36', 'A37', 'AN8', 'C38', 'A39', 'AN9', 'C39', 'A40', 'AP5', 'C40', 'A41', 'AP6', 'C41', 'AG11', 'AP7', 'D31', 'AG12', 'AP8', 'D32', 'AG8', 'AR5', 'D33', 'AG9', 'AR7', 'D35', 'AH10', 'AR8', 'D36', 'AH11', 'AT5', 'D38', 'AH7', 'AT6', 'D40', 'AH8', 'AT7', 'D41', 'AH9', 'AU6', 'D42', 'AJ10', 'AV5', 'E42', 'AJ11', 'AV6', 'F33', 'AJ8', 'B31', 'J34', 'AK10', 'B32', 'AK11', 'B33']},{'label': 'uI', 'num': 9, 'pin_nums': ['BB39', 'L17', 'K15', 'AW40', 'AW31', 'AY37', 'BA34', 'BB31', 'BB41', 'K17', 'L27', 'AW41', 'AY38', 'BA35', 'AW32', 'BB32', 'E26', 'K28', 'L29', 'AW38', 'AY35', 'AW33', 'AW42', 'AY39', 'BA32', 'BA36', 'BA42', 'BB33', 'H27', 'K29', 'L30', 'AW34', 'AY30', 'AY40', 'BA37', 'BB34', 'J15', 'K30', 'M17', 'AW35', 'AY32', 'AY42', 'BA39', 'BB36', 'J16', 'L14', 'M26', 'AW36', 'AY33', 'BA30', 'BA40', 'BB37', 'J17', 'L15', 'M27', 'AT33', 'AW37', 'AY34', 'BA31', 'BA41', 'BB38', 'J30', 'L16', 'M28', 'AV37']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AK17', 'AM26', 'E17', 'AP16', 'H28', 'K18', 'L25', 'P20', 'AL15', 'AM27', 'AP27', 'E18', 'G18', 'H29', 'K19', 'L26', 'AL16', 'AN15', 'AP28', 'F16', 'G27', 'H30', 'K24', 'M18', 'AL17', 'AN16', 'AP30', 'F17', 'G28', 'J18', 'K25', 'M19', 'AL26', 'AN28', 'AR16', 'F23', 'G29', 'J25', 'K27', 'M24', 'AL27', 'AN29', 'AT13', 'F27', 'H16', 'J26', 'L19', 'N18', 'AM16', 'AN30', 'B25', 'F29', 'G17', 'H18', 'J27', 'L20', 'N19', 'AM17', 'AP15', 'C22', 'G16', 'H26', 'J28', 'L24', 'N20']},{'label': 'uK', 'num': 11, 'pin_nums': ['H17', 'AT16', 'AK18', 'AT17', 'H19', 'AK19', 'AT19', 'H20', 'AK24', 'H21', 'AT23', 'AK25', 'AT26', 'H23', 'AL19', 'H24', 'AT27', 'AL24', 'AT29', 'H25', 'AL25', 'AT30', 'J20', 'AM18', 'AU28', 'J21', 'AM19', 'AU29', 'J22', 'AM24', 'AW24', 'J23', 'AN18', 'AY21', 'K20', 'AN19', 'D18', 'K22', 'AN20', 'D19', 'K23', 'AN24', 'E19', 'L21', 'AN25', 'L22', 'E20', 'AN26', 'E22', 'M21', 'AP17', 'E23', 'M22', 'AP18', 'F19', 'M23', 'AP25', 'F20', 'N21', 'AP26', 'F21', 'N22', 'AR14', 'F22', 'N23', 'AR15', 'F24', 'N24', 'AR17', 'F25', 'AR18', 'F26', 'AR19', 'G19', 'AR27', 'G20', 'AR28', 'G21', 'AR29', 'G22', 'AR30', 'G23', 'AT14', 'G24', 'AT15', 'G26']},{'label': 'uL', 'num': 12, 'pin_nums': ['AJ21', 'AT21', 'AP22', 'AU22', 'AV23', 'AJ22', 'AM22', 'AP23', 'AT22', 'AU23', 'AV24', 'AK20', 'AM23', 'AR20', 'AT24', 'AU24', 'AV25', 'AK22', 'AN21', 'AR22', 'AT25', 'AU26', 'AK23', 'AN23', 'AR23', 'AU18', 'AU27', 'AL20', 'AP19', 'AR24', 'AU19', 'AV17', 'AL21', 'AM21', 'AP20', 'AR25', 'AU20', 'AV20', 'AL22', 'AP21', 'AT20', 'AU21', 'AV21']},{'label': 'uM', 'num': 13, 'pin_nums': ['AD3', 'U2', 'V1', 'AD4', 'V3', 'AE1', 'AA2', 'AF1', 'V4', 'W1', 'AB2', 'AF2', 'AD1', 'AC1', 'AG2', 'Y1', 'T2', 'AC2', 'Y2', 'U1']},{'label': 'uN', 'num': 14, 'pin_nums': ['N1', 'AJ1', 'P1', 'AN2', 'AJ2', 'K2', 'P2', 'AK1', 'L1', 'R2', 'AK3', 'L2', 'AK4', 'M1', 'AL1', 'M3', 'AM1', 'AH2', 'M4', 'AM2']},{'label': 'uO', 'num': 15, 'pin_nums': ['AT3', 'E2', 'AT4', 'F1', 'AU1', 'F3', 'AV1', 'F4', 'AP2', 'AV2', 'G1', 'AR1', 'AW2', 'H1', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2']},{'label': 'uP', 'num': 16, 'pin_nums': ['BB4', 'B5', 'A2', 'B2', 'B6', 'BB5', 'A3', 'C3', 'A4', 'BA1', 'A5', 'BA2', 'C4', 'BA5', 'AW4', 'AY4', 'BA6', 'B1', 'BB2', 'BB3']},{'label': 'uQ', 'num': 17, 'pin_nums': ['D10', 'AW9', 'BA7', 'AY9', 'BA8', 'B11', 'A9', 'BB10', 'B12', 'BB11', 'A10', 'B7', 'BB8', 'A11', 'B8', 'BB9', 'BA11', 'A8', 'C10', 'BA12']},{'label': 'uR', 'num': 18, 'pin_nums': ['C7', 'AY1', 'AF3', 'AP3', 'AY7', 'G3', 'P3', 'AA3', 'AG3', 'AR3', 'AY10', 'AY8', 'C8', 'G4', 'R3', 'AA5', 'AH3', 'AU3', 'AY11', 'C1', 'C9', 'H3', 'T3', 'AB3', 'AJ3', 'AU4', 'AY12', 'C11', 'D3', 'J3', 'U3', 'AB4', 'AL3', 'AV3', 'AY2', 'C12', 'D4', 'K3', 'W3', 'AC3', 'AL4', 'AW10', 'AY3', 'C2', 'D5', 'L3', 'W4', 'AE3', 'AM3', 'AW3', 'AY5', 'C5', 'D9', 'N3', 'Y3', 'AE4', 'AN3', 'AW5', 'AY6', 'C6', 'E3', 'N4']},{'label': 'uS', 'num': 19, 'pin_nums': ['AH15', 'P15', 'AA22', 'AB21', 'AH16', 'R14', 'AB22', 'AH29', 'R15', 'AA21', 'AH14', 'AC21', 'AH30', 'R29', 'AC22', 'AJ15', 'R30', 'AG29', 'AJ16', 'T14', 'AG30', 'AJ28', 'T30', 'AL28']},{'label': 'uT', 'num': 20, 'pin_nums': ['A19', 'AG20', 'K11', 'D17', 'P19', 'T25', 'A23', 'Y13', 'AD15', 'AG22', 'K16', 'D24', 'T27', 'P21', 'A28', 'Y15', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'A33', 'Y17', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'A38', 'Y19', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'U14', 'AA12', 'Y21', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'U16', 'AA14', 'Y22', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'AA16', 'Y23', 'AD27', 'AH19', 'L13', 'E21', 'U20', 'P34', 'AA18', 'Y25', 'AD29', 'AH21', 'E31', 'L18', 'P4', 'U22', 'AA20', 'Y27', 'AD31', 'AH23', 'E4', 'L23', 'R11', 'U24', 'AA24', 'Y29', 'AE12', 'AH25', 'E41', 'L28', 'R12', 'U26', 'AA26', 'Y31', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'J9', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'M2', 'R19', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'AB27', 'T23', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'AD13', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'P16', 'W30']},{'label': 'uU', 'num': 21, 'pin_nums': ['V2', 'AB40', 'AH12', 'AE17', 'AM10', 'AU15', 'BB30', 'V20', 'AB5', 'Y36', 'AH18', 'AE19', 'AU2', 'AM15', 'BB35', 'V22', 'AC11', 'Y4', 'AE2', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'AC13', 'Y6', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AT8', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AH32', 'AE29', 'AM5', 'AV32', 'T20', 'V42', 'AC25', 'AE31', 'AH42', 'AN12', 'AV4', 'T22', 'W13', 'AC27', 'AE41', 'AJ13', 'AN17', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'W19', 'AA13', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'W2', 'AA15', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'W21', 'AA17', 'AC4', 'AF22', 'AJ25', 'AN42', 'AW29', 'T8', 'W23', 'AA19', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AA23', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'W27', 'AA25', 'AD12', 'AF28', 'AJ39', 'AP24', 'AW8', 'U17', 'W29', 'AA27', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AF8', 'AK2', 'AR11', 'BA10', 'U25', 'W9', 'AB10', 'AD20', 'AG13', 'AK21', 'AR21', 'BA15', 'U27', 'Y11', 'AB12', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'Y12', 'AB14', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'Y14', 'AB16', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'Y16', 'AB18', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'Y18', 'AB20', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'Y20', 'AB24', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'AG5', 'V14', 'Y24', 'AB26', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'Y26', 'AB28', 'AE13', 'Y30', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'Y28', 'AB30', 'AE15', 'AL33', 'BB25']}] }),
        Part(**{ 'name':'XC5VFX200T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX200T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX200T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L2P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A31',name='IO_L2N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A32',name='IO_L3P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A34',name='IO_L7P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A35',name='IO_L7N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A36',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A37',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A39',name='IO_L15P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A40',name='IO_L15N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A41',name='IO_L16P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B31',name='IO_L1N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B32',name='IO_L3N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B33',name='IO_L4P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B34',name='IO_L6N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='B36',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B37',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B38',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B39',name='IO_L14P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B41',name='IO_L16N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B42',name='IO_L17P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C30',name='IO_L1P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C31',name='IO_L0N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C33',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C34',name='IO_L6P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C35',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C36',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C38',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C39',name='IO_L13P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C40',name='IO_L13N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C41',name='IO_L17N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D31',name='IO_L0P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D32',name='IO_L5P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D33',name='IO_L5N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D35',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D36',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D38',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D40',name='IO_L18P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D41',name='IO_L18N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D42',name='IO_L19N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='E42',name='IO_L19P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW31',name='IO_L19N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW32',name='IO_L15N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW33',name='IO_L15P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW35',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW36',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW37',name='IO_L6N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW38',name='IO_L7P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW40',name='IO_L1N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW41',name='IO_L1P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW42',name='IO_L0N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY30',name='IO_L19P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY32',name='IO_L16P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY33',name='IO_L14P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY34',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY35',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY37',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY38',name='IO_L6P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY39',name='IO_L7N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY40',name='IO_L2P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY42',name='IO_L0P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA30',name='IO_L18P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA31',name='IO_L18N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA32',name='IO_L16N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA34',name='IO_L13N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA35',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA36',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA37',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA39',name='IO_L5N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA40',name='IO_L4P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA41',name='IO_L2N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA42',name='IO_L3P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB31',name='IO_L17N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB32',name='IO_L17P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB33',name='IO_L13P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB34',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB36',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB37',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB38',name='IO_L5P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB39',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB41',name='IO_L3N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='A20',name='IO_L2P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A21',name='IO_L2N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A22',name='IO_L3P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A24',name='IO_L6N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A25',name='IO_L13N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A26',name='IO_L13P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A27',name='IO_L14P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A29',name='IO_L15N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='AV26',name='IO_L11P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV28',name='IO_L10P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV29',name='IO_L5P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV30',name='IO_L4N_VREF_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW20',name='IO_L19N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW21',name='IO_L19P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW22',name='IO_L15N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW23',name='IO_L15P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW25',name='IO_L9N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW26',name='IO_L11N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW27',name='IO_L10N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW28',name='IO_L5N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW30',name='IO_L4P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY19',name='IO_L18P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY20',name='IO_L18N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY22',name='IO_L14P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY23',name='IO_L14N_VREF_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY24',name='IO_L9P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY25',name='IO_L3N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY27',name='IO_L6P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY28',name='IO_L6N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY29',name='IO_L7P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='B21',name='IO_L3N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B22',name='IO_L5N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B23',name='IO_L6P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B24',name='IO_L7P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B26',name='IO_L12N_VRP_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B27',name='IO_L14N_VREF_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B28',name='IO_L15P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B29',name='IO_L18N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='BA19',name='IO_L17N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA20',name='IO_L17P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA21',name='IO_L16N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA22',name='IO_L13N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA24',name='IO_L8N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA25',name='IO_L3P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA26',name='IO_L2N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA27',name='IO_L1N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='BA29',name='IO_L7N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB20',name='IO_L16P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB21',name='IO_L13P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB22',name='IO_L12P_VRN_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB23',name='IO_L12N_VRP_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB24',name='IO_L8P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB26',name='IO_L2P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB27',name='IO_L1P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB28',name='IO_L0N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB29',name='IO_L0P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='C20',name='IO_L1N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C21',name='IO_L1P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C23',name='IO_L5P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C24',name='IO_L7N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C25',name='IO_L12P_VRN_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C26',name='IO_L11N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C28',name='IO_L19P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C29',name='IO_L18P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C32',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D20',name='IO_L0P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D21',name='IO_L0N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D22',name='IO_L4P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D23',name='IO_L4N_VREF_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D25',name='IO_L9P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D26',name='IO_L9N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D27',name='IO_L11P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D28',name='IO_L19N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D30',name='IO_L17N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E24',name='IO_L8P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E25',name='IO_L8N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E27',name='IO_L10N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E28',name='IO_L10P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E29',name='IO_L17P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E30',name='IO_L16N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='F30',name='IO_L16P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL11',name='IO_L1P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AL12',name='IO_L1N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM11',name='IO_L3P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AM12',name='IO_L3N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN10',name='IO_L5N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AN11',name='IO_L5P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP10',name='IO_L7P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP11',name='IO_L9P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP12',name='IO_L9N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP9',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AR10',name='IO_L10P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR12',name='IO_L12N_VRP_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR13',name='IO_L14P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AR9',name='IO_L7N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT10',name='IO_L10N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT11',name='IO_L12P_VRN_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT12',name='IO_L14N_VREF_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AT9',name='IO_L18N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AU11',name='IO_L13P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU12',name='IO_L13N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU13',name='IO_L15N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU14',name='IO_L15P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU16',name='IO_L4N_VREF_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU17',name='IO_L2N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU7',name='IO_L19N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU8',name='IO_L19P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU9',name='IO_L18P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV10',name='IO_L17P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV11',name='IO_L11N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV13',name='IO_L8N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV14',name='IO_L6N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV15',name='IO_L6P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV16',name='IO_L4P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV18',name='IO_L2P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV19',name='IO_L0N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV7',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AV8',name='IO_L16N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV9',name='IO_L17N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW12',name='IO_L11P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW13',name='IO_L8P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW18',name='IO_L0P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW7',name='IO_L16P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=12),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=12),
            Pin(num='AJ21',name='IO_L2N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AJ22',name='IO_L2P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK20',name='IO_L3P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK22',name='IO_L1N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK23',name='IO_L1P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL20',name='IO_L3N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL21',name='IO_L0P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL22',name='IO_L0N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM21',name='IO_L19N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM22',name='IO_L16P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM23',name='IO_L16N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AN21',name='IO_L19P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AN23',name='IO_L17P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AP20',name='IO_L18P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP21',name='IO_L18N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP22',name='IO_L14N_VREF_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP23',name='IO_L17N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR20',name='IO_L7P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR22',name='IO_L15P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR23',name='IO_L14P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR24',name='IO_L8N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR25',name='IO_L6P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT20',name='IO_L7N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT21',name='IO_L9N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT22',name='IO_L15N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT24',name='IO_L8P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT25',name='IO_L6N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU18',name='IO_L5N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU19',name='IO_L5P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AU21',name='IO_L9P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU22',name='IO_L12N_VRP_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU23',name='IO_L12P_VRN_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU24',name='IO_L11P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU26',name='IO_L4P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU27',name='IO_L4N_VREF_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AV20',name='IO_L10N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV21',name='IO_L10P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV23',name='IO_L13P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV24',name='IO_L13N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV25',name='IO_L11N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='D18',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=13),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='E19',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E20',name='IO_L14P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E22',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E23',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F19',name='IO_L16P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F20',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F21',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F24',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F25',name='IO_L17N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F26',name='IO_L17P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G19',name='IO_L16N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='G21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G22',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G23',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G24',name='IO_L15P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G26',name='IO_L19N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='H19',name='IO_L18P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H20',name='IO_L18N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H21',name='IO_L4P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H23',name='IO_L13N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H24',name='IO_L15N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H25',name='IO_L19P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J20',name='IO_L5P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J21',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J22',name='IO_L7N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J23',name='IO_L13P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K20',name='IO_L5N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K22',name='IO_L7P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K23',name='IO_L6N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='L21',name='IO_L1N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='L22',name='IO_L6P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M21',name='IO_L1P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M22',name='IO_L0N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M23',name='IO_L0P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N21',name='IO_L3N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N22',name='IO_L3P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N23',name='IO_L2N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N24',name='IO_L2P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=14),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=15),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=16),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=17),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A10',name='MGTRXN0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A11',name='MGTRXP0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A8',name='MGTRXP1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A9',name='MGTRXN1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='AW9',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=18),
            Pin(num='AY9',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=18),
            Pin(num='B11',name='MGTTXN0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B12',name='MGTTXP0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B7',name='MGTTXP1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B8',name='MGTTXN1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='BA11',name='MGTTXN1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA12',name='MGTTXP1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA7',name='MGTTXP0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA8',name='MGTTXN0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB10',name='MGTRXN1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB11',name='MGTRXP1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB8',name='MGTRXP0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB9',name='MGTRXN0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='C10',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=18),
            Pin(num='D10',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A14',name='MGTRXP1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A15',name='MGTRXN1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A16',name='MGTRXN0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A17',name='MGTRXP0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='AW15',name='MGTREFCLKP_134',func=pin_types.BIDIR,unit=19),
            Pin(num='AY15',name='MGTREFCLKN_134',func=pin_types.BIDIR,unit=19),
            Pin(num='B13',name='MGTTXP1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B14',name='MGTTXN1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B17',name='MGTTXN0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B18',name='MGTTXP0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='BA13',name='MGTTXP0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA14',name='MGTTXN0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA17',name='MGTTXN1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA18',name='MGTTXP1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB14',name='MGTRXP0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB15',name='MGTRXN0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB16',name='MGTRXN1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB17',name='MGTRXP1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='C16',name='MGTREFCLKN_132',func=pin_types.BIDIR,unit=19),
            Pin(num='D16',name='MGTREFCLKP_132',func=pin_types.BIDIR,unit=19),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=20),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AW16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY11',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY12',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY13',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY14',name='MGTAVTTRX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY17',name='MGTAVCCPLL_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY18',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY7',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY8',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C11',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C12',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C13',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C14',name='MGTAVCCPLL_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C17',name='MGTAVTTRX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C18',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C7',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C8',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=20),
            Pin(num='D15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=20),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=20),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=20),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=20),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=20),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=20),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=20),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=20),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=20),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=20),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=20),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=20),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=21),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=21),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=22),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=22),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=22),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=23)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G42', 'N26', 'R40', 'P18', 'V40', 'Y40', 'M16', 'H41', 'P25', 'R42', 'V41', 'Y41', 'N28', 'M29', 'J14', 'AA40', 'M41', 'N29', 'P26', 'T40', 'J41', 'W40', 'Y42', 'AA37', 'M42', 'J42', 'N30', 'P27', 'T41', 'AA38', 'W41', 'AA41', 'N13', 'K42', 'N40', 'P28', 'T42', 'W42', 'N14', 'AA42', 'L40', 'AA39', 'N15', 'N41', 'P40', 'F13', 'L41', 'U41', 'Y37', 'P17', 'Y38', 'F41', 'L42', 'N16', 'P13', 'P41', 'P42', 'U42', 'M14', 'V37', 'Y39', 'F42', 'M13', 'N25', 'G41']},{'label': 'uB', 'num': 2, 'pin_nums': ['J5', 'J6', 'AE40', 'Y9', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AA6', 'AK42', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AA9', 'AL42', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'AR42', 'V8', 'AC38', 'AT41', 'W10', 'AC39', 'AT42', 'W11', 'AC40', 'AU41', 'W5', 'AC41', 'AU42', 'W6', 'AD39', 'AV41', 'W7', 'AD40', 'G6', 'W8', 'AD41', 'H5', 'Y10', 'Y8', 'AD42', 'H6', 'Y7', 'AE36']},{'label': 'uC', 'num': 3, 'pin_nums': ['AL37', 'M39', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AM38', 'AA35', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AN39', 'AB36', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'G38', 'W37', 'AG39', 'G39', 'W38', 'AG40', 'H38', 'Y34', 'AH37', 'H39', 'Y35', 'AH38', 'H40', 'AK41', 'AH39', 'J38', 'J40', 'AJ37', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'L39', 'M38']},{'label': 'uD', 'num': 4, 'pin_nums': ['AC5', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'AD5', 'E37', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'AE7', 'H36', 'Y33', 'AE8', 'J35', 'AE9', 'J36', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'AG10', 'L38', 'AA32', 'AG4', 'M36', 'AB11', 'AG6', 'M37', 'AB6', 'AG7', 'N35', 'AB7', 'AH4', 'N36', 'AB8', 'AH5', 'P35', 'AB9', 'AH6', 'AJ6', 'P36', 'AC10', 'AJ5', 'R34']},{'label': 'uE', 'num': 5, 'pin_nums': ['AK29', 'AJ30', 'AK30', 'AN13', 'E8', 'G9', 'L7', 'P7', 'T11', 'AM29', 'AK12', 'AL14', 'P8', 'T9', 'H8', 'E9', 'AN14', 'L8', 'AK13', 'AL29', 'AP13', 'F5', 'H9', 'L9', 'P9', 'U11', 'AK14', 'AL30', 'G8', 'AR26', 'F6', 'J7', 'K9', 'M7', 'N9', 'R6', 'U8', 'T10', 'AK15', 'AM13', 'V9', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AK27', 'AM14', 'D7', 'F9', 'K7', 'M9', 'R8', 'V10', 'AK28', 'AM28', 'E5', 'G7', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'E7']},{'label': 'uF', 'num': 6, 'pin_nums': ['AH35', 'E35', 'P33', 'E36', 'AH36', 'R32', 'AJ34', 'F31', 'R33', 'F32', 'AJ35', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'E34', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AT37', 'M31', 'AE34', 'AU37', 'M32', 'AE35', 'AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AG36', 'E33', 'P31', 'AH34', 'P32']},{'label': 'uG', 'num': 7, 'pin_nums': ['AR33', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'K10', 'AJ32', 'AV34', 'K12', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31', 'E15', 'N11', 'AN33', 'E6', 'P10', 'AP31', 'F10', 'P11', 'AP32', 'F11', 'P12', 'AP33', 'F12', 'R10', 'AP39', 'F14', 'G10', 'AR32', 'F15']},{'label': 'uH', 'num': 8, 'pin_nums': ['A32', 'C33', 'AM9', 'A34', 'C34', 'AN4', 'A35', 'AN5', 'C35', 'A36', 'C36', 'AN6', 'A37', 'AN8', 'C38', 'A39', 'C39', 'AN9', 'A40', 'AP5', 'C40', 'A41', 'AP6', 'C41', 'AG11', 'AP7', 'D31', 'AG12', 'AP8', 'D32', 'AG8', 'AR5', 'D33', 'AG9', 'AR7', 'D35', 'AH10', 'AR8', 'D36', 'AH11', 'AT5', 'D38', 'AH7', 'AT6', 'D40', 'AH8', 'AT7', 'D41', 'AH9', 'AU6', 'D42', 'AJ10', 'AV5', 'E42', 'AJ11', 'AV6', 'F33', 'AJ8', 'B31', 'J34', 'AK10', 'B32', 'AK11', 'B33', 'AK8', 'B34', 'AK9', 'B35', 'AL10', 'B36', 'AL6', 'B37', 'AL7', 'B38', 'AL8', 'B39', 'AM8', 'AL9', 'B41', 'AM6', 'B42', 'A30', 'AM7', 'C30', 'A31', 'C31']},{'label': 'uI', 'num': 9, 'pin_nums': ['AW32', 'E26', 'BA35', 'AY38', 'BB32', 'K28', 'L29', 'AW33', 'AW42', 'AY39', 'BA36', 'BB33', 'H27', 'K29', 'L30', 'AW34', 'AY30', 'AY40', 'BA37', 'BB34', 'J15', 'K30', 'M17', 'AW35', 'AY32', 'AY42', 'BA39', 'BB36', 'J16', 'L14', 'M26', 'AW36', 'AY33', 'BA30', 'BA40', 'BB37', 'J17', 'L15', 'M27', 'AT33', 'AW37', 'AY34', 'BA31', 'BA41', 'BB38', 'J30', 'L16', 'M28', 'AV37', 'AW38', 'AW41', 'AY35', 'BA32', 'BA42', 'BB39', 'K15', 'L17', 'AW31', 'AW40', 'AY37', 'BA34', 'BB31', 'BB41', 'K17', 'L27']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AV28', 'BA21', 'D27', 'BA22', 'AV29', 'D28', 'AV30', 'BA24', 'D29', 'BA25', 'AW20', 'D30', 'AW21', 'BA26', 'E24', 'AW22', 'BA27', 'E25', 'AW23', 'BA28', 'E27', 'AW25', 'BA29', 'E28', 'AW26', 'BB20', 'E29', 'AW27', 'BB21', 'E30', 'AW28', 'BB22', 'F30', 'BA20', 'AW30', 'BB23', 'G30', 'AY19', 'BB24', 'AY20', 'BB26', 'AY22', 'BB27', 'AY23', 'BB28', 'AY24', 'BB29', 'AY25', 'C20', 'AY27', 'C21', 'AY28', 'C23', 'AY29', 'C24', 'AY31', 'C25', 'A20', 'B21', 'C26', 'A21', 'B22', 'C28', 'A22', 'B23', 'C29', 'A24', 'B24', 'C32', 'A25', 'B26', 'D20', 'A26', 'B27', 'D21', 'A27', 'B28', 'D22', 'A29', 'B29', 'D23', 'AU30', 'BA19', 'D25', 'AV26', 'D26']},{'label': 'uK', 'num': 11, 'pin_nums': ['AL15', 'AM17', 'AP28', 'AN29', 'AT10', 'AU13', 'AV8', 'AL16', 'AM26', 'AN30', 'AP30', 'AT11', 'AU14', 'AV13', 'AV9', 'AL17', 'AM27', 'AP10', 'AP9', 'AT12', 'AU16', 'AV14', 'AW12', 'AL26', 'AN10', 'AP11', 'AR10', 'AT13', 'AU17', 'AV15', 'AW13', 'AL27', 'AN11', 'AP12', 'AR12', 'AT9', 'AU7', 'AV16', 'AW18', 'AK17', 'AM11', 'AN15', 'AP15', 'AR13', 'AU10', 'AU8', 'AV18', 'AW7', 'AL11', 'AM12', 'AN16', 'AP16', 'AR16', 'AU11', 'AU9', 'AV11', 'AV19', 'AL12', 'AM16', 'AN28', 'AP27', 'AR9', 'AU12', 'AV10', 'AV7']},{'label': 'uL', 'num': 12, 'pin_nums': ['AP25', 'N18', 'F27', 'AP26', 'N19', 'F29', 'AR14', 'G16', 'N20', 'AR15', 'P20', 'G17', 'AR17', 'G18', 'AR18', 'G27', 'AR19', 'G28', 'AR27', 'G29', 'AR28', 'H16', 'AR29', 'H18', 'AR30', 'H26', 'AT14', 'H28', 'AT15', 'H29', 'AT16', 'H30', 'AK18', 'AT17', 'J18', 'AK19', 'AT19', 'J25', 'AK24', 'AT23', 'J26', 'AK25', 'AT26', 'J27', 'AL19', 'AT27', 'J28', 'AP18', 'AL24', 'AT29', 'K18', 'AL25', 'AT30', 'K19', 'AM18', 'AU28', 'K24', 'AM19', 'AU29', 'K25', 'AM24', 'AW24', 'K27', 'AN18', 'AY21', 'L19', 'AN19', 'B25', 'L20', 'AN20', 'C22', 'L24', 'AN24', 'E17', 'L25', 'AN25', 'E18', 'L26', 'AN26', 'F16', 'M18', 'AP17', 'F17', 'M19', 'F23', 'M24']},{'label': 'uM', 'num': 13, 'pin_nums': ['G22', 'AU18', 'G23', 'AU19', 'G24', 'AU20', 'G26', 'AU21', 'H17', 'AJ21', 'AU22', 'H19', 'AJ22', 'AU23', 'H20', 'AK20', 'AU24', 'H21', 'AK22', 'AU26', 'H23', 'AK23', 'AU27', 'H24', 'AL20', 'AV17', 'H25', 'AL21', 'AV20', 'J20', 'AL22', 'AV21', 'J21', 'AM21', 'AV23', 'J22', 'AM22', 'AV24', 'J23', 'AM23', 'AV25', 'K20', 'AN21', 'D18', 'K22', 'AN23', 'D19', 'K23', 'AP19', 'E19', 'L21', 'AP20', 'E20', 'L22', 'AP21', 'E22', 'M21', 'AP22', 'E23', 'M22', 'AP23', 'F19', 'M23', 'AR20', 'F20', 'N21', 'AR22', 'F21', 'N22', 'AR23', 'F22', 'N23', 'AR24', 'F24', 'N24', 'AR25', 'F25', 'AT20', 'F26', 'AT21', 'G19', 'AT22', 'AT25', 'G20', 'AT24', 'G21']},{'label': 'uN', 'num': 14, 'pin_nums': ['AD3', 'U2', 'AD4', 'V1', 'V3', 'AE1', 'AA2', 'AF1', 'V4', 'AB2', 'W1', 'AF2', 'AC1', 'AG2', 'Y1', 'AC2', 'Y2', 'T2', 'AD1', 'U1']},{'label': 'uO', 'num': 15, 'pin_nums': ['AH2', 'AM2', 'N1', 'AJ1', 'AN2', 'P1', 'AJ2', 'K2', 'P2', 'AK1', 'L1', 'R2', 'AK3', 'L2', 'AK4', 'M1', 'AL1', 'M3', 'AM1', 'M4']},{'label': 'uP', 'num': 16, 'pin_nums': ['E2', 'AT3', 'F1', 'AT4', 'AU1', 'F3', 'AV1', 'F4', 'AP2', 'AV2', 'G1', 'AR1', 'AW2', 'H1', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A2', 'B5', 'BB4', 'A3', 'BB5', 'B6', 'A4', 'C3', 'BA1', 'A5', 'BA2', 'C4', 'AW4', 'BA5', 'AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3']},{'label': 'uR', 'num': 18, 'pin_nums': ['A9', 'BA12', 'D10', 'BA7', 'AW9', 'AY9', 'BA8', 'B11', 'BB10', 'B12', 'BB11', 'A10', 'B7', 'BB8', 'A11', 'B8', 'BB9', 'A8', 'BA11', 'C10']},{'label': 'uS', 'num': 19, 'pin_nums': ['BB15', 'B14', 'A14', 'BB16', 'B17', 'A15', 'B18', 'BB17', 'A16', 'BA13', 'C16', 'A17', 'BA14', 'D16', 'AW15', 'BA17', 'AY15', 'BA18', 'B13', 'BB14']},{'label': 'uT', 'num': 20, 'pin_nums': ['AB4', 'AY5', 'AY12', 'AL3', 'AV3', 'C14', 'C8', 'G3', 'P3', 'AC3', 'AB3', 'C15', 'C9', 'G4', 'R3', 'AW10', 'AY13', 'AL4', 'AY6', 'AE3', 'AM3', 'AW16', 'AY14', 'AY7', 'C17', 'D15', 'H3', 'T3', 'AE4', 'AN3', 'AW3', 'AY16', 'AY8', 'C18', 'D3', 'J3', 'U3', 'AF3', 'L3', 'AP3', 'AW5', 'AY17', 'C1', 'C2', 'D4', 'K3', 'W3', 'AU4', 'AA3', 'AG3', 'W4', 'AR3', 'AY1', 'AY18', 'AY3', 'C11', 'C13', 'C5', 'D5', 'C7', 'AA5', 'AH3', 'E3', 'AU3', 'AY10', 'AY2', 'C12', 'C6', 'D9', 'N3', 'N4', 'Y3', 'AJ3', 'AY11']},{'label': 'uU', 'num': 21, 'pin_nums': ['AL28', 'AA21', 'AH14', 'AH15', 'AA22', 'P15', 'AB21', 'AH16', 'R14', 'AB22', 'AH29', 'R15', 'AC21', 'AH30', 'R29', 'AC22', 'AJ15', 'R30', 'AG29', 'AJ16', 'T14', 'AG30', 'AJ28', 'T30']},{'label': 'uV', 'num': 22, 'pin_nums': ['L13', 'U20', 'Y25', 'AA18', 'AD29', 'AH21', 'E31', 'L18', 'P4', 'U22', 'AA20', 'Y27', 'AH23', 'AD31', 'E4', 'L23', 'R11', 'U24', 'AA24', 'Y29', 'AE12', 'AH25', 'E41', 'L28', 'R12', 'U26', 'AA26', 'Y31', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AJ24', 'AE22', 'F8', 'M2', 'R19', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'AB27', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'AD27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'J9', 'P16', 'T23', 'W30', 'A19', 'AD13', 'AG20', 'D17', 'K11', 'P19', 'T25', 'Y13', 'A23', 'AD15', 'AG22', 'D24', 'K16', 'P21', 'AH19', 'T27', 'Y15', 'A28', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'Y17', 'A33', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'Y19', 'A38', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'U14', 'Y21', 'AA12', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'P34', 'U16', 'Y22', 'AA14', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'Y23', 'AA16', 'E21']},{'label': 'uW', 'num': 23, 'pin_nums': ['AH32', 'AV32', 'V42', 'T20', 'AC25', 'AE31', 'AH42', 'AN12', 'AV4', 'W13', 'T22', 'AC27', 'AE41', 'AJ13', 'AN17', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'W19', 'AA13', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'W2', 'AA15', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'W21', 'AA17', 'AC4', 'AF22', 'AJ25', 'AN42', 'AW29', 'W23', 'T8', 'AA19', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AA23', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'W27', 'AA25', 'AD12', 'AF28', 'AJ39', 'AC23', 'AP24', 'AW8', 'U17', 'W29', 'AA27', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AF8', 'AK2', 'AR11', 'BA10', 'U25', 'W9', 'AB10', 'AD20', 'AG13', 'AK21', 'AR21', 'BA15', 'U27', 'Y11', 'AB12', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'Y12', 'AB14', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'Y14', 'AB16', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'Y16', 'AB18', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'Y18', 'AB20', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'Y20', 'AB24', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'V14', 'Y24', 'AB26', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'Y26', 'AB28', 'AE13', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'Y28', 'AB30', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'Y30', 'AB40', 'AE17', 'AH12', 'AM10', 'AU15', 'BB30', 'V20', 'Y36', 'AB5', 'AE19', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'Y4', 'AC11', 'AE2', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'Y6', 'AC13', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AM5', 'AV12', 'T16', 'V30', 'AC19', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AE29']}] }),
        Part(**{ 'name':'XC5VFX30T-FF665', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX30T-FF665'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX30T-FF665\n\nFPGA', 'pins':[
            Pin(num='B13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G24',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J25',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='M24',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA23',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA24',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P23',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='P8',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V22',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V23',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V25',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='V26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W23',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y23',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='IO_L13N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='IO_L15N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L14P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A9',name='IO_L4P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='IO_L13P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B11',name='IO_L15P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='IO_L17P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L16P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='IO_L16N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B9',name='IO_L6P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C10',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C11',name='IO_L19P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='IO_L17N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C8',name='IO_L6N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D10',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='IO_L19N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L18P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='IO_L7N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E5',name='IO_L18N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L7P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L5N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='IO_L5P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='F7',name='IO_L1P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F8',name='IO_L1N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F9',name='IO_L2P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L0N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G9',name='IO_L2N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L0P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L3P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='IO_L3N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AA7',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA8',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB23',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AB5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC20',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC26',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC7',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD13',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD14',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD15',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD16',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD18',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD20',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD24',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD26',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE13',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE15',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE16',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE17',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE18',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE20',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE21',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE22',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE24',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE26',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF13',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF14',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF15',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF17',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF18',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF19',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF20',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF22',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF24',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF25',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='D18',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='G21',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W16',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y15',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y16',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y17',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y20',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA20',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB11',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB14',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB15',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC11',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='L1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=7),
            Pin(num='U1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='W2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AC1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AE2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='B2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=8),
            Pin(num='E1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='G2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='Y2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AD3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AE3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='C3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='F3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='H3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='J3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=9),
            Pin(num='N3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='P4',name='MGTRREF_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=9),
            Pin(num='R3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='V3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=9),
            Pin(num='W3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='Y3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='F11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='H12',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J10',name='D_IN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J12',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='J20',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='HSWAPEN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='CS_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M20',name='RDWR_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N14',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N15',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P14',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P15',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R14',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R15',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T20',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U12',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U20',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V12',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V13',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W20',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='VBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='AVSS_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='AVDD_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W10',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y9',name='GND',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E25', 'H23', 'L22', 'J24', 'G10', 'M25', 'B13', 'G25', 'E26', 'G11', 'H24', 'J25', 'L23', 'M26', 'G26', 'F13', 'G12', 'H25', 'J26', 'L24', 'N21', 'H11', 'F14', 'G14', 'H13', 'H26', 'K21', 'L25', 'F15', 'G15', 'N22', 'F17', 'G16', 'H18', 'H9', 'K22', 'M21', 'N23', 'F18', 'G17', 'H19', 'J21', 'K23', 'M22', 'F22', 'N24', 'G19', 'E14', 'F23', 'H21', 'J22', 'G20', 'K25', 'M23', 'N26', 'F24', 'E22', 'G22', 'H22', 'J23', 'E23', 'K26', 'M24', 'F25', 'G24']},{'label': 'uB', 'num': 2, 'pin_nums': ['M7', 'U25', 'U26', 'N6', 'N7', 'U5', 'U6', 'N8', 'P21', 'U7', 'P23', 'V21', 'V22', 'P24', 'AA22', 'V23', 'P25', 'AA23', 'P26', 'V24', 'AA24', 'P6', 'V25', 'AA25', 'P7', 'V26', 'AB24', 'P8', 'V6', 'AB25', 'R21', 'V7', 'AB26', 'R22', 'W21', 'F5', 'R23', 'W22', 'G4', 'R24', 'W23', 'G5', 'R25', 'W24', 'G6', 'R26', 'W25', 'H4', 'R5', 'W26', 'H5', 'R6', 'W4', 'H6', 'R7', 'W5', 'J5', 'R8', 'W6', 'J6', 'T22', 'Y22', 'K5', 'Y23', 'T23', 'K6', 'T24', 'Y25', 'K7', 'T25', 'Y26', 'K8', 'T5', 'Y4', 'L5', 'T7', 'Y5', 'L6', 'T8', 'Y6', 'L7', 'U21', 'L8', 'U22', 'M6', 'U24']},{'label': 'uC', 'num': 3, 'pin_nums': ['B4', 'B5', 'A14', 'D6', 'A15', 'B6', 'D7', 'A17', 'B7', 'D8', 'A18', 'B9', 'D9', 'A19', 'C10', 'E24', 'A20', 'C11', 'E5', 'A22', 'C12', 'E6', 'A23', 'C13', 'E7', 'A24', 'C14', 'E8', 'A25', 'C16', 'F21', 'A3', 'C17', 'F7', 'A4', 'C18', 'F8', 'A5', 'C19', 'F9', 'A7', 'C21', 'G7', 'A8', 'C22', 'G8', 'A9', 'C23', 'G9', 'B10', 'C24', 'H7', 'B11', 'C26', 'H8', 'B12', 'C6', 'J8', 'B14', 'C7', 'B15', 'C8', 'B16', 'C9', 'B17', 'D10', 'B19', 'D11', 'B20', 'D19', 'B21', 'D20', 'B22', 'D21', 'B23', 'D23', 'B24', 'D24', 'A10', 'B25', 'D25', 'D5', 'A12', 'B26', 'D26', 'A13']},{'label': 'uD', 'num': 4, 'pin_nums': ['AC20', 'AF5', 'AE12', 'AC21', 'AF7', 'AE13', 'AC22', 'AE15', 'AF8', 'AC23', 'AF9', 'AE16', 'AC24', 'AE17', 'V8', 'AC26', 'V9', 'AE18', 'AC6', 'AE20', 'W8', 'AC7', 'W9', 'AE21', 'AC8', 'AE22', 'Y7', 'AC9', 'AE23', 'Y8', 'AD10', 'AE24', 'AD11', 'AE25', 'AD13', 'AE26', 'AD14', 'AE5', 'AD15', 'AE6', 'AD16', 'AE7', 'AD18', 'AE8', 'AC10', 'AD19', 'AF10', 'AD20', 'AF12', 'AD21', 'AF13', 'AA5', 'AD23', 'AF14', 'AA6', 'AD24', 'AF15', 'AA7', 'AD25', 'AF17', 'AA8', 'AD26', 'AF18', 'AA9', 'AD4', 'AF19', 'AB22', 'AD5', 'AF20', 'AB23', 'AD6', 'AF22', 'AB5', 'AD7', 'AF23', 'AD8', 'AB6', 'AF24', 'AB7', 'AD9', 'AF25', 'AB9', 'AE10', 'AF3', 'AE11', 'AF4']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA16', 'D16', 'Y12', 'F20', 'AA17', 'D17', 'E17', 'G18', 'Y13', 'AA18', 'D18', 'E18', 'G21', 'Y15', 'AA10', 'AA19', 'E10', 'E20', 'W11', 'Y16', 'AA12', 'AD17', 'E11', 'E21', 'W14', 'Y17', 'AA13', 'D13', 'E12', 'F10', 'W16', 'Y18', 'AA14', 'D14', 'E13', 'E16', 'F12', 'Y10', 'Y20', 'AA15', 'D15', 'E15', 'F19', 'Y11']},{'label': 'uF', 'num': 6, 'pin_nums': ['AB19', 'AB10', 'AC17', 'AC18', 'AB20', 'AB11', 'AA20', 'AB17', 'AB12', 'AB21', 'AC19', 'AC11', 'AE14', 'AB13', 'AB14', 'AC12', 'Y21', 'AB15', 'AC13', 'AB16', 'AC14', 'AC16']},{'label': 'uG', 'num': 7, 'pin_nums': ['J2', 'P2', 'R1', 'K1', 'W2', 'K3', 'R2', 'K4', 'T1', 'L1', 'T3', 'M1', 'T4', 'H2', 'M2', 'U1', 'V2', 'J1', 'N2', 'V1']},{'label': 'uH', 'num': 8, 'pin_nums': ['AD1', 'D4', 'E1', 'AD2', 'AA1', 'AE2', 'F1', 'B2', 'F2', 'AA2', 'AB1', 'C1', 'G2', 'AB3', 'C2', 'Y2', 'AC1', 'AB4', 'D1', 'D3']},{'label': 'uI', 'num': 9, 'pin_nums': ['F3', 'Y3', 'G3', 'AC4', 'P4', 'H3', 'P5', 'AD3', 'AE3', 'J3', 'R3', 'L3', 'U3', 'B3', 'C3', 'L4', 'U4', 'E3', 'M3', 'V3', 'AC3', 'AA3', 'E4', 'N3', 'W3', 'P3']},{'label': 'uJ', 'num': 10, 'pin_nums': ['W20', 'F11', 'L20', 'K20', 'T20', 'H12', 'M20', 'U12', 'J10', 'N14', 'U20', 'J11', 'N15', 'V11', 'J12', 'P14', 'V12', 'J20', 'P15', 'V13', 'R14', 'K11', 'W13', 'R15']},{'label': 'uK', 'num': 11, 'pin_nums': ['AF16', 'J15', 'L9', 'P18', 'U14', 'AF2', 'M10', 'J16', 'U15', 'P19', 'AF21', 'J17', 'M11', 'P22', 'U16', 'AF26', 'M12', 'J18', 'P9', 'U17', 'AF6', 'J19', 'M13', 'R10', 'U18', 'B18', 'J4', 'M14', 'R11', 'U19', 'B8', 'J7', 'M15', 'R12', 'U2', 'C15', 'M16', 'K10', 'U23', 'R13', 'C20', 'K12', 'M17', 'R16', 'U8', 'L26', 'A11', 'C25', 'K13', 'M18', 'R17', 'U9', 'A16', 'C4', 'K14', 'M19', 'R18', 'V10', 'A2', 'C5', 'K15', 'M4', 'R19', 'V14', 'A21', 'D12', 'K16', 'M8', 'R4', 'V15', 'A26', 'D2', 'K17', 'M9', 'R9', 'V16', 'A6', 'D22', 'K18', 'N10', 'T10', 'V17', 'AA11', 'E19', 'K19', 'N11', 'T11', 'V18', 'AA21', 'E2', 'K2', 'N12', 'T12', 'V19', 'AA26', 'E9', 'K24', 'N13', 'T13', 'V20', 'AA4', 'F16', 'K9', 'N16', 'T14', 'V4', 'AB18', 'F26', 'L10', 'N17', 'T15', 'V5', 'AB2', 'F4', 'L11', 'N18', 'T16', 'W10', 'AB8', 'F6', 'L12', 'N19', 'T17', 'W12', 'AC15', 'G13', 'L13', 'N20', 'T18', 'W15', 'AC2', 'G23', 'L14', 'N25', 'T19', 'W17', 'AC25', 'H10', 'L15', 'N5', 'T2', 'W18', 'AC5', 'H14', 'L16', 'N9', 'T21', 'W19', 'AD12', 'H15', 'L17', 'P10', 'T26', 'W7', 'AD22', 'H16', 'L18', 'P11', 'T6', 'Y14', 'AE19', 'H17', 'L19', 'P12', 'T9', 'Y19', 'AE4', 'H20', 'L2', 'P13', 'U10', 'Y24', 'AE9', 'J13', 'L21', 'P16', 'U11', 'Y9', 'AF11', 'J14', 'P17', 'U13']}] }),
        Part(**{ 'name':'XC5VFX70T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX70T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX70T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A15',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A16',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AH23',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AH24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ14',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ19',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ20',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ21',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ22',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK13',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK14',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK16',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK18',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK19',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK21',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK22',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK24',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL13',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL14',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL15',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL19',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL20',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL21',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN17',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='B15',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B16',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B17',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C14',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C15',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C17',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D14',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D15',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D16',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D17',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D19',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D20',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D21',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D22',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E14',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E16',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E17',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E21',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E23',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E24',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F14',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F15',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F18',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A6',name='MGTRXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A7',name='MGTRXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A8',name='MGTRXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A9',name='MGTRXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AL7',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AM7',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN10',name='MGTTXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN5',name='MGTTXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN6',name='MGTTXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN9',name='MGTTXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP6',name='MGTRXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP7',name='MGTRXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP8',name='MGTRXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP9',name='MGTRXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='B10',name='MGTTXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B5',name='MGTTXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B6',name='MGTTXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B9',name='MGTTXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='C8',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D8',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM10',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM5',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM6',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM9',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=14),
            Pin(num='C10',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C5',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C6',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C9',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=14),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=14),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=16),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=17)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['H22', 'K23', 'J32', 'T34', 'P32', 'E34', 'B32', 'H23', 'J34', 'K32', 'F33', 'L33', 'P34', 'U31', 'F34', 'H32', 'K12', 'K33', 'B33', 'L34', 'R30', 'U32', 'C32', 'G14', 'H33', 'K13', 'K34', 'C33', 'M32', 'R32', 'U33', 'G22', 'H34', 'K14', 'L14', 'C34', 'G23', 'M33', 'R33', 'V31', 'D13', 'G32', 'J12', 'K16', 'A33', 'L15', 'N32', 'R34', 'D32', 'G33', 'J15', 'K21', 'L16', 'L21', 'N33', 'T27', 'D34', 'E32', 'H12', 'J22', 'K22', 'L20', 'N34', 'T33', 'E33']},{'label': 'uB', 'num': 2, 'pin_nums': ['AE32', 'U10', 'J5', 'AE33', 'U7', 'J6', 'AE34', 'J7', 'V32', 'AF33', 'V33', 'K6', 'AF34', 'K7', 'V34', 'AG32', 'W28', 'L4', 'AG33', 'L5', 'W32', 'AH32', 'W34', 'L6', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6', 'AK34', 'N7', 'AL33', 'N8', 'AL34', 'P10', 'AM32', 'P5', 'AM33', 'P6', 'AN32', 'P7', 'AN33', 'P9', 'AA32', 'AN34', 'R11', 'AA33', 'AP32', 'R6', 'AA34', 'E6', 'R7', 'AB29', 'E7', 'R8', 'AD34', 'AB32', 'F5', 'R9', 'AB33', 'F6', 'T10', 'AC32', 'G5', 'T11', 'AC33', 'G6', 'T6', 'AC34', 'G7', 'T7', 'AD32', 'H5', 'T8', 'H7', 'T9']},{'label': 'uC', 'num': 3, 'pin_nums': ['R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'K29', 'V25', 'AC30', 'K31', 'V27', 'AD29', 'L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'AD33', 'L32', 'W24', 'AE29', 'M29', 'W25', 'AE30', 'M30', 'W26', 'AE31', 'M31', 'W27', 'AF29', 'N29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'AH30', 'P31', 'Y27', 'AH29', 'P33', 'Y28']},{'label': 'uD', 'num': 4, 'pin_nums': ['E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'F28', 'AA6', 'P25', 'AB5', 'G25', 'P26', 'G26', 'AB6', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'E28', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'J24', 'W10', 'AD6', 'J25', 'W11', 'AD7', 'J26', 'W6', 'AE6', 'J27', 'W7', 'AE7', 'J28', 'W8', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AG7', 'L24', 'Y8', 'AH5', 'L25', 'Y9', 'AH7', 'L26', 'AJ6', 'L28', 'AJ7', 'M25', 'AK6', 'M26', 'AK7', 'M27', 'E26', 'M28', 'E27', 'N24', 'N25']},{'label': 'uE', 'num': 5, 'pin_nums': ['H10', 'B12', 'AE17', 'AF16', 'E11', 'F8', 'H11', 'K8', 'M8', 'N10', 'A13', 'AE19', 'AF20', 'B13', 'H8', 'K9', 'E12', 'F9', 'N9', 'AD19', 'AE21', 'AF21', 'C12', 'E13', 'G10', 'H9', 'L10', 'AD20', 'AE22', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'D11', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AE16', 'AF15', 'AM19', 'E10', 'K11', 'F13']},{'label': 'uF', 'num': 6, 'pin_nums': ['AA8', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AH28', 'AD25', 'AH8', 'AD26', 'AH9', 'AD27', 'AJ10', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AE24', 'AJ26', 'AE26', 'AJ27', 'AE27', 'AJ28', 'AE28', 'AJ29', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AF25', 'AK26', 'AA28', 'AF24', 'AK27']},{'label': 'uG', 'num': 7, 'pin_nums': ['AP22', 'AL25', 'D26', 'AL26', 'AP24', 'D27', 'AL28', 'AP25', 'D29', 'AP26', 'AL29', 'D30', 'AL30', 'AP27', 'D31', 'AP29', 'AL31', 'F27', 'AM18', 'AP30', 'G24', 'AP31', 'AM20', 'AM21', 'B18', 'AM22', 'B20', 'AM23', 'B21', 'AM25', 'B22', 'AM26', 'B23', 'AM27', 'B25', 'AM28', 'B26', 'AM30', 'B27', 'AM31', 'B28', 'A18', 'AN18', 'B30', 'A19', 'AN19', 'B31', 'A20', 'AN20', 'C18', 'A21', 'AN22', 'C19', 'A23', 'AN23', 'C20', 'A24', 'AN24', 'C22', 'A25', 'AN25', 'C23', 'A26', 'AN26', 'C24', 'A28', 'AN27', 'C25', 'A29', 'AN28', 'C26', 'A30', 'C27', 'AN29', 'AP21', 'A31', 'AN30', 'C28', 'AK25', 'AP19', 'C29', 'AL22', 'AP20', 'C30', 'AL24', 'D25']},{'label': 'uH', 'num': 8, 'pin_nums': ['H20', 'AG18', 'G15', 'AE18', 'AH17', 'K18', 'AF18', 'AG20', 'AH18', 'G16', 'J14', 'K19', 'AF19', 'AG21', 'AH19', 'H13', 'J16', 'L18', 'AG13', 'AG22', 'AH20', 'H14', 'J17', 'L19', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20', 'AG16', 'AH14', 'D23', 'H18', 'J21', 'AG17', 'AH15', 'E20', 'H19', 'K17']},{'label': 'uI', 'num': 9, 'pin_nums': ['AP16', 'AJ20', 'F18', 'AJ21', 'AP17', 'F19', 'AJ22', 'B15', 'F20', 'B16', 'AJ24', 'F21', 'AK12', 'B17', 'F23', 'B19', 'AK13', 'F24', 'AK14', 'C14', 'G17', 'AK15', 'C15', 'G18', 'AP15', 'AK16', 'C16', 'G20', 'AK17', 'C17', 'G21', 'AK18', 'D14', 'AK19', 'D15', 'AK21', 'D16', 'AK22', 'D17', 'AK23', 'D19', 'D20', 'AK24', 'AL13', 'D21', 'AL14', 'D22', 'AL15', 'D24', 'AL16', 'E14', 'A14', 'AL18', 'E16', 'A15', 'AL19', 'E17', 'A16', 'AL20', 'E18', 'AH23', 'AL21', 'E19', 'AH24', 'AL23', 'E21', 'AJ12', 'AM15', 'E22', 'AJ14', 'AM16', 'E23', 'AJ15', 'AM17', 'E24', 'AJ16', 'AN15', 'F14', 'AJ17', 'AN16', 'F15', 'AJ18', 'AN17', 'F16', 'AJ19', 'F17']},{'label': 'uJ', 'num': 10, 'pin_nums': ['N1', 'U2', 'V2', 'N2', 'P1', 'W1', 'AA1', 'P3', 'W2', 'AB1', 'P4', 'Y1', 'AB2', 'R1', 'Y3', 'AC2', 'T1', 'Y4', 'M2', 'T2']},{'label': 'uK', 'num': 11, 'pin_nums': ['K1', 'AE1', 'AJ2', 'AE2', 'F2', 'K2', 'AF1', 'G1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4', 'AD2', 'AH2', 'J1']},{'label': 'uL', 'num': 12, 'pin_nums': ['AL4', 'B4', 'AL5', 'C1', 'AM1', 'D1', 'A2', 'AN3', 'AL2', 'D2', 'A3', 'AN4', 'D4', 'AK2', 'AP2', 'E2', 'AL1', 'AP3', 'E4', 'B3']},{'label': 'uM', 'num': 13, 'pin_nums': ['A6', 'B6', 'AN6', 'AN9', 'A7', 'B9', 'A8', 'AP6', 'C8', 'A9', 'AP7', 'D8', 'AL7', 'AP8', 'AM7', 'AP9', 'AN10', 'B10', 'AN5', 'B5']},{'label': 'uN', 'num': 14, 'pin_nums': ['C9', 'AM8', 'AD3', 'AK5', 'J3', 'T3', 'AE3', 'AL3', 'AM9', 'D3', 'U3', 'J4', 'AG3', 'AL8', 'C10', 'D5', 'K3', 'V3', 'AG4', 'AM10', 'C3', 'D7', 'L3', 'V4', 'AA3', 'AH3', 'AM3', 'C4', 'E3', 'M3', 'V5', 'AA4', 'AJ3', 'AM4', 'C5', 'F3', 'N3', 'W3', 'AB3', 'AJ4', 'AM5', 'C6', 'F4', 'R3', 'AC3', 'AK3', 'AM6', 'C7', 'R4', 'G3']},{'label': 'uO', 'num': 15, 'pin_nums': ['U17', 'AC14', 'M15', 'U18', 'AC15', 'M22', 'AC22', 'M23', 'V17', 'V18', 'AD14', 'N14', 'AD15', 'N15', 'W17', 'AB15', 'N22', 'AD21', 'W18', 'P15', 'AA22', 'AD22', 'N23', 'AD23']},{'label': 'uP', 'num': 16, 'pin_nums': ['J13', 'N11', 'R16', 'V13', 'R15', 'B24', 'J18', 'R17', 'N12', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'R19', 'N16', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'T20', 'AB17', 'F32', 'M12', 'P2', 'T21', 'AB19', 'F7', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'G29', 'M16', 'P22', 'T4', 'AC16', 'G34', 'M17', 'P23', 'T5', 'AC18', 'G4', 'M18', 'P28', 'U12', 'AC20', 'G9', 'M19', 'P8', 'U14', 'AD13', 'H16', 'M20', 'R10', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'B2', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'V11']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AB22', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AE15', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'AE25', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AA19', 'AE5', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'AN11', 'W19', 'AA23', 'AF2', 'AN2', 'W21', 'AA27', 'AF22', 'AN21', 'W23', 'AA7', 'AF27', 'AN31', 'W33', 'AB12', 'AF32', 'AN7', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AG34', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14']}] }),
        Part(**{ 'name':'XC5VFX70T-FF665', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VFX70T-FF665'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VFX70T-FF665\n\nFPGA', 'pins':[
            Pin(num='B13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G24',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J25',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='M24',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA23',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA24',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P23',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='P8',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V22',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V23',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V25',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='V26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W23',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y23',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='IO_L13N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='IO_L15N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L14P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A9',name='IO_L4P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='IO_L13P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B11',name='IO_L15P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='IO_L17P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L16P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='IO_L16N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B9',name='IO_L6P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C10',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C11',name='IO_L19P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='IO_L17N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C8',name='IO_L6N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D10',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='IO_L19N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L18P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='IO_L7N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E5',name='IO_L18N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L7P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L5N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='IO_L5P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='F7',name='IO_L1P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F8',name='IO_L1N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F9',name='IO_L2P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L0N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G9',name='IO_L2N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L0P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L3P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='IO_L3N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AA7',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA8',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB23',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AB5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC20',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC26',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC7',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD13',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD14',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD15',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD16',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD18',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD20',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD24',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD26',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE13',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE15',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE16',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE17',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE18',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE20',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE21',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE22',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE24',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE26',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF13',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF14',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF15',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF17',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF18',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF19',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF20',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF22',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF24',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF25',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='D18',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='G21',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W16',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y15',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y16',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y17',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y20',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA20',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB11',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB14',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB15',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC11',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='L1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=7),
            Pin(num='U1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='W2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AC1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AE2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='B2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=8),
            Pin(num='E1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='G2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='Y2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AD3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AE3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='C3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='F3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='H3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='J3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=9),
            Pin(num='N3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='P4',name='MGTRREF_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=9),
            Pin(num='R3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='V3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=9),
            Pin(num='W3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='Y3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='F11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='H12',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J10',name='D_IN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J12',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='J20',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='HSWAPEN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='CS_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M20',name='RDWR_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N14',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N15',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P14',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P15',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R14',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R15',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T20',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U12',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U20',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V12',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V13',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W20',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='VBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='AVSS_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='AVDD_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W10',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y9',name='GND',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['M24', 'H22', 'K26', 'J23', 'E26', 'G11', 'G25', 'H23', 'J24', 'L22', 'F13', 'G12', 'M25', 'F14', 'G14', 'G26', 'H24', 'J25', 'L23', 'M26', 'F15', 'G15', 'B13', 'H11', 'H25', 'J26', 'F17', 'L24', 'N21', 'E23', 'G16', 'F18', 'H13', 'H26', 'K21', 'G17', 'L25', 'N22', 'F22', 'G10', 'G19', 'H18', 'H9', 'K22', 'M21', 'N23', 'F23', 'G20', 'H19', 'J21', 'K23', 'M22', 'E22', 'F24', 'N24', 'E14', 'G22', 'F25', 'H21', 'J22', 'K25', 'M23', 'N26', 'E25', 'G24']},{'label': 'uB', 'num': 2, 'pin_nums': ['M6', 'U24', 'U25', 'M7', 'N6', 'U26', 'U5', 'N7', 'N8', 'U6', 'P21', 'U7', 'V21', 'P23', 'V22', 'P24', 'AA22', 'V23', 'P25', 'AA23', 'P26', 'V24', 'AA24', 'P6', 'V25', 'AA25', 'P7', 'V26', 'AB24', 'P8', 'V6', 'AB25', 'R21', 'V7', 'AB26', 'R22', 'W21', 'F5', 'R23', 'W22', 'G4', 'R24', 'W23', 'G5', 'R25', 'W24', 'G6', 'R26', 'W25', 'H4', 'R5', 'W26', 'H5', 'R6', 'W4', 'H6', 'R7', 'W5', 'J5', 'R8', 'W6', 'J6', 'T22', 'Y22', 'K5', 'T23', 'Y23', 'K6', 'T24', 'Y25', 'K7', 'T25', 'Y26', 'K8', 'T5', 'Y4', 'L5', 'T7', 'Y5', 'L6', 'T8', 'Y6', 'L7', 'U21', 'L8', 'U22']},{'label': 'uC', 'num': 3, 'pin_nums': ['B26', 'A13', 'B4', 'D5', 'A14', 'B5', 'D6', 'A15', 'B6', 'D7', 'A17', 'B7', 'D8', 'A18', 'B9', 'D9', 'A19', 'C10', 'E24', 'A20', 'C11', 'E5', 'A22', 'C12', 'E6', 'A23', 'C13', 'E7', 'A24', 'C14', 'E8', 'A25', 'C16', 'F21', 'A3', 'C17', 'F7', 'A4', 'C18', 'F8', 'A5', 'C19', 'F9', 'A7', 'C21', 'G7', 'A8', 'C22', 'G8', 'A9', 'C23', 'G9', 'B10', 'C24', 'H7', 'B11', 'C26', 'H8', 'B12', 'C6', 'J8', 'B14', 'C7', 'B15', 'C8', 'B16', 'C9', 'B17', 'D10', 'B19', 'D11', 'B20', 'D19', 'D20', 'B21', 'B22', 'D21', 'B23', 'D23', 'B24', 'D24', 'D26', 'A10', 'B25', 'D25', 'A12']},{'label': 'uD', 'num': 4, 'pin_nums': ['AC10', 'AF4', 'AE11', 'AC20', 'AF5', 'AE12', 'AC21', 'AE13', 'AF7', 'AC22', 'AF8', 'AE15', 'AC23', 'AE16', 'AF9', 'AC24', 'V8', 'AE17', 'AE10', 'AC26', 'AE18', 'V9', 'AC6', 'W8', 'AE20', 'AC7', 'AE21', 'W9', 'AC8', 'AE22', 'Y7', 'AC9', 'AE23', 'Y8', 'AD10', 'AE24', 'AD11', 'AE25', 'AD13', 'AE26', 'AD14', 'AE5', 'AD15', 'AE6', 'AD16', 'AE7', 'AD18', 'AE8', 'AD19', 'AF10', 'AD20', 'AF12', 'AD21', 'AF13', 'AA5', 'AD23', 'AF14', 'AA6', 'AD24', 'AF15', 'AA7', 'AD25', 'AF17', 'AA8', 'AD26', 'AF18', 'AA9', 'AD4', 'AF19', 'AB22', 'AD5', 'AF20', 'AB23', 'AD6', 'AF22', 'AB5', 'AD7', 'AF23', 'AB6', 'AD8', 'AF24', 'AB7', 'AD9', 'AF25', 'AB9', 'AF3']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA15', 'D15', 'Y11', 'F19', 'AA16', 'D16', 'E16', 'F20', 'Y12', 'AA17', 'D17', 'E17', 'G18', 'Y13', 'AA18', 'D18', 'E18', 'G21', 'Y15', 'AA10', 'AA19', 'E10', 'E20', 'W11', 'Y16', 'AA12', 'AD17', 'E11', 'E21', 'W14', 'Y17', 'AA13', 'D13', 'E12', 'E15', 'F10', 'W16', 'Y18', 'AA14', 'D14', 'E13', 'F12', 'Y10', 'Y20']},{'label': 'uF', 'num': 6, 'pin_nums': ['AB16', 'AB17', 'AA20', 'AC16', 'AC17', 'AB19', 'AB10', 'AB11', 'AB20', 'AC18', 'AB21', 'AC19', 'AB12', 'AB13', 'AC11', 'AE14', 'AB14', 'AC12', 'Y21', 'AB15', 'AC13', 'AC14']},{'label': 'uG', 'num': 7, 'pin_nums': ['J1', 'N2', 'P2', 'J2', 'V2', 'K1', 'R1', 'W2', 'K3', 'R2', 'K4', 'T1', 'L1', 'T3', 'M1', 'T4', 'V1', 'H2', 'M2', 'U1']},{'label': 'uH', 'num': 8, 'pin_nums': ['AC1', 'D3', 'AD1', 'D4', 'AD2', 'E1', 'AE2', 'F1', 'AA1', 'AB4', 'AA2', 'B2', 'F2', 'AB1', 'C1', 'G2', 'AB3', 'C2', 'Y2', 'D1']},{'label': 'uI', 'num': 9, 'pin_nums': ['F3', 'Y3', 'AC3', 'P3', 'P4', 'G3', 'AC4', 'AD3', 'H3', 'P5', 'J3', 'R3', 'AE3', 'B3', 'L3', 'U3', 'C3', 'L4', 'U4', 'E4', 'N3', 'W3', 'E3', 'M3', 'V3', 'AA3']},{'label': 'uJ', 'num': 10, 'pin_nums': ['W13', 'K20', 'W20', 'R15', 'L20', 'F11', 'T20', 'H12', 'M20', 'U12', 'J10', 'N14', 'U20', 'J11', 'N15', 'V11', 'J12', 'P14', 'V12', 'P15', 'J20', 'K11', 'V13', 'R14']},{'label': 'uK', 'num': 11, 'pin_nums': ['AF11', 'J14', 'L26', 'P17', 'U13', 'AF16', 'L9', 'J15', 'U14', 'P18', 'AF2', 'J16', 'M10', 'P19', 'U15', 'AF21', 'M11', 'J17', 'P22', 'U16', 'AF26', 'J18', 'M12', 'P9', 'U17', 'AF6', 'J19', 'M13', 'R10', 'U18', 'U11', 'B18', 'J4', 'M14', 'R11', 'U19', 'B8', 'M15', 'J7', 'R12', 'U2', 'C15', 'K10', 'M16', 'R13', 'U23', 'C20', 'K12', 'M17', 'R16', 'U8', 'A11', 'C25', 'K13', 'M18', 'R17', 'U9', 'A16', 'C4', 'K14', 'M19', 'R18', 'V10', 'A2', 'C5', 'K15', 'M4', 'R19', 'V14', 'A21', 'D12', 'K16', 'M8', 'R4', 'V15', 'A26', 'D2', 'K17', 'M9', 'R9', 'V16', 'A6', 'D22', 'K18', 'N10', 'T10', 'V17', 'AA11', 'E19', 'K19', 'N11', 'T11', 'V18', 'AA21', 'E2', 'K2', 'N12', 'T12', 'V19', 'AA26', 'E9', 'K24', 'N13', 'T13', 'V20', 'AA4', 'F16', 'K9', 'N16', 'T14', 'V4', 'AB18', 'F26', 'L10', 'N17', 'T15', 'V5', 'AB2', 'F4', 'L11', 'N18', 'T16', 'W10', 'AB8', 'F6', 'L12', 'N19', 'T17', 'W12', 'AC15', 'G13', 'L13', 'N20', 'T18', 'W15', 'AC2', 'G23', 'L14', 'N25', 'T19', 'W17', 'AC25', 'H10', 'L15', 'N5', 'T2', 'W18', 'AC5', 'H14', 'L16', 'N9', 'T21', 'W19', 'P16', 'AD12', 'H15', 'L17', 'P10', 'T26', 'W7', 'AD22', 'H16', 'L18', 'P11', 'T6', 'Y14', 'AE19', 'H17', 'L19', 'P12', 'T9', 'Y19', 'AE4', 'H20', 'L2', 'P13', 'U10', 'Y24', 'AE9', 'J13', 'L21', 'Y9']}] }),
        Part(**{ 'name':'XC5VLX110-FF1153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX110-FF1153'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX110-FF1153\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P33',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V32',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AC2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AD1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF1',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF3',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG2',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH2',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL3',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN3',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H31',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H5',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K5',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L6',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P4',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R11',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T10',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T9',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA4',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC5',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AD4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG5',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ4',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ5',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='B29',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F27',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V8',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W7',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y9',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC15',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC20',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD19',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE19',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AG23',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AL22',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E7',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E9',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F7',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='F8',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G4',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G8',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H7',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H8',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K8',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L11',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M11',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AA10',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA11',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA8',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA9',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB10',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB11',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB8',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD7',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD9',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE11',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE7',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF8',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG10',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH7',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ10',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ6',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ9',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AK6',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AN6',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='A10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A11',name='IO_L7P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A13',name='IO_L3N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L0N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A15',name='IO_L0P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A16',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A4',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A5',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A6',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A8',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A9',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B10',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B11',name='IO_L7N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B12',name='IO_L5P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B13',name='IO_L3P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B15',name='IO_L2P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B16',name='IO_L4P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B17',name='IO_L6P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B5',name='IO_L14P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B6',name='IO_L13P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B7',name='IO_L13N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B8',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B9',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='C10',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C12',name='IO_L5N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C13',name='IO_L1N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C14',name='IO_L1P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C15',name='IO_L2N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C17',name='IO_L6N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C4',name='IO_L16P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C5',name='IO_L16N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C6',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='C7',name='IO_L15N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C8',name='IO_L15P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C9',name='IO_L17N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D10',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D11',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D23',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='IO_L18N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D5',name='IO_L18P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D6',name='IO_L19P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D7',name='IO_L19N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D9',name='IO_L17P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E10',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='AF27',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AG24',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AH11',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AL10',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL12',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL4',name='IO_L2N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL5',name='IO_L0P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL6',name='IO_L0N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL8',name='IO_L4P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL9',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM10',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM11',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM12',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM13',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L17P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L17N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L13N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM5',name='IO_L2P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM6',name='IO_L5N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM7',name='IO_L6N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM8',name='IO_L6P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM9',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AN10',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN12',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN13',name='IO_L14P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN14',name='IO_L18N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L19N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN17',name='IO_L13P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN4',name='IO_L1N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN5',name='IO_L1P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN7',name='IO_L5P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN8',name='IO_L7N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN9',name='IO_L7P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP10',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP11',name='IO_L16P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP12',name='IO_L16N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP14',name='IO_L18P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L19P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L15P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L15N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP4',name='IO_L3N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP5',name='IO_L3P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP6',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP7',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP9',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AE18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF17',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AF18',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF19',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF20',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF21',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG13',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG20',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH12',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH19',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AK15',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AK19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='F20',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G20',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G21',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G22',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H12',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H13',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H15',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H18',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H19',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H20',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H21',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='H22',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H23',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J14',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J15',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J16',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J17',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J20',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J21',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='AG18',name='IO_L14P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH13',name='IO_L1N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH14',name='IO_L1P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH15',name='IO_L3N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH17',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH22',name='IO_L0P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH23',name='IO_L0N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH24',name='IO_L2P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ11',name='IO_L5P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ12',name='IO_L5N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ14',name='IO_L3P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ15',name='IO_L7N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ17',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AJ20',name='IO_L6P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ21',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ22',name='IO_L4P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ24',name='IO_L2N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK11',name='IO_L18P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK12',name='IO_L16N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK13',name='IO_L16P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK14',name='IO_L7P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK21',name='IO_L6N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK22',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK23',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK24',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL11',name='IO_L18N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL13',name='IO_L19P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL14',name='IO_L19N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L17P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L17N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL18',name='IO_L15P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL19',name='IO_L15N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL20',name='IO_L13P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL21',name='IO_L13N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL23',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AM19',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='IO_L1P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D14',name='IO_L0N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D15',name='IO_L0P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D16',name='IO_L2P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D17',name='IO_L2N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D19',name='IO_L6P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D21',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D22',name='IO_L13P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E11',name='IO_L1N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E12',name='IO_L3P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E13',name='IO_L3N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E14',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E16',name='IO_L7P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E17',name='IO_L5N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E18',name='IO_L5P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E19',name='IO_L6N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E23',name='IO_L13N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E24',name='IO_L17N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F11',name='IO_L18N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F13',name='IO_L16N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F14',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F15',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F16',name='IO_L7N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='F18',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F19',name='IO_L4P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G11',name='IO_L18P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G12',name='IO_L16P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G15',name='IO_L14P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G16',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G17',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G23',name='IO_L19N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='H17',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='AA13',name='TCK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AB13',name='TMS_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC13',name='TDI_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC14',name='TDO_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD13',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='AD14',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AG14',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='L13',name='INIT_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M13',name='CCLK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M23',name='CS_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N13',name='D_IN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N14',name='DONE_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N22',name='HSWAPEN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P22',name='VBATT_0',func=pin_types.PWRIN,unit=13),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='T27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=14)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C32', 'N34', 'T33', 'E32', 'H34', 'E33', 'J12', 'K16', 'K32', 'K33', 'L21', 'L23', 'P32', 'T34', 'E34', 'J19', 'K17', 'K34', 'F33', 'L33', 'P33', 'U31', 'B33', 'F34', 'J22', 'K18', 'L14', 'L34', 'P34', 'U32', 'G14', 'J32', 'K19', 'L15', 'C33', 'M32', 'R30', 'U33', 'G32', 'J34', 'K21', 'L16', 'C34', 'G33', 'M33', 'R32', 'V31', 'H32', 'D13', 'K12', 'K22', 'L19', 'N32', 'R33', 'D32', 'A33', 'B32', 'H33', 'K13', 'K23', 'L20', 'N33', 'R34', 'D34', 'K14']},{'label': 'uB', 'num': 2, 'pin_nums': ['AD32', 'E1', 'U3', 'AD34', 'U4', 'E2', 'AE32', 'E3', 'V32', 'AE33', 'V33', 'F1', 'AE34', 'F3', 'V34', 'AF33', 'G1', 'W28', 'AF34', 'G2', 'W32', 'AG32', 'W34', 'G3', 'AG33', 'H2', 'W8', 'AH32', 'H3', 'Y32', 'AH33', 'J1', 'Y33', 'AH34', 'J2', 'Y34', 'AJ32', 'K1', 'AJ34', 'K2', 'AK32', 'K3', 'AK33', 'L1', 'AK34', 'L3', 'AL33', 'M1', 'AL34', 'M2', 'AM32', 'M3', 'AM33', 'N2', 'AN32', 'N3', 'A3', 'AN33', 'P1', 'AA32', 'AN34', 'P2', 'AA33', 'AP32', 'R1', 'AA34', 'B1', 'R2', 'AB29', 'B2', 'R3', 'AB32', 'B3', 'T1', 'AB33', 'C2', 'T3', 'AC32', 'C3', 'T7', 'AC33', 'D1', 'U1', 'AC34', 'D2', 'U2']},{'label': 'uC', 'num': 3, 'pin_nums': ['L31', 'L32', 'AH3', 'Y3', 'AJ1', 'M29', 'Y5', 'AJ2', 'M30', 'AK1', 'M31', 'AK2', 'N29', 'AK3', 'N30', 'AL1', 'P29', 'AL3', 'P30', 'AM1', 'P31', 'AM2', 'R26', 'AM3', 'R27', 'AN2', 'R28', 'AA1', 'AN3', 'R29', 'AA3', 'AP2', 'R31', 'AB1', 'E29', 'T25', 'AB2', 'E31', 'T26', 'AB3', 'F29', 'T28', 'AB9', 'F30', 'T29', 'AC2', 'F31', 'T30', 'AC3', 'G30', 'T31', 'AC6', 'G31', 'U25', 'AD1', 'H29', 'U26', 'AD2', 'H30', 'U27', 'AE1', 'H31', 'U28', 'AE2', 'J29', 'U30', 'AE3', 'J30', 'V2', 'AF1', 'J31', 'V3', 'AF3', 'K29', 'V4', 'AG1', 'K31', 'W1', 'AG2', 'L29', 'W2', 'Y2', 'AG3', 'L30', 'Y1', 'AH2']},{'label': 'uD', 'num': 4, 'pin_nums': ['H4', 'T9', 'H5', 'U10', 'J4', 'U11', 'J5', 'AA29', 'U5', 'AA30', 'J6', 'U6', 'AA31', 'K4', 'U7', 'K5', 'AB30', 'U8', 'AB31', 'K6', 'V24', 'AC29', 'L4', 'V25', 'AC30', 'L5', 'V27', 'AD29', 'L6', 'V28', 'AD30', 'M5', 'V29', 'AD31', 'M6', 'V30', 'AD33', 'N4', 'W24', 'AE29', 'N5', 'W25', 'AE30', 'N6', 'W26', 'AE31', 'P3', 'W27', 'AF29', 'P4', 'W29', 'AF30', 'P5', 'W30', 'AF31', 'P6', 'W31', 'AG30', 'R11', 'Y26', 'AG31', 'R4', 'Y27', 'AH29', 'R6', 'Y28', 'AH30', 'R7', 'Y29', 'AH31', 'R8', 'Y31', 'AJ30', 'R9', 'AJ31', 'T10', 'G5', 'AK31', 'T11', 'E4', 'T4', 'F4', 'T5', 'F5', 'T6', 'T8']},{'label': 'uE', 'num': 5, 'pin_nums': ['AC5', 'V7', 'AD3', 'H25', 'V8', 'AD4', 'H27', 'V9', 'AD5', 'H28', 'W10', 'AD6', 'J24', 'W11', 'AE4', 'J25', 'W4', 'AE6', 'J26', 'W5', 'AF4', 'J27', 'W6', 'AF5', 'K24', 'W7', 'AF6', 'K26', 'W9', 'AF7', 'K27', 'Y11', 'AG4', 'K28', 'Y4', 'AG5', 'L24', 'Y6', 'AG6', 'L25', 'Y7', 'AH4', 'L26', 'Y8', 'AH5', 'L28', 'Y9', 'AJ4', 'M25', 'AJ5', 'M26', 'AK4', 'M27', 'B29', 'M28', 'E26', 'N24', 'E27', 'N25', 'E28', 'N27', 'E30', 'N28', 'F25', 'P24', 'F26', 'P25', 'AA4', 'F27', 'P26', 'AA5', 'F28', 'P27', 'AA6', 'G25', 'R24', 'AB5', 'G26', 'T24', 'AB6', 'G27', 'H24', 'V10', 'AC4', 'G28', 'V5']},{'label': 'uF', 'num': 6, 'pin_nums': ['E7', 'H9', 'M7', 'K8', 'G10', 'P7', 'AC15', 'AE13', 'AE12', 'AF15', 'E8', 'G4', 'J10', 'K9', 'M8', 'P9', 'AC19', 'AE14', 'AF16', 'E9', 'G6', 'J11', 'L10', 'N10', 'AC20', 'AE16', 'AF23', 'F10', 'G7', 'J7', 'L11', 'N7', 'AD15', 'AE17', 'AG23', 'F6', 'G8', 'J8', 'L8', 'N8', 'AD16', 'AE19', 'AH21', 'F7', 'H10', 'J9', 'L9', 'N9', 'AD19', 'AE21', 'AL22', 'F8', 'H7', 'K11', 'M10', 'P10', 'AE22', 'AD20', 'E6', 'F9', 'H8', 'K7', 'M11', 'P11', 'AE23']},{'label': 'uG', 'num': 7, 'pin_nums': ['AB7', 'AF8', 'AK6', 'AF9', 'AB8', 'AK7', 'AC10', 'AG10', 'AK8', 'AG11', 'AC24', 'AK9', 'AC25', 'AG25', 'AL32', 'AC27', 'AG26', 'AM29', 'AC28', 'AG27', 'AN6', 'AC7', 'AG28', 'Y24', 'AC8', 'AG7', 'AC9', 'AG8', 'AD10', 'AH10', 'AD11', 'AH25', 'AD24', 'AH27', 'AD25', 'AH28', 'AD26', 'AH7', 'AD27', 'AH8', 'AD7', 'AH9', 'AF28', 'AD9', 'AJ10', 'AA10', 'AE11', 'AJ25', 'AA11', 'AE24', 'AJ26', 'AA24', 'AE26', 'AJ27', 'AA25', 'AE27', 'AJ28', 'AA26', 'AE28', 'AJ29', 'AA28', 'AE7', 'AJ6', 'AA8', 'AE8', 'AJ7', 'AA9', 'AE9', 'AJ8', 'AB10', 'AF10', 'AJ9', 'AB11', 'AF11', 'AK26', 'AB25', 'AF24', 'AK27', 'AB26', 'AF25', 'AK28', 'AB27', 'AF26', 'AK29', 'AB28', 'AK5']},{'label': 'uH', 'num': 8, 'pin_nums': ['B10', 'B11', 'C23', 'B12', 'C24', 'B13', 'C25', 'B15', 'C26', 'B16', 'C27', 'B17', 'C28', 'B18', 'C29', 'B20', 'C30', 'A10', 'B21', 'C4', 'A11', 'B22', 'C5', 'A13', 'B23', 'C6', 'A14', 'B25', 'C7', 'A15', 'B26', 'C8', 'A16', 'B27', 'C9', 'A18', 'B28', 'D10', 'A19', 'B30', 'D11', 'A20', 'B31', 'D23', 'A21', 'B5', 'D25', 'A23', 'B6', 'D26', 'A24', 'B7', 'D27', 'A25', 'B8', 'D29', 'A26', 'B9', 'D30', 'A28', 'C10', 'D31', 'A29', 'C12', 'D4', 'A30', 'C13', 'D5', 'A31', 'C14', 'D6', 'A4', 'C15', 'D7', 'A5', 'C17', 'D9', 'A6', 'C18', 'E10', 'A8', 'C19', 'C22', 'G24', 'A9', 'C20']},{'label': 'uI', 'num': 9, 'pin_nums': ['AG24', 'AP12', 'AM28', 'AH11', 'AP14', 'AM30', 'AK25', 'AM31', 'AP15', 'AL10', 'AP16', 'AM5', 'AL12', 'AM6', 'AP17', 'AL24', 'AP19', 'AM7', 'AL25', 'AM8', 'AP20', 'AL26', 'AM9', 'AP21', 'AL28', 'AN10', 'AP22', 'AL29', 'AN12', 'AP24', 'AL30', 'AN13', 'AP25', 'AL31', 'AN14', 'AP26', 'AL4', 'AN15', 'AP27', 'AL5', 'AN17', 'AP29', 'AL6', 'AN18', 'AP30', 'AL8', 'AP31', 'AN19', 'AL9', 'AN20', 'AP4', 'AM10', 'AN22', 'AP5', 'AM11', 'AN23', 'AP6', 'AM12', 'AN24', 'AP7', 'AM13', 'AN25', 'AP9', 'AM15', 'AN27', 'AM16', 'AN28', 'AM17', 'AN29', 'AM18', 'AN30', 'AM20', 'AN4', 'AM21', 'AN5', 'AF27', 'AM22', 'AN7', 'AM23', 'AN8', 'AM25', 'AN9', 'AM26', 'AP10', 'AM27', 'AP11']},{'label': 'uJ', 'num': 10, 'pin_nums': ['J20', 'AH20', 'H20', 'G21', 'AF17', 'AG16', 'AJ19', 'G22', 'H21', 'J21', 'AG15', 'AF18', 'AG17', 'AK15', 'H12', 'H22', 'AF19', 'AG20', 'AK19', 'H13', 'H23', 'AF20', 'AG21', 'E20', 'H14', 'J14', 'AF21', 'AG22', 'F20', 'H15', 'J15', 'AE18', 'AG12', 'AH12', 'G13', 'H18', 'J16', 'AF13', 'AG13', 'AH19', 'G20', 'H19', 'J17', 'AF14']},{'label': 'uK', 'num': 11, 'pin_nums': ['AK24', 'E19', 'E21', 'AL11', 'AG18', 'AL13', 'E22', 'AH13', 'E23', 'AL14', 'AH14', 'AL15', 'E24', 'AH15', 'AL16', 'F11', 'AH17', 'AL18', 'F13', 'AH18', 'AL19', 'F14', 'AH22', 'AL20', 'F15', 'AH23', 'AL21', 'F16', 'AH24', 'AL23', 'F17', 'AJ11', 'AM19', 'F18', 'AJ12', 'AN16', 'F19', 'AJ14', 'B19', 'F21', 'AJ15', 'C16', 'F23', 'AJ16', 'D12', 'F24', 'AJ17', 'D14', 'G11', 'AJ18', 'D15', 'G12', 'AJ20', 'D16', 'G15', 'AJ21', 'D17', 'G16', 'AJ22', 'D19', 'G17', 'AJ24', 'D20', 'G18', 'AK11', 'D21', 'G23', 'AK12', 'D22', 'H17', 'AK13', 'D24', 'AK14', 'E11', 'AK16', 'E12', 'AK17', 'E13', 'AK18', 'E14', 'AK21', 'E16', 'AK22', 'E17', 'AK23', 'E18']},{'label': 'uL', 'num': 12, 'pin_nums': ['N14', 'W18', 'AA13', 'AD22', 'N22', 'AB13', 'AG14', 'N23', 'AC13', 'L13', 'U17', 'AC14', 'M13', 'U18', 'AC22', 'M22', 'V17', 'AD13', 'M23', 'V18', 'AD14', 'N13', 'W17', 'AD21']},{'label': 'uM', 'num': 13, 'pin_nums': ['AB17', 'H1', 'M24', 'R13', 'U16', 'AB19', 'M34', 'H11', 'U19', 'R14', 'AB21', 'H16', 'M4', 'R15', 'U20', 'AC12', 'M9', 'H26', 'R16', 'U21', 'AC16', 'H6', 'N1', 'R17', 'U22', 'AC18', 'J13', 'N11', 'R18', 'U23', 'AD17', 'J18', 'N12', 'R19', 'U24', 'AD23', 'N15', 'J23', 'U9', 'R20', 'B14', 'J28', 'N16', 'R21', 'V11', 'B24', 'J3', 'N17', 'R22', 'V13', 'B34', 'J33', 'N18', 'R23', 'V15', 'B4', 'K10', 'N19', 'R25', 'V19', 'C1', 'K15', 'N20', 'R5', 'V21', 'C11', 'K20', 'N21', 'T12', 'V23', 'C21', 'K25', 'N26', 'T13', 'W12', 'C31', 'K30', 'N31', 'T14', 'W14', 'D18', 'L12', 'P12', 'T15', 'W16', 'A1', 'D28', 'L17', 'P13', 'T16', 'W20', 'A12', 'D3', 'L18', 'P14', 'T17', 'W22', 'A17', 'D33', 'L2', 'P15', 'T18', 'Y13', 'A2', 'D8', 'L22', 'P16', 'T19', 'Y15', 'M21', 'A22', 'E15', 'L27', 'P17', 'T2', 'Y17', 'A27', 'E25', 'L7', 'P18', 'T20', 'Y19', 'A32', 'E5', 'M12', 'P19', 'T21', 'Y21', 'A7', 'F12', 'M14', 'P20', 'T22', 'Y23', 'AA12', 'F2', 'M15', 'P21', 'T23', 'AA14', 'F22', 'M16', 'P22', 'T27', 'AA16', 'F32', 'M17', 'P23', 'T32', 'AA18', 'G19', 'M18', 'P28', 'U12', 'AA20', 'G29', 'M19', 'P8', 'U13', 'AA22', 'G34', 'M20', 'R10', 'U14', 'AB15', 'G9', 'R12', 'U15']},{'label': 'uN', 'num': 14, 'pin_nums': ['AG34', 'AP8', 'AA7', 'AG9', 'U29', 'AB12', 'AH1', 'U34', 'AB14', 'AH16', 'V1', 'AB16', 'AH26', 'V12', 'AB18', 'AH6', 'V14', 'AB20', 'AJ13', 'V16', 'AB22', 'AJ23', 'V20', 'AB24', 'AJ3', 'V22', 'AB34', 'AJ33', 'V26', 'AB4', 'AK10', 'V6', 'AC1', 'AK20', 'W13', 'AC11', 'AK30', 'W15', 'AC17', 'AL17', 'W19', 'AC21', 'AL2', 'W21', 'AC26', 'AL27', 'W23', 'AC31', 'AL7', 'W3', 'AD12', 'AM14', 'W33', 'AD18', 'AM24', 'Y10', 'AD28', 'AM34', 'Y12', 'AD8', 'AM4', 'Y14', 'AE10', 'AN1', 'Y16', 'AE15', 'AN11', 'Y18', 'AE20', 'AN21', 'Y20', 'AE25', 'AN26', 'Y22', 'AE5', 'AN31', 'Y25', 'AA15', 'AF12', 'AP13', 'Y30', 'AA17', 'AF2', 'AP18', 'AA19', 'AF22', 'AP23', 'AA2', 'AF32', 'AP28', 'AA21', 'AA27', 'AG19', 'AP3', 'AA23', 'AG29', 'AP33']}] }),
        Part(**{ 'name':'XC5VLX110-FF1760', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX110-FF1760'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX110-FF1760\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R27',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U40',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA38',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC4',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC5',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD3',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AE2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AF1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AG2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH1',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ3',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP1',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AR2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT2',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU1',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M35',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA10',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE36',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G4',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V5',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='W10',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y10',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB8',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB9',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC9',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD11',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AF4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG4',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ6',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL4',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM4',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN4',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AP3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR3',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H37',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AH16',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH29',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ16',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ17',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ30',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK15',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL15',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL29',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL30',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E5',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F5',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H6',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J5',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J6',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L7',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M5',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M6',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P6',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P8',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R7',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R9',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T11',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T9',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U7',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE10',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF12',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG12',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG9',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH11',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AL7',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AL9',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AM7',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM8',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN6',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN8',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP5',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP6',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP7',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP9',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR5',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT4',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT5',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT6',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU3',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU4',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV3',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV4',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV5',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='IO_L14P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E13',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='IO_L18P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E8',name='IO_L18N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E9',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F10',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F11',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F12',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F3',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F7',name='IO_L19P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F9',name='IO_L15P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G11',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G12',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G13',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G40',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='G8',name='IO_L19N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G9',name='IO_L15N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H10',name='IO_L13N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H11',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='H8',name='IO_L16P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H9',name='IO_L13P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J10',name='IO_L7P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='IO_L7N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J12',name='IO_L6N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J4',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='IO_L16N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K12',name='IO_L6P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K8',name='IO_L17P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K9',name='IO_L17N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L10',name='IO_L5N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L11',name='IO_L5P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L12',name='IO_L2N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L9',name='IO_L4P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M11',name='IO_L3N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M12',name='IO_L2P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N10',name='IO_L1N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N11',name='IO_L3P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P10',name='IO_L1P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P11',name='IO_L0N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P12',name='IO_L0P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ10',name='IO_L18P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ11',name='IO_L18N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L19P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK10',name='IO_L17P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L19N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL10',name='IO_L17N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL11',name='IO_L16P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL12',name='IO_L16N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM11',name='IO_L15N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM12',name='IO_L15P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM9',name='IO_L13P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN10',name='IO_L13N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN11',name='IO_L14P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP11',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP12',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AP8',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR10',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR12',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AR6',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AR7',name='IO_L3P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR8',name='IO_L3N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR9',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT10',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT11',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT12',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT3',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT7',name='IO_L2P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT9',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU11',name='IO_L7N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU12',name='IO_L6N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU13',name='IO_L6P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AU6',name='IO_L2N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU7',name='IO_L0N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU8',name='IO_L1P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU9',name='IO_L4P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV10',name='IO_L5P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV11',name='IO_L7P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV6',name='IO_L0P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV8',name='IO_L1N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV9',name='IO_L5N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AW4',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='C32',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='D9',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='E6',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='G10',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=11),
            Pin(num='J24',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J30',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K13',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K14',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K28',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K29',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L15',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L16',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L29',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M16',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M27',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N26',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='AV7',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='BA8',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='H27',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='B15',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='C12',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='F13',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='AK17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK27',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK28',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL16',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM13',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM27',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM28',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN13',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN16',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN28',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN29',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN30',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP13',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP30',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AT13',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AV17',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AW14',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AY11',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='BA18',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ18',name='IO_L16N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ25',name='IO_L17P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK18',name='IO_L1P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK19',name='IO_L16P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK24',name='IO_L17N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK25',name='IO_L19N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL17',name='IO_L1N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL19',name='IO_L18P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL24',name='IO_L19P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL25',name='IO_L15P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL26',name='IO_L0P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM17',name='IO_L3N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM18',name='IO_L3P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM19',name='IO_L18N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM24',name='IO_L15N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM26',name='IO_L0N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN18',name='IO_L5P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN19',name='IO_L7P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN25',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN26',name='IO_L4P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP16',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP17',name='IO_L5N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP18',name='IO_L7N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP26',name='IO_L6P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP27',name='IO_L2N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP28',name='IO_L2P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR13',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR14',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR15',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR27',name='IO_L6N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR28',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR29',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR30',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT14',name='IO_L14P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT15',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AT29',name='IO_L13N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT30',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AU29',name='IO_L13P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='G14',name='IO_L1P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G16',name='IO_L3N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G27',name='IO_L15P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G28',name='IO_L17P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G29',name='IO_L17N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H14',name='IO_L1N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H15',name='IO_L7P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H16',name='IO_L3P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J15',name='IO_L7N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J16',name='IO_L5N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J17',name='IO_L5P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J26',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J27',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J28',name='IO_L13P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K17',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K18',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K19',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K24',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K27',name='IO_L13N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L17',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L19',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L24',name='IO_L2N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L25',name='IO_L2P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L26',name='IO_L6N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M17',name='IO_L14P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M24',name='IO_L0P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M26',name='IO_L6P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N18',name='IO_L16P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N19',name='IO_L16N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N24',name='IO_L0N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N25',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P18',name='IO_L18N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P25',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='R18',name='IO_L18P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AR16',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AE30',name='TCK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF14',name='TMS_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF15',name='CCLK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF30',name='M1_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG14',name='TDI_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG29',name='M0_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='AH14',name='TDO_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH28',name='M2_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='R14',name='D_IN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T14',name='HSWAPEN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T15',name='DONE_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='U14',name='INIT_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R29',name='VBATT_0',func=pin_types.PWRIN,unit=18),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=19)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['M13', 'R27', 'N30', 'U41', 'P27', 'G41', 'M29', 'Y37', 'G42', 'N29', 'R28', 'U42', 'P26', 'M41', 'N40', 'AA37', 'P28', 'Y38', 'H41', 'U40', 'W42', 'AA39', 'M42', 'N41', 'P30', 'J14', 'R40', 'V37', 'Y39', 'J41', 'N13', 'P13', 'P40', 'AA40', 'R42', 'V40', 'Y40', 'J42', 'AA41', 'N14', 'P15', 'P41', 'T40', 'V41', 'Y41', 'K42', 'AA42', 'N15', 'P16', 'P42', 'T41', 'L40', 'W40', 'Y42', 'E16', 'L41', 'N28', 'P17', 'R15', 'F42', 'T42', 'W41', 'F41', 'L42', 'R17']},{'label': 'uB', 'num': 2, 'pin_nums': ['AP41', 'U2', 'AB41', 'AP42', 'U3', 'AB42', 'AR42', 'V1', 'AB5', 'AT41', 'V3', 'AC38', 'AT42', 'V4', 'AC39', 'AU41', 'W1', 'AC40', 'AU42', 'W2', 'AC41', 'AV41', 'W3', 'AD39', 'E2', 'W4', 'AD40', 'F1', 'Y2', 'AD41', 'F2', 'Y3', 'AD42', 'G1', 'Y4', 'AE40', 'G2', 'Y5', 'AE42', 'H1', 'AF40', 'J1', 'AF41', 'J2', 'AF42', 'K2', 'AG41', 'L1', 'AG42', 'L2', 'AH40', 'M1', 'AH41', 'M2', 'AJ40', 'M3', 'AJ41', 'N1', 'AA1', 'AJ42', 'N3', 'AA2', 'AK40', 'P1', 'AA38', 'AK42', 'P2', 'AA4', 'AL40', 'P3', 'AA5', 'AL41', 'R2', 'AA8', 'AL42', 'R3', 'AB35', 'AM41', 'T1', 'AB37', 'AB39', 'AM42', 'T2', 'AB38', 'AN41', 'U1']},{'label': 'uC', 'num': 3, 'pin_nums': ['W37', 'AE6', 'W38', 'G39', 'AF1', 'H38', 'Y34', 'AF2', 'H39', 'Y35', 'AG1', 'H40', 'AG10', 'J38', 'AG2', 'J40', 'AG3', 'K38', 'AH1', 'K39', 'AH3', 'K40', 'AJ1', 'L39', 'AJ2', 'M35', 'AJ3', 'M38', 'AK2', 'M39', 'AA34', 'AK3', 'N38', 'AA35', 'AL1', 'N39', 'AA36', 'AL2', 'P37', 'AB1', 'AM1', 'P38', 'AB2', 'AM2', 'P39', 'AB3', 'AM3', 'R36', 'AB4', 'AN1', 'R37', 'AB6', 'AP1', 'R38', 'G38', 'AC1', 'AP2', 'R39', 'AC3', 'AR2', 'T37', 'AC4', 'AT1', 'T39', 'AC5', 'AT2', 'U37', 'AC6', 'AU1', 'U38', 'AD1', 'AU2', 'U39', 'E39', 'AD2', 'V38', 'AD3', 'E40', 'V39', 'AD9', 'F39', 'W35', 'AE2', 'F40', 'W36', 'AE3']},{'label': 'uD', 'num': 4, 'pin_nums': ['AJ38', 'M4', 'N4', 'AK37', 'AK38', 'N5', 'P5', 'AK39', 'AA10', 'AL37', 'R4', 'AA11', 'AL39', 'R5', 'AA6', 'R6', 'AM37', 'AA7', 'AM38', 'T3', 'AA9', 'AM39', 'T4', 'AB34', 'AN38', 'T5', 'AB36', 'AN39', 'T6', 'AC34', 'AN40', 'U4', 'AC35', 'AP38', 'U6', 'AC36', 'AP40', 'V5', 'AD35', 'AR39', 'V6', 'AD36', 'AR40', 'V7', 'AD37', 'AT39', 'W10', 'AD38', 'AT40', 'W11', 'AE36', 'AU39', 'W5', 'AE37', 'AV40', 'W6', 'AE38', 'E3', 'W7', 'AE39', 'E4', 'W8', 'AF37', 'F4', 'Y10', 'AF39', 'G3', 'Y7', 'AG37', 'G4', 'Y8', 'AG38', 'H3', 'Y9', 'AG39', 'H4', 'AG40', 'J3', 'AH37', 'K3', 'AH38', 'K4', 'AH39', 'L4', 'AJ37', 'L5']},{'label': 'uE', 'num': 5, 'pin_nums': ['AM6', 'AN3', 'AC11', 'R34', 'AC8', 'AN4', 'R35', 'AC9', 'AN5', 'T34', 'AD10', 'AP3', 'T35', 'AD11', 'AR3', 'T36', 'AD5', 'AR4', 'U33', 'AD6', 'D37', 'U34', 'AD7', 'E37', 'U36', 'AD8', 'E38', 'V33', 'AE4', 'F36', 'V34', 'AE5', 'F37', 'V35', 'AE7', 'G36', 'V36', 'AF3', 'G37', 'W32', 'AF4', 'H35', 'W33', 'AF5', 'H36', 'Y32', 'AF6', 'H37', 'Y33', 'AG4', 'J35', 'AG6', 'J36', 'AH4', 'J37', 'AH5', 'K35', 'AH6', 'K37', 'AH7', 'K41', 'AJ4', 'L35', 'AJ5', 'L36', 'AJ6', 'L37', 'AK4', 'L38', 'AA32', 'AK5', 'M36', 'AB11', 'AL4', 'M37', 'AB7', 'AL5', 'N35', 'AB8', 'AL6', 'N36', 'P36', 'AB9', 'AM4', 'P35', 'AC10']},{'label': 'uF', 'num': 6, 'pin_nums': ['T11', 'V11', 'AK29', 'J6', 'AJ26', 'AK30', 'F5', 'J7', 'M6', 'M7', 'P7', 'P8', 'T7', 'V8', 'AL14', 'F6', 'K5', 'AH16', 'AJ27', 'M8', 'P9', 'T9', 'V9', 'AH29', 'AJ28', 'AL15', 'G6', 'K7', 'M9', 'R10', 'U11', 'AL29', 'AH30', 'AJ30', 'G7', 'L6', 'N6', 'R7', 'U7', 'AJ13', 'AK13', 'AL30', 'H5', 'L7', 'N8', 'R8', 'U8', 'AK14', 'AJ15', 'AR26', 'H6', 'L8', 'N9', 'R9', 'U9', 'AJ16', 'AK15', 'AV27', 'J5', 'M5', 'P6', 'T10', 'V10', 'AJ17', 'E5']},{'label': 'uG', 'num': 7, 'pin_nums': ['AF11', 'AL35', 'AU3', 'AF12', 'AU37', 'AL36', 'AF34', 'AL38', 'AU38', 'AF35', 'AU4', 'AL7', 'AF36', 'AL8', 'AV3', 'AF7', 'AL9', 'AV38', 'AF9', 'AM34', 'AV39', 'AG11', 'AV4', 'AM35', 'AG12', 'AM36', 'AV5', 'AG34', 'AM5', 'AG36', 'AM7', 'AG7', 'AM8', 'AG8', 'AN34', 'AG9', 'AN35', 'AH10', 'AN36', 'AH11', 'AN6', 'AH34', 'AN8', 'AH35', 'AP35', 'AH36', 'AP36', 'AB32', 'AH8', 'AP37', 'AB33', 'AH9', 'AP5', 'AC33', 'AJ34', 'AP6', 'AD32', 'AJ35', 'AP7', 'AD33', 'AJ36', 'AP9', 'AE10', 'AJ7', 'AR37', 'AE32', 'AJ8', 'AR38', 'AE33', 'AK34', 'AR5', 'AK35', 'AE34', 'AT36', 'AE35', 'AK7', 'AT37', 'AE8', 'AK8', 'AT4', 'AE9', 'AK9', 'AT5', 'AF10', 'AL34', 'AT6']},{'label': 'uH', 'num': 8, 'pin_nums': ['K8', 'K9', 'G12', 'L10', 'G13', 'G31', 'L11', 'G32', 'L12', 'G33', 'L31', 'G34', 'L32', 'G40', 'L34', 'G8', 'L9', 'G9', 'M11', 'D39', 'H10', 'M12', 'E10', 'H11', 'M31', 'E12', 'H13', 'M32', 'E13', 'H31', 'M33', 'E32', 'H33', 'M34', 'E33', 'H34', 'N10', 'E34', 'H7', 'N11', 'E35', 'H8', 'N31', 'E36', 'H9', 'N33', 'E7', 'J10', 'N34', 'E8', 'J11', 'P10', 'E9', 'J12', 'P11', 'F10', 'J31', 'P12', 'F11', 'J32', 'P31', 'F12', 'J33', 'P32', 'F3', 'J4', 'P33', 'F31', 'J8', 'R32', 'F32', 'K10', 'R33', 'F34', 'K12', 'T31', 'F35', 'K32', 'T32', 'F7', 'K33', 'U31', 'F9', 'K34', 'U32', 'G11']},{'label': 'uI', 'num': 9, 'pin_nums': ['AF31', 'AN9', 'AU13', 'AP10', 'AF32', 'AU31', 'AG31', 'AP11', 'AU32', 'AP12', 'AG32', 'AU33', 'AG33', 'AP31', 'AU34', 'AH31', 'AP32', 'AU36', 'AH33', 'AP33', 'AU40', 'AJ10', 'AP39', 'AU6', 'AJ11', 'AP8', 'AU7', 'AJ12', 'AR10', 'AU8', 'AJ31', 'AR12', 'AU9', 'AJ32', 'AR32', 'AV10', 'AJ33', 'AR33', 'AV11', 'AK10', 'AR34', 'AV31', 'AK12', 'AR35', 'AV33', 'AK32', 'AR36', 'AV34', 'AK33', 'AR6', 'AV35', 'AL10', 'AR7', 'AV36', 'AL11', 'AR8', 'AV6', 'AL12', 'AR9', 'AV8', 'AL31', 'AT10', 'AV9', 'AL32', 'AT11', 'AW4', 'AM11', 'AT12', 'AM12', 'AT3', 'AM31', 'AT31', 'AM32', 'AT32', 'AM33', 'AT34', 'AM9', 'AT35', 'AN10', 'AT7', 'AN33', 'AN11', 'AT9', 'AN31', 'AU11', 'AU12']},{'label': 'uJ', 'num': 10, 'pin_nums': ['G10', 'C32', 'E6', 'F33', 'D9', 'B35']},{'label': 'uK', 'num': 11, 'pin_nums': ['M14', 'E26', 'K29', 'K30', 'J13', 'M16', 'J24', 'L14', 'M27', 'J30', 'L15', 'M28', 'K13', 'L16', 'N16', 'AT33', 'K14', 'L27', 'N26', 'AV37', 'K15', 'L29', 'AW34', 'K28', 'L30']},{'label': 'uL', 'num': 12, 'pin_nums': ['AV7', 'D29', 'H27', 'BA8', 'AU10', 'G30']},{'label': 'uM', 'num': 13, 'pin_nums': ['B15', 'AY31', 'F13', 'BA28', 'AU30', 'C12']},{'label': 'uN', 'num': 14, 'pin_nums': ['AN15', 'AV17', 'AM13', 'AN16', 'AM14', 'AW14', 'AN28', 'AM16', 'AY11', 'AK17', 'AM27', 'AN29', 'BA18', 'AN30', 'AK27', 'AM28', 'AM29', 'AP13', 'AK28', 'AL16', 'AN13', 'AP30', 'AL27', 'AN14', 'AT13']},{'label': 'uO', 'num': 15, 'pin_nums': ['AK19', 'K25', 'AK24', 'AT15', 'K27', 'AK25', 'AT23', 'L17', 'AL17', 'AT29', 'L19', 'AL19', 'AT30', 'L24', 'AL24', 'AU29', 'L25', 'AL25', 'AW24', 'L26', 'AL26', 'AY21', 'M17', 'AM17', 'B25', 'M18', 'AM18', 'C22', 'M19', 'AM19', 'F23', 'M24', 'AM24', 'G14', 'M26', 'AM26', 'G16', 'N18', 'AN18', 'G27', 'N19', 'AN19', 'G28', 'N24', 'AN25', 'G29', 'N25', 'AN26', 'H14', 'P18', 'AP15', 'H15', 'P25', 'AP16', 'H16', 'R18', 'AP17', 'H28', 'AP18', 'H29', 'AP26', 'H30', 'AP27', 'J15', 'AP28', 'J16', 'AR13', 'J17', 'AR14', 'J26', 'AR15', 'J27', 'AR17', 'J28', 'AR27', 'K17', 'AJ18', 'AR28', 'K18', 'AJ25', 'AR29', 'AT14', 'K19', 'AK18', 'AR30', 'K24']},{'label': 'uP', 'num': 16, 'pin_nums': ['AP19', 'G20', 'AU20', 'AR16', 'D19', 'H17']},{'label': 'uQ', 'num': 17, 'pin_nums': ['T30', 'AH15', 'U14', 'AF14', 'AH28', 'AA21', 'AF15', 'AL28', 'AA22', 'AF30', 'R14', 'AB21', 'AG14', 'R30', 'AB22', 'AG29', 'T14', 'AC21', 'AE30', 'AG30', 'T15', 'AC22', 'AH14', 'T29']},{'label': 'uR', 'num': 18, 'pin_nums': ['N7', 'W24', 'AA26', 'AE16', 'B30', 'J29', 'P14', 'T24', 'W26', 'AA28', 'B40', 'AE18', 'J34', 'P19', 'T25', 'W28', 'AA30', 'AE20', 'B5', 'J39', 'P24', 'T26', 'W30', 'AB13', 'AE22', 'C17', 'J9', 'P29', 'T27', 'Y13', 'AB15', 'AE24', 'C2', 'K1', 'P34', 'T28', 'Y15', 'AB17', 'AE26', 'C27', 'K11', 'P4', 'T33', 'Y17', 'AB19', 'AE28', 'C37', 'K16', 'R1', 'T8', 'Y19', 'AB23', 'C42', 'AF13', 'K21', 'R11', 'U12', 'Y21', 'AB25', 'AF17', 'C7', 'K26', 'R12', 'U16', 'Y22', 'AB27', 'AF19', 'D14', 'K31', 'R13', 'U18', 'Y23', 'AB29', 'AF21', 'D24', 'K36', 'R16', 'U20', 'Y25', 'AB31', 'AF23', 'D34', 'K6', 'R19', 'U22', 'Y27', 'AC12', 'AF25', 'D4', 'L13', 'R20', 'U24', 'Y29', 'AC14', 'AF27', 'E1', 'L18', 'R21', 'U26', 'Y31', 'AC16', 'AF29', 'E11', 'L23', 'R22', 'U28', 'AC18', 'AG16', 'E21', 'L28', 'R23', 'U30', 'AC20', 'AG18', 'E31', 'AA24', 'L3', 'R24', 'V13', 'AC24', 'AG20', 'E41', 'L33', 'R25', 'V15', 'A13', 'AC26', 'AG22', 'F18', 'M10', 'R26', 'V17', 'A18', 'AC28', 'AG24', 'F28', 'M15', 'R29', 'V19', 'A23', 'AC30', 'AG26', 'F38', 'M20', 'R31', 'V21', 'A28', 'AD13', 'AG28', 'F8', 'M25', 'R41', 'V23', 'A3', 'AD15', 'AH13', 'G15', 'M30', 'T12', 'V25', 'AD17', 'A33', 'AH17', 'G25', 'M40', 'T13', 'B20', 'V27', 'A38', 'AD19', 'AH19', 'G35', 'N12', 'T16', 'V29', 'A8', 'AD21', 'AH21', 'G5', 'N17', 'T17', 'W12', 'AA12', 'AD23', 'AH23', 'H12', 'N2', 'T18', 'W14', 'AA14', 'AD25', 'AH25', 'H2', 'N27', 'T19', 'W16', 'AA16', 'AD27', 'AH27', 'H22', 'N32', 'T20', 'W18', 'AA18', 'AD29', 'AJ24', 'H32', 'N37', 'T21', 'T23', 'W20', 'AA20', 'AE12', 'B10', 'H42', 'N42', 'T22', 'W22', 'AE14', 'J19']},{'label': 'uS', 'num': 19, 'pin_nums': ['AM25', 'U21', 'W9', 'AB24', 'AE11', 'AH12', 'AM30', 'AV32', 'U23', 'Y1', 'AE13', 'AB26', 'AH18', 'AM40', 'AV42', 'U25', 'Y11', 'AB28', 'AE15', 'AH2', 'AN12', 'AW19', 'U27', 'Y12', 'AB30', 'AE17', 'AH20', 'AN17', 'AW29', 'U29', 'Y14', 'AB40', 'AE19', 'AH22', 'AN2', 'AW39', 'U35', 'Y16', 'AC13', 'AE21', 'AH24', 'AN22', 'AW9', 'U5', 'Y18', 'AC15', 'AE23', 'AH26', 'AN27', 'AY1', 'V12', 'Y20', 'AC17', 'AE25', 'AH32', 'AN32', 'AE1', 'AY16', 'V14', 'Y24', 'AC19', 'AE27', 'AH42', 'AN37', 'AY26', 'V16', 'Y26', 'AC2', 'AE29', 'AJ14', 'AN42', 'AY36', 'V18', 'Y28', 'AC23', 'AE31', 'AJ19', 'AN7', 'AY41', 'V2', 'Y30', 'AC25', 'AE41', 'AJ29', 'AP14', 'AY6', 'V20', 'Y36', 'AC27', 'AF16', 'AJ39', 'AP24', 'BA13', 'V22', 'Y6', 'AC29', 'AF18', 'AJ9', 'AP29', 'BA23', 'V24', 'AC31', 'AF20', 'AK1', 'AP34', 'BA3', 'V26', 'AA13', 'AC32', 'AF22', 'AK11', 'AP4', 'BA33', 'V28', 'AA15', 'AC37', 'AF24', 'AK16', 'AR1', 'BA38', 'V30', 'AA17', 'AC42', 'AF26', 'AK21', 'AR11', 'BB10', 'V32', 'AA19', 'AC7', 'AF28', 'AK26', 'AR21', 'BB15', 'V42', 'AA23', 'AD12', 'AF33', 'AK31', 'AR31', 'BB20', 'W13', 'AA25', 'AD14', 'AF38', 'AK36', 'AR41', 'BB25', 'W15', 'AA27', 'AD16', 'AF8', 'AK41', 'AT18', 'BB30', 'W17', 'AA29', 'AD18', 'AG13', 'AK6', 'AT28', 'BB35', 'W19', 'AA3', 'AG15', 'AD20', 'AL13', 'AT38', 'BB40', 'W21', 'AA31', 'AD22', 'AG17', 'AL18', 'AT8', 'BB5', 'W23', 'AA33', 'AD24', 'AG19', 'AL23', 'AU15', 'T38', 'W25', 'AB10', 'AD26', 'AG21', 'AL3', 'AU25', 'U10', 'W27', 'AB12', 'AD28', 'AG23', 'AL33', 'AU35', 'U13', 'W29', 'AB14', 'AD30', 'AG25', 'AM10', 'AU5', 'U15', 'W31', 'AB16', 'AD34', 'AG27', 'AM15', 'AV12', 'AV22', 'U17', 'W34', 'AB18', 'AD4', 'AG35', 'AM20', 'AV2', 'U19', 'W39', 'AB20', 'AG5']}] }),
        Part(**{ 'name':'XC5VLX110-FF676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX110-FF676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX110-FF676\n\nFPGA', 'pins':[
            Pin(num='C10',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='F22',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC26',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F7',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G24',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='J24',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K25',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M23',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='M24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='N24',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N26',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V26',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA2',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C20',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='C21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E3',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='T2',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='W1',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='Y1',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A12',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A2',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A7',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA19',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA20',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA22',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA23',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA24',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB19',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB20',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB24',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC19',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B12',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C12',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C13',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D3',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='R20',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='R21',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T19',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T20',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T21',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='T22',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T23',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U19',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U20',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U21',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U22',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V19',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V21',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V22',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W20',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W21',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W22',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y20',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y21',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y23',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA3',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AA7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA8',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA9',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB14',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB15',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AB4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC3',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC6',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AD3',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD4',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AE3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T4',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T5',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T7',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U4',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U7',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V3',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V4',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W3',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y3',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB23',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AC20',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AD16',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD21',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD23',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE10',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE15',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE18',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE20',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AE25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE7',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF12',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF13',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF14',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF17',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF18',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF19',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF20',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF22',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF8',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D13',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D14',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D15',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E10',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E11',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E12',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E13',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E14',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E16',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E17',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E18',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F12',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F14',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F17',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F18',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F19',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F8',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AB12',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='VCCO_4',func=pin_types.PWRIN,unit=7),
            Pin(num='AC11',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC12',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC13',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC14',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC16',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC17',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC18',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD13',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD14',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD15',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD18',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD8',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='J10',name='CCLK_0',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='INIT_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='J18',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='DONE_0',func=pin_types.BIDIR,unit=8),
            Pin(num='K11',name='D_IN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='HSWAPEN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N13',name='VREFN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N14',name='VP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N18',name='CS_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P13',name='VN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P14',name='VREFP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P18',name='RDWR_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='R13',name='DXN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='R14',name='DXP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='U11',name='TCK_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V11',name='TDI_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V12',name='TMS_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V18',name='M2_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W10',name='TDO_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W11',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W12',name='VCCO_0',func=pin_types.PWRIN,unit=8),
            Pin(num='W18',name='M0_0',func=pin_types.BIDIR,unit=8),
            Pin(num='Y17',name='M1_0',func=pin_types.BIDIR,unit=8),
            Pin(num='Y9',name='VCCO_0',func=pin_types.PWRIN,unit=8),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='K18',name='VBATT_0',func=pin_types.PWRIN,unit=9),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M13',name='AVSS_0',func=pin_types.PWRIN,unit=9),
            Pin(num='M14',name='AVDD_0',func=pin_types.PWRIN,unit=9),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W16',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L22', 'H22', 'J22', 'E22', 'H12', 'N22', 'G14', 'F11', 'H13', 'H23', 'J23', 'G15', 'L23', 'N23', 'F13', 'G16', 'H14', 'H25', 'K20', 'M19', 'P19', 'F15', 'G17', 'H16', 'H8', 'K21', 'M20', 'F20', 'P20', 'G19', 'F21', 'H17', 'H9', 'K22', 'M21', 'E21', 'G20', 'P21', 'F22', 'C10', 'G21', 'H18', 'J19', 'K23', 'F23', 'M22', 'P23', 'E20', 'G22', 'G10', 'H19', 'J20', 'L19', 'N19', 'R22', 'G9', 'E23', 'G11', 'H21', 'J21', 'L20', 'N21', 'H11', 'R23', 'G12']},{'label': 'uB', 'num': 2, 'pin_nums': ['M25', 'G26', 'U26', 'M26', 'G4', 'V26', 'M24', 'G5', 'M4', 'W25', 'M5', 'G6', 'W26', 'G7', 'M6', 'Y25', 'M7', 'H24', 'Y26', 'H26', 'N20', 'H4', 'N24', 'H5', 'N26', 'H6', 'N3', 'H7', 'N4', 'J2', 'N6', 'J24', 'N7', 'J25', 'P24', 'J26', 'P25', 'J4', 'P26', 'AA25', 'J5', 'P3', 'AB25', 'J6', 'P4', 'AB26', 'K25', 'P5', 'AC26', 'K26', 'P6', 'E25', 'K5', 'R24', 'E26', 'K6', 'R25', 'E5', 'K7', 'R26', 'E6', 'L24', 'R3', 'E7', 'L25', 'R5', 'F24', 'L3', 'R6', 'F25', 'L4', 'R7', 'F4', 'L5', 'T24', 'F5', 'L6', 'T25', 'F7', 'L7', 'T3', 'G24', 'M23', 'U24', 'G25', 'U25']},{'label': 'uC', 'num': 3, 'pin_nums': ['B21', 'G1', 'B22', 'G2', 'B23', 'H1', 'B24', 'H2', 'B25', 'H3', 'B26', 'J1', 'C14', 'J3', 'A14', 'C16', 'K1', 'A15', 'C17', 'K2', 'A17', 'C18', 'K3', 'A18', 'C19', 'L2', 'A19', 'C20', 'M1', 'A20', 'C21', 'M2', 'A22', 'C22', 'N1', 'A23', 'C23', 'N2', 'A24', 'C24', 'P1', 'A25', 'C26', 'R1', 'AA2', 'D16', 'R2', 'AB1', 'D18', 'R4', 'AB2', 'D19', 'T2', 'AC1', 'D20', 'U1', 'AC2', 'D21', 'U2', 'AD1', 'D23', 'V1', 'AE1', 'D24', 'V2', 'AE2', 'D25', 'V5', 'AF2', 'D26', 'W1', 'B14', 'E1', 'W2', 'B15', 'E2', 'Y1', 'B16', 'E24', 'Y2', 'B17', 'E3', 'B19', 'F2', 'B20', 'F3']},{'label': 'uD', 'num': 4, 'pin_nums': ['U19', 'A2', 'U20', 'B9', 'A3', 'C1', 'U21', 'A4', 'C11', 'U22', 'A5', 'C12', 'V19', 'A7', 'C13', 'V21', 'A8', 'C2', 'V22', 'A9', 'C3', 'V23', 'AA19', 'C4', 'V24', 'AA20', 'C6', 'V25', 'AA22', 'C7', 'W19', 'AA23', 'C8', 'W20', 'B7', 'AA24', 'C9', 'W21', 'AB19', 'D1', 'W22', 'AB20', 'D10', 'W23', 'AB21', 'D11', 'W24', 'AB22', 'D3', 'Y20', 'AB24', 'D4', 'Y21', 'AC19', 'D5', 'Y22', 'AC21', 'D6', 'Y23', 'AC22', 'D7', 'AC23', 'D8', 'AC24', 'D9', 'AD19', 'E4', 'B1', 'G8', 'B10', 'R20', 'B11', 'R21', 'B12', 'T19', 'B2', 'T20', 'B4', 'T21', 'A10', 'B5', 'T22', 'A12', 'B6', 'T23', 'A13']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA15', 'AA7', 'AB3', 'AE6', 'AD17', 'U5', 'W4', 'Y3', 'AA16', 'AB4', 'AD3', 'AF3', 'U6', 'W5', 'Y5', 'AA8', 'AB17', 'AA17', 'AA9', 'AB5', 'AD4', 'AE5', 'AF4', 'U4', 'U7', 'W6', 'W3', 'Y6', 'AA18', 'Y18', 'AB11', 'AB6', 'AD5', 'AF5', 'V3', 'Y10', 'Y7', 'AA10', 'AA3', 'AB14', 'AB7', 'AD6', 'T4', 'V4', 'Y11', 'Y8', 'AA12', 'AA4', 'AB15', 'AC3', 'AD7', 'T5', 'V6', 'Y12', 'AA13', 'AA5', 'AB16', 'AC4', 'AE3', 'T7', 'V7', 'Y13', 'AA14', 'AA6', 'AC6']},{'label': 'uF', 'num': 6, 'pin_nums': ['AD16', 'AF9', 'AE8', 'AE20', 'AF19', 'E13', 'F12', 'AD20', 'AE11', 'AE21', 'AF10', 'AF20', 'D13', 'E14', 'F14', 'AD21', 'AE12', 'AE22', 'AF12', 'AF22', 'D14', 'E15', 'F17', 'AD23', 'AE13', 'AE23', 'AF13', 'AF23', 'D15', 'E16', 'F18', 'AD24', 'AE15', 'AE24', 'AF14', 'AF24', 'D17', 'E17', 'F19', 'AD25', 'AE16', 'AE25', 'AF15', 'AF25', 'E10', 'E18', 'F8', 'AB23', 'AD26', 'AE10', 'AE17', 'AE26', 'AF17', 'AF7', 'E11', 'E8', 'F9', 'AC20', 'AD9', 'AE18', 'AE7', 'AF18', 'AF8', 'E12', 'F10']},{'label': 'uG', 'num': 7, 'pin_nums': ['AB12', 'AC16', 'AD13', 'AB13', 'AB10', 'AD14', 'AC17', 'AB9', 'AC18', 'AD15', 'AC10', 'AC7', 'AD18', 'AC11', 'AC8', 'AD8', 'AC12', 'AC9', 'AC13', 'AD10', 'AC14', 'AD11']},{'label': 'uH', 'num': 8, 'pin_nums': ['J18', 'P14', 'W10', 'K10', 'P18', 'W11', 'K11', 'R13', 'W12', 'L18', 'R14', 'W18', 'N13', 'U11', 'Y17', 'N14', 'V11', 'Y9', 'J10', 'N18', 'V12', 'J11', 'P13', 'V18']},{'label': 'uI', 'num': 9, 'pin_nums': ['AF26', 'J8', 'R16', 'M15', 'V14', 'J9', 'AF6', 'R17', 'M16', 'V15', 'B13', 'K12', 'M17', 'R19', 'J7', 'V16', 'K13', 'B18', 'M18', 'R8', 'V17', 'B3', 'K14', 'M3', 'R9', 'V20', 'B8', 'K15', 'M8', 'T1', 'V8', 'A1', 'C15', 'K16', 'M9', 'T10', 'V9', 'A11', 'C25', 'K17', 'T11', 'N10', 'W13', 'A16', 'C5', 'K18', 'N11', 'T12', 'W14', 'A21', 'D12', 'K19', 'N12', 'T13', 'W15', 'R15', 'A26', 'D2', 'K24', 'N15', 'T14', 'W16', 'A6', 'D22', 'K4', 'N16', 'T15', 'W17', 'AA1', 'E19', 'K8', 'N17', 'T16', 'W7', 'AA11', 'E9', 'K9', 'N25', 'T17', 'W8', 'AA21', 'F1', 'L1', 'N5', 'T26', 'W9', 'AA26', 'F16', 'L10', 'N8', 'T6', 'Y14', 'AB18', 'F26', 'L11', 'N9', 'T8', 'Y15', 'AB8', 'F6', 'L12', 'P10', 'T9', 'Y16', 'AC15', 'G13', 'L13', 'P11', 'U10', 'Y19', 'AC25', 'G18', 'L14', 'P12', 'U12', 'Y24', 'AC5', 'G23', 'L15', 'P15', 'U13', 'Y4', 'AD12', 'G3', 'L16', 'P16', 'U14', 'AD2', 'H10', 'L17', 'P17', 'U15', 'AD22', 'H15', 'L21', 'P2', 'U16', 'AE14', 'H20', 'L26', 'P22', 'U17', 'AE19', 'J12', 'L8', 'P7', 'U18', 'AE4', 'J13', 'L9', 'P8', 'U23', 'AE9', 'J14', 'M10', 'P9', 'U3', 'AF1', 'J15', 'M11', 'R10', 'U8', 'AF11', 'J16', 'M12', 'R11', 'U9', 'AF16', 'J17', 'M13', 'R12', 'V10', 'AF21', 'M14', 'V13']}] }),
        Part(**{ 'name':'XC5VLX110T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX110T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX110T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A15',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A16',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AH23',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AH24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ14',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ19',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ20',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ21',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ22',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK13',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK14',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK16',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK18',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK19',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK21',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK22',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK24',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL13',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL14',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL15',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL19',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL20',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL21',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN17',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='B15',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B16',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B17',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C14',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C15',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C17',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D14',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D15',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D16',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D17',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D19',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D20',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D21',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D22',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E14',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E16',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E17',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E21',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E23',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E24',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F14',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F15',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F18',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A6',name='MGTRXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A7',name='MGTRXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A8',name='MGTRXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A9',name='MGTRXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AL7',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AM7',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN10',name='MGTTXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN5',name='MGTTXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN6',name='MGTTXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN9',name='MGTTXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP6',name='MGTRXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP7',name='MGTRXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP8',name='MGTRXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP9',name='MGTRXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='B10',name='MGTTXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B5',name='MGTTXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B6',name='MGTTXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B9',name='MGTTXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='C8',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D8',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM10',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM5',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM6',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM9',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=14),
            Pin(num='C10',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C5',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C6',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C9',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=14),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=14),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=16),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=17)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D34', 'G33', 'L16', 'K21', 'N33', 'T27', 'E32', 'H12', 'E33', 'J22', 'K22', 'L20', 'N34', 'T33', 'E34', 'H22', 'J32', 'K23', 'L21', 'P32', 'T34', 'B32', 'F33', 'H23', 'J34', 'K32', 'L33', 'P34', 'F34', 'U31', 'B33', 'C32', 'H32', 'G14', 'K12', 'K33', 'L34', 'R30', 'U32', 'C33', 'G22', 'H33', 'K13', 'K34', 'M32', 'R32', 'U33', 'C34', 'A33', 'G23', 'H34', 'J15', 'K14', 'L14', 'M33', 'D13', 'R33', 'V31', 'G32', 'J12', 'D32', 'K16', 'L15', 'N32', 'R34']},{'label': 'uB', 'num': 2, 'pin_nums': ['N7', 'AK34', 'AL33', 'N8', 'AL34', 'P10', 'P5', 'AM32', 'AM33', 'P6', 'P7', 'AN32', 'AN33', 'P9', 'AA32', 'AN34', 'R11', 'AA33', 'AP32', 'R6', 'AA34', 'E6', 'R7', 'AB29', 'E7', 'R8', 'AB32', 'F5', 'R9', 'AB33', 'F6', 'T10', 'AC32', 'G5', 'T11', 'AC33', 'G6', 'T6', 'AC34', 'T7', 'G7', 'AD32', 'H5', 'T8', 'AD34', 'H7', 'T9', 'AE32', 'J5', 'U10', 'AE33', 'J6', 'U7', 'AE34', 'J7', 'V32', 'AF33', 'K6', 'V33', 'AF34', 'K7', 'V34', 'AG32', 'W28', 'L4', 'AG33', 'L5', 'W32', 'AH32', 'L6', 'W34', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6']},{'label': 'uC', 'num': 3, 'pin_nums': ['J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'K29', 'V25', 'AC30', 'K31', 'V27', 'AD29', 'L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'AD33', 'L32', 'W24', 'AE29', 'M29', 'W25', 'AE30', 'M30', 'W26', 'AE31', 'M31', 'W27', 'AF29', 'N29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'P33', 'Y28', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'T30', 'F31', 'G30', 'T31', 'G31', 'U25', 'AA29', 'AA31', 'H29', 'U26', 'AA30', 'H30', 'U27']},{'label': 'uD', 'num': 4, 'pin_nums': ['W10', 'AD6', 'W11', 'J25', 'AD7', 'J26', 'W6', 'AE6', 'J27', 'W7', 'J24', 'AE7', 'J28', 'W8', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AG7', 'L24', 'Y8', 'AH5', 'L25', 'Y9', 'AH7', 'L26', 'AJ6', 'L28', 'AJ7', 'M25', 'AK6', 'M26', 'AK7', 'M27', 'E26', 'M28', 'E27', 'N24', 'E28', 'N25', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5']},{'label': 'uE', 'num': 5, 'pin_nums': ['AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AE16', 'AF15', 'E10', 'F13', 'H10', 'K11', 'M8', 'AM19', 'D11', 'AE17', 'AF16', 'B12', 'E11', 'F8', 'G13', 'H11', 'J8', 'K8', 'N10', 'L9', 'A13', 'AE19', 'AF20', 'B13', 'E12', 'F9', 'H8', 'K9', 'N9', 'AD19', 'AE21', 'AF21', 'C12', 'E13', 'G10', 'H9', 'L10', 'AD20', 'AE22', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'F10']},{'label': 'uF', 'num': 6, 'pin_nums': ['AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AH28', 'AD25', 'AH8', 'AD26', 'AH9', 'AD27', 'AJ10', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AE24', 'AJ26', 'AE26', 'AJ27', 'AE27', 'AJ28', 'AE28', 'AJ29', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AC9', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14']},{'label': 'uG', 'num': 7, 'pin_nums': ['AM28', 'B26', 'AM30', 'B27', 'AM31', 'B28', 'AN18', 'A18', 'B30', 'A19', 'AN19', 'B31', 'AN20', 'A20', 'C18', 'A21', 'AN22', 'C19', 'A23', 'AN23', 'C20', 'A24', 'AN24', 'C22', 'A25', 'AN25', 'C23', 'A26', 'AN26', 'C24', 'A28', 'AN27', 'C25', 'A29', 'AN28', 'C26', 'A30', 'AN29', 'C27', 'A31', 'AN30', 'C28', 'AK25', 'AP19', 'C29', 'AL22', 'AP20', 'C30', 'AL24', 'AP21', 'D25', 'AL25', 'AP22', 'D26', 'AL26', 'AP24', 'D27', 'AL28', 'AP25', 'D29', 'AL29', 'AP26', 'D30', 'AM27', 'AL30', 'AP27', 'D31', 'AP29', 'AL31', 'F27', 'AM18', 'AP30', 'G24', 'AM20', 'AP31', 'AM21', 'B18', 'AM22', 'B20', 'AM23', 'B21', 'B22', 'AM25', 'AM26', 'B23', 'B25']},{'label': 'uH', 'num': 8, 'pin_nums': ['D23', 'H18', 'AG16', 'AH14', 'J21', 'AG17', 'AH15', 'E20', 'H19', 'K17', 'AE18', 'AG18', 'AH17', 'G15', 'H20', 'K18', 'AF18', 'AG20', 'AH18', 'G16', 'J14', 'K19', 'AF19', 'AG21', 'AH19', 'H13', 'J16', 'L18', 'AG13', 'AG22', 'AH20', 'H14', 'J17', 'L19', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20']},{'label': 'uI', 'num': 9, 'pin_nums': ['AK22', 'AK23', 'D19', 'AK24', 'D20', 'AL13', 'D21', 'AL14', 'D22', 'AL15', 'D24', 'AL16', 'E14', 'A14', 'AL18', 'E16', 'A15', 'AL19', 'E17', 'A16', 'AL20', 'E18', 'AH23', 'AL21', 'E19', 'AH24', 'AL23', 'E21', 'AJ12', 'AM15', 'E22', 'AJ14', 'AM16', 'E23', 'AJ15', 'AM17', 'E24', 'AJ16', 'AN15', 'F14', 'AN16', 'AJ17', 'F15', 'AJ18', 'AN17', 'F16', 'AJ19', 'AP15', 'F17', 'AJ20', 'AP16', 'F18', 'AJ21', 'AP17', 'F19', 'AJ22', 'B15', 'F20', 'AJ24', 'B16', 'F21', 'AK12', 'B17', 'F23', 'B19', 'AK13', 'F24', 'AK14', 'C14', 'G17', 'AK15', 'C15', 'G18', 'AK16', 'C16', 'G20', 'AK17', 'C17', 'G21', 'AK18', 'D14', 'AK19', 'D15', 'AK21', 'D16', 'D17']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AC2', 'T1', 'Y4', 'M2', 'T2', 'N1', 'U2', 'N2', 'V2', 'P1', 'W1', 'AA1', 'P3', 'W2', 'AB1', 'P4', 'Y1', 'AB2', 'R1', 'Y3']},{'label': 'uK', 'num': 11, 'pin_nums': ['AH1', 'H4', 'AD2', 'AH2', 'J1', 'AE1', 'AJ2', 'K1', 'AE2', 'F2', 'K2', 'AF1', 'G1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3']},{'label': 'uL', 'num': 12, 'pin_nums': ['AP3', 'AL1', 'E4', 'B3', 'AL2', 'AL4', 'B4', 'AL5', 'C1', 'AM1', 'D1', 'AK2', 'AP2', 'A2', 'AN3', 'D2', 'A3', 'AN4', 'D4', 'E2']},{'label': 'uM', 'num': 13, 'pin_nums': ['AN10', 'B10', 'B5', 'AN5', 'A6', 'AN6', 'B6', 'A7', 'AN9', 'B9', 'A8', 'AP6', 'C8', 'A9', 'AP7', 'D8', 'AL7', 'AP8', 'AM7', 'AP9']},{'label': 'uN', 'num': 14, 'pin_nums': ['C5', 'AB3', 'AJ4', 'F3', 'AM5', 'C6', 'F4', 'R3', 'W3', 'AC3', 'AK3', 'C7', 'G3', 'R4', 'AM6', 'AD3', 'AK5', 'AM8', 'C9', 'J3', 'T3', 'AE3', 'AL3', 'AM9', 'D3', 'J4', 'U3', 'AG3', 'AL8', 'C10', 'D5', 'K3', 'V3', 'AG4', 'AM10', 'C3', 'D7', 'L3', 'V4', 'AA3', 'AH3', 'AM3', 'C4', 'E3', 'M3', 'V5', 'AA4', 'AJ3', 'AM4', 'N3']},{'label': 'uO', 'num': 15, 'pin_nums': ['N23', 'AA22', 'AD22', 'AB15', 'P15', 'AD23', 'AD21', 'AC14', 'M15', 'U17', 'W18', 'AC15', 'M22', 'U18', 'AC22', 'M23', 'V17', 'AD14', 'N14', 'V18', 'AD15', 'N15', 'W17', 'N22']},{'label': 'uP', 'num': 16, 'pin_nums': ['D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'P14', 'L22', 'Y23', 'T16', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'T20', 'AB17', 'F32', 'M12', 'P2', 'T21', 'AB19', 'F7', 'P20', 'M13', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'G29', 'M16', 'P22', 'T4', 'AC16', 'G34', 'M17', 'P23', 'T5', 'AC18', 'G4', 'M18', 'P28', 'U12', 'AC20', 'G9', 'M19', 'P8', 'U14', 'AD13', 'H16', 'M20', 'R10', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'R15', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'R17', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'P12', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'AA14', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'T14', 'Y19']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AE15', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'AE25', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AA19', 'AE5', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'AN11', 'W19', 'AA23', 'AF2', 'AN2', 'W21', 'AA27', 'AF22', 'AN21', 'W23', 'AA7', 'AF27', 'AN31', 'W33', 'AB12', 'AF32', 'AN7', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14', 'AB22', 'AG34', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AD28', 'AK30', 'U6', 'AD18', 'AK4', 'U9']}] }),
        Part(**{ 'name':'XC5VLX110T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX110T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX110T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='C32',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP9',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AU10',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AV7',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=12),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=12),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=14),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=15),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=16),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=17),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=18),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AW16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=18),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=18),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='D15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=18),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=18),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=18),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=20),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=21)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['J14', 'M41', 'N28', 'R42', 'P25', 'AA39', 'V41', 'Y41', 'J41', 'M42', 'N29', 'P26', 'T40', 'W40', 'AA40', 'Y42', 'J42', 'AA41', 'K42', 'N13', 'N30', 'P27', 'T41', 'W41', 'AA42', 'L40', 'N14', 'N40', 'P28', 'T42', 'W42', 'AA38', 'F13', 'L41', 'AA37', 'N15', 'N41', 'P40', 'U41', 'F41', 'L42', 'Y37', 'F42', 'M13', 'N16', 'P13', 'P41', 'U42', 'Y38', 'G41', 'H41', 'M14', 'N25', 'N26', 'P17', 'P42', 'G42', 'P18', 'V37', 'Y39', 'M16', 'R40', 'V40', 'Y40', 'M29']},{'label': 'uB', 'num': 2, 'pin_nums': ['AL42', 'AM41', 'AB35', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'AR42', 'V8', 'AC38', 'AT41', 'W10', 'AC39', 'AT42', 'W11', 'AC40', 'AU41', 'W5', 'AC41', 'AU42', 'W6', 'AD39', 'AV41', 'W7', 'AD40', 'G6', 'W8', 'AD41', 'H5', 'Y10', 'AD42', 'H6', 'Y7', 'AE36', 'J5', 'Y8', 'AE40', 'J6', 'Y9', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AA6', 'AK42', 'T5', 'AA7', 'AL40', 'T6', 'U10', 'AA8', 'AL41', 'T7', 'AA9']},{'label': 'uC', 'num': 3, 'pin_nums': ['AF37', 'V39', 'E40', 'AF39', 'W35', 'F39', 'AG37', 'F40', 'W36', 'AG38', 'W37', 'G38', 'AG39', 'G39', 'W38', 'AG40', 'Y34', 'H38', 'AH37', 'H39', 'Y35', 'AH38', 'H40', 'AH39', 'J38', 'AJ37', 'J40', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'L39', 'AK41', 'M38', 'AL37', 'M39', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AE39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'E39', 'V38']},{'label': 'uD', 'num': 4, 'pin_nums': ['J37', 'AF11', 'K35', 'K37', 'AF12', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'AG10', 'L38', 'AA32', 'AG4', 'M36', 'AB11', 'AG6', 'M37', 'AB6', 'AG7', 'N35', 'AB7', 'AH4', 'N36', 'AB8', 'AH5', 'P35', 'AB9', 'AH6', 'P36', 'AC10', 'AJ5', 'R34', 'AC5', 'AJ6', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'AD5', 'E37', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'AE7', 'H36', 'Y33', 'AE8', 'AF10', 'J35', 'AE9', 'J36']},{'label': 'uE', 'num': 5, 'pin_nums': ['H8', 'AK12', 'E9', 'AN14', 'AL14', 'L8', 'P8', 'T9', 'AK30', 'AN13', 'H9', 'L9', 'P9', 'AK13', 'AL29', 'E8', 'AP13', 'F5', 'L7', 'U11', 'P7', 'AK14', 'AL30', 'AR26', 'F6', 'J7', 'M7', 'R6', 'T11', 'U8', 'AK15', 'AM13', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AM14', 'AK27', 'D7', 'F9', 'K7', 'M9', 'R8', 'V10', 'AK28', 'AM28', 'E5', 'G7', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'AM29', 'AK29', 'E7', 'G8', 'K9', 'N9', 'T10', 'V9', 'AJ30', 'G9']},{'label': 'uF', 'num': 6, 'pin_nums': ['AB32', 'AP35', 'K32', 'AP36', 'AB33', 'K33', 'AC33', 'AP37', 'K34', 'AR37', 'AD32', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AT37', 'M31', 'AE34', 'AU37', 'M32', 'AE35', 'AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AN36', 'AG36', 'E33', 'P31', 'AH34', 'E34', 'P32', 'AH35', 'E35', 'P33', 'AH36', 'E36', 'R32', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'G33', 'AL35', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'J33']},{'label': 'uG', 'num': 7, 'pin_nums': ['AJ33', 'K13', 'AK32', 'K14', 'AV36', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31', 'E15', 'N11', 'AN33', 'E6', 'P10', 'AP31', 'F10', 'P11', 'AP32', 'F11', 'P12', 'AP33', 'F12', 'R10', 'AP39', 'F14', 'AR32', 'F15', 'AR33', 'G10', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'AV35', 'K10', 'AJ32', 'AV34', 'K12']},{'label': 'uH', 'num': 8, 'pin_nums': ['AG9', 'AJ8', 'AR7', 'AL8', 'AN6', 'B35', 'AH10', 'AK10', 'AJ11', 'AR8', 'AL9', 'AN8', 'AL7', 'F33', 'AH11', 'AK11', 'AM6', 'AN9', 'AT5', 'J34', 'AN5', 'AH7', 'AK8', 'AM7', 'AP5', 'AT6', 'AV6', 'AH8', 'AK9', 'AM8', 'AP6', 'AT7', 'AH9', 'AG11', 'AL10', 'AM9', 'AP7', 'AU6', 'AG12', 'AJ10', 'AL6', 'AN4', 'AP8', 'AV5', 'AG8', 'AR5']},{'label': 'uI', 'num': 9, 'pin_nums': ['H27', 'K29', 'L30', 'K30', 'J15', 'M17', 'J16', 'L14', 'M26', 'J17', 'L15', 'M27', 'AT33', 'J30', 'L16', 'M28', 'AV37', 'K15', 'L17', 'AW34', 'K17', 'L27', 'E26', 'K28', 'L29']},{'label': 'uJ', 'num': 10, 'pin_nums': ['C32', 'G30', 'AY31', 'BA28', 'AU30', 'D29']},{'label': 'uK', 'num': 11, 'pin_nums': ['AR16', 'AL27', 'AN29', 'AN28', 'AM16', 'AT13', 'AN30', 'AM17', 'AP15', 'AU10', 'AK17', 'AM26', 'AV7', 'AP16', 'AL15', 'AM27', 'AP27', 'AL16', 'AN15', 'AP28', 'AL17', 'AN16', 'AP30', 'AL26', 'AP9']},{'label': 'uL', 'num': 12, 'pin_nums': ['AN19', 'L20', 'AN20', 'C22', 'L24', 'AN24', 'E17', 'L25', 'AN25', 'E18', 'L26', 'AN26', 'F16', 'M18', 'AP17', 'F17', 'M19', 'AP18', 'F23', 'M24', 'AP25', 'F27', 'N18', 'AP26', 'F29', 'N19', 'AR14', 'G16', 'N20', 'AR15', 'G17', 'P20', 'AR17', 'G18', 'AR18', 'G27', 'AR19', 'G28', 'AR27', 'G29', 'AR28', 'H16', 'AR29', 'H18', 'AR30', 'H26', 'AT14', 'H28', 'AT15', 'H29', 'AT16', 'H30', 'AK18', 'AT17', 'J18', 'AK19', 'AT19', 'J25', 'AK24', 'AT23', 'J26', 'AK25', 'AT26', 'J27', 'AL19', 'AT27', 'J28', 'AL24', 'AT29', 'K18', 'AL25', 'AT30', 'K19', 'AM18', 'AU28', 'K24', 'AM19', 'AU29', 'K25', 'AM24', 'AW24', 'B25', 'K27', 'AN18', 'AY21', 'L19']},{'label': 'uM', 'num': 13, 'pin_nums': ['AP19', 'AV17', 'G20', 'D19', 'AU20', 'H17']},{'label': 'uN', 'num': 14, 'pin_nums': ['AD4', 'AE1', 'V3', 'AF1', 'AA2', 'V4', 'AB2', 'AF2', 'W1', 'AC1', 'AG2', 'Y1', 'AC2', 'T2', 'Y2', 'AD1', 'U1', 'V1', 'AD3', 'U2']},{'label': 'uO', 'num': 15, 'pin_nums': ['AJ2', 'P2', 'K2', 'L1', 'R2', 'AK1', 'AN2', 'AK3', 'L2', 'P1', 'AK4', 'M1', 'AL1', 'M3', 'AM1', 'M4', 'AH2', 'N1', 'AM2', 'AJ1']},{'label': 'uP', 'num': 16, 'pin_nums': ['AU1', 'F3', 'F4', 'AV1', 'AP2', 'AV2', 'G1', 'AW2', 'H1', 'AR1', 'AT4', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2', 'AT3', 'E2', 'F1']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A3', 'B6', 'BA1', 'A4', 'C3', 'A5', 'BA2', 'C4', 'AW4', 'BA5', 'AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3', 'BB5', 'A2', 'B5', 'BB4']},{'label': 'uR', 'num': 18, 'pin_nums': ['AC3', 'AL4', 'AE3', 'AW16', 'AM3', 'AY5', 'AY3', 'D15', 'H3', 'T3', 'C9', 'G4', 'AE4', 'AN3', 'AW3', 'AY6', 'D3', 'J3', 'R3', 'U3', 'AF3', 'AP3', 'AW5', 'C1', 'D4', 'K3', 'W3', 'AG3', 'AR3', 'AA3', 'AY1', 'C15', 'D5', 'L3', 'W4', 'AA5', 'AH3', 'AU3', 'AY10', 'C2', 'D9', 'N3', 'Y3', 'AB3', 'AJ3', 'AU4', 'AY16', 'C5', 'E3', 'N4', 'AB4', 'AL3', 'AV3', 'AY2', 'C6', 'G3', 'P3', 'AW10']},{'label': 'uS', 'num': 19, 'pin_nums': ['AH16', 'R14', 'AB22', 'R15', 'AH29', 'AC21', 'AH30', 'R29', 'AC22', 'AJ15', 'R30', 'AG29', 'AJ16', 'T14', 'AG30', 'AJ28', 'T30', 'AA21', 'AH14', 'AL28', 'AA22', 'AH15', 'P15', 'AB21']},{'label': 'uT', 'num': 20, 'pin_nums': ['U24', 'AA24', 'AH25', 'AE12', 'E41', 'L28', 'R12', 'U26', 'AA26', 'Y31', 'AH27', 'AE14', 'L33', 'F18', 'R13', 'U28', 'L23', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'M2', 'R19', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'B15', 'AE26', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'AB27', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'J9', 'P16', 'T23', 'W30', 'A19', 'AD13', 'AG20', 'D17', 'K11', 'P19', 'T25', 'Y13', 'A23', 'AD15', 'AG22', 'D24', 'K16', 'P21', 'T27', 'Y15', 'A28', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'Y17', 'A33', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'Y19', 'A38', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'AH23', 'U14', 'Y21', 'AA12', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'U16', 'Y22', 'AA14', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'Y23', 'AA16', 'AD27', 'AH19', 'E21', 'L13', 'P34', 'U20', 'Y25', 'AA18', 'AD29', 'Y29', 'AH21', 'E31', 'L18', 'P4', 'U22', 'Y27', 'AA20', 'AD31', 'E4', 'R11']},{'label': 'uU', 'num': 21, 'pin_nums': ['AV42', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AJ17', 'AF16', 'AN27', 'AW14', 'T28', 'W19', 'AA13', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'W2', 'AA15', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'W21', 'AA17', 'AC4', 'AF22', 'AJ25', 'AN42', 'AW29', 'T8', 'W23', 'AA19', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AA23', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'W27', 'AA25', 'AD12', 'AJ39', 'AF28', 'AP24', 'AW8', 'U17', 'W29', 'AA27', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AF8', 'AK2', 'AR11', 'BA10', 'U25', 'W9', 'AB10', 'AD20', 'AG13', 'AK21', 'AC27', 'AR21', 'BA15', 'U27', 'Y11', 'AB12', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'Y12', 'AB14', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'Y14', 'AB16', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'Y16', 'AB18', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'Y18', 'AB20', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'AJ13', 'V12', 'Y20', 'AB24', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'V14', 'Y24', 'AB26', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'Y26', 'AB28', 'AE13', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'Y28', 'AB30', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'Y30', 'AB40', 'AE17', 'AH12', 'AM10', 'AU15', 'BB30', 'V20', 'Y36', 'AB5', 'AE19', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'Y4', 'AC11', 'AE2', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'Y6', 'AC13', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AE29', 'AH32', 'AM5', 'AV32', 'T20', 'T24', 'V42', 'AC25', 'AE31', 'AH42', 'AN12', 'AV4', 'T22', 'W13', 'AE41', 'AN17']}] }),
        Part(**{ 'name':'XC5VLX155-FF1153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX155-FF1153'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX155-FF1153\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P33',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V32',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AC2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AD1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF1',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF3',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG2',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH2',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL3',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN3',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H31',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H5',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K5',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L6',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P4',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R11',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T10',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T9',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA4',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC5',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AD4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG5',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ4',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ5',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='B29',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F27',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V8',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W7',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y9',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC15',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC20',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD19',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE19',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AG23',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AL22',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E7',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E9',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F7',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='F8',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G4',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G8',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H7',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H8',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K8',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L11',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M11',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AA10',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA11',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA8',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA9',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB10',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB11',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB8',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD7',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD9',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE11',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE7',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF8',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG10',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH7',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ10',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ6',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ9',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AK6',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AN6',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='A10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A11',name='IO_L7P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A13',name='IO_L3N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L0N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A15',name='IO_L0P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A16',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='A4',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A5',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A6',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A8',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='A9',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B10',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B11',name='IO_L7N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B12',name='IO_L5P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B13',name='IO_L3P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B15',name='IO_L2P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B16',name='IO_L4P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B17',name='IO_L6P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='B5',name='IO_L14P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B6',name='IO_L13P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B7',name='IO_L13N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B8',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='B9',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='C10',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C12',name='IO_L5N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C13',name='IO_L1N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C14',name='IO_L1P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C15',name='IO_L2N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C17',name='IO_L6N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='C4',name='IO_L16P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C5',name='IO_L16N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C6',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='C7',name='IO_L15N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C8',name='IO_L15P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='C9',name='IO_L17N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D10',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D11',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D23',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='IO_L18N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D5',name='IO_L18P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D6',name='IO_L19P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D7',name='IO_L19N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='D9',name='IO_L17P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E10',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='AF27',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AG24',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AH11',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AL10',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL12',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL4',name='IO_L2N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL5',name='IO_L0P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL6',name='IO_L0N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL8',name='IO_L4P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL9',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM10',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM11',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM12',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM13',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L17P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L17N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L13N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM5',name='IO_L2P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM6',name='IO_L5N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM7',name='IO_L6N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM8',name='IO_L6P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM9',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AN10',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN12',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN13',name='IO_L14P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN14',name='IO_L18N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L19N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN17',name='IO_L13P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN4',name='IO_L1N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN5',name='IO_L1P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN7',name='IO_L5P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN8',name='IO_L7N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN9',name='IO_L7P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP10',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP11',name='IO_L16P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP12',name='IO_L16N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP14',name='IO_L18P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L19P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L15P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L15N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP4',name='IO_L3N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP5',name='IO_L3P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP6',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP7',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP9',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AE18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF17',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AF18',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF19',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF20',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF21',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG13',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG20',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH12',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH19',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AK15',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AK19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='F20',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G20',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G21',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G22',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H12',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H13',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H15',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H18',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H19',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H20',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H21',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='H22',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H23',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J14',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J15',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J16',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J17',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J20',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J21',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='AG18',name='IO_L14P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH13',name='IO_L1N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH14',name='IO_L1P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH15',name='IO_L3N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH17',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH22',name='IO_L0P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH23',name='IO_L0N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AH24',name='IO_L2P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ11',name='IO_L5P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ12',name='IO_L5N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ14',name='IO_L3P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ15',name='IO_L7N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ17',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AJ20',name='IO_L6P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ21',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ22',name='IO_L4P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ24',name='IO_L2N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK11',name='IO_L18P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK12',name='IO_L16N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK13',name='IO_L16P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK14',name='IO_L7P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK21',name='IO_L6N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK22',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK23',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AK24',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL11',name='IO_L18N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL13',name='IO_L19P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL14',name='IO_L19N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L17P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L17N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL18',name='IO_L15P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL19',name='IO_L15N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL20',name='IO_L13P_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL21',name='IO_L13N_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AL23',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=11),
            Pin(num='AM19',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='IO_L1P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D14',name='IO_L0N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D15',name='IO_L0P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D16',name='IO_L2P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D17',name='IO_L2N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D19',name='IO_L6P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D21',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D22',name='IO_L13P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E11',name='IO_L1N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E12',name='IO_L3P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E13',name='IO_L3N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E14',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E16',name='IO_L7P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E17',name='IO_L5N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E18',name='IO_L5P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E19',name='IO_L6N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E23',name='IO_L13N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='E24',name='IO_L17N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F11',name='IO_L18N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F13',name='IO_L16N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F14',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F15',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F16',name='IO_L7N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='F18',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F19',name='IO_L4P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G11',name='IO_L18P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G12',name='IO_L16P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G15',name='IO_L14P_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G16',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G17',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='G23',name='IO_L19N_5',func=pin_types.BIDIR,unit=11),
            Pin(num='H17',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=11),
            Pin(num='AA13',name='TCK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AB13',name='TMS_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC13',name='TDI_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC14',name='TDO_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD13',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='AD14',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AG14',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='L13',name='INIT_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M13',name='CCLK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M23',name='CS_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N13',name='D_IN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N14',name='DONE_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N22',name='HSWAPEN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P22',name='VBATT_0',func=pin_types.PWRIN,unit=13),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='T27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=14)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['J34', 'B33', 'L19', 'K22', 'G14', 'N32', 'K12', 'R33', 'C33', 'G32', 'L20', 'N33', 'R34', 'K13', 'K23', 'C34', 'G33', 'K14', 'K32', 'L21', 'N34', 'T33', 'D13', 'H32', 'K16', 'H33', 'D32', 'K33', 'L23', 'P32', 'T34', 'A33', 'D34', 'H34', 'K17', 'B32', 'K34', 'L33', 'P33', 'E32', 'U31', 'J12', 'K18', 'E33', 'L14', 'L34', 'P34', 'J19', 'U32', 'L16', 'E34', 'K19', 'J22', 'L15', 'M32', 'R30', 'R32', 'U33', 'V31', 'C32', 'F33', 'J32', 'K21', 'M33', 'F34']},{'label': 'uB', 'num': 2, 'pin_nums': ['N3', 'A3', 'AN33', 'P1', 'AA32', 'AN34', 'P2', 'AA33', 'AP32', 'R1', 'AA34', 'B1', 'R2', 'AB29', 'B2', 'R3', 'AB32', 'B3', 'T1', 'AB33', 'C2', 'T3', 'AC32', 'C3', 'T7', 'AC33', 'D1', 'U1', 'AC34', 'D2', 'U2', 'AD32', 'E1', 'U3', 'AD34', 'E2', 'U4', 'AE32', 'E3', 'V32', 'AE33', 'F1', 'V33', 'AE34', 'F3', 'V34', 'AF33', 'G1', 'W28', 'AF34', 'G2', 'W32', 'AG32', 'G3', 'W34', 'AG33', 'H2', 'W8', 'AH32', 'H3', 'Y32', 'AH33', 'J1', 'Y33', 'AH34', 'J2', 'Y34', 'AJ32', 'K1', 'AJ34', 'K2', 'AK32', 'K3', 'AK33', 'L1', 'AK34', 'L3', 'AL33', 'M1', 'AL34', 'M2', 'AM32', 'M3', 'AM33', 'N2', 'AN32']},{'label': 'uC', 'num': 3, 'pin_nums': ['AD1', 'H29', 'U26', 'H30', 'AD2', 'U27', 'AE1', 'H31', 'U28', 'J29', 'AE2', 'U30', 'AE3', 'J30', 'V2', 'AF1', 'J31', 'V3', 'AF3', 'K29', 'V4', 'AG1', 'K31', 'W1', 'AG2', 'L29', 'W2', 'AG3', 'L30', 'Y1', 'AH2', 'L31', 'Y2', 'AH3', 'L32', 'Y3', 'AJ1', 'M29', 'Y5', 'AJ2', 'M30', 'AK1', 'M31', 'AK2', 'N29', 'AK3', 'N30', 'G31', 'AL1', 'P29', 'AL3', 'P30', 'AM1', 'P31', 'AM2', 'R26', 'AM3', 'R27', 'AN2', 'R28', 'AA1', 'AN3', 'R29', 'AA3', 'AP2', 'R31', 'AB1', 'E29', 'T25', 'AB2', 'T26', 'E31', 'AB3', 'F29', 'T28', 'AB9', 'F30', 'T29', 'AC2', 'F31', 'T30', 'AC3', 'G30', 'T31', 'AC6', 'U25']},{'label': 'uD', 'num': 4, 'pin_nums': ['AG31', 'Y27', 'AH29', 'R6', 'Y28', 'AH30', 'R7', 'Y29', 'AH31', 'R8', 'Y31', 'AJ30', 'R9', 'AJ31', 'T10', 'AK31', 'T11', 'E4', 'T4', 'F4', 'T5', 'F5', 'T6', 'G5', 'T8', 'H4', 'T9', 'H5', 'U10', 'J4', 'U11', 'AA29', 'J5', 'U5', 'AA30', 'J6', 'U6', 'AA31', 'K4', 'U7', 'AB30', 'K5', 'U8', 'AB31', 'K6', 'V24', 'AC29', 'L4', 'V25', 'AC30', 'L5', 'V27', 'AD29', 'L6', 'V28', 'AD30', 'M5', 'V29', 'AD31', 'M6', 'V30', 'AD33', 'N4', 'W24', 'AE29', 'N5', 'W25', 'AE30', 'N6', 'W26', 'AE31', 'P3', 'W27', 'AF29', 'P4', 'W29', 'AF30', 'P5', 'W30', 'AF31', 'P6', 'R4', 'W31', 'AG30', 'R11', 'Y26']},{'label': 'uE', 'num': 5, 'pin_nums': ['N27', 'E28', 'E30', 'N28', 'F25', 'P24', 'P25', 'F26', 'AA4', 'F27', 'P26', 'AA5', 'P27', 'F28', 'AA6', 'G25', 'R24', 'AB5', 'G26', 'T24', 'AB6', 'G27', 'V10', 'AC4', 'G28', 'V5', 'AC5', 'H24', 'V7', 'AD3', 'H25', 'V8', 'AD4', 'H27', 'V9', 'AD5', 'H28', 'W10', 'AD6', 'J24', 'W11', 'AE4', 'J25', 'W4', 'AE6', 'J26', 'W5', 'AF4', 'J27', 'W6', 'AF5', 'K24', 'W7', 'AF6', 'K26', 'W9', 'AF7', 'K27', 'Y11', 'AG4', 'K28', 'Y4', 'AG5', 'L24', 'Y6', 'AG6', 'L25', 'Y7', 'AH4', 'L26', 'Y8', 'AH5', 'L28', 'Y9', 'AJ4', 'M25', 'AJ5', 'M26', 'AK4', 'M27', 'B29', 'M28', 'E26', 'N24', 'E27', 'N25']},{'label': 'uF', 'num': 6, 'pin_nums': ['AD19', 'AE21', 'F8', 'AL22', 'H7', 'K11', 'M10', 'P10', 'E6', 'F9', 'H8', 'K7', 'M11', 'AE22', 'P11', 'AD20', 'AE12', 'AE23', 'E7', 'G10', 'H9', 'K8', 'M7', 'P7', 'AC15', 'AF15', 'AE13', 'E8', 'G4', 'J10', 'K9', 'M8', 'P9', 'AE19', 'AC19', 'AE14', 'AF16', 'E9', 'F7', 'G6', 'H10', 'J11', 'L10', 'J9', 'N10', 'AC20', 'L9', 'AE16', 'AF23', 'F10', 'G7', 'J7', 'L11', 'N7', 'N9', 'AD15', 'AE17', 'AG23', 'F6', 'G8', 'J8', 'L8', 'N8', 'AD16', 'AH21']},{'label': 'uG', 'num': 7, 'pin_nums': ['AE27', 'AE28', 'AA26', 'AJ29', 'AA28', 'AE7', 'AJ6', 'AA8', 'AE8', 'AJ7', 'AA9', 'AE9', 'AJ8', 'AB10', 'AF10', 'AJ9', 'AB11', 'AF11', 'AK26', 'AB25', 'AF24', 'AK27', 'AB26', 'AF25', 'AK28', 'AB27', 'AF26', 'AK29', 'AB28', 'AF28', 'AK5', 'AB7', 'AF8', 'AK6', 'AB8', 'AF9', 'AK7', 'AC10', 'AG10', 'AK8', 'AC24', 'AG11', 'AK9', 'AC25', 'AG25', 'AL32', 'AC27', 'AG26', 'AM29', 'AC28', 'AG27', 'AN6', 'AC7', 'AG28', 'Y24', 'AC8', 'AG7', 'AC9', 'AG8', 'AD10', 'AH10', 'AD11', 'AH25', 'AD24', 'AH27', 'AD25', 'AH28', 'AD26', 'AH7', 'AH8', 'AD27', 'AD7', 'AH9', 'AD9', 'AJ10', 'AA10', 'AE11', 'AJ25', 'AA11', 'AE24', 'AJ26', 'AJ28', 'AA24', 'AE26', 'AJ27', 'AA25']},{'label': 'uH', 'num': 8, 'pin_nums': ['A26', 'D30', 'B9', 'A28', 'D31', 'C10', 'A29', 'C12', 'D4', 'A30', 'D5', 'C13', 'A31', 'C14', 'D6', 'A4', 'D7', 'C15', 'A5', 'C17', 'D9', 'A6', 'E10', 'C18', 'A8', 'C19', 'G24', 'A9', 'C20', 'B10', 'C22', 'B11', 'C23', 'B12', 'C24', 'B13', 'C25', 'B15', 'C26', 'A25', 'B16', 'C27', 'B17', 'C28', 'B18', 'C29', 'B20', 'C30', 'A10', 'B21', 'C4', 'A11', 'B22', 'C5', 'A13', 'B23', 'C6', 'A14', 'B25', 'C7', 'B26', 'A15', 'C8', 'A16', 'B27', 'C9', 'A18', 'B28', 'D10', 'A19', 'B30', 'D11', 'A20', 'B31', 'D23', 'A21', 'B5', 'D25', 'A23', 'B6', 'D26', 'A24', 'B7', 'D27', 'B8', 'D29']},{'label': 'uI', 'num': 9, 'pin_nums': ['AN27', 'AN28', 'AM16', 'AN29', 'AM17', 'AM18', 'AN30', 'AM20', 'AN4', 'AM21', 'AN5', 'AM22', 'AN7', 'AM23', 'AN8', 'AM25', 'AN9', 'AM26', 'AP10', 'AF27', 'AM27', 'AP11', 'AG24', 'AM28', 'AP12', 'AH11', 'AM30', 'AP14', 'AK25', 'AM31', 'AP15', 'AL10', 'AM5', 'AP16', 'AL12', 'AM6', 'AP17', 'AL24', 'AM7', 'AP19', 'AL25', 'AM8', 'AP20', 'AL26', 'AM9', 'AP21', 'AL28', 'AN10', 'AP22', 'AL29', 'AN12', 'AP24', 'AL30', 'AN13', 'AP25', 'AL31', 'AN14', 'AP26', 'AL4', 'AN15', 'AP27', 'AL5', 'AN17', 'AP29', 'AL6', 'AN18', 'AP30', 'AL8', 'AN19', 'AP31', 'AL9', 'AN20', 'AP4', 'AM10', 'AN22', 'AP5', 'AM11', 'AN23', 'AP6', 'AM12', 'AM15', 'AN24', 'AP7', 'AM13', 'AN25', 'AP9']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AE18', 'AG12', 'H18', 'AH12', 'G13', 'J16', 'AH19', 'G20', 'H19', 'J17', 'AG13', 'AF13', 'J20', 'AF14', 'AG15', 'AH20', 'G21', 'H20', 'AG16', 'AF17', 'AJ19', 'G22', 'H21', 'J21', 'AF21', 'AF18', 'AG17', 'AK15', 'F20', 'H12', 'H15', 'H22', 'J15', 'AF19', 'AG20', 'AK19', 'H13', 'H23', 'AF20', 'AG21', 'E20', 'H14', 'J14', 'AG22']},{'label': 'uK', 'num': 11, 'pin_nums': ['D20', 'D21', 'AK11', 'G23', 'AK12', 'D22', 'H17', 'AK13', 'D24', 'AK14', 'E11', 'AK16', 'E12', 'AK17', 'E13', 'AK18', 'E14', 'AK21', 'E16', 'AK22', 'E17', 'AK23', 'E18', 'AK24', 'E19', 'AL11', 'E21', 'AG18', 'AL13', 'E22', 'AH13', 'AL14', 'E23', 'AH14', 'AL15', 'E24', 'AH15', 'AL16', 'F11', 'AH17', 'AL18', 'F13', 'AH18', 'AL19', 'F14', 'AH22', 'AL20', 'F15', 'AH23', 'AL21', 'F16', 'AH24', 'AL23', 'F17', 'AJ11', 'AM19', 'F18', 'AJ12', 'AN16', 'F19', 'AJ14', 'B19', 'F21', 'AJ15', 'C16', 'F23', 'AJ16', 'D12', 'F24', 'AJ17', 'D14', 'G11', 'AJ18', 'D15', 'G12', 'AJ20', 'D16', 'G15', 'AJ21', 'D17', 'G16', 'G18', 'AJ22', 'D19', 'G17', 'AJ24']},{'label': 'uL', 'num': 12, 'pin_nums': ['AC22', 'M22', 'V18', 'AD13', 'M23', 'AD14', 'N13', 'W17', 'AD21', 'N14', 'W18', 'AD22', 'N22', 'AA13', 'AB13', 'AG14', 'N23', 'AC13', 'L13', 'U17', 'AC14', 'M13', 'U18', 'V17']},{'label': 'uM', 'num': 13, 'pin_nums': ['L27', 'T2', 'Y17', 'A27', 'E25', 'L7', 'P18', 'T20', 'Y19', 'A32', 'E5', 'M12', 'P19', 'T21', 'Y21', 'A7', 'F12', 'M14', 'P20', 'T22', 'Y23', 'AA12', 'F2', 'M15', 'P21', 'T23', 'AA14', 'F22', 'M16', 'P22', 'T27', 'AA16', 'F32', 'M17', 'P23', 'T32', 'AA18', 'G19', 'M18', 'P28', 'U12', 'AA20', 'G29', 'M19', 'P8', 'U13', 'AA22', 'G34', 'M20', 'R10', 'U14', 'AB15', 'G9', 'M21', 'A22', 'R12', 'U15', 'AB17', 'H1', 'M24', 'R13', 'U16', 'AB19', 'H11', 'M34', 'R14', 'U19', 'AB21', 'H16', 'M4', 'R15', 'U20', 'AC12', 'H26', 'M9', 'R16', 'U21', 'AC16', 'H6', 'N1', 'R17', 'U22', 'AC18', 'J13', 'N11', 'R18', 'U23', 'AD17', 'J18', 'N12', 'R19', 'U24', 'AD23', 'J23', 'N15', 'R20', 'U9', 'B14', 'J28', 'N16', 'R21', 'V11', 'B24', 'J3', 'N17', 'R22', 'V13', 'B34', 'J33', 'N18', 'R23', 'V15', 'B4', 'K10', 'N19', 'R25', 'V19', 'C1', 'K15', 'N20', 'R5', 'V21', 'C11', 'K20', 'N21', 'T12', 'V23', 'C21', 'K25', 'N26', 'T13', 'W12', 'C31', 'K30', 'N31', 'T14', 'W14', 'D18', 'L12', 'P12', 'T15', 'W16', 'A1', 'D28', 'L17', 'P13', 'T16', 'W20', 'A12', 'D3', 'L18', 'P14', 'T17', 'W22', 'A17', 'D33', 'L2', 'P15', 'P17', 'T18', 'Y13', 'A2', 'D8', 'L22', 'P16', 'T19', 'Y15', 'E15']},{'label': 'uN', 'num': 14, 'pin_nums': ['Y16', 'AE15', 'Y18', 'AN11', 'AE20', 'AN21', 'Y20', 'AE25', 'AN26', 'Y22', 'AE5', 'AN31', 'Y25', 'AA15', 'AF12', 'AP13', 'Y30', 'AF2', 'AA17', 'AP18', 'AA19', 'AF22', 'AP23', 'AF32', 'AA2', 'AP28', 'AA21', 'AG19', 'AP3', 'AA23', 'AG29', 'AP33', 'AA27', 'AG34', 'AP8', 'AA7', 'AG9', 'U29', 'AB12', 'AH1', 'U34', 'AB14', 'AH16', 'V1', 'AB16', 'AH26', 'V12', 'AB18', 'AH6', 'V14', 'AB20', 'AJ13', 'V16', 'AB22', 'AJ23', 'V20', 'AB24', 'AJ3', 'V22', 'AB34', 'AJ33', 'V26', 'AB4', 'AK10', 'V6', 'AC1', 'AK20', 'W13', 'AC11', 'AK30', 'W15', 'AL17', 'AC17', 'W19', 'AC21', 'AL2', 'W21', 'AC26', 'AL27', 'W23', 'AE10', 'AC31', 'AL7', 'W3', 'AD12', 'AM14', 'W33', 'AD18', 'AM24', 'Y10', 'AD28', 'AM34', 'Y12', 'AD8', 'AM4', 'Y14', 'AN1']}] }),
        Part(**{ 'name':'XC5VLX155-FF1760', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX155-FF1760'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX155-FF1760\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R27',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U40',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA38',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC4',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC5',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD3',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AE2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AF1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AG2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH1',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ3',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP1',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AR2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT2',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU1',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M35',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA10',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE36',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G4',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V5',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='W10',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y10',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB8',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB9',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC9',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD11',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AF4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG4',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ6',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL4',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM4',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN4',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AP3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR3',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H37',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AH16',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH29',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ16',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ17',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ30',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK15',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL15',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL29',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL30',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E5',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F5',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H6',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J5',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J6',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L7',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M5',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M6',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P6',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P8',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R7',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R9',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T11',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T9',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U7',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE10',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF12',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG12',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG9',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH11',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AL7',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AL9',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AM7',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM8',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN6',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN8',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP5',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP6',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP7',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP9',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR5',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT4',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT5',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT6',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU3',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU4',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV3',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV4',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV5',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='IO_L14P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E13',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='IO_L18P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E8',name='IO_L18N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E9',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F10',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F11',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F12',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F3',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F7',name='IO_L19P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F9',name='IO_L15P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G11',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G12',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G13',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G40',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='G8',name='IO_L19N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G9',name='IO_L15N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H10',name='IO_L13N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H11',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='H8',name='IO_L16P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H9',name='IO_L13P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J10',name='IO_L7P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='IO_L7N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J12',name='IO_L6N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J4',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='IO_L16N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K12',name='IO_L6P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K8',name='IO_L17P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K9',name='IO_L17N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L10',name='IO_L5N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L11',name='IO_L5P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L12',name='IO_L2N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L9',name='IO_L4P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M11',name='IO_L3N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M12',name='IO_L2P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N10',name='IO_L1N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N11',name='IO_L3P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P10',name='IO_L1P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P11',name='IO_L0N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P12',name='IO_L0P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ10',name='IO_L18P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ11',name='IO_L18N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L19P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK10',name='IO_L17P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L19N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL10',name='IO_L17N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL11',name='IO_L16P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL12',name='IO_L16N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM11',name='IO_L15N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM12',name='IO_L15P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM9',name='IO_L13P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN10',name='IO_L13N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN11',name='IO_L14P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP11',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP12',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AP8',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR10',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR12',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AR6',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AR7',name='IO_L3P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR8',name='IO_L3N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR9',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT10',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT11',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT12',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT3',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT7',name='IO_L2P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT9',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU11',name='IO_L7N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU12',name='IO_L6N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU13',name='IO_L6P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AU6',name='IO_L2N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU7',name='IO_L0N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU8',name='IO_L1P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU9',name='IO_L4P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV10',name='IO_L5P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV11',name='IO_L7P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV6',name='IO_L0P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV8',name='IO_L1N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV9',name='IO_L5N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AW4',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='C32',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='D9',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='E6',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='G10',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=11),
            Pin(num='J24',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J30',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K13',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K14',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K28',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K29',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L15',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L16',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L29',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M16',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M27',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N26',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='AV7',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='BA8',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='H27',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='B15',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='C12',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='F13',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='AK17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK27',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK28',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL16',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM13',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM27',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM28',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN13',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN16',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN28',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN29',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN30',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP13',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP30',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AT13',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AV17',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AW14',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AY11',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='BA18',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ18',name='IO_L16N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ25',name='IO_L17P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK18',name='IO_L1P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK19',name='IO_L16P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK24',name='IO_L17N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK25',name='IO_L19N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL17',name='IO_L1N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL19',name='IO_L18P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL24',name='IO_L19P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL25',name='IO_L15P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL26',name='IO_L0P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM17',name='IO_L3N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM18',name='IO_L3P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM19',name='IO_L18N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM24',name='IO_L15N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM26',name='IO_L0N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN18',name='IO_L5P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN19',name='IO_L7P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN25',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN26',name='IO_L4P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP16',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP17',name='IO_L5N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP18',name='IO_L7N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP26',name='IO_L6P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP27',name='IO_L2N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP28',name='IO_L2P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR13',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR14',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR15',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR27',name='IO_L6N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR28',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR29',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR30',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT14',name='IO_L14P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT15',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AT29',name='IO_L13N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT30',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AU29',name='IO_L13P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='G14',name='IO_L1P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G16',name='IO_L3N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G27',name='IO_L15P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G28',name='IO_L17P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G29',name='IO_L17N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H14',name='IO_L1N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H15',name='IO_L7P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H16',name='IO_L3P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J15',name='IO_L7N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J16',name='IO_L5N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J17',name='IO_L5P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J26',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J27',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J28',name='IO_L13P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K17',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K18',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K19',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K24',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K27',name='IO_L13N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L17',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L19',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L24',name='IO_L2N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L25',name='IO_L2P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L26',name='IO_L6N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M17',name='IO_L14P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M24',name='IO_L0P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M26',name='IO_L6P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N18',name='IO_L16P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N19',name='IO_L16N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N24',name='IO_L0N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N25',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P18',name='IO_L18N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P25',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='R18',name='IO_L18P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AR16',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AE30',name='TCK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF14',name='TMS_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF15',name='CCLK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF30',name='M1_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG14',name='TDI_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG29',name='M0_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='AH14',name='TDO_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH28',name='M2_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='R14',name='D_IN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T14',name='HSWAPEN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T15',name='DONE_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='U14',name='INIT_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R29',name='VBATT_0',func=pin_types.PWRIN,unit=18),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=19)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['P42', 'P16', 'AA42', 'N15', 'L40', 'T41', 'W40', 'Y42', 'E16', 'L41', 'N28', 'P17', 'R15', 'T42', 'W41', 'F41', 'L42', 'N29', 'P26', 'R17', 'U40', 'W42', 'F42', 'M13', 'N30', 'P27', 'R27', 'U41', 'G41', 'M29', 'Y37', 'G42', 'M41', 'N40', 'P28', 'R28', 'AA37', 'U42', 'Y38', 'H41', 'M42', 'N41', 'P30', 'R40', 'J14', 'AA39', 'V37', 'Y39', 'J41', 'N13', 'P13', 'P40', 'R42', 'V40', 'Y40', 'AA40', 'J42', 'N14', 'P15', 'P41', 'T40', 'AA41', 'V41', 'Y41', 'K42']},{'label': 'uB', 'num': 2, 'pin_nums': ['AJ41', 'N1', 'AJ42', 'AA1', 'N3', 'AA2', 'AK40', 'P1', 'AK42', 'AA38', 'P2', 'AA4', 'AL40', 'P3', 'AL41', 'AA5', 'R2', 'AJ40', 'AA8', 'AL42', 'R3', 'AB35', 'AM41', 'T1', 'AB37', 'AM42', 'T2', 'AB38', 'AN41', 'U1', 'AB39', 'AP41', 'U2', 'AB41', 'AP42', 'U3', 'AB42', 'AR42', 'V1', 'AB5', 'AT41', 'V3', 'AC38', 'AT42', 'V4', 'AC39', 'AU41', 'W1', 'AC40', 'AU42', 'W2', 'AC41', 'AV41', 'W3', 'AD39', 'E2', 'W4', 'AD40', 'F1', 'Y2', 'AD41', 'F2', 'Y3', 'AD42', 'G1', 'Y4', 'AE40', 'G2', 'Y5', 'AE42', 'H1', 'AF40', 'J1', 'J2', 'AF41', 'AF42', 'K2', 'AG41', 'L1', 'AG42', 'L2', 'M1', 'AH40', 'AH41', 'M2', 'M3']},{'label': 'uC', 'num': 3, 'pin_nums': ['AC1', 'AP2', 'R39', 'AC3', 'T37', 'AR2', 'AC4', 'AT1', 'T39', 'AC5', 'U37', 'AT2', 'AC6', 'AU1', 'U38', 'AD1', 'AU2', 'U39', 'AD2', 'E39', 'V38', 'AD3', 'V39', 'E40', 'AD9', 'F39', 'W35', 'AE2', 'F40', 'W36', 'AE3', 'G38', 'W37', 'AE6', 'G39', 'W38', 'AF1', 'H38', 'Y34', 'AF2', 'H39', 'Y35', 'AG1', 'H40', 'AG10', 'J38', 'AG2', 'J40', 'AG3', 'K38', 'AH1', 'K39', 'AH3', 'K40', 'AJ1', 'L39', 'AJ2', 'M35', 'AJ3', 'M38', 'AK2', 'M39', 'AA34', 'AK3', 'N38', 'AA35', 'AL1', 'N39', 'AA36', 'AL2', 'P37', 'AB1', 'AM1', 'P38', 'AB2', 'AM2', 'P39', 'AB3', 'AM3', 'R36', 'AB4', 'AN1', 'R37', 'AB6', 'AP1', 'R38']},{'label': 'uD', 'num': 4, 'pin_nums': ['E4', 'F4', 'AF37', 'Y10', 'AF39', 'G3', 'Y7', 'AG37', 'G4', 'Y8', 'AG38', 'H3', 'Y9', 'AG39', 'H4', 'AG40', 'J3', 'AH37', 'K3', 'AH38', 'K4', 'AH39', 'L4', 'AJ37', 'L5', 'AJ38', 'M4', 'AK37', 'N4', 'AK38', 'N5', 'AK39', 'P5', 'AA10', 'AL37', 'R4', 'AA11', 'AL39', 'R5', 'AA6', 'AM37', 'R6', 'AA7', 'AM38', 'T3', 'AA9', 'AM39', 'T4', 'AB34', 'AN38', 'T5', 'AB36', 'AN39', 'T6', 'AC34', 'AN40', 'U4', 'AC35', 'AP38', 'U6', 'AC36', 'AP40', 'V5', 'AD35', 'AR39', 'V6', 'AD36', 'AR40', 'V7', 'AD37', 'AT39', 'W10', 'AD38', 'AT40', 'W11', 'AE36', 'AU39', 'W5', 'AE37', 'AV40', 'W6', 'W8', 'AE38', 'E3', 'W7', 'AE39']},{'label': 'uE', 'num': 5, 'pin_nums': ['AH7', 'K41', 'AJ4', 'L35', 'AJ5', 'L36', 'AJ6', 'L37', 'AK4', 'L38', 'AA32', 'AK5', 'M36', 'AB11', 'AL4', 'M37', 'AL5', 'AB7', 'N35', 'AB8', 'AL6', 'N36', 'AB9', 'AM4', 'P35', 'AC10', 'AM6', 'P36', 'AC11', 'AN3', 'R34', 'AC8', 'AN4', 'R35', 'AC9', 'AN5', 'T34', 'AD10', 'AP3', 'T35', 'AD11', 'AR3', 'T36', 'AD5', 'AR4', 'U33', 'AD6', 'D37', 'U34', 'AD7', 'E37', 'U36', 'AD8', 'E38', 'V33', 'AE4', 'F36', 'V34', 'AE5', 'F37', 'V35', 'AE7', 'G36', 'V36', 'AF3', 'G37', 'W32', 'AF4', 'H35', 'W33', 'AF5', 'H36', 'Y32', 'AF6', 'H37', 'Y33', 'AG4', 'J35', 'AG6', 'J36', 'AH6', 'AH4', 'J37', 'AH5', 'K35', 'K37']},{'label': 'uF', 'num': 6, 'pin_nums': ['H6', 'AR26', 'AJ15', 'AK14', 'L8', 'N9', 'R9', 'U9', 'AJ16', 'AK15', 'AV27', 'J5', 'P6', 'T10', 'V10', 'M5', 'AJ17', 'AK29', 'E5', 'J6', 'M6', 'P7', 'T11', 'V11', 'AJ26', 'AK30', 'F5', 'J7', 'M7', 'P8', 'T7', 'V8', 'AH16', 'AJ27', 'AL14', 'F6', 'K5', 'M8', 'P9', 'T9', 'V9', 'AH29', 'AJ28', 'AL15', 'G6', 'K7', 'M9', 'R10', 'U11', 'AH30', 'AJ30', 'AL29', 'G7', 'L6', 'N6', 'R7', 'R8', 'U7', 'U8', 'AJ13', 'AK13', 'AL30', 'H5', 'N8', 'L7']},{'label': 'uG', 'num': 7, 'pin_nums': ['AP6', 'AD32', 'AP7', 'AJ35', 'AD33', 'AJ36', 'AP9', 'AE10', 'AJ7', 'AR37', 'AE32', 'AJ8', 'AR38', 'AE33', 'AK34', 'AR5', 'AE34', 'AK35', 'AT36', 'AE35', 'AK7', 'AT37', 'AE8', 'AK8', 'AT4', 'AC33', 'AE9', 'AK9', 'AT5', 'AF10', 'AL34', 'AT6', 'AF11', 'AL35', 'AU3', 'AF12', 'AL36', 'AU37', 'AF34', 'AL38', 'AU38', 'AF35', 'AL7', 'AU4', 'AF36', 'AL8', 'AV3', 'AF7', 'AL9', 'AV38', 'AF9', 'AM34', 'AV39', 'AG11', 'AM35', 'AV4', 'AG12', 'AM36', 'AV5', 'AG34', 'AM5', 'AG36', 'AM7', 'AG7', 'AM8', 'AG8', 'AN34', 'AG9', 'AN35', 'AH10', 'AN36', 'AH11', 'AN6', 'AH34', 'AN8', 'AH35', 'AP35', 'AH36', 'AP36', 'AB32', 'AH8', 'AP37', 'AB33', 'AH9', 'AP5', 'AJ34']},{'label': 'uH', 'num': 8, 'pin_nums': ['F10', 'J31', 'P12', 'J32', 'F11', 'P31', 'F12', 'J33', 'P32', 'J4', 'F3', 'P33', 'F31', 'J8', 'R32', 'F32', 'K10', 'R33', 'F34', 'K12', 'T31', 'F35', 'K32', 'T32', 'F7', 'K33', 'U31', 'F9', 'K34', 'U32', 'G11', 'K8', 'G12', 'K9', 'G13', 'L10', 'G31', 'L11', 'G32', 'L12', 'G33', 'L31', 'G34', 'L32', 'J12', 'G40', 'L34', 'G8', 'L9', 'G9', 'M11', 'D39', 'H10', 'M12', 'E10', 'H11', 'M31', 'E12', 'H13', 'M32', 'E13', 'H31', 'M33', 'E32', 'H33', 'M34', 'E33', 'H34', 'N10', 'E34', 'H7', 'N11', 'E35', 'H8', 'N31', 'E36', 'H9', 'N33', 'E7', 'J10', 'N34', 'E8', 'J11', 'P10', 'E9', 'P11']},{'label': 'uI', 'num': 9, 'pin_nums': ['AL32', 'AW4', 'AM11', 'AT12', 'AM12', 'AT3', 'AM31', 'AT31', 'AM32', 'AT32', 'AM33', 'AT34', 'AM9', 'AT35', 'AN10', 'AT7', 'AN11', 'AT9', 'AN31', 'AU11', 'AN33', 'AU12', 'AF31', 'AN9', 'AU13', 'AF32', 'AP10', 'AU31', 'AG31', 'AP11', 'AU32', 'AG32', 'AP12', 'AU33', 'AG33', 'AP31', 'AU34', 'AH31', 'AP32', 'AU36', 'AH33', 'AP33', 'AU40', 'AJ10', 'AP39', 'AU6', 'AJ11', 'AP8', 'AU7', 'AJ12', 'AR10', 'AU8', 'AJ31', 'AR12', 'AU9', 'AJ32', 'AR32', 'AV10', 'AJ33', 'AR33', 'AV11', 'AK10', 'AR34', 'AV31', 'AK12', 'AR35', 'AV33', 'AK32', 'AR36', 'AV34', 'AK33', 'AR6', 'AV35', 'AL10', 'AR7', 'AV36', 'AL11', 'AR8', 'AV6', 'AL12', 'AR9', 'AT11', 'AV8', 'AL31', 'AT10', 'AV9']},{'label': 'uJ', 'num': 10, 'pin_nums': ['B35', 'F33', 'G10', 'E6', 'C32', 'D9']},{'label': 'uK', 'num': 11, 'pin_nums': ['K15', 'AV37', 'L29', 'AW34', 'L30', 'K28', 'E26', 'K29', 'M14', 'J13', 'K30', 'M16', 'AT33', 'K14', 'M27', 'J24', 'L14', 'N26', 'J30', 'L15', 'M28', 'K13', 'L16', 'N16', 'L27']},{'label': 'uL', 'num': 12, 'pin_nums': ['H27', 'D29', 'AV7', 'BA8', 'G30', 'AU10']},{'label': 'uM', 'num': 13, 'pin_nums': ['C12', 'AU30', 'B15', 'BA28', 'AY31', 'F13']},{'label': 'uN', 'num': 14, 'pin_nums': ['AP13', 'AK28', 'AM29', 'AN13', 'AL16', 'AP30', 'AL27', 'AN14', 'AT13', 'AM13', 'AN15', 'AV17', 'AM14', 'AN16', 'AW14', 'AM16', 'AN28', 'AY11', 'AK17', 'AM27', 'AN29', 'BA18', 'AK27', 'AM28', 'AN30']},{'label': 'uO', 'num': 15, 'pin_nums': ['J15', 'AP27', 'AP28', 'J16', 'AR13', 'J17', 'J26', 'AR14', 'AR15', 'J27', 'J28', 'AR17', 'AR27', 'K17', 'AJ18', 'AR28', 'K18', 'AJ25', 'AR29', 'K19', 'AK18', 'AR30', 'K24', 'AK19', 'AT14', 'K25', 'AK24', 'AT15', 'K27', 'AK25', 'AT23', 'L17', 'AL17', 'AT29', 'L19', 'AL19', 'AT30', 'L24', 'AL24', 'L25', 'AU29', 'AL25', 'AW24', 'L26', 'AL26', 'AY21', 'M17', 'AM17', 'B25', 'M18', 'AM18', 'C22', 'M19', 'AM19', 'F23', 'M24', 'AM24', 'G14', 'M26', 'AM26', 'G16', 'N18', 'AN18', 'N19', 'G27', 'AN19', 'G28', 'N24', 'AN25', 'G29', 'N25', 'AN26', 'H14', 'P18', 'AP15', 'H15', 'P25', 'AP16', 'H16', 'R18', 'AP17', 'H28', 'AP18', 'H29', 'AP26', 'H30']},{'label': 'uP', 'num': 16, 'pin_nums': ['AP19', 'G20', 'AU20', 'D19', 'AR16', 'H17']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AG30', 'AC21', 'T15', 'AG29', 'T14', 'AH14', 'AC22', 'T29', 'AE30', 'AH15', 'T30', 'AF14', 'AH28', 'U14', 'AL28', 'AA21', 'AF15', 'AF30', 'AA22', 'R14', 'R30', 'AB21', 'AG14', 'AB22']},{'label': 'uR', 'num': 18, 'pin_nums': ['A28', 'AG28', 'M25', 'F8', 'R41', 'V23', 'A3', 'AD15', 'AH13', 'M30', 'G15', 'V25', 'T12', 'A33', 'AD17', 'AH17', 'G25', 'M40', 'T13', 'V27', 'A38', 'AD19', 'AH19', 'G35', 'N12', 'T16', 'V29', 'A8', 'AD21', 'AH21', 'G5', 'N17', 'T17', 'W12', 'AA12', 'AD23', 'AH23', 'H12', 'N2', 'T18', 'W14', 'AA14', 'AD25', 'AH25', 'H2', 'N27', 'T19', 'W16', 'AA16', 'AD27', 'AH27', 'N32', 'H22', 'W18', 'T20', 'AA18', 'AD29', 'AJ24', 'H32', 'N37', 'T21', 'W20', 'AA20', 'AE12', 'B10', 'H42', 'N42', 'T22', 'W22', 'AA24', 'AE14', 'B20', 'J19', 'N7', 'T23', 'W24', 'AA26', 'AE16', 'B30', 'J29', 'P14', 'T24', 'W26', 'AA28', 'AE18', 'B40', 'J34', 'P19', 'T25', 'W28', 'AA30', 'AE20', 'B5', 'J39', 'P24', 'T26', 'W30', 'AB13', 'AE22', 'C17', 'J9', 'P29', 'T27', 'Y13', 'AB15', 'AE24', 'C2', 'K1', 'P34', 'T28', 'Y15', 'AB17', 'AE26', 'C27', 'K11', 'P4', 'T33', 'Y17', 'AB19', 'AE28', 'C37', 'K16', 'R1', 'T8', 'Y19', 'AB23', 'AF13', 'C42', 'K21', 'R11', 'U12', 'Y21', 'AB25', 'AF17', 'C7', 'K26', 'R12', 'U16', 'Y22', 'AB27', 'AF19', 'D14', 'K31', 'R13', 'U18', 'Y23', 'M20', 'AB29', 'AF21', 'D24', 'K36', 'R16', 'U20', 'Y25', 'AB31', 'AF23', 'D34', 'K6', 'R19', 'U22', 'Y27', 'AC12', 'AF25', 'D4', 'L13', 'R20', 'U24', 'Y29', 'AC14', 'AF27', 'E1', 'L18', 'R21', 'U26', 'Y31', 'AC16', 'AF29', 'E11', 'L23', 'R22', 'U28', 'AC18', 'AG16', 'E21', 'L28', 'R23', 'U30', 'AC20', 'AG18', 'E31', 'L3', 'R24', 'V13', 'AC24', 'AG20', 'E41', 'L33', 'R25', 'V15', 'A13', 'AC26', 'AG22', 'F18', 'M10', 'R26', 'V17', 'A18', 'AC28', 'AD13', 'AG24', 'F28', 'M15', 'R29', 'V19', 'A23', 'AC30', 'AG26', 'F38', 'R31', 'V21']},{'label': 'uS', 'num': 19, 'pin_nums': ['AD16', 'AF8', 'AK41', 'BB30', 'AT18', 'W17', 'AA29', 'AD18', 'AK6', 'AG13', 'BB35', 'AT28', 'W19', 'AA3', 'AD20', 'AG15', 'AL13', 'AT38', 'BB40', 'AK36', 'W21', 'AA31', 'AD22', 'AG17', 'AL18', 'AT8', 'BB5', 'W23', 'AA33', 'AD24', 'AG19', 'AL23', 'AU15', 'T38', 'W25', 'AB10', 'AD26', 'AG21', 'AL3', 'AU25', 'U10', 'W27', 'AB12', 'AD28', 'AG23', 'AL33', 'AU35', 'U13', 'W29', 'AB14', 'AD30', 'AG25', 'AM10', 'U15', 'AU5', 'W31', 'AB16', 'AD34', 'AG27', 'AM15', 'AV12', 'U17', 'W34', 'AB18', 'AD4', 'AG35', 'AM20', 'AV2', 'U19', 'W39', 'BB25', 'AB20', 'AE1', 'AG5', 'AM25', 'AV22', 'U21', 'W9', 'AB24', 'AE11', 'AH12', 'AM30', 'AV32', 'U23', 'Y1', 'AB26', 'AE13', 'AH18', 'AM40', 'AV42', 'U25', 'Y11', 'AB28', 'AE15', 'AH2', 'AN12', 'AW19', 'U27', 'Y12', 'AB30', 'AE17', 'AH20', 'AN17', 'AW29', 'U29', 'Y14', 'AB40', 'AE19', 'AH22', 'AN2', 'AW39', 'U35', 'Y16', 'AC13', 'AE21', 'AH24', 'AN22', 'AW9', 'U5', 'Y18', 'AC15', 'AE23', 'AH26', 'AN27', 'AY1', 'V12', 'Y20', 'AC17', 'AE25', 'AH32', 'AN32', 'AY16', 'V14', 'Y24', 'AC19', 'AE27', 'AH42', 'AN37', 'AY26', 'V16', 'Y26', 'AC2', 'AE29', 'AJ14', 'AN42', 'AY36', 'V18', 'Y28', 'AC23', 'AE31', 'AJ19', 'AN7', 'AY41', 'V2', 'Y30', 'AC25', 'AE41', 'AJ29', 'AP14', 'AY6', 'V20', 'Y36', 'AC27', 'AF16', 'AJ39', 'AP24', 'BA13', 'V22', 'Y6', 'AC29', 'AF18', 'AJ9', 'AP29', 'BA23', 'V24', 'AC31', 'AF20', 'AK1', 'AP34', 'BA3', 'V26', 'AA13', 'AC32', 'AF22', 'AK11', 'AP4', 'BA33', 'V28', 'AA15', 'AC37', 'AF24', 'AK16', 'AR1', 'BA38', 'V30', 'AA17', 'AC42', 'AF26', 'AK21', 'AR11', 'BB10', 'V32', 'AA19', 'AC7', 'AF28', 'AK26', 'AR21', 'BB15', 'V42', 'AA23', 'AA27', 'AD12', 'AF33', 'AK31', 'AR31', 'BB20', 'W13', 'AA25', 'AD14', 'AF38', 'AR41', 'W15']}] }),
        Part(**{ 'name':'XC5VLX155T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX155T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX155T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A15',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A16',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AH23',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AH24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ14',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ19',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ20',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ21',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ22',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK13',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK14',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK16',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK18',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK19',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK21',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK22',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK24',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL13',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL14',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL15',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL19',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL20',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL21',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN17',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='B15',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B16',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B17',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C14',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C15',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C17',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D14',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D15',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D16',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D17',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D19',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D20',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D21',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D22',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E14',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E16',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E17',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E21',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E23',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E24',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F14',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F15',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F18',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A6',name='MGTRXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A7',name='MGTRXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A8',name='MGTRXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A9',name='MGTRXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AL7',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AM7',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN10',name='MGTTXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN5',name='MGTTXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN6',name='MGTTXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN9',name='MGTTXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP6',name='MGTRXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP7',name='MGTRXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP8',name='MGTRXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP9',name='MGTRXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='B10',name='MGTTXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B5',name='MGTTXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B6',name='MGTTXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B9',name='MGTTXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='C8',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D8',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM10',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM5',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM6',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM9',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=14),
            Pin(num='C10',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C5',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C6',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C9',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=14),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=14),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=16),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=17)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['R30', 'H23', 'K12', 'L34', 'K33', 'U32', 'C32', 'E34', 'H32', 'K13', 'K34', 'M32', 'R32', 'F33', 'U33', 'H33', 'F34', 'K14', 'L14', 'M33', 'H34', 'R33', 'V31', 'C33', 'G14', 'B33', 'J12', 'K16', 'L15', 'N32', 'R34', 'G22', 'J15', 'K21', 'L16', 'N33', 'C34', 'G23', 'T27', 'B32', 'D13', 'G32', 'J22', 'K22', 'L20', 'N34', 'T33', 'G33', 'D32', 'J32', 'K23', 'L21', 'P32', 'T34', 'D34', 'H12', 'A33', 'E32', 'J34', 'K32', 'H22', 'L33', 'P34', 'U31', 'E33']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB33', 'F6', 'T10', 'G5', 'AC32', 'T11', 'AC33', 'G6', 'T6', 'G7', 'AC34', 'T7', 'AD32', 'H5', 'T8', 'AD34', 'H7', 'T9', 'AE32', 'J5', 'U10', 'AE33', 'J6', 'U7', 'AE34', 'J7', 'V32', 'AF33', 'K6', 'V33', 'AF34', 'K7', 'V34', 'AG32', 'L4', 'W28', 'AG33', 'L5', 'W32', 'AH32', 'L6', 'W34', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6', 'AK34', 'N7', 'AL33', 'N8', 'AL34', 'P10', 'F5', 'AM32', 'P5', 'AM33', 'P6', 'AN32', 'P7', 'AN33', 'P9', 'AA32', 'AN34', 'R11', 'AA33', 'AP32', 'R6', 'AA34', 'E6', 'R7', 'AB29', 'R8', 'E7', 'AB32', 'R9']},{'label': 'uC', 'num': 3, 'pin_nums': ['AF29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'P33', 'Y28', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'K29', 'V25', 'AC30', 'K31', 'V27', 'AD29', 'L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'AD33', 'L32', 'W24', 'AE29', 'M29', 'W25', 'AE30', 'M30', 'N29', 'W26', 'AE31', 'M31', 'W27']},{'label': 'uD', 'num': 4, 'pin_nums': ['M25', 'AJ7', 'AK6', 'M26', 'AK7', 'M27', 'M28', 'E26', 'E27', 'N24', 'N25', 'E28', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'J24', 'W10', 'AD6', 'J25', 'W11', 'AD7', 'J26', 'W6', 'AE6', 'J27', 'W7', 'AE7', 'W8', 'J28', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AG7', 'L24', 'Y8', 'AH5', 'L25', 'Y9', 'AH7', 'L26', 'AJ6', 'L28']},{'label': 'uE', 'num': 5, 'pin_nums': ['G10', 'AF21', 'E13', 'AE21', 'C12', 'H9', 'L10', 'AD20', 'AE22', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'D11', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AE16', 'AF15', 'AM19', 'E10', 'F13', 'H10', 'K11', 'M8', 'AD19', 'AE17', 'AF16', 'B12', 'E11', 'F8', 'H11', 'K8', 'N10', 'A13', 'AE19', 'AF20', 'B13', 'E12', 'F9', 'H8', 'K9', 'N9']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE28', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AH28', 'AD25', 'AH8', 'AD26', 'AH9', 'AJ10', 'AD27', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AE24', 'AJ26', 'AE26', 'AJ27', 'AJ29', 'AE27', 'AJ28']},{'label': 'uG', 'num': 7, 'pin_nums': ['A29', 'C26', 'AN28', 'A30', 'C27', 'AN29', 'A31', 'AN30', 'C28', 'AK25', 'C29', 'AP19', 'AL22', 'AP20', 'C30', 'AL24', 'D25', 'AP21', 'AL25', 'AP22', 'D26', 'AL26', 'D27', 'AP24', 'AL28', 'AP25', 'D29', 'AL29', 'AP26', 'D30', 'AL30', 'AP27', 'D31', 'AL31', 'AP29', 'F27', 'AM18', 'AP30', 'G24', 'AM20', 'AP31', 'AM21', 'B18', 'AM22', 'B20', 'AM23', 'B21', 'AM25', 'B22', 'AM26', 'B23', 'AM27', 'B25', 'AM28', 'B26', 'AM30', 'B27', 'AM31', 'B28', 'A28', 'AN18', 'A18', 'B30', 'A19', 'AN19', 'B31', 'A20', 'AN20', 'C18', 'A21', 'AN22', 'C19', 'A23', 'AN23', 'C20', 'AN24', 'A24', 'C22', 'A25', 'AN25', 'C23', 'A26', 'AN26', 'C24', 'AN27', 'C25']},{'label': 'uH', 'num': 8, 'pin_nums': ['AF19', 'AG21', 'J16', 'H13', 'L18', 'AG13', 'AG22', 'AH20', 'H14', 'J17', 'L19', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20', 'AG16', 'AH14', 'D23', 'H18', 'J21', 'AG17', 'AH15', 'E20', 'H19', 'K17', 'AE18', 'AG18', 'AH17', 'AH19', 'G15', 'H20', 'K18', 'AF18', 'AG20', 'AH18', 'G16', 'J14', 'K19']},{'label': 'uI', 'num': 9, 'pin_nums': ['AJ14', 'E23', 'AM16', 'AJ15', 'E24', 'AM17', 'AJ16', 'AN15', 'F14', 'AJ17', 'F15', 'AN16', 'AM15', 'AJ18', 'AN17', 'F16', 'AJ19', 'F17', 'AP15', 'AJ20', 'AP16', 'F18', 'AJ21', 'F19', 'AP17', 'AJ22', 'B15', 'F20', 'AJ24', 'B16', 'F21', 'AK12', 'B17', 'F23', 'AK13', 'B19', 'F24', 'AK14', 'C14', 'G17', 'AK15', 'C15', 'G18', 'AK16', 'C16', 'G20', 'AK17', 'G21', 'C17', 'AK18', 'D14', 'AK19', 'D15', 'AK21', 'D16', 'AK22', 'D17', 'AK23', 'D19', 'AK24', 'D20', 'AL13', 'D21', 'AL14', 'D22', 'AL15', 'D24', 'AL16', 'E14', 'A14', 'AL18', 'E16', 'A15', 'AL19', 'E17', 'A16', 'AL20', 'E18', 'AH23', 'AL21', 'E19', 'AH24', 'AL23', 'E21', 'AJ12', 'E22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AA1', 'P3', 'P1', 'W2', 'AB1', 'P4', 'Y1', 'AB2', 'R1', 'Y3', 'AC2', 'T1', 'Y4', 'M2', 'T2', 'N1', 'U2', 'V2', 'N2', 'W1']},{'label': 'uK', 'num': 11, 'pin_nums': ['G1', 'AF1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4', 'AD2', 'AH2', 'J1', 'AE1', 'AJ2', 'K1', 'AE2', 'F2', 'K2']},{'label': 'uL', 'num': 12, 'pin_nums': ['D1', 'AM1', 'A2', 'D2', 'AN3', 'D4', 'A3', 'AN4', 'AK2', 'AP2', 'E2', 'E4', 'AP3', 'AL1', 'AL5', 'AL2', 'B3', 'B4', 'AL4', 'C1']},{'label': 'uM', 'num': 13, 'pin_nums': ['A9', 'AP7', 'D8', 'AL7', 'AP8', 'AM7', 'AP9', 'AN10', 'B10', 'B5', 'AN5', 'A6', 'AN6', 'B6', 'B9', 'A7', 'AN9', 'AP6', 'C8', 'A8']},{'label': 'uN', 'num': 14, 'pin_nums': ['K3', 'AL8', 'D5', 'AG3', 'C10', 'V3', 'AG4', 'AM10', 'C3', 'D7', 'L3', 'V4', 'AA3', 'AH3', 'AM3', 'C4', 'E3', 'M3', 'V5', 'AA4', 'AJ3', 'AM4', 'C5', 'F3', 'N3', 'W3', 'AB3', 'AJ4', 'AM5', 'C6', 'F4', 'R3', 'AC3', 'AK3', 'AM6', 'C7', 'G3', 'R4', 'AD3', 'AK5', 'AM8', 'C9', 'J3', 'T3', 'AE3', 'AL3', 'AM9', 'D3', 'J4', 'U3']},{'label': 'uO', 'num': 15, 'pin_nums': ['AC22', 'M23', 'V17', 'AD14', 'AC15', 'V18', 'N14', 'AD15', 'N15', 'W17', 'AD21', 'N22', 'W18', 'AA22', 'AD22', 'N23', 'AB15', 'AD23', 'P15', 'AC14', 'M15', 'U17', 'M22', 'U18']},{'label': 'uP', 'num': 16, 'pin_nums': ['AC20', 'M19', 'U14', 'P8', 'AD13', 'H16', 'M20', 'U16', 'R10', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'U22', 'R13', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'R15', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'V15', 'R17', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'T20', 'AB17', 'F32', 'M12', 'P2', 'T21', 'AB19', 'F7', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'G29', 'M16', 'P22', 'T4', 'AC16', 'G34', 'G9', 'M17', 'P23', 'T5', 'AC18', 'G4', 'M18', 'P28', 'U12']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AF27', 'W33', 'AF32', 'AB12', 'AN7', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14', 'AB22', 'AG34', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AE15', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'AE25', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AA19', 'AE5', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'AN11', 'W19', 'AA23', 'AF2', 'AN2', 'AN31', 'W21', 'AA27', 'AF22', 'AN21', 'W23', 'AA7']}] }),
        Part(**{ 'name':'XC5VLX155T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX155T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX155T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='C32',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP9',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AU10',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AV7',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=12),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=12),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=14),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=15),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=16),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=17),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=18),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AW16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=18),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=18),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='D15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=18),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=18),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=18),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=20),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=21)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L41', 'N41', 'AA37', 'N15', 'P40', 'F41', 'L42', 'U41', 'Y37', 'F42', 'M13', 'N16', 'P13', 'Y38', 'P41', 'U42', 'G41', 'M14', 'N25', 'P17', 'P42', 'AA39', 'G42', 'V37', 'Y39', 'M16', 'H41', 'N26', 'P18', 'R40', 'M29', 'V40', 'Y40', 'J14', 'M41', 'N28', 'P25', 'R42', 'V41', 'Y41', 'AA38', 'J41', 'AA40', 'M42', 'N29', 'P26', 'J42', 'T40', 'W40', 'Y42', 'AA41', 'K42', 'N13', 'N30', 'P27', 'T41', 'W41', 'AA42', 'L40', 'N14', 'N40', 'P28', 'T42', 'W42', 'F13']},{'label': 'uB', 'num': 2, 'pin_nums': ['W8', 'AD41', 'Y10', 'H5', 'AD42', 'H6', 'Y7', 'AE36', 'J5', 'Y8', 'AE40', 'J6', 'Y9', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AA6', 'AK42', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AA9', 'AL42', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'G6', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'AR42', 'V8', 'AC38', 'AT41', 'W10', 'AC39', 'AT42', 'W11', 'AC40', 'AU41', 'W5', 'AC41', 'AU42', 'W6', 'AD39', 'AV41', 'W7', 'AD40']},{'label': 'uC', 'num': 3, 'pin_nums': ['AK38', 'K40', 'L39', 'AK39', 'AK41', 'M38', 'M39', 'AL37', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'P38', 'AM39', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'W37', 'G38', 'AG39', 'G39', 'W38', 'AG40', 'H38', 'Y34', 'AH37', 'H39', 'Y35', 'AH38', 'H40', 'AH39', 'J38', 'AJ37', 'J40', 'AJ38', 'K38', 'AK37', 'K39']},{'label': 'uD', 'num': 4, 'pin_nums': ['AH5', 'AH6', 'AB9', 'P36', 'AC10', 'AJ5', 'R34', 'AC5', 'AJ6', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'AD5', 'E37', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'AE7', 'H36', 'Y33', 'AE8', 'J35', 'AE9', 'J36', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'AG10', 'L38', 'AA32', 'AG4', 'M36', 'AB11', 'AG6', 'M37', 'AB6', 'AG7', 'N35', 'P35', 'AB7', 'AH4', 'N36', 'AB8']},{'label': 'uE', 'num': 5, 'pin_nums': ['AK27', 'D7', 'F9', 'AM14', 'K7', 'M9', 'R8', 'V10', 'AM13', 'AK15', 'F7', 'AK28', 'AM28', 'E5', 'G7', 'J8', 'N8', 'K8', 'M8', 'R9', 'V11', 'AJ26', 'AK29', 'AM29', 'E7', 'G8', 'K9', 'N9', 'T10', 'V9', 'AJ30', 'AK30', 'AN13', 'E8', 'G9', 'L7', 'P7', 'T11', 'AN14', 'AK12', 'AL14', 'E9', 'H8', 'L8', 'P8', 'T9', 'R7', 'AL29', 'AK13', 'AP13', 'F5', 'H9', 'L9', 'P9', 'U11', 'AK14', 'AL30', 'AR26', 'F6', 'J7', 'M7', 'R6', 'U8', 'AV27', 'U9']},{'label': 'uF', 'num': 6, 'pin_nums': ['AG34', 'E32', 'N34', 'AG36', 'P31', 'E33', 'AH34', 'E34', 'P32', 'AH35', 'P33', 'E35', 'AH36', 'E36', 'R32', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'T32', 'F34', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AT37', 'M31', 'AE34', 'AU37', 'M32', 'AE35', 'AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33']},{'label': 'uG', 'num': 7, 'pin_nums': ['F12', 'F14', 'AP39', 'F15', 'AR32', 'AR33', 'G10', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'K10', 'AJ32', 'AV34', 'K12', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31', 'E15', 'N11', 'AN33', 'E6', 'P10', 'AP31', 'F10', 'P11', 'R10', 'AP32', 'F11', 'P12', 'AP33']},{'label': 'uH', 'num': 8, 'pin_nums': ['AT7', 'AH8', 'AM8', 'AP6', 'AK9', 'AL10', 'AM9', 'AP7', 'AU6', 'AH9', 'AG11', 'AH7', 'AG12', 'AJ10', 'AM7', 'AL6', 'AP5', 'AN4', 'AP8', 'AV5', 'AT6', 'AJ11', 'AL7', 'AG8', 'AN5', 'AR5', 'AV6', 'AG9', 'AJ8', 'AL8', 'AN6', 'AR7', 'B35', 'AH10', 'AK10', 'AL9', 'AN8', 'AR8', 'F33', 'AH11', 'AK11', 'AM6', 'AN9', 'AT5', 'J34', 'AK8']},{'label': 'uI', 'num': 9, 'pin_nums': ['M28', 'AV37', 'K15', 'L17', 'AW34', 'K17', 'L27', 'E26', 'K28', 'L29', 'H27', 'K29', 'L30', 'AT33', 'J15', 'K30', 'L16', 'M17', 'J16', 'L14', 'M26', 'L15', 'J17', 'M27', 'J30']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AU30', 'D29', 'AY31', 'G30', 'C32', 'BA28']},{'label': 'uK', 'num': 11, 'pin_nums': ['AK17', 'AL15', 'AM27', 'AP27', 'AP16', 'AV7', 'AL16', 'AN15', 'AP28', 'AL17', 'AN16', 'AP30', 'AL26', 'AN28', 'AP9', 'AR16', 'AL27', 'AN29', 'AM16', 'AN30', 'AT13', 'AM17', 'AP15', 'AU10', 'AM26']},{'label': 'uL', 'num': 12, 'pin_nums': ['G27', 'G28', 'AR19', 'G29', 'AR27', 'AR28', 'H16', 'AR29', 'H18', 'AR30', 'H26', 'AT14', 'H28', 'AT15', 'H29', 'AT16', 'H30', 'AK18', 'AT17', 'J18', 'AK19', 'AT19', 'J25', 'AK24', 'AT23', 'J26', 'AK25', 'AT26', 'J27', 'AL19', 'AT27', 'J28', 'AL24', 'AT29', 'K18', 'AL25', 'AT30', 'K19', 'AM18', 'AU28', 'K24', 'AM19', 'AU29', 'K25', 'AM24', 'AW24', 'K27', 'AN18', 'AY21', 'L19', 'AN19', 'B25', 'L20', 'AN20', 'C22', 'L24', 'AN24', 'E17', 'L25', 'AN25', 'E18', 'L26', 'AN26', 'F16', 'M18', 'AP17', 'F17', 'M19', 'AP18', 'F23', 'M24', 'AP25', 'F27', 'N18', 'AP26', 'F29', 'N19', 'AR14', 'G16', 'N20', 'AR15', 'G17', 'P20', 'AR17', 'G18', 'AR18']},{'label': 'uM', 'num': 13, 'pin_nums': ['G20', 'AV17', 'H17', 'D19', 'AU20', 'AP19']},{'label': 'uN', 'num': 14, 'pin_nums': ['AC1', 'Y1', 'AG2', 'T2', 'AC2', 'Y2', 'AD1', 'U1', 'AD3', 'U2', 'AD4', 'V1', 'AE1', 'V3', 'AA2', 'AF1', 'V4', 'AB2', 'AF2', 'W1']},{'label': 'uO', 'num': 15, 'pin_nums': ['AL1', 'M3', 'M4', 'AM1', 'AH2', 'AM2', 'N1', 'AJ1', 'AN2', 'P1', 'AJ2', 'K2', 'P2', 'AK1', 'L1', 'R2', 'AK3', 'L2', 'AK4', 'M1']},{'label': 'uP', 'num': 16, 'pin_nums': ['AR2', 'D2', 'H2', 'AT1', 'E1', 'J2', 'AT3', 'E2', 'AT4', 'F1', 'AU1', 'F3', 'AR1', 'AV1', 'F4', 'AW2', 'AP2', 'AV2', 'G1', 'H1']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3', 'A2', 'B5', 'BB4', 'A3', 'B6', 'BB5', 'A4', 'BA1', 'C3', 'A5', 'BA2', 'C4', 'AW4', 'BA5']},{'label': 'uR', 'num': 18, 'pin_nums': ['L3', 'AH3', 'AA5', 'AU3', 'AY10', 'C2', 'D9', 'N3', 'Y3', 'AB3', 'AJ3', 'AU4', 'AY16', 'N4', 'C5', 'E3', 'AB4', 'AL3', 'AV3', 'AY2', 'C6', 'G3', 'P3', 'AC3', 'AL4', 'AW10', 'AY3', 'C9', 'G4', 'R3', 'AE3', 'AM3', 'AW16', 'AY5', 'D15', 'H3', 'T3', 'AE4', 'AN3', 'AW3', 'AY6', 'D3', 'J3', 'U3', 'AF3', 'AP3', 'AW5', 'C1', 'D4', 'K3', 'W3', 'AA3', 'AG3', 'AR3', 'AY1', 'W4', 'C15', 'D5']},{'label': 'uS', 'num': 19, 'pin_nums': ['AJ28', 'AG30', 'T30', 'AA21', 'AL28', 'AH14', 'AG29', 'AJ16', 'AA22', 'AH15', 'P15', 'R14', 'AH16', 'AB21', 'AB22', 'AH29', 'R15', 'AH30', 'AC21', 'R29', 'AC22', 'AJ15', 'R30', 'T14']},{'label': 'uT', 'num': 20, 'pin_nums': ['AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'H32', 'B4', 'R27', 'N17', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'H12', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'T19', 'N7', 'W26', 'R25', 'AC28', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'J9', 'P16', 'T23', 'A19', 'W30', 'AD13', 'AG20', 'D17', 'K11', 'P19', 'T25', 'A23', 'Y13', 'AD15', 'AG22', 'D24', 'K16', 'P21', 'T27', 'A28', 'Y15', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'A33', 'Y17', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'A38', 'Y19', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'U14', 'AA12', 'Y21', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'U16', 'AA14', 'Y22', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'AA16', 'Y23', 'AD27', 'AH19', 'E21', 'L13', 'P34', 'U20', 'AA18', 'Y25', 'AD29', 'AH21', 'E31', 'L18', 'P4', 'U22', 'AA20', 'Y27', 'AD31', 'AH23', 'E4', 'L23', 'R11', 'U24', 'AA24', 'Y29', 'AE12', 'AH25', 'E41', 'L28', 'R12', 'U26', 'AA26', 'Y31', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'M2', 'R19', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'AB27', 'AB31', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'M5', 'V29']},{'label': 'uU', 'num': 21, 'pin_nums': ['U25', 'AB10', 'AG13', 'AD20', 'AK21', 'AR21', 'BA15', 'U27', 'AB12', 'Y11', 'AG15', 'AD22', 'AR31', 'AK26', 'BA16', 'U29', 'AB14', 'Y12', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'AB16', 'Y14', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'AB18', 'Y16', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'AB20', 'Y18', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'AB24', 'Y20', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'V14', 'AB26', 'Y24', 'AG27', 'AE11', 'AT28', 'AL2', 'BA9', 'V16', 'AB28', 'Y26', 'AE13', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'AB30', 'Y28', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'AB40', 'Y30', 'AE17', 'AH12', 'AM10', 'AU15', 'BB30', 'V20', 'AB5', 'Y36', 'AE19', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'AC11', 'Y4', 'AE2', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'AC13', 'Y6', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AE29', 'AH32', 'AM5', 'AV32', 'T20', 'V42', 'AC25', 'AE31', 'AH42', 'AN12', 'AV4', 'AF8', 'T22', 'W13', 'AC27', 'AE41', 'AJ13', 'AN17', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'W19', 'AA13', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'W2', 'AA15', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'W21', 'AR11', 'AA17', 'AC4', 'AF22', 'AJ25', 'AN42', 'AW29', 'T8', 'W23', 'AA19', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AA23', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'W27', 'AA25', 'AD12', 'AF28', 'AJ39', 'AP24', 'AW8', 'U17', 'W29', 'AA27', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'W9', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AK2', 'BA10']}] }),
        Part(**{ 'name':'XC5VLX20T-FF323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX20T-FF323'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX20T-FF323\n\nFPGA', 'pins':[
            Pin(num='A10',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='A16',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='H15',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H17',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J18',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K12',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='L12',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='L16',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L4P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='P12',name='IO_L17P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO_L17N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='P17',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO_L6N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='R14',name='IO_L14P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L13P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L6P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L16N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='IO_L5N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO_L5P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L7P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L15N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L13N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L18P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='U18',name='IO_L7N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L15P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L19N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L18N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='V15',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V17',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M8',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N6',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P3',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P7',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='P8',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='P9',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='R4',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R6',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='R7',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='R8',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='R9',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T3',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='T6',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T7',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T8',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T9',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='U3',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U4',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='U8',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='U9',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V7',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='A2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='E1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='E2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='F2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='G2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='H1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='H2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='J1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=4),
            Pin(num='K1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='L1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='L2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='M2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='B3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=5),
            Pin(num='D3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=5),
            Pin(num='F3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=5),
            Pin(num='F5',name='MGTRREF_112',func=pin_types.PWRIN,unit=5),
            Pin(num='G4',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=5),
            Pin(num='K3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=5),
            Pin(num='L4',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=5),
            Pin(num='M3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=5),
            Pin(num='A4',name='CS_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='B5',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='E10',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='E11',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='E6',name='RDWR_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='F11',name='HSWAPEN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='D_IN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='J9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='K10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='N5',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D5',name='VBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='AVDD_0',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='AVSS_0',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J13',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L6',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A6', 'D12', 'A11', 'B16', 'C15', 'D8', 'E7', 'F7', 'B18', 'C16', 'D13', 'D9', 'E8', 'A7', 'F8', 'B6', 'A8', 'C17', 'D14', 'E12', 'B7', 'E9', 'G13', 'A13', 'A9', 'B8', 'C18', 'D15', 'E13', 'F13', 'G14', 'B10', 'A12', 'B9', 'C6', 'D16', 'E14', 'F14', 'B11', 'G15', 'A14', 'C10', 'B12', 'C7', 'D17', 'E15', 'C11', 'F16', 'G16', 'A15', 'B13', 'C12', 'C8', 'D18', 'E16', 'A10', 'A16', 'F17', 'B14', 'A18', 'A17', 'C13', 'D10', 'D7', 'B15', 'E17', 'F18']},{'label': 'uB', 'num': 2, 'pin_nums': ['P13', 'J18', 'V13', 'K12', 'P14', 'V14', 'K14', 'P15', 'V15', 'P16', 'K15', 'V16', 'K16', 'P17', 'V17', 'P18', 'K17', 'V18', 'K18', 'R10', 'L12', 'R11', 'L13', 'R12', 'L14', 'R13', 'L15', 'R14', 'L16', 'R15', 'P12', 'L17', 'R16', 'L18', 'R17', 'M10', 'T11', 'M11', 'T12', 'M13', 'T13', 'M14', 'T14', 'M15', 'T16', 'M16', 'T17', 'M18', 'T18', 'N10', 'U10', 'G18', 'N11', 'U11', 'H13', 'N12', 'U13', 'H14', 'N13', 'U14', 'H15', 'N15', 'U15', 'H16', 'N16', 'U16', 'H17', 'U17', 'N17', 'H18', 'N18', 'U18', 'J14', 'P10', 'V10', 'J15', 'P11', 'V11', 'J17', 'V12']},{'label': 'uC', 'num': 3, 'pin_nums': ['P7', 'T5', 'M8', 'R6', 'U4', 'V5', 'N6', 'P8', 'R7', 'T6', 'U5', 'V6', 'N7', 'P9', 'R8', 'T7', 'U6', 'V7', 'N8', 'R1', 'R9', 'T8', 'U8', 'V8', 'P2', 'R2', 'T1', 'T9', 'U9', 'V9', 'P3', 'R3', 'T2', 'U1', 'V1', 'P4', 'R4', 'T3', 'U2', 'V2', 'M7', 'P5', 'R5', 'T4', 'U3', 'V3']},{'label': 'uD', 'num': 4, 'pin_nums': ['C1', 'H1', 'M2', 'C3', 'H2', 'C4', 'J1', 'D1', 'J3', 'E1', 'J4', 'L2', 'A2', 'E2', 'K1', 'B1', 'F2', 'L1', 'B2', 'G2']},{'label': 'uE', 'num': 5, 'pin_nums': ['B3', 'E4', 'F5', 'H3', 'L4', 'F3', 'D3', 'G4', 'K3', 'M3']},{'label': 'uF', 'num': 6, 'pin_nums': ['E6', 'N1', 'J10', 'F11', 'N3', 'J9', 'F6', 'K10', 'N4', 'F9', 'K5', 'N5', 'K9', 'A4', 'G6', 'E11', 'M9', 'H10', 'M5', 'B5', 'M6', 'E10', 'H5', 'H9']},{'label': 'uG', 'num': 7, 'pin_nums': ['L8', 'G3', 'J5', 'K6', 'H6', 'P1', 'B4', 'D5', 'F15', 'G5', 'H7', 'J6', 'K7', 'M1', 'P6', 'D6', 'C14', 'F4', 'G7', 'H8', 'J7', 'K8', 'M12', 'R18', 'C2', 'E18', 'G1', 'G8', 'J11', 'J8', 'L11', 'M17', 'T10', 'C5', 'E3', 'G10', 'G9', 'J12', 'K11', 'L3', 'M4', 'T15', 'E5', 'A1', 'C9', 'G11', 'H11', 'J13', 'K13', 'L5', 'N14', 'U12', 'D11', 'F1', 'A3', 'G12', 'H12', 'J16', 'K2', 'L6', 'N2', 'U7', 'B17', 'F10', 'A5', 'D2', 'F12', 'G17', 'H4', 'J2', 'K4', 'L7', 'N9', 'V4', 'D4']}] }),
        Part(**{ 'name':'XC5VLX220-FF1760', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX220-FF1760'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX220-FF1760\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R27',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U40',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA38',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC4',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC5',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD3',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AE2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AF1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AG2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH1',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ3',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP1',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AR2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT2',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU1',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M35',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA10',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE36',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G4',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V5',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='W10',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y10',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB8',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB9',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC9',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD11',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AF4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG4',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ6',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL4',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM4',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN4',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AP3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR3',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H37',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AH16',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH29',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ16',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ17',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ30',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK15',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL15',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL29',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL30',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E5',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F5',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H6',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J5',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J6',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L7',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M5',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M6',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P6',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P8',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R7',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R9',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T11',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T9',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U7',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE10',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF12',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG12',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG9',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH11',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AL7',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AL9',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AM7',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM8',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN6',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN8',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP5',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP6',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP7',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP9',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR5',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT4',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT5',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT6',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU3',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU4',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV3',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV4',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV5',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='IO_L14P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E13',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='IO_L18P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E8',name='IO_L18N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E9',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F10',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F11',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F12',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F3',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F7',name='IO_L19P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F9',name='IO_L15P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G11',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G12',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G13',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G40',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='G8',name='IO_L19N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G9',name='IO_L15N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H10',name='IO_L13N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H11',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='H8',name='IO_L16P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H9',name='IO_L13P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J10',name='IO_L7P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='IO_L7N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J12',name='IO_L6N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J4',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='IO_L16N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K12',name='IO_L6P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K8',name='IO_L17P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K9',name='IO_L17N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L10',name='IO_L5N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L11',name='IO_L5P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L12',name='IO_L2N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L9',name='IO_L4P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M11',name='IO_L3N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M12',name='IO_L2P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N10',name='IO_L1N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N11',name='IO_L3P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P10',name='IO_L1P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P11',name='IO_L0N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P12',name='IO_L0P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ10',name='IO_L18P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ11',name='IO_L18N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L19P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK10',name='IO_L17P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L19N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL10',name='IO_L17N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL11',name='IO_L16P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL12',name='IO_L16N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM11',name='IO_L15N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM12',name='IO_L15P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM9',name='IO_L13P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN10',name='IO_L13N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN11',name='IO_L14P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP11',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP12',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AP8',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR10',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR12',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AR6',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AR7',name='IO_L3P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR8',name='IO_L3N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR9',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT10',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT11',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT12',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT3',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT7',name='IO_L2P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT9',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU11',name='IO_L7N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU12',name='IO_L6N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU13',name='IO_L6P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AU6',name='IO_L2N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU7',name='IO_L0N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU8',name='IO_L1P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU9',name='IO_L4P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV10',name='IO_L5P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV11',name='IO_L7P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV6',name='IO_L0P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV8',name='IO_L1N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV9',name='IO_L5N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AW4',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='C32',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='D9',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='E6',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='G10',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=11),
            Pin(num='J24',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J30',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K13',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K14',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K28',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K29',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L15',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L16',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L29',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M16',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M27',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N26',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='AV7',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='BA8',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='H27',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='B15',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='C12',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='F13',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='AK17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK27',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK28',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL16',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM13',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM27',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM28',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN13',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN16',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN28',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN29',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN30',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP13',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP30',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AT13',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AV17',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AW14',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AY11',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='BA18',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ18',name='IO_L16N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ25',name='IO_L17P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK18',name='IO_L1P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK19',name='IO_L16P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK24',name='IO_L17N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK25',name='IO_L19N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL17',name='IO_L1N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL19',name='IO_L18P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL24',name='IO_L19P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL25',name='IO_L15P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL26',name='IO_L0P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM17',name='IO_L3N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM18',name='IO_L3P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM19',name='IO_L18N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM24',name='IO_L15N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM26',name='IO_L0N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN18',name='IO_L5P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN19',name='IO_L7P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN25',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN26',name='IO_L4P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP16',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP17',name='IO_L5N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP18',name='IO_L7N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP26',name='IO_L6P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP27',name='IO_L2N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP28',name='IO_L2P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR13',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR14',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR15',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR27',name='IO_L6N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR28',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR29',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR30',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT14',name='IO_L14P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT15',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AT29',name='IO_L13N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT30',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AU29',name='IO_L13P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='G14',name='IO_L1P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G16',name='IO_L3N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G27',name='IO_L15P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G28',name='IO_L17P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G29',name='IO_L17N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H14',name='IO_L1N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H15',name='IO_L7P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H16',name='IO_L3P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J15',name='IO_L7N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J16',name='IO_L5N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J17',name='IO_L5P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J26',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J27',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J28',name='IO_L13P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K17',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K18',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K19',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K24',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K27',name='IO_L13N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L17',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L19',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L24',name='IO_L2N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L25',name='IO_L2P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L26',name='IO_L6N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M17',name='IO_L14P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M24',name='IO_L0P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M26',name='IO_L6P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N18',name='IO_L16P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N19',name='IO_L16N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N24',name='IO_L0N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N25',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P18',name='IO_L18N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P25',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='R18',name='IO_L18P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AR16',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AE30',name='TCK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF14',name='TMS_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF15',name='CCLK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF30',name='M1_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG14',name='TDI_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG29',name='M0_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='AH14',name='TDO_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH28',name='M2_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='R14',name='D_IN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T14',name='HSWAPEN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T15',name='DONE_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='U14',name='INIT_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R29',name='VBATT_0',func=pin_types.PWRIN,unit=18),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=19)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['H41', 'N30', 'R27', 'M29', 'P27', 'U41', 'Y37', 'AA37', 'J14', 'N40', 'P28', 'R28', 'U42', 'J41', 'Y38', 'M41', 'AA39', 'AA40', 'J42', 'M42', 'N41', 'P30', 'R40', 'V37', 'Y39', 'AA41', 'K42', 'N13', 'P13', 'P40', 'AA42', 'R42', 'V40', 'Y40', 'L40', 'N14', 'P15', 'P41', 'E16', 'T40', 'V41', 'Y41', 'L41', 'F41', 'N15', 'P16', 'N29', 'P42', 'T41', 'W40', 'P26', 'Y42', 'M13', 'F42', 'R17', 'L42', 'N28', 'P17', 'R15', 'T42', 'U40', 'W41', 'W42', 'G41', 'G42']},{'label': 'uB', 'num': 2, 'pin_nums': ['AF42', 'K2', 'AG41', 'L1', 'AG42', 'L2', 'AH40', 'M1', 'AH41', 'M2', 'AJ40', 'M3', 'AJ41', 'N1', 'AA1', 'AJ42', 'N3', 'AA2', 'AK40', 'P1', 'AA38', 'AK42', 'P2', 'AA4', 'AL40', 'P3', 'AA5', 'AL41', 'R2', 'AA8', 'AL42', 'R3', 'AB35', 'AM41', 'T1', 'AB37', 'AM42', 'T2', 'AB38', 'AN41', 'U1', 'AB39', 'AP41', 'U2', 'AB41', 'AP42', 'U3', 'AB42', 'AR42', 'V1', 'AB5', 'AT41', 'V3', 'AC38', 'AT42', 'V4', 'AC39', 'AU41', 'W1', 'AC40', 'AU42', 'W2', 'AC41', 'AV41', 'W3', 'AD39', 'E2', 'W4', 'AD40', 'F1', 'Y2', 'AD41', 'F2', 'Y3', 'AD42', 'G1', 'Y4', 'AE40', 'G2', 'Y5', 'AE42', 'H1', 'AF40', 'J1', 'AF41', 'J2']},{'label': 'uC', 'num': 3, 'pin_nums': ['P37', 'AB1', 'AM1', 'P38', 'AB2', 'AM2', 'P39', 'AB3', 'AM3', 'R36', 'AB4', 'AN1', 'R37', 'AB6', 'AP1', 'R38', 'AC1', 'AP2', 'R39', 'AC3', 'AR2', 'T37', 'AC4', 'AT1', 'T39', 'AA36', 'AC5', 'AT2', 'U37', 'AC6', 'AU1', 'U38', 'AD1', 'AU2', 'U39', 'AD2', 'E39', 'V38', 'AD3', 'E40', 'V39', 'AD9', 'F39', 'W35', 'AE2', 'F40', 'W36', 'AE3', 'G38', 'W37', 'AE6', 'G39', 'W38', 'AF1', 'H38', 'Y34', 'AF2', 'H39', 'Y35', 'AG1', 'H40', 'AG10', 'J38', 'AG2', 'J40', 'AG3', 'K38', 'AH1', 'K39', 'AH3', 'K40', 'AJ1', 'L39', 'AJ2', 'M35', 'AJ3', 'M38', 'AK2', 'M39', 'AA34', 'AK3', 'N38', 'AA35', 'AL1', 'N39', 'AL2']},{'label': 'uD', 'num': 4, 'pin_nums': ['AD37', 'AT39', 'W10', 'AT40', 'AD38', 'W11', 'AE36', 'AU39', 'W5', 'AV40', 'AE37', 'W6', 'AE38', 'E3', 'W7', 'AE39', 'E4', 'W8', 'AF37', 'F4', 'Y10', 'AF39', 'G3', 'Y7', 'AG37', 'G4', 'Y8', 'AG38', 'H3', 'Y9', 'AG39', 'H4', 'AG40', 'J3', 'AH37', 'K3', 'AH38', 'K4', 'AH39', 'L4', 'AJ37', 'L5', 'AJ38', 'M4', 'AR40', 'AK37', 'N4', 'AK38', 'N5', 'AK39', 'P5', 'AA10', 'AL37', 'R4', 'AA11', 'AL39', 'R5', 'AA6', 'AM37', 'R6', 'AA7', 'AM38', 'T3', 'AA9', 'AM39', 'T4', 'AB34', 'AN38', 'T5', 'AB36', 'AN39', 'T6', 'AC34', 'AN40', 'U4', 'AC35', 'AP38', 'U6', 'AC36', 'AP40', 'V5', 'AD35', 'AR39', 'V6', 'AD36', 'V7']},{'label': 'uE', 'num': 5, 'pin_nums': ['AF6', 'Y33', 'AG4', 'J35', 'AG6', 'J36', 'AH4', 'J37', 'AH5', 'K35', 'AH6', 'K37', 'AH7', 'K41', 'AJ4', 'L35', 'AJ5', 'L36', 'AJ6', 'L37', 'AK4', 'L38', 'AA32', 'AK5', 'M36', 'AB11', 'AL4', 'M37', 'AB7', 'AL5', 'N35', 'AB8', 'AL6', 'N36', 'AB9', 'AM4', 'P35', 'AC10', 'AM6', 'P36', 'AC11', 'AN3', 'R34', 'AC8', 'AN4', 'R35', 'AC9', 'AN5', 'T34', 'AD10', 'AP3', 'T35', 'AD11', 'AR3', 'T36', 'AD5', 'AR4', 'U33', 'AD6', 'D37', 'U34', 'AD7', 'E37', 'U36', 'AD8', 'E38', 'V33', 'AE4', 'F36', 'V34', 'AE5', 'F37', 'V35', 'AE7', 'G36', 'V36', 'AF3', 'G37', 'W32', 'AF4', 'H35', 'H37', 'W33', 'AF5', 'H36', 'Y32']},{'label': 'uF', 'num': 6, 'pin_nums': ['V11', 'M6', 'T11', 'P7', 'AJ26', 'AK30', 'F5', 'J7', 'M7', 'P8', 'T7', 'V8', 'AJ27', 'AL14', 'F6', 'AH16', 'K5', 'M8', 'P9', 'T9', 'V9', 'AH29', 'AJ28', 'AL15', 'G6', 'K7', 'M9', 'R10', 'U11', 'AH30', 'AJ30', 'AL29', 'G7', 'L6', 'N6', 'R7', 'U7', 'AJ13', 'AK13', 'AL30', 'H5', 'L7', 'N8', 'R8', 'U8', 'AK14', 'AJ15', 'AR26', 'H6', 'L8', 'N9', 'R9', 'U9', 'AJ17', 'AJ16', 'AK15', 'AV27', 'E5', 'J5', 'J6', 'M5', 'P6', 'T10', 'V10', 'AK29']},{'label': 'uG', 'num': 7, 'pin_nums': ['AH34', 'AN8', 'AP35', 'AH35', 'AH36', 'AP36', 'AB32', 'AP37', 'AH8', 'AB33', 'AH9', 'AP5', 'AC33', 'AJ34', 'AP6', 'AD32', 'AJ35', 'AP7', 'AD33', 'AJ36', 'AP9', 'AE10', 'AJ7', 'AR37', 'AE32', 'AJ8', 'AR38', 'AE33', 'AK34', 'AR5', 'AE34', 'AK35', 'AT36', 'AE35', 'AK7', 'AT37', 'AE8', 'AK8', 'AT4', 'AE9', 'AK9', 'AT5', 'AF10', 'AL34', 'AT6', 'AF11', 'AL35', 'AU3', 'AF12', 'AL36', 'AU37', 'AF34', 'AL38', 'AU38', 'AF35', 'AL7', 'AU4', 'AF36', 'AL8', 'AV3', 'AF7', 'AL9', 'AV38', 'AF9', 'AM34', 'AV39', 'AG11', 'AM35', 'AV4', 'AG12', 'AM36', 'AV5', 'AG34', 'AM5', 'AG36', 'AM7', 'AG7', 'AM8', 'AG8', 'AN34', 'AG9', 'AN35', 'AH10', 'AN36', 'AH11', 'AN6']},{'label': 'uH', 'num': 8, 'pin_nums': ['H7', 'H8', 'E35', 'N31', 'E36', 'H9', 'N33', 'E7', 'J10', 'N34', 'E8', 'J11', 'P10', 'E9', 'J12', 'P11', 'F10', 'J31', 'P12', 'F11', 'J32', 'P31', 'F12', 'J33', 'P32', 'F3', 'J4', 'P33', 'F31', 'J8', 'R32', 'F32', 'K10', 'R33', 'F34', 'K12', 'T31', 'F35', 'K32', 'T32', 'F7', 'K33', 'U31', 'F9', 'K34', 'U32', 'G11', 'K8', 'G12', 'K9', 'G13', 'L10', 'G31', 'L11', 'G32', 'L12', 'G33', 'L31', 'G34', 'L32', 'G40', 'L34', 'G8', 'L9', 'G9', 'M11', 'D39', 'H10', 'M12', 'E10', 'H11', 'M31', 'E12', 'H13', 'M32', 'E13', 'H31', 'M33', 'E32', 'H33', 'M34', 'N11', 'E33', 'H34', 'N10', 'E34']},{'label': 'uI', 'num': 9, 'pin_nums': ['AK33', 'AV35', 'AR6', 'AL10', 'AV36', 'AR7', 'AL11', 'AR8', 'AV6', 'AL12', 'AV8', 'AR9', 'AL31', 'AT10', 'AV9', 'AL32', 'AW4', 'AT11', 'AM11', 'AT12', 'AM12', 'AT3', 'AM31', 'AT31', 'AM32', 'AT32', 'AM33', 'AT34', 'AM9', 'AT35', 'AN10', 'AT7', 'AN11', 'AT9', 'AN31', 'AU11', 'AN33', 'AU12', 'AF31', 'AN9', 'AU13', 'AF32', 'AP10', 'AU31', 'AG31', 'AP11', 'AU32', 'AK32', 'AG32', 'AP12', 'AU33', 'AG33', 'AP31', 'AU34', 'AH31', 'AP32', 'AU36', 'AH33', 'AP33', 'AU40', 'AJ10', 'AP39', 'AU6', 'AJ11', 'AP8', 'AU7', 'AJ12', 'AR10', 'AU8', 'AJ31', 'AR12', 'AU9', 'AJ32', 'AR32', 'AV10', 'AJ33', 'AR33', 'AV11', 'AK10', 'AR34', 'AV31', 'AK12', 'AR35', 'AV33', 'AR36', 'AV34']},{'label': 'uJ', 'num': 10, 'pin_nums': ['G10', 'C32', 'E6', 'F33', 'D9', 'B35']},{'label': 'uK', 'num': 11, 'pin_nums': ['E26', 'K29', 'M14', 'J13', 'K30', 'M16', 'J24', 'L14', 'M27', 'J30', 'L15', 'M28', 'K13', 'L16', 'N16', 'AT33', 'K14', 'L27', 'N26', 'AV37', 'K15', 'L29', 'AW34', 'K28', 'L30']},{'label': 'uL', 'num': 12, 'pin_nums': ['H27', 'D29', 'AV7', 'AU10', 'G30', 'BA8']},{'label': 'uM', 'num': 13, 'pin_nums': ['BA28', 'F13', 'AY31', 'B15', 'C12', 'AU30']},{'label': 'uN', 'num': 14, 'pin_nums': ['AN15', 'AM13', 'AV17', 'AW14', 'AN16', 'AM14', 'AM16', 'AN28', 'AY11', 'AN29', 'BA18', 'AK17', 'AM27', 'AL27', 'AT13', 'AK27', 'AM28', 'AN30', 'AM29', 'AP13', 'AK28', 'AL16', 'AN13', 'AP30', 'AN14']},{'label': 'uO', 'num': 15, 'pin_nums': ['H14', 'P18', 'AP15', 'H15', 'P25', 'AP16', 'H16', 'R18', 'AP17', 'H28', 'AP18', 'H29', 'AP26', 'H30', 'AP27', 'J15', 'AP28', 'J16', 'AR13', 'J17', 'AR14', 'J26', 'AR15', 'J27', 'AR17', 'J28', 'AR27', 'K17', 'AJ18', 'AR28', 'K18', 'AJ25', 'AR29', 'K19', 'AK18', 'AR30', 'K24', 'AK19', 'AT14', 'K25', 'AK24', 'AT15', 'K27', 'AK25', 'AT23', 'L17', 'AL17', 'AT29', 'L19', 'AL19', 'AT30', 'L24', 'AL24', 'AU29', 'L25', 'AL25', 'AW24', 'L26', 'AL26', 'AY21', 'M17', 'AM17', 'B25', 'M18', 'AM18', 'C22', 'M19', 'AM19', 'F23', 'M24', 'AM24', 'G14', 'M26', 'AM26', 'G16', 'N18', 'AN18', 'G27', 'N19', 'AN19', 'AN26', 'G28', 'N24', 'AN25', 'G29', 'N25']},{'label': 'uP', 'num': 16, 'pin_nums': ['AP19', 'G20', 'AU20', 'D19', 'AR16', 'H17']},{'label': 'uQ', 'num': 17, 'pin_nums': ['T30', 'AE30', 'AH15', 'AH28', 'AF14', 'U14', 'AA21', 'AF15', 'AL28', 'AA22', 'AF30', 'R14', 'AB21', 'AG14', 'R30', 'AB22', 'AG29', 'T14', 'AC21', 'AG30', 'T15', 'AC22', 'AH14', 'T29']},{'label': 'uR', 'num': 18, 'pin_nums': ['L28', 'U30', 'AC20', 'AG18', 'E31', 'L3', 'R24', 'V13', 'AG20', 'AC24', 'E41', 'L33', 'R25', 'V15', 'A13', 'AC26', 'AG22', 'F18', 'M10', 'R26', 'V17', 'A18', 'AC28', 'AG24', 'F28', 'M15', 'R29', 'V19', 'A23', 'AC30', 'AG26', 'F38', 'M20', 'R31', 'V21', 'A28', 'AD13', 'AG28', 'F8', 'M25', 'R41', 'V23', 'A3', 'AD15', 'AH13', 'G15', 'M30', 'T12', 'V25', 'A33', 'AH17', 'AD17', 'G25', 'M40', 'T13', 'V27', 'A38', 'AD19', 'AH19', 'G35', 'N12', 'T16', 'V29', 'A8', 'AD21', 'AH21', 'G5', 'N17', 'T17', 'W12', 'AA12', 'AD23', 'AH23', 'H12', 'N2', 'T18', 'W14', 'AA14', 'AD25', 'AH25', 'H2', 'N27', 'AG16', 'T19', 'W16', 'AA16', 'AD27', 'AH27', 'H22', 'N32', 'T20', 'W18', 'AA18', 'AD29', 'AJ24', 'H32', 'N37', 'T21', 'W20', 'AA20', 'AE12', 'B10', 'H42', 'N42', 'T22', 'W22', 'AA24', 'AE14', 'B20', 'J19', 'N7', 'T23', 'W24', 'AA26', 'AE16', 'B30', 'J29', 'P14', 'T24', 'W26', 'AA28', 'AE18', 'B40', 'J34', 'P19', 'T25', 'W28', 'AA30', 'AE20', 'B5', 'J39', 'P24', 'T26', 'W30', 'AB13', 'AE22', 'C17', 'J9', 'P29', 'T27', 'Y13', 'AB15', 'AE24', 'C2', 'K1', 'P34', 'T28', 'Y15', 'AB17', 'AE26', 'C27', 'K11', 'P4', 'T33', 'Y17', 'AB19', 'AE28', 'C37', 'K16', 'R1', 'T8', 'Y19', 'AB23', 'AF13', 'C42', 'K21', 'R11', 'U12', 'Y21', 'AB25', 'AF17', 'C7', 'K26', 'R12', 'U16', 'Y22', 'AB27', 'AF19', 'D14', 'K31', 'R13', 'U18', 'Y23', 'AB29', 'AF21', 'D24', 'K36', 'R16', 'U20', 'Y25', 'AB31', 'AF23', 'D34', 'K6', 'R19', 'U22', 'Y27', 'AC12', 'AF25', 'D4', 'L13', 'R20', 'U24', 'Y29', 'AC14', 'AF27', 'E1', 'L18', 'R21', 'R23', 'U26', 'Y31', 'AC16', 'AF29', 'E11', 'L23', 'R22', 'U28', 'AC18', 'E21']},{'label': 'uS', 'num': 19, 'pin_nums': ['AK11', 'V28', 'BA33', 'AC37', 'AA15', 'AF24', 'AK16', 'AR1', 'BA38', 'V30', 'AC42', 'AA17', 'AF26', 'AK21', 'AR11', 'BB10', 'V32', 'AA19', 'AC7', 'AF28', 'AK26', 'AR21', 'BB15', 'V42', 'AA23', 'AD12', 'AF33', 'AK31', 'AR31', 'BB20', 'W13', 'AA25', 'AD14', 'AF38', 'AK36', 'AR41', 'BB25', 'W15', 'AA27', 'AD16', 'AF8', 'AK41', 'AT18', 'BB30', 'W17', 'AA29', 'AD18', 'AG13', 'AK6', 'AT28', 'BB35', 'W19', 'AA3', 'AD20', 'AG15', 'AL13', 'AT38', 'BB40', 'W21', 'AA31', 'AD22', 'AG17', 'AL18', 'AT8', 'BB5', 'W23', 'AA33', 'AD24', 'AG19', 'AL23', 'AU15', 'T38', 'W25', 'AB10', 'AD26', 'AG21', 'AL3', 'AU25', 'U10', 'W27', 'AB12', 'AD28', 'AG23', 'AL33', 'AU35', 'U13', 'W29', 'AB14', 'AD30', 'AG25', 'AM10', 'AU5', 'U15', 'W31', 'AB16', 'AD34', 'AG27', 'AM15', 'AV12', 'U17', 'W34', 'AB18', 'AD4', 'AG35', 'AM20', 'AV2', 'U19', 'W39', 'AB20', 'AE1', 'AG5', 'AM25', 'AV22', 'U21', 'W9', 'AB24', 'AE11', 'AH12', 'AM30', 'AV32', 'U23', 'Y1', 'AB26', 'AE13', 'AH18', 'AM40', 'AV42', 'U25', 'Y11', 'AB28', 'AE15', 'AH2', 'AN12', 'AW19', 'U27', 'Y12', 'AB30', 'AE17', 'AH20', 'AN17', 'AW29', 'U29', 'Y14', 'AB40', 'AE19', 'AH22', 'AN2', 'AW39', 'U35', 'Y16', 'AC13', 'AE21', 'AH24', 'AN22', 'AW9', 'U5', 'Y18', 'AC15', 'AE23', 'AH26', 'AN27', 'AY1', 'V12', 'Y20', 'AC17', 'AE25', 'AH32', 'AN32', 'AY16', 'V14', 'Y24', 'AC19', 'AE27', 'AH42', 'AN37', 'AY26', 'V16', 'Y26', 'AC2', 'AE29', 'AJ14', 'AN42', 'AY36', 'V18', 'Y28', 'AC23', 'AE31', 'AJ19', 'AN7', 'AY41', 'V2', 'Y30', 'AE41', 'AC25', 'AJ29', 'AP14', 'AC32', 'AY6', 'V20', 'Y36', 'AC27', 'AF16', 'AJ39', 'AP24', 'BA13', 'V22', 'Y6', 'AC29', 'AF18', 'AJ9', 'AP29', 'AP4', 'BA23', 'V24', 'AC31', 'AF20', 'AK1', 'AP34', 'BA3', 'V26', 'AA13', 'AF22']}] }),
        Part(**{ 'name':'XC5VLX220T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX220T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX220T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='C32',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP9',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AU10',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AV7',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=12),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=12),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=14),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=15),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=16),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=17),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=18),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=18),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=18),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AW16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=18),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=18),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=18),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=18),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=18),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=18),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=18),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='D15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=18),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=18),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=18),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=18),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=18),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=18),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=18),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=18),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=18),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=18),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=18),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=19),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=19),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=19),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=20),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=20),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=20),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=20),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=21),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=21)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['J41', 'P26', 'T40', 'N29', 'M42', 'W40', 'AA39', 'J42', 'N13', 'N30', 'P27', 'T41', 'AA41', 'W41', 'K42', 'N14', 'N40', 'P28', 'T42', 'AA42', 'L40', 'W42', 'F13', 'L41', 'N15', 'N41', 'P40', 'U41', 'Y37', 'F41', 'L42', 'N16', 'P13', 'P41', 'U42', 'Y38', 'F42', 'M13', 'AA38', 'G41', 'N25', 'P17', 'P42', 'M14', 'V37', 'Y39', 'G42', 'AA37', 'M16', 'N26', 'P18', 'R40', 'V40', 'Y40', 'Y42', 'H41', 'M29', 'N28', 'P25', 'R42', 'V41', 'AA40', 'J14', 'Y41', 'M41']},{'label': 'uB', 'num': 2, 'pin_nums': ['AJ41', 'R4', 'AJ42', 'AA10', 'R5', 'AA11', 'AK40', 'T4', 'AK42', 'AA6', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AL42', 'AA9', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'AR42', 'V8', 'AC38', 'AT41', 'W10', 'AC39', 'AT42', 'W11', 'AC40', 'AU41', 'W5', 'AC41', 'AU42', 'W6', 'AD39', 'AV41', 'W7', 'AD40', 'G6', 'W8', 'AD41', 'H5', 'Y10', 'AD42', 'H6', 'Y7', 'AJ40', 'AE36', 'J5', 'Y8', 'AE40', 'J6', 'Y9', 'K4', 'AE42', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'P6']},{'label': 'uC', 'num': 3, 'pin_nums': ['AD35', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'G38', 'W37', 'AG39', 'G39', 'W38', 'AG40', 'H38', 'Y34', 'AH37', 'H39', 'Y35', 'AH38', 'H40', 'AH39', 'J38', 'AJ37', 'J40', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'L39', 'AK41', 'M38', 'AL37', 'M39', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'AR39', 'R38', 'AC36', 'AP40', 'R39']},{'label': 'uD', 'num': 4, 'pin_nums': ['G37', 'AE10', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'H36', 'AE7', 'Y33', 'AE8', 'J35', 'J36', 'AE9', 'G36', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'AG10', 'L38', 'AA32', 'AG4', 'M36', 'AB11', 'AG6', 'M37', 'AB6', 'AG7', 'N35', 'AB7', 'AH4', 'N36', 'AB8', 'AH5', 'P35', 'AB9', 'AH6', 'P36', 'AC10', 'AJ5', 'R34', 'AC5', 'AJ6', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'AD5', 'E37', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'V36']},{'label': 'uE', 'num': 5, 'pin_nums': ['F5', 'AL29', 'H9', 'AK13', 'AP13', 'L9', 'P9', 'U11', 'AK14', 'AL30', 'AR26', 'F6', 'J7', 'M7', 'R6', 'U8', 'AK15', 'AM13', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AK27', 'AM14', 'D7', 'F9', 'K7', 'M9', 'R8', 'V10', 'AK28', 'AM28', 'E5', 'G7', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'AK29', 'AM29', 'E7', 'G8', 'K9', 'N9', 'T10', 'V9', 'AJ30', 'AK30', 'AN13', 'E8', 'G9', 'L7', 'P7', 'T11', 'AK12', 'AL14', 'AN14', 'E9', 'H8', 'L8', 'P8', 'T9']},{'label': 'uF', 'num': 6, 'pin_nums': ['AL38', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AT37', 'M31', 'AE34', 'AU37', 'M32', 'AE35', 'AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AG36', 'E33', 'P31', 'AH34', 'E34', 'P32', 'AH35', 'E35', 'P33', 'AH36', 'E36', 'R32', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'H31', 'AL36', 'G34']},{'label': 'uG', 'num': 7, 'pin_nums': ['AG32', 'J10', 'AU34', 'AG33', 'J11', 'AU36', 'AH31', 'AU40', 'J12', 'AH33', 'J13', 'AV31', 'AJ31', 'AV33', 'K10', 'AJ32', 'K12', 'AV34', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31', 'E15', 'N11', 'AN33', 'E6', 'P10', 'AP31', 'F10', 'P11', 'AP32', 'F11', 'P12', 'AP33', 'F12', 'R10', 'AP39', 'F14', 'AR32', 'F15', 'AG31', 'AR33', 'G10', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AU33', 'H7']},{'label': 'uH', 'num': 8, 'pin_nums': ['AH10', 'AN8', 'F33', 'AL9', 'AR8', 'AH11', 'AK11', 'AM6', 'AN9', 'AT5', 'J34', 'AH7', 'AK8', 'AM7', 'AP5', 'AT6', 'AH8', 'AK9', 'AM8', 'AP6', 'AT7', 'AG11', 'AH9', 'AL10', 'AM9', 'AP7', 'AU6', 'AG12', 'AJ10', 'AL6', 'AN4', 'AP8', 'AV5', 'AG8', 'AJ11', 'AK10', 'AL7', 'AN5', 'AR5', 'AV6', 'AG9', 'AJ8', 'AL8', 'AN6', 'AR7', 'B35']},{'label': 'uI', 'num': 9, 'pin_nums': ['L14', 'J16', 'M26', 'J17', 'L15', 'M27', 'L16', 'AT33', 'J30', 'M28', 'AV37', 'K15', 'L17', 'AW34', 'K17', 'L27', 'K28', 'E26', 'L29', 'H27', 'K29', 'L30', 'J15', 'K30', 'M17']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AU30', 'BA28', 'D29', 'C32', 'AY31', 'G30']},{'label': 'uK', 'num': 11, 'pin_nums': ['AN30', 'AM16', 'AT13', 'AM17', 'AP15', 'AU10', 'AK17', 'AM26', 'AP16', 'AV7', 'AL15', 'AM27', 'AP27', 'AL16', 'AN15', 'AP28', 'AL17', 'AN16', 'AP30', 'AL26', 'AN28', 'AP9', 'AL27', 'AN29', 'AR16']},{'label': 'uL', 'num': 12, 'pin_nums': ['AL24', 'K18', 'AT29', 'AL25', 'K19', 'AT30', 'AM18', 'AU28', 'K24', 'AM19', 'K25', 'AU29', 'AM24', 'AW24', 'K27', 'AN18', 'L19', 'AY21', 'AT27', 'AN19', 'B25', 'L20', 'AN20', 'C22', 'L24', 'AN24', 'E17', 'L25', 'AN25', 'E18', 'L26', 'AN26', 'F16', 'M18', 'AP17', 'F17', 'M19', 'AP18', 'F23', 'M24', 'AP25', 'F27', 'N18', 'AP26', 'F29', 'N19', 'AR14', 'G16', 'N20', 'AR15', 'G17', 'P20', 'AR17', 'G18', 'AR18', 'G27', 'AR19', 'G28', 'AR27', 'G29', 'AR28', 'H16', 'AR29', 'H18', 'AR30', 'H26', 'AT14', 'H28', 'AT15', 'H29', 'AT16', 'H30', 'AK18', 'AT17', 'J18', 'AK19', 'AT19', 'J25', 'AK24', 'AT23', 'J26', 'AK25', 'AT26', 'J27', 'AL19', 'J28']},{'label': 'uM', 'num': 13, 'pin_nums': ['AV17', 'G20', 'AP19', 'AU20', 'D19', 'H17']},{'label': 'uN', 'num': 14, 'pin_nums': ['AA2', 'AF1', 'V4', 'AB2', 'W1', 'AF2', 'AC1', 'Y1', 'AG2', 'AC2', 'T2', 'Y2', 'AD1', 'U1', 'AD3', 'U2', 'AD4', 'V1', 'AE1', 'V3']},{'label': 'uO', 'num': 15, 'pin_nums': ['AK1', 'L1', 'R2', 'AK3', 'L2', 'AK4', 'M1', 'AL1', 'M3', 'AM1', 'M4', 'AH2', 'AM2', 'N1', 'AJ1', 'AN2', 'P1', 'AJ2', 'K2', 'P2']},{'label': 'uP', 'num': 16, 'pin_nums': ['F4', 'AV1', 'G1', 'AP2', 'AV2', 'AR1', 'AW2', 'H1', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2', 'AT3', 'E2', 'AT4', 'F1', 'AU1', 'F3']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A5', 'BA2', 'C4', 'AW4', 'BA1', 'BA5', 'AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3', 'A2', 'B5', 'BB4', 'A3', 'B6', 'BB5', 'A4', 'C3']},{'label': 'uR', 'num': 18, 'pin_nums': ['D3', 'AE4', 'AN3', 'AY6', 'AW3', 'J3', 'AF3', 'AP3', 'AW5', 'C1', 'D4', 'K3', 'W3', 'AA3', 'AG3', 'AR3', 'AY1', 'C15', 'D5', 'L3', 'W4', 'AA5', 'AH3', 'AU3', 'AY10', 'C2', 'D9', 'N3', 'Y3', 'AB3', 'AJ3', 'AU4', 'AY16', 'C5', 'E3', 'N4', 'AB4', 'AL3', 'AV3', 'AY2', 'C6', 'G3', 'P3', 'AC3', 'AL4', 'AW10', 'AY3', 'C9', 'G4', 'R3', 'U3', 'AE3', 'AM3', 'AW16', 'AY5', 'D15', 'H3', 'T3']},{'label': 'uS', 'num': 19, 'pin_nums': ['AC21', 'R29', 'AH30', 'AC22', 'R30', 'AJ15', 'AB22', 'AG29', 'AJ16', 'R15', 'T14', 'AG30', 'AJ28', 'T30', 'AA21', 'AH14', 'AL28', 'AH15', 'P15', 'AA22', 'AB21', 'AH16', 'R14', 'AH29']},{'label': 'uT', 'num': 20, 'pin_nums': ['AG26', 'K26', 'U12', 'P23', 'A38', 'Y19', 'AD21', 'AG28', 'D8', 'K31', 'U14', 'P24', 'Y21', 'AA12', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'U16', 'AA14', 'Y22', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'AA16', 'Y23', 'AD27', 'AH19', 'E21', 'L13', 'P34', 'U20', 'AA18', 'Y25', 'AD29', 'AH21', 'E31', 'L18', 'P4', 'U22', 'AA20', 'Y27', 'AD31', 'AH23', 'E4', 'L23', 'R11', 'U24', 'AA24', 'Y29', 'AE12', 'AH25', 'E41', 'L28', 'U26', 'R12', 'Y31', 'AA26', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'T29', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'M2', 'R19', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'AB27', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'J9', 'P16', 'T23', 'W30', 'A19', 'AD13', 'AG20', 'D17', 'AD19', 'K11', 'P19', 'T25', 'Y13', 'A23', 'AD15', 'AG22', 'D24', 'D6', 'K16', 'P21', 'T27', 'Y15', 'A28', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'Y17', 'A33']},{'label': 'uU', 'num': 21, 'pin_nums': ['AC13', 'V24', 'AH22', 'AU35', 'AM25', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AU5', 'AM30', 'V28', 'T12', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AE29', 'AH32', 'AM5', 'AV32', 'T20', 'V42', 'AC25', 'AE31', 'AH42', 'AN12', 'AV4', 'T22', 'W13', 'AC27', 'AE41', 'AJ13', 'AN17', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AW11', 'AN22', 'W17', 'T26', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'W19', 'AA13', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'W2', 'AA15', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'W21', 'AA17', 'AC4', 'AF22', 'AJ25', 'AN42', 'AW29', 'T8', 'W23', 'AA19', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AA23', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'W27', 'AA25', 'AD12', 'AF28', 'AJ39', 'AP24', 'AW8', 'U17', 'W29', 'AA27', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AF8', 'AK2', 'AR11', 'BA10', 'U25', 'W9', 'AB10', 'AD20', 'AG13', 'AK21', 'AR21', 'BA15', 'U27', 'Y11', 'AB12', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'Y12', 'AB14', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'Y14', 'AB16', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'Y16', 'AB18', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'Y18', 'AB20', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'Y20', 'AB24', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'V14', 'Y24', 'AB26', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'Y26', 'AU25', 'AB28', 'AE13', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'Y28', 'AB30', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'Y30', 'AB40', 'AE17', 'AH12', 'AM10', 'AU15', 'BB30', 'V20', 'Y36', 'AB5', 'AE19', 'AE21', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'Y4', 'AC11', 'AE2', 'AH20', 'AM20', 'BB40', 'Y6']}] }),
        Part(**{ 'name':'XC5VLX30-FF324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX30-FF324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX30-FF324\n\nFPGA', 'pins':[
            Pin(num='A13',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='F16',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A1',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A2',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B4',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='C5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='F6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='M18',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='N15',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P17',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L1N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L1P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='VCCO_18',func=pin_types.PWRIN,unit=3),
            Pin(num='K4',name='IO_L0N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='K5',name='IO_L0P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L3N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L3P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L4P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L2P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L5N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L6N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L6P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L2N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L5P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N10',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N11',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L7P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L7N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='VCCO_18',func=pin_types.PWRIN,unit=3),
            Pin(num='N5',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N6',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='IO_L13P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P10',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P12',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P3',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L15P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P7',name='IO_L13N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P9',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R15',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L15N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='IO_L17P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R6',name='IO_L17N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R8',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='R9',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T13',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T14',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T16',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T3',name='IO_L18N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L19P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='VCCO_18',func=pin_types.PWRIN,unit=3),
            Pin(num='T7',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T8',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T9',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=3),
            Pin(num='U16',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L18P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='U4',name='IO_L19N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L14P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L16P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L16N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='A10',name='VCCO_3',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A12',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A7',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C10',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C8',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='VCCO_3',func=pin_types.PWRIN,unit=4),
            Pin(num='D9',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='VCCO_4',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='R11',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='R12',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='T12',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U11',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U12',name='VCCO_4',func=pin_types.PWRIN,unit=4),
            Pin(num='U13',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U14',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U15',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U9',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V11',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V12',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V13',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V15',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V6',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='N12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='N13',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P15',name='RDWR_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R16',name='CS_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R18',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='D_IN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T15',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='HSWAPEN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T6',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U18',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='AVDD_0',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='AVSS_0',func=pin_types.PWRIN,unit=6),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T18',name='VBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['F11', 'G16', 'H18', 'F7', 'B13', 'C17', 'E12', 'F12', 'F8', 'G18', 'B14', 'C18', 'J14', 'B15', 'C6', 'E14', 'F13', 'F9', 'G8', 'J15', 'B16', 'D12', 'A14', 'E15', 'F14', 'G10', 'B18', 'G9', 'J16', 'D13', 'A13', 'B7', 'E16', 'F15', 'G11', 'D14', 'H13', 'J17', 'C12', 'D15', 'E17', 'F16', 'G13', 'H15', 'J18', 'C13', 'A17', 'D17', 'E7', 'F17', 'G14', 'H16', 'C14', 'K17', 'D18', 'A16', 'C15', 'D8', 'E8', 'F18', 'D7', 'G15', 'H17', 'A18', 'C16']},{'label': 'uB', 'num': 2, 'pin_nums': ['C2', 'A2', 'E1', 'F4', 'G6', 'J4', 'L17', 'N14', 'A3', 'C3', 'E2', 'H1', 'J5', 'L18', 'N15', 'F5', 'A4', 'C4', 'E4', 'F6', 'H2', 'K14', 'M13', 'N16', 'B1', 'C5', 'E5', 'G1', 'H3', 'K15', 'M14', 'N17', 'G5', 'B3', 'D2', 'E6', 'G2', 'H5', 'K16', 'L16', 'M15', 'M18', 'N18', 'R17', 'B4', 'D3', 'F1', 'G3', 'H6', 'L13', 'M16', 'P17', 'B5', 'D4', 'F2', 'G4', 'J2', 'L14', 'M17', 'P18', 'A1', 'C1', 'D5', 'F3', 'J3']},{'label': 'uC', 'num': 3, 'pin_nums': ['P4', 'T2', 'U16', 'V3', 'R5', 'K1', 'L4', 'M6', 'N6', 'P5', 'R6', 'T3', 'U3', 'V9', 'L6', 'N1', 'K2', 'N7', 'P7', 'R8', 'T4', 'U4', 'K3', 'M1', 'N10', 'P10', 'P9', 'R9', 'T5', 'V1', 'M10', 'K4', 'N11', 'P12', 'R1', 'T1', 'T7', 'V16', 'K5', 'M11', 'N2', 'P13', 'R15', 'T13', 'T8', 'V17', 'L1', 'M3', 'N3', 'P2', 'R2', 'T14', 'T9', 'V18', 'L3', 'L2', 'M4', 'N4', 'N5', 'P3', 'R4', 'T16', 'U1', 'V2', 'M5']},{'label': 'uD', 'num': 4, 'pin_nums': ['A9', 'C7', 'P11', 'U12', 'V12', 'B10', 'C8', 'U13', 'V13', 'R10', 'A10', 'B11', 'D10', 'R11', 'U14', 'V15', 'A11', 'B6', 'D11', 'R12', 'U15', 'V6', 'A12', 'B8', 'D9', 'T11', 'U8', 'V7', 'A6', 'B9', 'E10', 'T12', 'U9', 'V8', 'U11', 'A7', 'C10', 'E11', 'U10', 'V10', 'A8', 'C11', 'E9', 'V11']},{'label': 'uE', 'num': 5, 'pin_nums': ['N12', 'N13', 'T17', 'K10', 'N8', 'T6', 'K9', 'L10', 'P15', 'U18', 'P8', 'U5', 'L11', 'L9', 'R16', 'U6', 'M8', 'R18', 'V5', 'J10', 'M9', 'R7', 'T15', 'J9']},{'label': 'uF', 'num': 6, 'pin_nums': ['A5', 'E13', 'H11', 'J11', 'K13', 'L7', 'P6', 'V14', 'B12', 'E18', 'J12', 'K18', 'L8', 'R13', 'V4', 'H12', 'B17', 'E3', 'H14', 'J13', 'K6', 'M12', 'R3', 'B2', 'F10', 'H4', 'J6', 'K7', 'M2', 'T10', 'J1', 'C9', 'G12', 'H7', 'J7', 'K8', 'L5', 'M7', 'P16', 'T18', 'U7', 'D1', 'G17', 'H8', 'J8', 'L12', 'N9', 'U17', 'D16', 'G7', 'H9', 'K11', 'L15', 'P1', 'U2', 'A15', 'D6', 'H10', 'K12']}] }),
        Part(**{ 'name':'XC5VLX30-FF676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX30-FF676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX30-FF676\n\nFPGA', 'pins':[
            Pin(num='C10',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='F22',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC26',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F7',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G24',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='J24',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K25',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M23',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='M24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='N24',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N26',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V26',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA2',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C20',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='C21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E3',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='T2',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='W1',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='Y1',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A12',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A2',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A7',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA19',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA20',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA22',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA23',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA24',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB19',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB20',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB24',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC19',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B12',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C12',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C13',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D3',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='R20',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='R21',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T19',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T20',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T21',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='T22',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T23',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U19',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U20',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U21',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U22',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V19',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V21',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V22',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W20',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W21',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W22',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y20',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y21',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y23',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA3',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AA7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA8',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA9',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB14',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB15',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AB4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC3',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC6',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AD3',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD4',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AE3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T4',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T5',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T7',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U4',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U7',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V3',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V4',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W3',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y3',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB9',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AC11',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC7',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD13',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD14',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD15',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD18',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AD8',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='D13',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D14',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D15',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E10',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E11',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E12',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E13',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E14',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E16',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E17',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E18',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F12',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F14',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F17',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F18',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F19',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F8',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='CCLK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='INIT_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='J18',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='DONE_0',func=pin_types.BIDIR,unit=7),
            Pin(num='K11',name='D_IN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='L18',name='HSWAPEN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N13',name='VREFN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N14',name='VP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N18',name='CS_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P13',name='VN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P14',name='VREFP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P18',name='RDWR_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R13',name='DXN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R14',name='DXP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='U11',name='TCK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='V11',name='TDI_0',func=pin_types.BIDIR,unit=7),
            Pin(num='V12',name='TMS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='V18',name='M2_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W10',name='TDO_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W11',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W12',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='M0_0',func=pin_types.BIDIR,unit=7),
            Pin(num='Y17',name='M1_0',func=pin_types.BIDIR,unit=7),
            Pin(num='Y9',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K18',name='VBATT_0',func=pin_types.PWRIN,unit=8),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='AVSS_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M14',name='AVDD_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T9',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V9',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W16',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G17', 'H13', 'G19', 'H25', 'H14', 'K20', 'F23', 'J23', 'M19', 'P19', 'L23', 'N23', 'G20', 'H16', 'H8', 'K21', 'M20', 'P20', 'G10', 'E22', 'E21', 'G11', 'G21', 'H17', 'H9', 'K22', 'M21', 'P21', 'E23', 'G12', 'G22', 'H18', 'J19', 'K23', 'M22', 'P23', 'F11', 'G14', 'G9', 'H19', 'J20', 'L19', 'N19', 'R22', 'C10', 'F13', 'G15', 'H11', 'H21', 'J21', 'F15', 'L20', 'N21', 'R23', 'E20', 'F20', 'G16', 'H12', 'H22', 'J22', 'L22', 'N22', 'F21', 'H23', 'F22']},{'label': 'uB', 'num': 2, 'pin_nums': ['L3', 'L4', 'F25', 'R7', 'F4', 'L5', 'T24', 'F5', 'L6', 'T25', 'F7', 'L7', 'T3', 'G24', 'M23', 'U24', 'G25', 'M24', 'U25', 'G26', 'M25', 'U26', 'G4', 'M26', 'V26', 'G5', 'M4', 'W25', 'G6', 'M5', 'W26', 'G7', 'M6', 'Y25', 'H24', 'M7', 'Y26', 'H26', 'N20', 'H4', 'N24', 'H5', 'N26', 'H6', 'N3', 'H7', 'N4', 'J2', 'N6', 'J24', 'N7', 'J25', 'P24', 'J26', 'P25', 'J4', 'P26', 'AA25', 'J5', 'P3', 'AB25', 'J6', 'P4', 'AB26', 'K25', 'P5', 'AC26', 'K26', 'P6', 'E25', 'K5', 'R24', 'E26', 'K6', 'R25', 'E5', 'K7', 'R26', 'E6', 'L24', 'R3', 'R6', 'E7', 'L25', 'R5', 'F24']},{'label': 'uC', 'num': 3, 'pin_nums': ['B14', 'W2', 'E1', 'B15', 'Y1', 'E2', 'B16', 'E24', 'Y2', 'B17', 'E3', 'B19', 'F2', 'B20', 'F3', 'B21', 'G1', 'B22', 'G2', 'B23', 'H1', 'B24', 'H2', 'B25', 'H3', 'B26', 'J1', 'C14', 'J3', 'AF2', 'A14', 'C16', 'K1', 'A15', 'C17', 'K2', 'A17', 'C18', 'K3', 'A18', 'C19', 'L2', 'A19', 'C20', 'M1', 'A20', 'C21', 'M2', 'A22', 'C22', 'N1', 'A23', 'C23', 'N2', 'A24', 'C24', 'P1', 'A25', 'C26', 'R1', 'AA2', 'D16', 'R2', 'AB1', 'D18', 'R4', 'AB2', 'D19', 'T2', 'AC1', 'D20', 'U1', 'AC2', 'D21', 'U2', 'AD1', 'D23', 'V1', 'AE1', 'D24', 'V2', 'AE2', 'D25', 'V5', 'D26', 'W1']},{'label': 'uD', 'num': 4, 'pin_nums': ['R21', 'B12', 'T19', 'B2', 'T20', 'B4', 'T21', 'A10', 'B5', 'T22', 'A12', 'B6', 'T23', 'A13', 'B7', 'U19', 'A2', 'B9', 'U20', 'A3', 'C1', 'U21', 'A4', 'C11', 'U22', 'A5', 'C12', 'V19', 'A7', 'C13', 'V21', 'A8', 'C2', 'V22', 'A9', 'C3', 'V23', 'AA19', 'C4', 'V24', 'AA20', 'C6', 'V25', 'AA22', 'C7', 'W19', 'AA23', 'C8', 'W20', 'AA24', 'C9', 'W21', 'AB19', 'D1', 'W22', 'AB20', 'D10', 'W23', 'AB21', 'D11', 'W24', 'AB22', 'D3', 'Y20', 'AB24', 'D4', 'Y21', 'AC19', 'D5', 'Y22', 'AC21', 'D6', 'Y23', 'AC22', 'D7', 'AC23', 'D8', 'AC24', 'D9', 'AD19', 'E4', 'B1', 'B11', 'G8', 'B10', 'R20']},{'label': 'uE', 'num': 5, 'pin_nums': ['AF4', 'AB5', 'AD4', 'AA17', 'AA9', 'U7', 'W6', 'Y6', 'AA8', 'AB4', 'AF5', 'V3', 'Y10', 'AA18', 'AB11', 'AD3', 'AB6', 'AD5', 'U6', 'Y7', 'AA10', 'W5', 'AB14', 'AA3', 'AB7', 'AD6', 'T4', 'V4', 'Y11', 'Y5', 'Y8', 'AA12', 'AA4', 'AB15', 'AC3', 'AD7', 'T5', 'V6', 'Y12', 'AA13', 'AB16', 'AA5', 'AC4', 'AE3', 'T7', 'V7', 'Y13', 'AA14', 'AA6', 'AB17', 'AC6', 'AE5', 'U4', 'W3', 'Y18', 'AA15', 'AA7', 'AB3', 'AD17', 'AE6', 'U5', 'W4', 'Y3', 'AA16', 'AF3']},{'label': 'uF', 'num': 6, 'pin_nums': ['AC10', 'AC7', 'E12', 'AD18', 'F10', 'AD8', 'E13', 'F12', 'AC8', 'AC11', 'AC12', 'AC9', 'D13', 'E14', 'F14', 'AD10', 'D14', 'E15', 'AC13', 'F17', 'AB10', 'AC14', 'AD11', 'D15', 'E16', 'F18', 'AB12', 'AC16', 'AD13', 'D17', 'E17', 'F19', 'AC18', 'AB13', 'AC17', 'AD14', 'E10', 'E11', 'E18', 'E8', 'F8', 'F9', 'AB9', 'AD15']},{'label': 'uG', 'num': 7, 'pin_nums': ['N14', 'N18', 'J10', 'V12', 'V11', 'J11', 'P13', 'V18', 'J18', 'P14', 'W10', 'K10', 'P18', 'W11', 'W12', 'K11', 'R13', 'L18', 'R14', 'W18', 'N13', 'U11', 'Y17', 'Y9']},{'label': 'uH', 'num': 8, 'pin_nums': ['B8', 'K15', 'M8', 'T1', 'V8', 'A1', 'C15', 'M9', 'K16', 'V9', 'T10', 'A11', 'C25', 'K17', 'N10', 'T11', 'W13', 'A16', 'C5', 'K18', 'N11', 'T12', 'W14', 'A21', 'D12', 'K19', 'N12', 'T13', 'W15', 'A26', 'D2', 'K24', 'N15', 'T14', 'W16', 'A6', 'D22', 'K4', 'N16', 'T15', 'W17', 'AA1', 'E19', 'N17', 'K8', 'W7', 'T16', 'AA11', 'E9', 'K9', 'N25', 'T17', 'W8', 'AA21', 'F1', 'L1', 'N5', 'T26', 'W9', 'AA26', 'F16', 'L10', 'N8', 'T6', 'Y14', 'M3', 'AB18', 'F26', 'L11', 'N9', 'T8', 'Y15', 'AB8', 'F6', 'L12', 'P10', 'T9', 'Y16', 'AC15', 'G13', 'L13', 'P11', 'U10', 'Y19', 'AC25', 'G18', 'L14', 'P12', 'U12', 'Y24', 'AC5', 'G23', 'L15', 'P15', 'U13', 'Y4', 'AD12', 'G3', 'L16', 'P16', 'U14', 'AD2', 'H10', 'L17', 'P17', 'U15', 'AD22', 'H15', 'L21', 'P2', 'U16', 'AE14', 'H20', 'L26', 'P22', 'U17', 'AE19', 'J12', 'L8', 'P7', 'U18', 'AE4', 'J13', 'L9', 'P8', 'U23', 'AE9', 'J14', 'M10', 'P9', 'U3', 'AF1', 'J15', 'M11', 'R10', 'U8', 'AF11', 'J16', 'M12', 'R11', 'U9', 'AF16', 'J17', 'M13', 'R12', 'V10', 'AF21', 'J7', 'M14', 'R15', 'V13', 'AF26', 'J8', 'M15', 'R16', 'V14', 'AF6', 'J9', 'M16', 'R17', 'V15', 'B13', 'K12', 'M17', 'R19', 'V16', 'B18', 'K13', 'M18', 'R8', 'V17', 'B3', 'K14', 'R9', 'V20']}] }),
        Part(**{ 'name':'XC5VLX30T-FF323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX30T-FF323'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX30T-FF323\n\nFPGA', 'pins':[
            Pin(num='A10',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='A16',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='H15',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H17',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J18',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K12',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='L12',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='L16',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L4P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='P12',name='IO_L17P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO_L17N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='P17',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO_L6N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='R14',name='IO_L14P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L13P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L6P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L16N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='IO_L5N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO_L5P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L7P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L15N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L13N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L18P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='U18',name='IO_L7N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L15P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L19N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19P_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L18N_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='VCCO_17',func=pin_types.PWRIN,unit=2),
            Pin(num='V15',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V17',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M8',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N6',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P3',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P7',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='P8',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='P9',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='R4',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R6',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='R7',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='R8',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='R9',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T3',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='T6',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T7',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T8',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='T9',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='U3',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U4',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='U8',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='U9',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V7',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='A2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='E1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='E2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='F2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=4),
            Pin(num='G2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='H1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='H2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='J1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=4),
            Pin(num='K1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='L1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='L2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='M2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=4),
            Pin(num='B3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=5),
            Pin(num='D3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=5),
            Pin(num='F3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=5),
            Pin(num='F5',name='MGTRREF_112',func=pin_types.PWRIN,unit=5),
            Pin(num='G4',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=5),
            Pin(num='K3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=5),
            Pin(num='L4',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=5),
            Pin(num='M3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=5),
            Pin(num='A4',name='CS_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='B5',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='E10',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='E11',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='E6',name='RDWR_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='F11',name='HSWAPEN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='D_IN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='J9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='K10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='N5',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D5',name='VBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='AVDD_0',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='AVSS_0',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J13',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L6',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C6', 'B14', 'D16', 'A17', 'C10', 'E14', 'F14', 'G15', 'A18', 'B15', 'C11', 'C7', 'D17', 'A6', 'E15', 'F16', 'G16', 'A11', 'A7', 'B16', 'C12', 'C8', 'D18', 'E16', 'F17', 'A8', 'B18', 'C13', 'D10', 'D7', 'E17', 'F18', 'A9', 'A12', 'B6', 'C15', 'D12', 'D8', 'B10', 'E7', 'F7', 'A13', 'B11', 'B7', 'C16', 'D13', 'D9', 'E8', 'F8', 'A14', 'B12', 'B8', 'C17', 'D14', 'E12', 'E9', 'G13', 'A10', 'A15', 'B13', 'B9', 'C18', 'D15', 'A16', 'E13', 'F13', 'G14']},{'label': 'uB', 'num': 2, 'pin_nums': ['M18', 'T18', 'N10', 'U10', 'G18', 'N11', 'U11', 'N12', 'H13', 'U13', 'H14', 'N13', 'U14', 'N15', 'H15', 'U15', 'H16', 'N16', 'U16', 'H17', 'N17', 'U17', 'H18', 'N18', 'U18', 'J14', 'P10', 'V10', 'J15', 'P11', 'V11', 'J17', 'P12', 'V12', 'J18', 'P13', 'V13', 'K12', 'P14', 'V14', 'K14', 'P15', 'V15', 'K15', 'P16', 'V16', 'K16', 'P17', 'V17', 'K17', 'P18', 'V18', 'K18', 'R10', 'L12', 'R11', 'L13', 'R12', 'L14', 'R13', 'L15', 'R14', 'L16', 'R15', 'L17', 'R16', 'L18', 'R17', 'M10', 'T11', 'T12', 'M11', 'M16', 'M13', 'T13', 'T14', 'M14', 'M15', 'T16', 'T17']},{'label': 'uC', 'num': 3, 'pin_nums': ['U9', 'R2', 'T9', 'P2', 'T1', 'V9', 'P3', 'R3', 'T2', 'U1', 'V1', 'V2', 'P4', 'R4', 'T3', 'U2', 'M7', 'P5', 'R5', 'T4', 'U3', 'V3', 'M8', 'P7', 'R6', 'T5', 'U4', 'V5', 'N6', 'P8', 'R7', 'T6', 'U5', 'V6', 'N7', 'P9', 'R8', 'T7', 'U6', 'V7', 'N8', 'R1', 'R9', 'T8', 'U8', 'V8']},{'label': 'uD', 'num': 4, 'pin_nums': ['J4', 'E1', 'A2', 'E2', 'K1', 'L1', 'B1', 'F2', 'B2', 'G2', 'L2', 'M2', 'C1', 'H1', 'D1', 'H2', 'C3', 'C4', 'J1', 'J3']},{'label': 'uE', 'num': 5, 'pin_nums': ['B3', 'E4', 'F5', 'H3', 'L4', 'F3', 'D3', 'G4', 'K3', 'M3']},{'label': 'uF', 'num': 6, 'pin_nums': ['K9', 'G6', 'A4', 'B5', 'M5', 'H10', 'M6', 'E10', 'H5', 'E11', 'H9', 'M9', 'N1', 'J10', 'E6', 'F9', 'N3', 'F11', 'J9', 'N5', 'K10', 'F6', 'N4', 'K5']},{'label': 'uG', 'num': 7, 'pin_nums': ['E3', 'G9', 'J12', 'G10', 'K11', 'L3', 'M4', 'A1', 'C9', 'E5', 'G11', 'H11', 'J13', 'K13', 'L5', 'N14', 'U12', 'A3', 'D11', 'F1', 'G12', 'H12', 'J16', 'K2', 'L6', 'N2', 'U7', 'A5', 'D2', 'F10', 'G17', 'H4', 'J2', 'K4', 'L7', 'N9', 'V4', 'B17', 'D4', 'F12', 'G3', 'H6', 'J5', 'K6', 'L8', 'P1', 'B4', 'D5', 'F15', 'G5', 'H7', 'J6', 'K7', 'M1', 'P6', 'C14', 'D6', 'F4', 'G7', 'H8', 'J7', 'K8', 'M12', 'R18', 'T15', 'C2', 'E18', 'G1', 'G8', 'J11', 'J8', 'L11', 'M17', 'T10', 'C5']}] }),
        Part(**{ 'name':'XC5VLX30T-FF665', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX30T-FF665'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX30T-FF665\n\nFPGA', 'pins':[
            Pin(num='B13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G24',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J25',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='M24',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA23',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA24',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P23',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='P8',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V22',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V23',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V25',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='V26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W23',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y23',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='IO_L13N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='IO_L15N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L14P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A9',name='IO_L4P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='IO_L13P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B11',name='IO_L15P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='IO_L17P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L16P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='IO_L16N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B9',name='IO_L6P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C10',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C11',name='IO_L19P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='IO_L17N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C8',name='IO_L6N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D10',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='IO_L19N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L18P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='IO_L7N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E5',name='IO_L18N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L7P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L5N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='IO_L5P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='F7',name='IO_L1P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F8',name='IO_L1N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F9',name='IO_L2P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L0N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G9',name='IO_L2N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L0P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L3P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='IO_L3N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AA7',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA8',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB23',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AB5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC20',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC26',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC7',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD13',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD14',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD15',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD16',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD18',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD20',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD24',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD26',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE13',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE15',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE16',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE17',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE18',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE20',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE21',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE22',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE24',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE26',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF13',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF14',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF15',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF17',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF18',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF19',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF20',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF22',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF24',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF25',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='D18',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='G21',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W16',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y15',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y16',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y17',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y20',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA20',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB11',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB14',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB15',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC11',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='L1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=7),
            Pin(num='U1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='W2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AC1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AE2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='B2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=8),
            Pin(num='E1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='G2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='Y2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AD3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AE3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='C3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='F3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='H3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='J3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=9),
            Pin(num='N3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='P4',name='MGTRREF_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=9),
            Pin(num='R3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='V3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=9),
            Pin(num='W3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='Y3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='F11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='H12',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J10',name='D_IN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J12',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='J20',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='HSWAPEN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='CS_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M20',name='RDWR_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N14',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N15',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P14',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P15',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R14',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R15',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T20',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U12',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U20',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V12',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V13',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W20',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='VBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='AVSS_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='AVDD_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W10',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y9',name='GND',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E26', 'M22', 'N24', 'G10', 'H19', 'F13', 'G11', 'G22', 'H21', 'J21', 'J22', 'K23', 'K25', 'M23', 'N26', 'F14', 'G12', 'G24', 'H22', 'J23', 'E14', 'K26', 'M24', 'F15', 'F17', 'G14', 'G25', 'H23', 'J24', 'L22', 'M25', 'F18', 'G15', 'G26', 'H24', 'J25', 'L23', 'M26', 'F22', 'G16', 'H11', 'H25', 'J26', 'F23', 'L24', 'N21', 'F24', 'E23', 'G17', 'H13', 'H26', 'K21', 'L25', 'N22', 'B13', 'E22', 'F25', 'G19', 'H18', 'E25', 'H9', 'K22', 'M21', 'N23', 'G20']},{'label': 'uB', 'num': 2, 'pin_nums': ['J5', 'R8', 'W6', 'J6', 'Y22', 'T22', 'K5', 'T23', 'Y23', 'K6', 'Y25', 'T24', 'K7', 'T25', 'Y26', 'K8', 'T5', 'Y4', 'L5', 'T7', 'Y5', 'L6', 'Y6', 'T8', 'L7', 'U21', 'L8', 'U22', 'M6', 'U24', 'M7', 'U25', 'N6', 'U26', 'N7', 'U5', 'N8', 'U6', 'P21', 'U7', 'P23', 'V21', 'P24', 'V22', 'AA22', 'P25', 'V23', 'AA23', 'P26', 'V24', 'AA24', 'P6', 'V25', 'AA25', 'P7', 'V26', 'AB24', 'P8', 'V6', 'AB25', 'R21', 'V7', 'AB26', 'R22', 'W21', 'F5', 'R23', 'W22', 'G4', 'R24', 'W23', 'R25', 'G5', 'W24', 'G6', 'R26', 'W25', 'H4', 'R5', 'W26', 'H5', 'R6', 'W4', 'H6', 'R7', 'W5']},{'label': 'uC', 'num': 3, 'pin_nums': ['C8', 'B16', 'C9', 'B17', 'D10', 'B19', 'D11', 'B20', 'D19', 'B21', 'D20', 'B22', 'D21', 'B23', 'D23', 'B24', 'D24', 'A10', 'B25', 'D25', 'A12', 'B26', 'D26', 'A13', 'B4', 'D5', 'A14', 'B5', 'D6', 'A15', 'B6', 'D7', 'A17', 'B7', 'D8', 'A18', 'B9', 'D9', 'A19', 'C10', 'E24', 'A20', 'C11', 'E5', 'A22', 'C12', 'E6', 'A23', 'C13', 'E7', 'A24', 'C14', 'E8', 'A25', 'C16', 'F21', 'A3', 'C17', 'F7', 'A4', 'C18', 'F8', 'A5', 'C19', 'F9', 'A7', 'C21', 'G7', 'A8', 'C22', 'G8', 'A9', 'C23', 'G9', 'B10', 'C24', 'H7', 'B11', 'C26', 'H8', 'B12', 'C6', 'J8', 'B14', 'C7', 'B15']},{'label': 'uD', 'num': 4, 'pin_nums': ['AA6', 'AD24', 'AF15', 'AD25', 'AA7', 'AF17', 'AA8', 'AD26', 'AF18', 'AD4', 'AA9', 'AF19', 'AB22', 'AD5', 'AF20', 'AD23', 'AB23', 'AD6', 'AF22', 'AB5', 'AD7', 'AF23', 'AB6', 'AD8', 'AF24', 'AB7', 'AD9', 'AF25', 'AB9', 'AE10', 'AF3', 'AC10', 'AE11', 'AF4', 'AC20', 'AE12', 'AF5', 'AC21', 'AE13', 'AF7', 'AC22', 'AE15', 'AF8', 'AC23', 'AE16', 'AF9', 'AC24', 'AE17', 'V8', 'AC26', 'AE18', 'V9', 'AC6', 'AE20', 'W8', 'AC7', 'AE21', 'W9', 'AC8', 'AE22', 'Y7', 'AC9', 'AE23', 'Y8', 'AD10', 'AE24', 'AD11', 'AE25', 'AD13', 'AE26', 'AD14', 'AE5', 'AD15', 'AE6', 'AD16', 'AE7', 'AD18', 'AE8', 'AD19', 'AF10', 'AD20', 'AF12', 'AD21', 'AF13', 'AA5', 'AF14']},{'label': 'uE', 'num': 5, 'pin_nums': ['W16', 'AA13', 'E12', 'F10', 'D13', 'AA14', 'D14', 'E13', 'F12', 'Y10', 'Y20', 'AA15', 'D15', 'E15', 'F19', 'Y11', 'AA16', 'D16', 'E16', 'F20', 'Y12', 'AA17', 'D17', 'E17', 'G18', 'Y13', 'AA18', 'D18', 'E18', 'G21', 'Y15', 'AA10', 'AA19', 'E10', 'E20', 'W11', 'Y16', 'Y18', 'AA12', 'AD17', 'E11', 'E21', 'W14', 'Y17']},{'label': 'uF', 'num': 6, 'pin_nums': ['AC13', 'AB15', 'AB16', 'AC14', 'AC16', 'AA20', 'AB17', 'AB10', 'AB19', 'AC17', 'AC18', 'AB11', 'AB20', 'AB21', 'AB12', 'AC19', 'AB13', 'AC11', 'AE14', 'AB14', 'AC12', 'Y21']},{'label': 'uG', 'num': 7, 'pin_nums': ['M1', 'T4', 'H2', 'U1', 'M2', 'J1', 'N2', 'V1', 'J2', 'P2', 'V2', 'K1', 'R1', 'W2', 'K3', 'R2', 'K4', 'T1', 'L1', 'T3']},{'label': 'uH', 'num': 8, 'pin_nums': ['AB3', 'C2', 'Y2', 'AB4', 'D1', 'AC1', 'D3', 'AD1', 'D4', 'AD2', 'E1', 'AA1', 'AE2', 'F1', 'AA2', 'B2', 'F2', 'AB1', 'C1', 'G2']},{'label': 'uI', 'num': 9, 'pin_nums': ['V3', 'M3', 'E3', 'E4', 'N3', 'AA3', 'W3', 'P3', 'AC3', 'F3', 'Y3', 'AC4', 'G3', 'P4', 'H3', 'P5', 'AD3', 'C3', 'J3', 'AE3', 'R3', 'U4', 'L3', 'B3', 'U3', 'L4']},{'label': 'uJ', 'num': 10, 'pin_nums': ['V13', 'J20', 'P15', 'R14', 'W13', 'K11', 'K20', 'R15', 'W20', 'L20', 'T20', 'F11', 'H12', 'M20', 'U12', 'J10', 'N14', 'U20', 'P14', 'V12', 'J11', 'N15', 'V11', 'J12']},{'label': 'uK', 'num': 11, 'pin_nums': ['F6', 'L12', 'N19', 'T17', 'W12', 'AC15', 'G13', 'N20', 'L13', 'W15', 'T18', 'AC2', 'G23', 'L14', 'N25', 'T19', 'W17', 'AC25', 'H10', 'L15', 'N5', 'T2', 'W18', 'AC5', 'H14', 'L16', 'N9', 'T21', 'W19', 'AD12', 'H15', 'L17', 'P10', 'T26', 'W7', 'AD22', 'H16', 'L18', 'P11', 'T6', 'Y14', 'AE19', 'H17', 'P12', 'L19', 'T9', 'Y19', 'AE4', 'H20', 'L2', 'P13', 'U10', 'Y24', 'AE9', 'J13', 'L21', 'P16', 'U11', 'Y9', 'AF11', 'J14', 'L26', 'P17', 'U13', 'AF16', 'J15', 'L9', 'P18', 'U14', 'AF2', 'J16', 'M10', 'P19', 'U15', 'AF21', 'J17', 'M11', 'P22', 'U16', 'AF26', 'J18', 'M12', 'P9', 'U17', 'AF6', 'J19', 'M13', 'R10', 'U18', 'B18', 'J4', 'M14', 'R11', 'U19', 'B8', 'J7', 'M15', 'R12', 'U2', 'C15', 'K10', 'M16', 'R13', 'U23', 'C20', 'K12', 'M17', 'R16', 'U8', 'A11', 'T16', 'C25', 'K13', 'M18', 'R17', 'U9', 'A16', 'C4', 'K14', 'M19', 'R18', 'V10', 'A2', 'C5', 'K15', 'M4', 'R19', 'V14', 'A21', 'D12', 'K16', 'M8', 'R4', 'V15', 'A26', 'D2', 'K17', 'M9', 'R9', 'V16', 'A6', 'D22', 'K18', 'N10', 'T10', 'V17', 'AA11', 'E19', 'K19', 'N11', 'T11', 'V18', 'AA21', 'E2', 'K2', 'N12', 'T12', 'V19', 'AA26', 'E9', 'K24', 'N13', 'T13', 'V20', 'AA4', 'F16', 'K9', 'N16', 'T14', 'V4', 'AB18', 'AB8', 'F26', 'L10', 'N17', 'T15', 'V5', 'AB2', 'F4', 'L11', 'N18', 'W10']}] }),
        Part(**{ 'name':'XC5VLX330-FF1760', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX330-FF1760'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX330-FF1760\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R27',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U40',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA38',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC4',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC5',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD3',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AE2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AF1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AG2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH1',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ3',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP1',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AR2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AT2',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU1',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AU2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M35',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA10',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE36',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G4',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V5',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='W10',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y10',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB8',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB9',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC9',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD11',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AF4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG4',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ6',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL4',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AL6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM4',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AM6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN4',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AN5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AP3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR3',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AR4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H37',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='AH16',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH29',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ16',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ17',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ30',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK15',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AK30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL15',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL29',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AL30',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E5',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F5',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H6',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J5',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J6',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L7',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M5',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='M6',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P6',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P8',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R7',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='R9',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T11',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='T9',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U7',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='V9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE10',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF12',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG12',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG9',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH11',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AL7',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AL9',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AM5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AM7',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AM8',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AN6',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AN8',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AP5',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP6',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP7',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AP9',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AR5',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AT4',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT5',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AT6',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU3',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AU4',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV3',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AV4',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AV5',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='IO_L14P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E13',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='IO_L18P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E8',name='IO_L18N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='E9',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F10',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F11',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F12',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F3',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=8),
            Pin(num='F7',name='IO_L19P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='F9',name='IO_L15P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G11',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G12',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G13',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='G40',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='G8',name='IO_L19N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='G9',name='IO_L15N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H10',name='IO_L13N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H11',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='H8',name='IO_L16P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='H9',name='IO_L13P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J10',name='IO_L7P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='IO_L7N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J12',name='IO_L6N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='J4',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='IO_L16N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K12',name='IO_L6P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=8),
            Pin(num='K8',name='IO_L17P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='K9',name='IO_L17N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L10',name='IO_L5N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L11',name='IO_L5P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L12',name='IO_L2N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=8),
            Pin(num='L9',name='IO_L4P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M11',name='IO_L3N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M12',name='IO_L2P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N10',name='IO_L1N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N11',name='IO_L3P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P10',name='IO_L1P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P11',name='IO_L0N_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P12',name='IO_L0P_24',func=pin_types.BIDIR,unit=8),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=8),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=8),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ10',name='IO_L18P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ11',name='IO_L18N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L19P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK10',name='IO_L17P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L19N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL10',name='IO_L17N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL11',name='IO_L16P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL12',name='IO_L16N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM11',name='IO_L15N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM12',name='IO_L15P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AM9',name='IO_L13P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN10',name='IO_L13N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN11',name='IO_L14P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AN9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP11',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP12',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AP8',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR10',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR12',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AR6',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AR7',name='IO_L3P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR8',name='IO_L3N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AR9',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT10',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT11',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT12',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT3',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AT7',name='IO_L2P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AT9',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU11',name='IO_L7N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU12',name='IO_L6N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU13',name='IO_L6P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AU6',name='IO_L2N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU7',name='IO_L0N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU8',name='IO_L1P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AU9',name='IO_L4P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV10',name='IO_L5P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV11',name='IO_L7P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=9),
            Pin(num='AV6',name='IO_L0P_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV8',name='IO_L1N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AV9',name='IO_L5N_26',func=pin_types.BIDIR,unit=9),
            Pin(num='AW4',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='A10',name='IO_L5N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='IO_L5P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A12',name='IO_L2N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A2',name='IO_L18P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A30',name='IO_L2P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A31',name='IO_L2N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A32',name='IO_L3P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A34',name='IO_L7P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A35',name='IO_L7N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A36',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A37',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A39',name='IO_L15P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A4',name='IO_L13N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A40',name='IO_L15N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A41',name='IO_L16P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='A5',name='IO_L12P_VRN_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A6',name='IO_L12N_VRP_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A7',name='IO_L11P_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='A9',name='IO_L7P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B1',name='IO_L17N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B11',name='IO_L1P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B12',name='IO_L2P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B2',name='IO_L18N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B3',name='IO_L16P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B31',name='IO_L1P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B32',name='IO_L3N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B33',name='IO_L4P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B34',name='IO_L6N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='B36',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B37',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B38',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B39',name='IO_L14P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B4',name='IO_L13P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B41',name='IO_L16N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B42',name='IO_L17P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='B6',name='IO_L9P_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B7',name='IO_L11N_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B8',name='IO_L8N_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='B9',name='IO_L7N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C1',name='IO_L17P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C10',name='IO_L6P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C11',name='IO_L1N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C13',name='IO_L0P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C3',name='IO_L16N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C30',name='IO_L1N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C31',name='IO_L0N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C32',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='C33',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C34',name='IO_L6P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C35',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C36',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C38',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C39',name='IO_L13P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C4',name='IO_L15N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C40',name='IO_L13N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C41',name='IO_L17N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='C5',name='IO_L14P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C6',name='IO_L9N_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C8',name='IO_L8P_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='C9',name='IO_L4P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D1',name='IO_L19P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D10',name='IO_L6N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D11',name='IO_L3P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D12',name='IO_L3N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D13',name='IO_L0N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D2',name='IO_L19N_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D3',name='IO_L15P_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D31',name='IO_L0P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D32',name='IO_L5P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D33',name='IO_L5N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D35',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D36',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D38',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D40',name='IO_L18P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D41',name='IO_L18N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D42',name='IO_L19N_27',func=pin_types.BIDIR,unit=10),
            Pin(num='D5',name='IO_L14N_VREF_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D6',name='IO_L10N_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D7',name='IO_L10P_CC_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D8',name='IO_L4N_VREF_28',func=pin_types.BIDIR,unit=10),
            Pin(num='D9',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='E42',name='IO_L19P_27',func=pin_types.BIDIR,unit=10),
            Pin(num='E6',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=10),
            Pin(num='G10',name='VCCO_28',func=pin_types.PWRIN,unit=10),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AW31',name='IO_L19N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW32',name='IO_L15N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW33',name='IO_L15P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=11),
            Pin(num='AW35',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW36',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW37',name='IO_L6N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW38',name='IO_L7P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW40',name='IO_L1N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW41',name='IO_L1P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AW42',name='IO_L0N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY30',name='IO_L19P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY32',name='IO_L16P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY33',name='IO_L14P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY34',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY35',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY37',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY38',name='IO_L6P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY39',name='IO_L7N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY40',name='IO_L2P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='AY42',name='IO_L0P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA30',name='IO_L18P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA31',name='IO_L18N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA32',name='IO_L16N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA34',name='IO_L13N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA35',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA36',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA37',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA39',name='IO_L5N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA40',name='IO_L4P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA41',name='IO_L2N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BA42',name='IO_L3P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB31',name='IO_L17N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB32',name='IO_L17P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB33',name='IO_L13P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB34',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB36',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB37',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB38',name='IO_L5P_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB39',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=11),
            Pin(num='BB41',name='IO_L3N_29',func=pin_types.BIDIR,unit=11),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=11),
            Pin(num='J24',name='VCCO_3',func=pin_types.PWRIN,unit=11),
            Pin(num='J30',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K13',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K14',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K28',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K29',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='K30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L15',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L16',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L29',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M16',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M27',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='N26',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='AV1',name='IO_L0P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AV7',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='AW1',name='IO_L0N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW10',name='IO_L13N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW11',name='IO_L16P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW12',name='IO_L16N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW2',name='IO_L1P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW3',name='IO_L3N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW5',name='IO_L5N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW6',name='IO_L9N_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW7',name='IO_L9P_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AW8',name='IO_L11N_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY10',name='IO_L13P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY12',name='IO_L19N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY13',name='IO_L19P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY2',name='IO_L1N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY3',name='IO_L3P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY4',name='IO_L6P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY5',name='IO_L5P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY7',name='IO_L11P_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY8',name='IO_L15P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='AY9',name='IO_L15N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA1',name='IO_L2P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA10',name='IO_L14N_VREF_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA11',name='IO_L18N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA12',name='IO_L17P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA2',name='IO_L2N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA4',name='IO_L6N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA5',name='IO_L7P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA6',name='IO_L10N_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA7',name='IO_L8N_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BA8',name='VCCO_30',func=pin_types.PWRIN,unit=12),
            Pin(num='BA9',name='IO_L12N_VRP_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB11',name='IO_L18P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB12',name='IO_L17N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB2',name='IO_L4P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB3',name='IO_L4N_VREF_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB4',name='IO_L7N_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB6',name='IO_L10P_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB7',name='IO_L8P_CC_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB8',name='IO_L12P_VRN_30',func=pin_types.BIDIR,unit=12),
            Pin(num='BB9',name='IO_L14P_30',func=pin_types.BIDIR,unit=12),
            Pin(num='D15',name='IO_L0N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D16',name='IO_L2P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D17',name='IO_L2N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D18',name='IO_L6P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D20',name='IO_L9N_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D21',name='IO_L9P_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D22',name='IO_L8P_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D23',name='IO_L8N_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D25',name='IO_L12P_VRN_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D26',name='IO_L12N_VRP_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D27',name='IO_L17P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D28',name='IO_L17N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='D30',name='IO_L19P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E14',name='IO_L0P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E15',name='IO_L1P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E17',name='IO_L4N_VREF_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L6N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E19',name='IO_L7P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E20',name='IO_L5P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E22',name='IO_L10N_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E23',name='IO_L11P_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E24',name='IO_L13P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E25',name='IO_L13N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E27',name='IO_L14N_VREF_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E28',name='IO_L16N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E29',name='IO_L16P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='E30',name='IO_L19N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F14',name='IO_L1N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F15',name='IO_L3N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L4P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F19',name='IO_L7N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F20',name='IO_L5N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F21',name='IO_L10P_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F24',name='IO_L11N_CC_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F25',name='IO_L15N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F26',name='IO_L15P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F27',name='IO_L14P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L18N_31',func=pin_types.BIDIR,unit=12),
            Pin(num='F30',name='IO_L18P_31',func=pin_types.BIDIR,unit=12),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='H27',name='VCCO_31',func=pin_types.PWRIN,unit=12),
            Pin(num='A14',name='IO_L16P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A15',name='IO_L16N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A16',name='IO_L14P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A17',name='IO_L14N_VREF_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A19',name='IO_L12P_VRN_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A20',name='IO_L10P_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A21',name='IO_L11P_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A22',name='IO_L11N_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A24',name='IO_L6N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A25',name='IO_L4N_VREF_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A26',name='IO_L1N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A27',name='IO_L3N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='A29',name='IO_L0P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='AU14',name='IO_L18P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU16',name='IO_L14N_VREF_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU17',name='IO_L14P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU18',name='IO_L12P_VRN_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU19',name='IO_L12N_VRP_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU22',name='IO_L9N_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU23',name='IO_L9P_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU24',name='IO_L3N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU26',name='IO_L1N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU27',name='IO_L4N_VREF_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU28',name='IO_L4P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='AV13',name='IO_L16P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV14',name='IO_L18N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV15',name='IO_L19N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV16',name='IO_L17N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV18',name='IO_L15N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV19',name='IO_L13N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV20',name='IO_L10N_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV21',name='IO_L10P_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV23',name='IO_L7N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV24',name='IO_L7P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV25',name='IO_L3P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV26',name='IO_L1P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV28',name='IO_L6N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV29',name='IO_L0P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AV30',name='IO_L2P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW13',name='IO_L16N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW15',name='IO_L19P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW16',name='IO_L17P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW17',name='IO_L15P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW18',name='IO_L13P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW20',name='IO_L11N_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW21',name='IO_L11P_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW22',name='IO_L5N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW23',name='IO_L5P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW25',name='IO_L8N_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW26',name='IO_L8P_CC_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW27',name='IO_L6P_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW28',name='IO_L0N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AW30',name='IO_L2N_33',func=pin_types.BIDIR,unit=13),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='B13',name='IO_L19P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B14',name='IO_L19N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B15',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='B16',name='IO_L17P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B17',name='IO_L15P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B18',name='IO_L15N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B19',name='IO_L12N_VRP_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B21',name='IO_L10N_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B22',name='IO_L8N_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B23',name='IO_L6P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B24',name='IO_L4P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B26',name='IO_L7N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B27',name='IO_L1P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B28',name='IO_L3P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='B29',name='IO_L0N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=13),
            Pin(num='C12',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='C14',name='IO_L18P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C15',name='IO_L18N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C16',name='IO_L17N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C18',name='IO_L13P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C19',name='IO_L13N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C20',name='IO_L9N_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C21',name='IO_L9P_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C23',name='IO_L8P_CC_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C24',name='IO_L5P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C25',name='IO_L5N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C26',name='IO_L7P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C28',name='IO_L2N_32',func=pin_types.BIDIR,unit=13),
            Pin(num='C29',name='IO_L2P_32',func=pin_types.BIDIR,unit=13),
            Pin(num='F13',name='VCCO_32',func=pin_types.PWRIN,unit=13),
            Pin(num='AK17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK27',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AK28',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL16',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM13',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM27',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM28',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AM29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN13',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN16',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN28',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN29',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AN30',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP13',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AP30',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=14),
            Pin(num='AT13',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AV17',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='AW14',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AY11',name='VCCO_34',func=pin_types.PWRIN,unit=14),
            Pin(num='AY14',name='IO_L1P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY15',name='IO_L1N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY17',name='IO_L7P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY18',name='IO_L7N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY19',name='IO_L6P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY20',name='IO_L10N_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY22',name='IO_L11P_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY23',name='IO_L11N_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY24',name='IO_L12N_VRP_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY25',name='IO_L12P_VRN_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY27',name='IO_L17P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY28',name='IO_L17N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AY29',name='IO_L19N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA14',name='IO_L0N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA15',name='IO_L3P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA16',name='IO_L2N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA17',name='IO_L5N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA18',name='VCCO_4',func=pin_types.PWRIN,unit=14),
            Pin(num='BA19',name='IO_L6N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA20',name='IO_L10P_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA21',name='IO_L8P_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA22',name='IO_L8N_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA24',name='IO_L13N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA25',name='IO_L15N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA26',name='IO_L14N_VREF_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA27',name='IO_L16P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BA29',name='IO_L19P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB13',name='IO_L0P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB14',name='IO_L3N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB16',name='IO_L2P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB17',name='IO_L5P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB18',name='IO_L4P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB19',name='IO_L4N_VREF_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB21',name='IO_L9P_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB22',name='IO_L9N_CC_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB23',name='IO_L13P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB24',name='IO_L15P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB26',name='IO_L14P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB27',name='IO_L16N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB28',name='IO_L18N_34',func=pin_types.BIDIR,unit=14),
            Pin(num='BB29',name='IO_L18P_34',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ18',name='IO_L16N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ25',name='IO_L17P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK18',name='IO_L1P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK19',name='IO_L16P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK24',name='IO_L17N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AK25',name='IO_L19N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL17',name='IO_L1N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL19',name='IO_L18P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL24',name='IO_L19P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL25',name='IO_L15P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AL26',name='IO_L0P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM17',name='IO_L3N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM18',name='IO_L3P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM19',name='IO_L18N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM24',name='IO_L15N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AM26',name='IO_L0N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN18',name='IO_L5P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN19',name='IO_L7P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN25',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AN26',name='IO_L4P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP16',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP17',name='IO_L5N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP18',name='IO_L7N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP26',name='IO_L6P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP27',name='IO_L2N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AP28',name='IO_L2P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR13',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR14',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR15',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR27',name='IO_L6N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR28',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR29',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AR30',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT14',name='IO_L14P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT15',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AT29',name='IO_L13N_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AT30',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AU29',name='IO_L13P_6',func=pin_types.BIDIR,unit=15),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=15),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=15),
            Pin(num='G14',name='IO_L1P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G16',name='IO_L3N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G27',name='IO_L15P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G28',name='IO_L17P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='G29',name='IO_L17N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H14',name='IO_L1N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H15',name='IO_L7P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H16',name='IO_L3P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J15',name='IO_L7N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J16',name='IO_L5N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J17',name='IO_L5P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J26',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J27',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='J28',name='IO_L13P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K17',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K18',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K19',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K24',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='K27',name='IO_L13N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L17',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L19',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L24',name='IO_L2N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L25',name='IO_L2P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='L26',name='IO_L6N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M17',name='IO_L14P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M24',name='IO_L0P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='M26',name='IO_L6P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N18',name='IO_L16P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N19',name='IO_L16N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N24',name='IO_L0N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='N25',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P18',name='IO_L18N_5',func=pin_types.BIDIR,unit=15),
            Pin(num='P25',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=15),
            Pin(num='R18',name='IO_L18P_5',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ20',name='IO_L1N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AJ21',name='IO_L1P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AJ22',name='IO_L0N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AJ23',name='IO_L0P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AK20',name='IO_L3P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AK22',name='IO_L2N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AK23',name='IO_L2P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AL20',name='IO_L3N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AL21',name='IO_L5N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AL22',name='IO_L17P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AM21',name='IO_L5P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AM22',name='IO_L17N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AM23',name='IO_L15P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AN20',name='IO_L7N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AN21',name='IO_L9P_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AN23',name='IO_L15N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AN24',name='IO_L13N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AP20',name='IO_L7P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AP21',name='IO_L9N_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AP22',name='IO_L19N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AP23',name='IO_L13P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AP25',name='IO_L4P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR16',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AR18',name='IO_L10P_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR19',name='IO_L10N_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR20',name='IO_L14P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR22',name='IO_L19P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR23',name='IO_L11P_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR24',name='IO_L11N_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AR25',name='IO_L4N_VREF_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT16',name='IO_L12P_VRN_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT17',name='IO_L12N_VRP_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT19',name='IO_L14N_VREF_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT20',name='IO_L16P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT21',name='IO_L16N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT22',name='IO_L18N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT24',name='IO_L8N_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT25',name='IO_L8P_CC_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT26',name='IO_L6N_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AT27',name='IO_L6P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=16),
            Pin(num='AU21',name='IO_L18P_8',func=pin_types.BIDIR,unit=16),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='F22',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G17',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G18',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G19',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='G21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G22',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G23',name='IO_L13N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G24',name='IO_L15N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='G26',name='IO_L19P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=16),
            Pin(num='H18',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H19',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H20',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H21',name='IO_L7N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H23',name='IO_L13P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H24',name='IO_L15P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H25',name='IO_L17P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='H26',name='IO_L19N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='J18',name='IO_L14P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='J20',name='IO_L16N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='J21',name='IO_L7P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='J22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='J23',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=16),
            Pin(num='J25',name='IO_L17N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='K20',name='IO_L16P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='K22',name='IO_L6P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='K23',name='IO_L6N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='L20',name='IO_L18P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='L21',name='IO_L18N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='L22',name='IO_L4P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='M21',name='IO_L5N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='M22',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=16),
            Pin(num='M23',name='IO_L0P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='N20',name='IO_L1N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='N21',name='IO_L3N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='N22',name='IO_L5P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='N23',name='IO_L0N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='P20',name='IO_L1P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='P21',name='IO_L3P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='P22',name='IO_L2N_7',func=pin_types.BIDIR,unit=16),
            Pin(num='P23',name='IO_L2P_7',func=pin_types.BIDIR,unit=16),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AE30',name='TCK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF14',name='TMS_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF15',name='CCLK_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AF30',name='M1_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG14',name='TDI_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG29',name='M0_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='AH14',name='TDO_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AH28',name='M2_0',func=pin_types.BIDIR,unit=17),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=17),
            Pin(num='R14',name='D_IN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T14',name='HSWAPEN_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T15',name='DONE_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='U14',name='INIT_B_0',func=pin_types.BIDIR,unit=17),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AB29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AD29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='R29',name='VBATT_0',func=pin_types.PWRIN,unit=18),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=18),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='V29',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=18),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=18),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=18),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AD4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AW9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AY6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='BB5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=19)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AA39', 'R15', 'F42', 'T42', 'M13', 'N29', 'P26', 'R17', 'U40', 'W41', 'W42', 'G41', 'P27', 'R27', 'G42', 'M29', 'AA40', 'N30', 'U41', 'Y37', 'H41', 'M41', 'N40', 'P28', 'R28', 'U42', 'Y38', 'J14', 'M42', 'N41', 'P30', 'R40', 'J41', 'V37', 'Y39', 'N28', 'AA41', 'AA37', 'J42', 'N13', 'P13', 'P40', 'R42', 'V40', 'Y40', 'K42', 'N14', 'P15', 'P41', 'T40', 'AA42', 'V41', 'Y41', 'L40', 'N15', 'P16', 'P42', 'T41', 'E16', 'L41', 'W40', 'Y42', 'F41', 'L42', 'P17']},{'label': 'uB', 'num': 2, 'pin_nums': ['AJ42', 'AA1', 'N3', 'AK40', 'AA2', 'P1', 'AA38', 'AK42', 'P2', 'AA4', 'AL40', 'P3', 'AA5', 'AL41', 'R2', 'AA8', 'AL42', 'R3', 'AB35', 'AM41', 'T1', 'AB37', 'AM42', 'T2', 'AB38', 'AN41', 'U1', 'AB39', 'AP41', 'U2', 'AB41', 'AP42', 'U3', 'AB42', 'AR42', 'V1', 'AB5', 'AT41', 'V3', 'AC38', 'AT42', 'V4', 'AC39', 'AU41', 'W1', 'AC40', 'AU42', 'W2', 'AC41', 'AV41', 'W3', 'AD39', 'E2', 'W4', 'AD40', 'F1', 'Y2', 'AD41', 'F2', 'Y3', 'AD42', 'G1', 'Y4', 'AE40', 'G2', 'Y5', 'AE42', 'H1', 'AF40', 'J1', 'AF41', 'J2', 'AF42', 'K2', 'AG41', 'L1', 'AG42', 'L2', 'AH40', 'M1', 'AH41', 'M2', 'AJ40', 'M3', 'AJ41', 'N1']},{'label': 'uC', 'num': 3, 'pin_nums': ['T37', 'AC4', 'T39', 'AT1', 'AC5', 'AT2', 'U37', 'AC6', 'AU1', 'U38', 'AD1', 'AU2', 'U39', 'AD2', 'E39', 'V38', 'AD3', 'E40', 'V39', 'AD9', 'F39', 'W35', 'AE2', 'F40', 'W36', 'AE3', 'G38', 'W37', 'AE6', 'G39', 'W38', 'AF1', 'H38', 'Y34', 'AF2', 'H39', 'Y35', 'AG1', 'H40', 'AG10', 'J38', 'AG2', 'J40', 'AG3', 'K38', 'AH1', 'K39', 'AH3', 'K40', 'AJ1', 'L39', 'AR2', 'AJ2', 'M35', 'AJ3', 'M38', 'AK2', 'M39', 'AA34', 'AK3', 'N38', 'AA35', 'AL1', 'N39', 'AA36', 'AL2', 'P37', 'AB1', 'AM1', 'P38', 'AM2', 'AB2', 'P39', 'AB3', 'AM3', 'R36', 'AB4', 'AN1', 'R37', 'AB6', 'AP1', 'R38', 'AC1', 'AP2', 'R39', 'AC3']},{'label': 'uD', 'num': 4, 'pin_nums': ['AF39', 'G3', 'Y7', 'G4', 'AG37', 'Y8', 'AG38', 'H3', 'Y9', 'H4', 'AG39', 'AG40', 'J3', 'AH37', 'K3', 'K4', 'AH38', 'L4', 'AH39', 'AJ37', 'L5', 'AJ38', 'M4', 'AK37', 'N4', 'AK38', 'N5', 'AK39', 'P5', 'AA10', 'AL37', 'R4', 'AA11', 'AL39', 'R5', 'AA6', 'AM37', 'R6', 'AA7', 'AM38', 'T3', 'AA9', 'AM39', 'T4', 'AB34', 'AN38', 'T5', 'AB36', 'AN39', 'T6', 'AC34', 'AN40', 'U4', 'AC35', 'AP38', 'U6', 'AC36', 'AP40', 'V5', 'AD35', 'AR39', 'V6', 'AD36', 'AR40', 'V7', 'AD37', 'AT39', 'W10', 'AD38', 'AT40', 'W11', 'AE36', 'AU39', 'W5', 'AE37', 'AV40', 'W6', 'F4', 'AE38', 'E3', 'W7', 'AE39', 'E4', 'W8', 'AF37', 'Y10']},{'label': 'uE', 'num': 5, 'pin_nums': ['AJ4', 'AJ5', 'L36', 'AJ6', 'L37', 'AK4', 'L38', 'AA32', 'AK5', 'M36', 'AB11', 'AL4', 'M37', 'AB7', 'AL5', 'N35', 'AB8', 'AL6', 'N36', 'AB9', 'AM4', 'P35', 'AC10', 'AM6', 'P36', 'AC11', 'AN3', 'R34', 'AC8', 'AN4', 'R35', 'AC9', 'AN5', 'T34', 'AD10', 'AP3', 'T35', 'AD11', 'AR3', 'T36', 'AD5', 'AR4', 'U33', 'AD6', 'D37', 'U34', 'AD7', 'E37', 'U36', 'AD8', 'E38', 'V33', 'AE4', 'F36', 'V34', 'AE5', 'F37', 'V35', 'AE7', 'G36', 'V36', 'AF3', 'G37', 'W32', 'AF4', 'H35', 'W33', 'AF5', 'H36', 'Y32', 'AF6', 'H37', 'Y33', 'AG4', 'J35', 'AG6', 'J36', 'AH4', 'J37', 'AH5', 'K35', 'AH6', 'K37', 'L35', 'AH7', 'K41']},{'label': 'uF', 'num': 6, 'pin_nums': ['P6', 'V10', 'T10', 'AK29', 'AJ17', 'E5', 'J6', 'M6', 'P7', 'T11', 'V11', 'AK30', 'F5', 'J7', 'AJ26', 'M7', 'P8', 'T7', 'V8', 'AJ16', 'AV27', 'AH16', 'AJ27', 'AL14', 'F6', 'J5', 'K5', 'M5', 'M8', 'P9', 'T9', 'V9', 'AJ28', 'AL15', 'AH29', 'G6', 'K7', 'M9', 'R10', 'U11', 'AH30', 'AJ30', 'AL29', 'G7', 'L6', 'N6', 'R7', 'U7', 'AK13', 'AJ13', 'AL30', 'H5', 'L7', 'N8', 'R8', 'U8', 'AJ15', 'AK14', 'AR26', 'H6', 'L8', 'N9', 'R9', 'U9', 'AK15']},{'label': 'uG', 'num': 7, 'pin_nums': ['AD33', 'AJ36', 'AP9', 'AE10', 'AR37', 'AJ7', 'AE32', 'AJ8', 'AR38', 'AE33', 'AR5', 'AK34', 'AE34', 'AK35', 'AT36', 'AE35', 'AK7', 'AT37', 'AE8', 'AK8', 'AT4', 'AE9', 'AT5', 'AK9', 'AF10', 'AL34', 'AT6', 'AF11', 'AL35', 'AU3', 'AF12', 'AL36', 'AU37', 'AF34', 'AL38', 'AU38', 'AF35', 'AL7', 'AU4', 'AF36', 'AL8', 'AV3', 'AF7', 'AL9', 'AV38', 'AF9', 'AM34', 'AV39', 'AG11', 'AM35', 'AV4', 'AG12', 'AM36', 'AV5', 'AG34', 'AM5', 'AG36', 'AM7', 'AG7', 'AM8', 'AG8', 'AN34', 'AG9', 'AN35', 'AH10', 'AN36', 'AH11', 'AN6', 'AH34', 'AN8', 'AH35', 'AP35', 'AH36', 'AP36', 'AB32', 'AH8', 'AP37', 'AB33', 'AH9', 'AP5', 'AC33', 'AJ34', 'AP6', 'AD32', 'AJ35', 'AP7']},{'label': 'uH', 'num': 8, 'pin_nums': ['J32', 'J33', 'F12', 'P32', 'F3', 'J4', 'P33', 'F31', 'J8', 'R32', 'F32', 'K10', 'R33', 'F34', 'K12', 'T31', 'F35', 'K32', 'T32', 'F7', 'K33', 'U31', 'F9', 'K34', 'U32', 'G11', 'K8', 'G12', 'K9', 'G13', 'L10', 'G31', 'L11', 'G32', 'L12', 'G33', 'L31', 'G34', 'L32', 'G40', 'L34', 'G8', 'L9', 'G9', 'M11', 'D39', 'H10', 'M12', 'E10', 'H11', 'M31', 'E12', 'H13', 'M32', 'E13', 'H31', 'M33', 'E32', 'H33', 'M34', 'E33', 'H34', 'N10', 'E34', 'H7', 'N11', 'E35', 'H8', 'N31', 'E36', 'H9', 'N33', 'E7', 'J10', 'N34', 'E8', 'J11', 'P10', 'E9', 'J12', 'P11', 'P31', 'F10', 'J31', 'P12', 'F11']},{'label': 'uI', 'num': 9, 'pin_nums': ['AM12', 'AT3', 'AM31', 'AT31', 'AM32', 'AT32', 'AM33', 'AT34', 'AM9', 'AT35', 'AN10', 'AT7', 'AN11', 'AT9', 'AN31', 'AU11', 'AN33', 'AU12', 'AF31', 'AN9', 'AU13', 'AF32', 'AP10', 'AU31', 'AG31', 'AP11', 'AU32', 'AG32', 'AP12', 'AU33', 'AG33', 'AP31', 'AU34', 'AH31', 'AP32', 'AU36', 'AH33', 'AP33', 'AU40', 'AJ10', 'AP39', 'AU6', 'AJ11', 'AP8', 'AU7', 'AJ12', 'AR10', 'AU8', 'AJ31', 'AR12', 'AU9', 'AJ32', 'AR32', 'AV10', 'AJ33', 'AR33', 'AV11', 'AK10', 'AR34', 'AV31', 'AK12', 'AR35', 'AV33', 'AK32', 'AR36', 'AV34', 'AK33', 'AR6', 'AV35', 'AL10', 'AR7', 'AV36', 'AL11', 'AR8', 'AV6', 'AL12', 'AR9', 'AV8', 'AM11', 'AL31', 'AT10', 'AV9', 'AL32', 'AT11', 'AW4', 'AT12']},{'label': 'uJ', 'num': 10, 'pin_nums': ['D12', 'A11', 'D13', 'B4', 'A12', 'B41', 'D2', 'A2', 'B42', 'D3', 'A30', 'B6', 'D31', 'A31', 'B7', 'D32', 'B39', 'A32', 'B8', 'D33', 'A34', 'B9', 'D35', 'A35', 'C1', 'D36', 'A36', 'C10', 'D38', 'A37', 'C11', 'D40', 'A39', 'C13', 'D41', 'A4', 'C3', 'D42', 'A40', 'C30', 'D5', 'A41', 'C31', 'D6', 'A5', 'C32', 'D7', 'A6', 'C33', 'D8', 'A7', 'C34', 'D9', 'A9', 'C35', 'E42', 'B1', 'C36', 'E6', 'B11', 'C38', 'F33', 'B12', 'C39', 'G10', 'B2', 'C4', 'B3', 'C40', 'B31', 'C41', 'B32', 'C5', 'B33', 'C6', 'B34', 'C8', 'B35', 'C9', 'B36', 'D1', 'B37', 'D10', 'B38', 'D11', 'A10']},{'label': 'uK', 'num': 11, 'pin_nums': ['AW31', 'AW40', 'AY37', 'BB31', 'BA34', 'BB41', 'K28', 'L30', 'AW32', 'AY38', 'BA35', 'BB32', 'E26', 'K29', 'M14', 'AW41', 'AW33', 'AW42', 'AY39', 'BA36', 'BB33', 'J13', 'K30', 'M16', 'AW34', 'AY30', 'AY40', 'BA37', 'BB34', 'J24', 'L14', 'M27', 'AY35', 'AW35', 'AY32', 'AY42', 'BA39', 'BA42', 'BB36', 'BB39', 'J30', 'L15', 'K15', 'M28', 'AW36', 'L29', 'AY33', 'BA30', 'BA40', 'BB37', 'K13', 'L16', 'N16', 'AT33', 'AW37', 'AY34', 'BA31', 'BA41', 'BB38', 'K14', 'L27', 'N26', 'AV37', 'AW38', 'BA32']},{'label': 'uL', 'num': 12, 'pin_nums': ['BB7', 'BB8', 'AW5', 'F16', 'AW6', 'BB9', 'F17', 'AW7', 'D15', 'F19', 'AW8', 'D16', 'F20', 'AY10', 'D17', 'F21', 'AY12', 'D18', 'F24', 'AY13', 'D20', 'F25', 'AY2', 'D21', 'F26', 'AY3', 'D22', 'F27', 'AY4', 'D23', 'F29', 'AY5', 'D25', 'F30', 'AY7', 'D26', 'G30', 'AY8', 'D27', 'H27', 'AY9', 'D28', 'BA1', 'D29', 'BA10', 'D30', 'BA11', 'E14', 'BA12', 'E15', 'BA2', 'E17', 'BA4', 'E18', 'BA5', 'E19', 'BA6', 'E20', 'BA7', 'E22', 'AU10', 'BA8', 'E23', 'AV1', 'BA9', 'E24', 'AV7', 'BB11', 'E25', 'AW1', 'BB12', 'E27', 'AW10', 'BB2', 'E28', 'AW11', 'BB3', 'E29', 'AW12', 'BB4', 'E30', 'F15', 'AW2', 'BB6', 'F14', 'AW3']},{'label': 'uM', 'num': 13, 'pin_nums': ['AU22', 'C26', 'AW26', 'AU23', 'C28', 'AW27', 'AU24', 'AW28', 'C29', 'AU26', 'F13', 'AW30', 'AU27', 'AY31', 'AU28', 'B13', 'AU30', 'B14', 'AV13', 'B15', 'AV14', 'B16', 'AV15', 'B17', 'AV16', 'B18', 'AV18', 'B19', 'AV19', 'B21', 'AV20', 'B22', 'A14', 'AV21', 'B23', 'A15', 'AV23', 'B24', 'A16', 'AV24', 'B26', 'A17', 'AV25', 'B27', 'A19', 'AV26', 'B28', 'A20', 'AV28', 'B29', 'A21', 'AV29', 'BA28', 'AU19', 'A22', 'AV30', 'C12', 'A24', 'AW13', 'C14', 'A25', 'AW15', 'C15', 'A26', 'AW16', 'C16', 'A27', 'AW17', 'C18', 'A29', 'AW18', 'C19', 'AU14', 'AW20', 'C20', 'AU16', 'AW21', 'C21', 'AU17', 'AW22', 'C23', 'AU18', 'AW23', 'C24', 'AW25', 'C25']},{'label': 'uN', 'num': 14, 'pin_nums': ['AL16', 'AP30', 'AN13', 'BA20', 'AY28', 'BB13', 'BB23', 'AL27', 'AN14', 'AT13', 'AY19', 'AY29', 'BA21', 'BB14', 'BB24', 'AM13', 'AN15', 'AV17', 'AY20', 'BA14', 'BA22', 'BB16', 'BB26', 'AM14', 'AN16', 'AW14', 'AY22', 'BA15', 'BA24', 'BB17', 'BB27', 'AM16', 'AN28', 'AY11', 'AY23', 'BA16', 'BA25', 'BB18', 'BB28', 'AK17', 'AM27', 'AN29', 'AY14', 'AY24', 'BA17', 'BA26', 'BB19', 'BB29', 'AK27', 'AM28', 'AN30', 'AY15', 'AY18', 'AY25', 'BA18', 'BA27', 'BB21', 'AK28', 'AM29', 'AP13', 'AY17', 'AY27', 'BA19', 'BA29', 'BB22']},{'label': 'uO', 'num': 15, 'pin_nums': ['J16', 'AP28', 'J17', 'AR13', 'AR14', 'J26', 'J27', 'AR15', 'AR17', 'J28', 'K17', 'AR27', 'AJ18', 'AR28', 'K18', 'AJ25', 'AR29', 'K19', 'AK18', 'AR30', 'K24', 'AK19', 'AT14', 'K25', 'AK24', 'AT15', 'K27', 'AK25', 'AT23', 'L17', 'AL17', 'AT29', 'L19', 'AL19', 'AT30', 'L24', 'AL24', 'AU29', 'L25', 'AL25', 'AW24', 'L26', 'AL26', 'AY21', 'M17', 'AM17', 'B25', 'M18', 'AM18', 'C22', 'M19', 'AM19', 'F23', 'M24', 'AM24', 'G14', 'M26', 'AM26', 'G16', 'N18', 'AN18', 'G27', 'N19', 'AN19', 'G28', 'N24', 'AN25', 'G29', 'N25', 'AN26', 'H14', 'P18', 'AP15', 'H15', 'P25', 'AP16', 'H16', 'R18', 'AP17', 'H28', 'AP18', 'H29', 'AP26', 'H30', 'AP27', 'J15']},{'label': 'uP', 'num': 16, 'pin_nums': ['AT21', 'J23', 'AK20', 'AT22', 'J25', 'AK22', 'AT24', 'K20', 'AK23', 'AT25', 'K22', 'AL20', 'AT26', 'K23', 'AL21', 'AT27', 'L20', 'AL22', 'AU20', 'L21', 'AM21', 'AU21', 'L22', 'AM22', 'D19', 'M21', 'AM23', 'F22', 'M22', 'AN20', 'G17', 'M23', 'AN21', 'G18', 'N20', 'AN23', 'G19', 'N21', 'AN24', 'G20', 'N22', 'AP19', 'G21', 'N23', 'AP20', 'G22', 'P20', 'AP21', 'G23', 'P21', 'AP22', 'G24', 'P22', 'AP23', 'G26', 'P23', 'AP25', 'H17', 'AR16', 'H18', 'AR18', 'H19', 'AR19', 'H20', 'AR20', 'H21', 'AR22', 'H23', 'AR23', 'H24', 'H25', 'AR24', 'AR25', 'H26', 'J18', 'AT16', 'AJ20', 'AT17', 'J20', 'AJ21', 'AJ23', 'AT19', 'J21', 'AJ22', 'AT20', 'J22']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AG30', 'AH14', 'AC22', 'T29', 'T30', 'AH15', 'AE30', 'AF14', 'AH28', 'U14', 'AL28', 'AA21', 'AF15', 'AA22', 'AF30', 'R14', 'AG14', 'R30', 'AB21', 'AB22', 'AG29', 'T14', 'AC21', 'T15']},{'label': 'uR', 'num': 18, 'pin_nums': ['T33', 'AE28', 'C37', 'K16', 'R1', 'T8', 'Y19', 'AB23', 'AF13', 'K21', 'C42', 'U12', 'R11', 'Y21', 'AB25', 'AF17', 'C7', 'K26', 'R12', 'U16', 'Y22', 'AB27', 'AF19', 'D14', 'K31', 'R13', 'U18', 'Y23', 'AB29', 'AF21', 'D24', 'K36', 'R16', 'U20', 'Y25', 'AB31', 'AF23', 'D34', 'K6', 'R19', 'U22', 'Y27', 'AC12', 'AF25', 'D4', 'L13', 'R20', 'U24', 'Y29', 'AC14', 'AF27', 'L18', 'E1', 'U26', 'R21', 'Y31', 'AC16', 'AF29', 'E11', 'L23', 'R22', 'U28', 'AC18', 'AG16', 'E21', 'L28', 'R23', 'U30', 'AC20', 'AG18', 'E31', 'L3', 'R24', 'V13', 'AC24', 'AG20', 'E41', 'L33', 'R25', 'V15', 'A13', 'AC26', 'AG22', 'F18', 'M10', 'R26', 'V17', 'A18', 'AC28', 'AG24', 'F28', 'M15', 'R29', 'V19', 'A23', 'AC30', 'AG26', 'F38', 'M20', 'R31', 'V21', 'A28', 'AD13', 'AG28', 'F8', 'M25', 'R41', 'V23', 'A3', 'AD15', 'AH13', 'G15', 'M30', 'T12', 'V25', 'A33', 'AD17', 'AH17', 'G25', 'M40', 'T13', 'V27', 'A38', 'AD19', 'AH19', 'G35', 'N12', 'T16', 'V29', 'A8', 'AD21', 'AH21', 'G5', 'N17', 'T17', 'W12', 'AA12', 'AD23', 'AH23', 'H12', 'N2', 'T18', 'W14', 'AA14', 'AD25', 'AH25', 'H2', 'N27', 'T19', 'W16', 'AA16', 'AD27', 'AH27', 'H22', 'N32', 'T20', 'W18', 'AA18', 'AD29', 'AJ24', 'H32', 'N37', 'T21', 'W20', 'AA20', 'AE12', 'B10', 'H42', 'N42', 'T22', 'W22', 'AA24', 'AE14', 'B20', 'J19', 'N7', 'T23', 'W24', 'AA26', 'AE16', 'B30', 'J29', 'P14', 'T24', 'W26', 'K11', 'AA28', 'AE18', 'B40', 'J34', 'P19', 'T25', 'W28', 'AA30', 'AE20', 'B5', 'J39', 'P24', 'T26', 'W30', 'AB13', 'AE22', 'C17', 'J9', 'P29', 'T27', 'Y13', 'AB15', 'AB19', 'AE24', 'C2', 'K1', 'P34', 'T28', 'Y15', 'AB17', 'AE26', 'C27', 'P4', 'Y17']},{'label': 'uS', 'num': 19, 'pin_nums': ['Y18', 'AC15', 'AH26', 'AE23', 'AN27', 'AY1', 'V12', 'Y20', 'AC17', 'AH32', 'AE25', 'AY16', 'AN32', 'V14', 'Y24', 'AC19', 'AE27', 'AH42', 'AN37', 'AY26', 'V16', 'Y26', 'AC2', 'AE29', 'AJ14', 'AN42', 'AY36', 'V18', 'Y28', 'AC23', 'AE31', 'AJ19', 'AN7', 'AY41', 'V2', 'Y30', 'AC25', 'AE41', 'AJ29', 'AP14', 'AY6', 'V20', 'Y36', 'AC27', 'AF16', 'AJ39', 'AP24', 'BA13', 'V22', 'Y6', 'AC29', 'AJ9', 'AF18', 'BA23', 'AP29', 'V24', 'AC31', 'AF20', 'AK1', 'AP34', 'BA3', 'V26', 'AA13', 'AC32', 'AF22', 'AK11', 'AP4', 'BA33', 'V28', 'AA15', 'AC37', 'AF24', 'AK16', 'AR1', 'BA38', 'AH24', 'V30', 'AA17', 'AC42', 'AF26', 'AK21', 'AR11', 'BB10', 'V32', 'AA19', 'AC7', 'AF28', 'AK26', 'AR21', 'BB15', 'V42', 'AA23', 'AD12', 'AF33', 'AK31', 'AR31', 'BB20', 'W13', 'AA25', 'AD14', 'AF38', 'AK36', 'AR41', 'BB25', 'W15', 'AA27', 'AD16', 'AF8', 'AK41', 'AT18', 'BB30', 'W17', 'AW9', 'AA29', 'AD18', 'AG13', 'AK6', 'AT28', 'BB35', 'W19', 'AA3', 'AD20', 'AG15', 'AL13', 'AT38', 'BB40', 'W21', 'AA31', 'AD22', 'AG17', 'AL18', 'AT8', 'BB5', 'W23', 'AA33', 'AD24', 'AG19', 'AL23', 'AU15', 'T38', 'W25', 'AB10', 'AD26', 'AG21', 'AL3', 'AU25', 'U10', 'W27', 'AB12', 'AD28', 'AG23', 'AL33', 'AU35', 'U13', 'W29', 'AB14', 'AD30', 'AG25', 'AM10', 'AU5', 'U15', 'W31', 'AB16', 'AD34', 'AG27', 'AM15', 'AV12', 'U17', 'W34', 'AB18', 'AD4', 'AG35', 'AM20', 'AV2', 'U19', 'W39', 'AB20', 'AE1', 'AG5', 'AM25', 'AV22', 'U21', 'W9', 'AB24', 'AE11', 'AH12', 'AM30', 'AV32', 'U23', 'Y1', 'AB26', 'AE13', 'AH18', 'AM40', 'AV42', 'U25', 'Y11', 'AB28', 'AE15', 'AH2', 'AN12', 'AW19', 'U27', 'Y12', 'AB30', 'AE17', 'AH20', 'AN17', 'AW29', 'U29', 'Y14', 'AB40', 'AE19', 'AH22', 'AN2', 'AW39', 'U35', 'Y16', 'AC13', 'AE21', 'AN22', 'U5']}] }),
        Part(**{ 'name':'XC5VLX330T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX330T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX330T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L2P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A31',name='IO_L2N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A32',name='IO_L3P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A34',name='IO_L7P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A35',name='IO_L7N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A36',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A37',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A39',name='IO_L15P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A40',name='IO_L15N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A41',name='IO_L16P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B31',name='IO_L1N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B32',name='IO_L3N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B33',name='IO_L4P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B34',name='IO_L6N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='B36',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B37',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B38',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B39',name='IO_L14P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B41',name='IO_L16N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B42',name='IO_L17P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C30',name='IO_L1P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C31',name='IO_L0N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C33',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C34',name='IO_L6P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C35',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C36',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C38',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C39',name='IO_L13P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C40',name='IO_L13N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C41',name='IO_L17N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D31',name='IO_L0P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D32',name='IO_L5P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D33',name='IO_L5N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D35',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D36',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D38',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D40',name='IO_L18P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D41',name='IO_L18N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D42',name='IO_L19N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='E42',name='IO_L19P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW31',name='IO_L19N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW32',name='IO_L15N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW33',name='IO_L15P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW35',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW36',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW37',name='IO_L6N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW38',name='IO_L7P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW40',name='IO_L1N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW41',name='IO_L1P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW42',name='IO_L0N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY30',name='IO_L19P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY32',name='IO_L16P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY33',name='IO_L14P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY34',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY35',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY37',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY38',name='IO_L6P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY39',name='IO_L7N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY40',name='IO_L2P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY42',name='IO_L0P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA30',name='IO_L18P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA31',name='IO_L18N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA32',name='IO_L16N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA34',name='IO_L13N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA35',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA36',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA37',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA39',name='IO_L5N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA40',name='IO_L4P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA41',name='IO_L2N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA42',name='IO_L3P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB31',name='IO_L17N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB32',name='IO_L17P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB33',name='IO_L13P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB34',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB36',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB37',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB38',name='IO_L5P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB39',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB41',name='IO_L3N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='A20',name='IO_L2P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A21',name='IO_L2N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A22',name='IO_L3P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A24',name='IO_L6N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A25',name='IO_L13N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A26',name='IO_L13P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A27',name='IO_L14P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A29',name='IO_L15N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='AV26',name='IO_L11P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV28',name='IO_L10P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV29',name='IO_L5P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV30',name='IO_L4N_VREF_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW20',name='IO_L19N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW21',name='IO_L19P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW22',name='IO_L15N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW23',name='IO_L15P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW25',name='IO_L9N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW26',name='IO_L11N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW27',name='IO_L10N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW28',name='IO_L5N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW30',name='IO_L4P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY19',name='IO_L18P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY20',name='IO_L18N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY22',name='IO_L14P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY23',name='IO_L14N_VREF_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY24',name='IO_L9P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY25',name='IO_L3N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY27',name='IO_L6P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY28',name='IO_L6N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY29',name='IO_L7P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='B21',name='IO_L3N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B22',name='IO_L5N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B23',name='IO_L6P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B24',name='IO_L7P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B26',name='IO_L12N_VRP_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B27',name='IO_L14N_VREF_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B28',name='IO_L15P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B29',name='IO_L18N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='BA19',name='IO_L17N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA20',name='IO_L17P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA21',name='IO_L16N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA22',name='IO_L13N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA24',name='IO_L8N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA25',name='IO_L3P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA26',name='IO_L2N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA27',name='IO_L1N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='BA29',name='IO_L7N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB20',name='IO_L16P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB21',name='IO_L13P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB22',name='IO_L12P_VRN_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB23',name='IO_L12N_VRP_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB24',name='IO_L8P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB26',name='IO_L2P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB27',name='IO_L1P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB28',name='IO_L0N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB29',name='IO_L0P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='C20',name='IO_L1N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C21',name='IO_L1P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C23',name='IO_L5P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C24',name='IO_L7N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C25',name='IO_L12P_VRN_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C26',name='IO_L11N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C28',name='IO_L19P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C29',name='IO_L18P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C32',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D20',name='IO_L0P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D21',name='IO_L0N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D22',name='IO_L4P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D23',name='IO_L4N_VREF_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D25',name='IO_L9P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D26',name='IO_L9N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D27',name='IO_L11P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D28',name='IO_L19N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D30',name='IO_L17N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E24',name='IO_L8P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E25',name='IO_L8N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E27',name='IO_L10N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E28',name='IO_L10P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E29',name='IO_L17P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E30',name='IO_L16N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='F30',name='IO_L16P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL11',name='IO_L1P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AL12',name='IO_L1N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM11',name='IO_L3P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AM12',name='IO_L3N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN10',name='IO_L5N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AN11',name='IO_L5P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP10',name='IO_L7P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP11',name='IO_L9P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP12',name='IO_L9N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP9',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AR10',name='IO_L10P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR12',name='IO_L12N_VRP_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR13',name='IO_L14P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AR9',name='IO_L7N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT10',name='IO_L10N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT11',name='IO_L12P_VRN_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT12',name='IO_L14N_VREF_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AT9',name='IO_L18N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AU11',name='IO_L13P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU12',name='IO_L13N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU13',name='IO_L15N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU14',name='IO_L15P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU16',name='IO_L4N_VREF_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU17',name='IO_L2N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU7',name='IO_L19N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU8',name='IO_L19P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU9',name='IO_L18P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV10',name='IO_L17P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV11',name='IO_L11N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV13',name='IO_L8N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV14',name='IO_L6N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV15',name='IO_L6P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV16',name='IO_L4P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV18',name='IO_L2P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV19',name='IO_L0N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV7',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AV8',name='IO_L16N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV9',name='IO_L17N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW12',name='IO_L11P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW13',name='IO_L8P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW18',name='IO_L0P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW7',name='IO_L16P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=12),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=12),
            Pin(num='AJ21',name='IO_L2N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AJ22',name='IO_L2P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK20',name='IO_L3P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK22',name='IO_L1N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK23',name='IO_L1P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL20',name='IO_L3N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL21',name='IO_L0P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL22',name='IO_L0N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM21',name='IO_L19N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM22',name='IO_L16P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM23',name='IO_L16N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AN21',name='IO_L19P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AN23',name='IO_L17P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AP20',name='IO_L18P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP21',name='IO_L18N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP22',name='IO_L14N_VREF_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP23',name='IO_L17N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR20',name='IO_L7P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR22',name='IO_L15P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR23',name='IO_L14P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR24',name='IO_L8N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR25',name='IO_L6P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT20',name='IO_L7N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT21',name='IO_L9N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT22',name='IO_L15N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT24',name='IO_L8P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT25',name='IO_L6N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU18',name='IO_L5N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU19',name='IO_L5P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AU21',name='IO_L9P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU22',name='IO_L12N_VRP_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU23',name='IO_L12P_VRN_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU24',name='IO_L11P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU26',name='IO_L4P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU27',name='IO_L4N_VREF_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AV20',name='IO_L10N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV21',name='IO_L10P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV23',name='IO_L13P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV24',name='IO_L13N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV25',name='IO_L11N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='D18',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=13),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='E19',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E20',name='IO_L14P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E22',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E23',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F19',name='IO_L16P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F20',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F21',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F24',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F25',name='IO_L17N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F26',name='IO_L17P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G19',name='IO_L16N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='G21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G22',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G23',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G24',name='IO_L15P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G26',name='IO_L19N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='H19',name='IO_L18P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H20',name='IO_L18N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H21',name='IO_L4P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H23',name='IO_L13N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H24',name='IO_L15N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H25',name='IO_L19P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J20',name='IO_L5P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J21',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J22',name='IO_L7N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J23',name='IO_L13P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K20',name='IO_L5N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K22',name='IO_L7P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K23',name='IO_L6N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='L21',name='IO_L1N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='L22',name='IO_L6P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M21',name='IO_L1P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M22',name='IO_L0N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M23',name='IO_L0P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N21',name='IO_L3N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N22',name='IO_L3P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N23',name='IO_L2N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N24',name='IO_L2P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=14),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=15),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=16),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=17),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A10',name='MGTRXN0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A11',name='MGTRXP0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A8',name='MGTRXP1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A9',name='MGTRXN1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='AW9',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=18),
            Pin(num='AY9',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=18),
            Pin(num='B11',name='MGTTXN0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B12',name='MGTTXP0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B7',name='MGTTXP1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B8',name='MGTTXN1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='BA11',name='MGTTXN1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA12',name='MGTTXP1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA7',name='MGTTXP0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA8',name='MGTTXN0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB10',name='MGTRXN1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB11',name='MGTRXP1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB8',name='MGTRXP0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB9',name='MGTRXN0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='C10',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=18),
            Pin(num='D10',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A14',name='MGTRXP1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A15',name='MGTRXN1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A16',name='MGTRXN0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A17',name='MGTRXP0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='AW15',name='MGTREFCLKP_134',func=pin_types.BIDIR,unit=19),
            Pin(num='AY15',name='MGTREFCLKN_134',func=pin_types.BIDIR,unit=19),
            Pin(num='B13',name='MGTTXP1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B14',name='MGTTXN1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B17',name='MGTTXN0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B18',name='MGTTXP0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='BA13',name='MGTTXP0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA14',name='MGTTXN0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA17',name='MGTTXN1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA18',name='MGTTXP1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB14',name='MGTRXP0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB15',name='MGTRXN0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB16',name='MGTRXN1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB17',name='MGTRXP1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='C16',name='MGTREFCLKN_132',func=pin_types.BIDIR,unit=19),
            Pin(num='D16',name='MGTREFCLKP_132',func=pin_types.BIDIR,unit=19),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=20),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AW16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY11',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY12',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY13',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY14',name='MGTAVTTRX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY17',name='MGTAVCCPLL_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY18',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY7',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY8',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C11',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C12',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C13',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C14',name='MGTAVCCPLL_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C17',name='MGTAVTTRX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C18',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C7',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C8',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=20),
            Pin(num='D15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=20),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=20),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=20),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=20),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=20),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=20),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=20),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=20),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=20),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=20),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=20),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=20),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=21),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=21),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=22),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=22),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=22),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=23)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['M16', 'N26', 'P18', 'R40', 'Y40', 'H41', 'M29', 'N28', 'P25', 'R42', 'AA38', 'J14', 'V41', 'Y41', 'M41', 'J41', 'N29', 'P26', 'T40', 'AA39', 'M42', 'W40', 'Y42', 'AA40', 'J42', 'N13', 'N30', 'P27', 'T41', 'AA41', 'W41', 'K42', 'N14', 'N40', 'P28', 'T42', 'AA42', 'L40', 'W42', 'F13', 'L41', 'N15', 'N41', 'P40', 'U41', 'Y37', 'L42', 'F41', 'N16', 'P13', 'P41', 'U42', 'AA37', 'V40', 'Y38', 'F42', 'M13', 'G41', 'N25', 'P17', 'P42', 'M14', 'V37', 'Y39', 'G42']},{'label': 'uB', 'num': 2, 'pin_nums': ['AE40', 'Y9', 'J6', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AA6', 'AK42', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AA9', 'AL42', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'AR42', 'V8', 'AC38', 'AT41', 'W10', 'AC39', 'AT42', 'W11', 'AC40', 'AU41', 'W5', 'AC41', 'AU42', 'W6', 'AD39', 'AV41', 'W7', 'AD40', 'G6', 'W8', 'AE36', 'AD41', 'H5', 'Y10', 'AD42', 'H6', 'Y7', 'J5', 'Y8']},{'label': 'uC', 'num': 3, 'pin_nums': ['M39', 'N38', 'AL39', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'G38', 'W37', 'AG39', 'G39', 'W38', 'AG40', 'H38', 'Y34', 'AH37', 'H39', 'Y35', 'AH38', 'H40', 'AH39', 'J38', 'AJ37', 'J40', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'AL37', 'L39', 'AK41', 'M38']},{'label': 'uD', 'num': 4, 'pin_nums': ['AJ7', 'AC6', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AL5', 'AD10', 'U33', 'AD11', 'D37', 'U34', 'E37', 'AD5', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AE6', 'H35', 'Y32', 'AE7', 'H36', 'Y33', 'AE8', 'J35', 'J36', 'AE9', 'AJ6', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'L38', 'AG10', 'AA32', 'AG4', 'M36', 'AB11', 'AG6', 'M37', 'AB6', 'AG7', 'N35', 'AB7', 'AH4', 'N36', 'AB8', 'AH5', 'P35', 'AB9', 'AH6', 'P36', 'AC10', 'AJ5', 'R34', 'AC5', 'R35']},{'label': 'uE', 'num': 5, 'pin_nums': ['T10', 'AN13', 'E8', 'AJ30', 'AK30', 'G9', 'L7', 'P7', 'T11', 'AK12', 'AL14', 'AN14', 'E9', 'T9', 'H8', 'L8', 'P8', 'AK13', 'AL29', 'AP13', 'F5', 'H9', 'L9', 'P9', 'U11', 'AK14', 'AL30', 'AR26', 'F6', 'J7', 'M7', 'R6', 'U8', 'AK15', 'AM13', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AK27', 'AM14', 'D7', 'F9', 'K7', 'M9', 'R8', 'V10', 'AK28', 'AM28', 'E5', 'G7', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'AK29', 'AM29', 'E7', 'V9', 'G8', 'K9', 'N9']},{'label': 'uF', 'num': 6, 'pin_nums': ['AH35', 'P33', 'AH36', 'R32', 'E36', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AT37', 'M31', 'AE34', 'AU37', 'M32', 'AE35', 'AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AG36', 'E33', 'E35', 'P31', 'AH34', 'E34', 'P32']},{'label': 'uG', 'num': 7, 'pin_nums': ['G11', 'AR34', 'AR35', 'G12', 'AR36', 'G13', 'G14', 'AT31', 'AT32', 'H10', 'H11', 'AT34', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'K10', 'AJ32', 'AV34', 'K12', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31', 'E15', 'N11', 'AN33', 'E6', 'P10', 'AP31', 'F10', 'P11', 'AP32', 'F11', 'P12', 'AP33', 'F12', 'R10', 'AP39', 'F14', 'AR32', 'F15', 'AR33', 'G10']},{'label': 'uH', 'num': 8, 'pin_nums': ['AM9', 'C33', 'A34', 'AN4', 'C34', 'A35', 'AN5', 'C35', 'A36', 'AN6', 'C36', 'A37', 'AN8', 'C38', 'A39', 'AN9', 'C39', 'A40', 'AP5', 'C40', 'A41', 'AP6', 'C41', 'AG11', 'AP7', 'D31', 'AG12', 'AP8', 'D32', 'AG8', 'AR5', 'D33', 'AG9', 'AR7', 'D35', 'AH10', 'AR8', 'D36', 'AH11', 'AT5', 'D38', 'AH7', 'AT6', 'D40', 'AH8', 'AT7', 'D41', 'AH9', 'AU6', 'D42', 'AJ10', 'AV5', 'E42', 'AJ11', 'AV6', 'F33', 'AJ8', 'B31', 'J34', 'AK10', 'B32', 'AK11', 'B33', 'AK8', 'B34', 'AK9', 'B35', 'AL10', 'B36', 'B37', 'AL6', 'AL7', 'B38', 'B39', 'AL8', 'B41', 'AL9', 'AM6', 'B42', 'A30', 'A32', 'AM7', 'C30', 'A31', 'AM8', 'C31']},{'label': 'uI', 'num': 9, 'pin_nums': ['K28', 'L29', 'AW42', 'AW33', 'AY39', 'BA36', 'BB33', 'H27', 'K29', 'L30', 'AY40', 'BA37', 'BB34', 'AY30', 'J15', 'K30', 'M17', 'AW34', 'AW35', 'AY32', 'AY42', 'BA39', 'BB36', 'J16', 'L14', 'M26', 'AY33', 'AW36', 'BA30', 'BA40', 'BB37', 'J17', 'L15', 'M27', 'AY38', 'AW41', 'BA35', 'AT33', 'AW37', 'AY34', 'BA31', 'BA41', 'BB32', 'BB38', 'E26', 'J30', 'L16', 'M28', 'AW38', 'AY35', 'AV37', 'BA32', 'BA42', 'BB39', 'K15', 'L17', 'AW31', 'AW40', 'AY37', 'BA34', 'BB31', 'BB41', 'K17', 'L27', 'AW32']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AV28', 'D27', 'AV29', 'BA22', 'D28', 'AV30', 'BA24', 'D29', 'AW20', 'BA25', 'D30', 'AW21', 'BA26', 'E24', 'AW22', 'BA27', 'E25', 'AW23', 'BA28', 'E27', 'AW25', 'BA29', 'E28', 'AW26', 'BB20', 'E29', 'AW27', 'BB21', 'E30', 'AW28', 'BB22', 'F30', 'AW30', 'BB23', 'G30', 'AY19', 'BB24', 'AY20', 'BB26', 'AY22', 'BB27', 'AY23', 'BB28', 'AY24', 'BB29', 'AY25', 'C20', 'AY27', 'C21', 'AY28', 'C23', 'AY29', 'C24', 'AY31', 'C25', 'A20', 'B21', 'C26', 'A21', 'B22', 'C28', 'A22', 'B23', 'C29', 'A24', 'B24', 'C32', 'A25', 'B26', 'D20', 'A26', 'B27', 'D21', 'A27', 'B28', 'D22', 'A29', 'B29', 'D23', 'AU30', 'BA19', 'BA21', 'D25', 'AV26', 'BA20', 'D26']},{'label': 'uK', 'num': 11, 'pin_nums': ['AL16', 'AM26', 'AT11', 'AN30', 'AP30', 'AU14', 'AV13', 'AV9', 'AL17', 'AM27', 'AT12', 'AV14', 'AW12', 'AP9', 'AP10', 'AU16', 'AL26', 'AN10', 'AP11', 'AR10', 'AT13', 'AU17', 'AV15', 'AW13', 'AN29', 'AL27', 'AN11', 'AT10', 'AP12', 'AR12', 'AT9', 'AU13', 'AU7', 'AV11', 'AV16', 'AW18', 'AV8', 'AK17', 'AM11', 'AN15', 'AP15', 'AR13', 'AU10', 'AU8', 'AV18', 'AW7', 'AM12', 'AL11', 'AN16', 'AP16', 'AR16', 'AU11', 'AU9', 'AV19', 'AL12', 'AM16', 'AN28', 'AP27', 'AR9', 'AU12', 'AV10', 'AV7', 'AL15', 'AM17', 'AP28']},{'label': 'uL', 'num': 12, 'pin_nums': ['F27', 'N18', 'AP26', 'F29', 'N19', 'AR14', 'G16', 'N20', 'AR15', 'G17', 'P20', 'AR17', 'G18', 'AR18', 'G27', 'AR19', 'G28', 'AR27', 'G29', 'AR28', 'H16', 'AR29', 'H18', 'AR30', 'H26', 'AT14', 'H28', 'AT15', 'H29', 'AT16', 'H30', 'AK18', 'AT17', 'J18', 'AK19', 'AT19', 'J25', 'AK24', 'AT23', 'J26', 'AK25', 'AT26', 'J27', 'AL19', 'AT27', 'J28', 'AL24', 'AT29', 'K18', 'AL25', 'AT30', 'K19', 'AM18', 'AU28', 'K24', 'AM19', 'AU29', 'K25', 'AM24', 'AW24', 'K27', 'AN18', 'AY21', 'L19', 'AN19', 'B25', 'L20', 'AN20', 'C22', 'L24', 'AN24', 'E17', 'L25', 'AN25', 'E18', 'L26', 'AN26', 'F16', 'M18', 'AP17', 'AP25', 'F17', 'M19', 'AP18', 'F23', 'M24']},{'label': 'uM', 'num': 13, 'pin_nums': ['AU18', 'G23', 'AU19', 'G24', 'AU20', 'G26', 'AU21', 'H17', 'AJ21', 'AU22', 'H19', 'AU23', 'AJ22', 'H20', 'AT25', 'AK20', 'AU24', 'H21', 'AK22', 'AU26', 'H23', 'AK23', 'AU27', 'H24', 'AL20', 'AV17', 'H25', 'AL21', 'AV20', 'J20', 'AL22', 'AV21', 'J21', 'AM21', 'AV23', 'J22', 'AM22', 'AV24', 'J23', 'AM23', 'AV25', 'K20', 'AN21', 'D18', 'K22', 'AN23', 'D19', 'K23', 'AP19', 'E19', 'L21', 'AP20', 'E20', 'L22', 'AP21', 'E22', 'M21', 'AP22', 'E23', 'M22', 'AP23', 'F19', 'M23', 'AR20', 'F20', 'N21', 'AR22', 'F21', 'N22', 'AR23', 'F22', 'N23', 'AR24', 'F24', 'N24', 'AR25', 'F25', 'AT20', 'F26', 'AT21', 'G19', 'G20', 'AT22', 'AT24', 'G21', 'G22']},{'label': 'uN', 'num': 14, 'pin_nums': ['AD3', 'U2', 'V1', 'AD4', 'AE1', 'V3', 'AA2', 'AF1', 'V4', 'AB2', 'AF2', 'W1', 'AC1', 'AG2', 'Y1', 'AC2', 'T2', 'Y2', 'AD1', 'U1']},{'label': 'uO', 'num': 15, 'pin_nums': ['AJ1', 'AN2', 'P1', 'AJ2', 'K2', 'P2', 'AK1', 'L1', 'R2', 'AK3', 'L2', 'AM2', 'N1', 'AK4', 'M1', 'M3', 'AL1', 'AM1', 'M4', 'AH2']},{'label': 'uP', 'num': 16, 'pin_nums': ['AT3', 'E2', 'F1', 'AT4', 'AU1', 'F3', 'AV1', 'F4', 'AP2', 'AV2', 'G1', 'AR1', 'AW2', 'H1', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2']},{'label': 'uQ', 'num': 17, 'pin_nums': ['B5', 'A2', 'BB4', 'A3', 'B6', 'BB5', 'A4', 'BA1', 'C3', 'A5', 'BA2', 'C4', 'AW4', 'BA5', 'AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3']},{'label': 'uR', 'num': 18, 'pin_nums': ['AW9', 'BA7', 'AY9', 'BA8', 'BA12', 'D10', 'B11', 'BB10', 'B12', 'BB11', 'A10', 'B7', 'BB8', 'A11', 'B8', 'BB9', 'A8', 'BA11', 'C10', 'A9']},{'label': 'uS', 'num': 19, 'pin_nums': ['B14', 'BB15', 'A14', 'B17', 'BB16', 'A15', 'B18', 'BB17', 'A16', 'BA13', 'C16', 'A17', 'BA14', 'D16', 'AW15', 'BA17', 'AY15', 'BA18', 'B13', 'BB14']},{'label': 'uT', 'num': 20, 'pin_nums': ['AY5', 'AL3', 'AY12', 'AB4', 'AV3', 'C14', 'C8', 'G3', 'P3', 'AC3', 'AL4', 'AW10', 'AY13', 'C9', 'G4', 'R3', 'AY6', 'C15', 'AE3', 'AM3', 'AW16', 'AY14', 'AY7', 'C17', 'D15', 'E3', 'H3', 'N4', 'T3', 'AE4', 'AN3', 'AW3', 'AY16', 'AY8', 'C18', 'D3', 'J3', 'U3', 'AF3', 'AP3', 'AW5', 'AY17', 'C1', 'C2', 'D4', 'K3', 'W3', 'AA3', 'AG3', 'AR3', 'AY1', 'AY18', 'C11', 'C5', 'D5', 'L3', 'W4', 'AA5', 'AH3', 'AU3', 'AY10', 'AY2', 'C12', 'C6', 'D9', 'N3', 'Y3', 'AB3', 'AJ3', 'AU4', 'AY11', 'C7', 'AY3', 'C13']},{'label': 'uU', 'num': 21, 'pin_nums': ['P15', 'AA22', 'AH15', 'AB21', 'R14', 'AH16', 'AB22', 'AH29', 'R15', 'AC21', 'AH30', 'R29', 'AA21', 'AL28', 'AC22', 'AJ15', 'R30', 'AG29', 'AJ16', 'T14', 'AG30', 'AJ28', 'T30', 'AH14']},{'label': 'uV', 'num': 22, 'pin_nums': ['Y25', 'AD29', 'E31', 'AH21', 'L18', 'P4', 'U22', 'Y27', 'AA20', 'AD31', 'E4', 'AH23', 'R11', 'L23', 'U24', 'Y29', 'AA24', 'AE12', 'AH25', 'E41', 'L28', 'R12', 'U26', 'Y31', 'AA26', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'E21', 'U30', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'R19', 'M2', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'P34', 'AB27', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'AG16', 'D11', 'J4', 'P14', 'T21', 'W28', 'AC30', 'AG18', 'D14', 'J9', 'P16', 'T23', 'A19', 'W30', 'AD13', 'AG20', 'D17', 'K11', 'P19', 'T25', 'A23', 'Y13', 'AD15', 'AG22', 'D24', 'K16', 'P21', 'T27', 'A28', 'Y15', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'A33', 'Y17', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'A38', 'Y19', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'U14', 'AA12', 'Y21', 'AD23', 'AH13', 'E11', 'K36', 'P29', 'U16', 'AA14', 'Y22', 'AA18', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'AA16', 'Y23', 'AD27', 'AH19', 'L13', 'U20']},{'label': 'uW', 'num': 23, 'pin_nums': ['T20', 'AE31', 'AC25', 'AN12', 'AH42', 'AV4', 'T22', 'W13', 'AE41', 'AC27', 'AN17', 'AJ13', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'AA13', 'W19', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'AA15', 'W2', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'AA17', 'W21', 'AC4', 'AF22', 'AJ25', 'AN42', 'AW29', 'T8', 'AA19', 'W23', 'AC42', 'AF24', 'AN7', 'AJ27', 'AW39', 'U13', 'AA23', 'W25', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'AA25', 'W27', 'AD12', 'AF28', 'AJ39', 'AP24', 'AW8', 'U17', 'AA27', 'W29', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'AA29', 'W31', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'AA31', 'W34', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'AA33', 'W39', 'AD2', 'AF8', 'AK2', 'AR11', 'BA10', 'U25', 'AB10', 'W9', 'AD20', 'AG13', 'AK21', 'AR21', 'BA15', 'U27', 'AB12', 'Y11', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'AB14', 'Y12', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'AB16', 'Y14', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'AB18', 'Y16', 'AD28', 'AG21', 'AK6', 'AR6', 'AE29', 'BA33', 'U5', 'AB20', 'Y18', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'AB24', 'Y20', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'V14', 'AB26', 'Y24', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'AB28', 'Y26', 'AE13', 'AG35', 'AL23', 'AT38', 'BB19', 'V18', 'AB30', 'Y28', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'AB40', 'Y30', 'AE17', 'AH12', 'AM10', 'AU15', 'BB30', 'V20', 'AB5', 'Y36', 'AE19', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'AM5', 'AC11', 'Y4', 'AE2', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'AC13', 'Y6', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'V42', 'AE27', 'AH28', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AH32', 'AV32']}] }),
        Part(**{ 'name':'XC5VLX50-FF1153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX50-FF1153'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX50-FF1153\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P33',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V32',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AC2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AD1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF1',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF3',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG2',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH2',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL3',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN3',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H31',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H5',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K5',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L6',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P4',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R11',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T10',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T9',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA4',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC5',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AD4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG5',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ4',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ5',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='B29',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F27',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V8',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W7',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y9',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC15',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC20',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD19',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE19',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AG23',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AL22',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E7',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E9',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F7',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='F8',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G4',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G8',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H7',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H8',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K8',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L11',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M11',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AA10',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA11',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA8',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA9',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB10',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB11',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB8',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD7',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD9',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE11',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE7',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF8',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG10',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH7',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ10',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ6',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ9',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AK6',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AN6',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='B9',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='AF27',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AG24',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AH11',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AL12',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AM9',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AE18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF17',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AF18',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF19',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF20',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF21',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG13',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG20',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH12',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH19',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AK15',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AK19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='F20',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G20',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G21',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G22',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H12',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H13',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H15',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H18',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H19',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H20',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H21',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='H22',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H23',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J14',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J15',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J16',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J17',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J20',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J21',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AM19',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='AA13',name='TCK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AB13',name='TMS_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC13',name='TDI_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC14',name='TDO_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD13',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='AD14',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AG14',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='L13',name='INIT_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M13',name='CCLK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M23',name='CS_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N13',name='D_IN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N14',name='DONE_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N22',name='HSWAPEN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P22',name='VBATT_0',func=pin_types.PWRIN,unit=13),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='T27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=14)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N33', 'K12', 'K23', 'L20', 'C33', 'G32', 'K13', 'K32', 'L21', 'N34', 'C34', 'G33', 'T33', 'K14', 'D13', 'H32', 'K33', 'L23', 'K16', 'P32', 'T34', 'D32', 'H33', 'K17', 'K34', 'L33', 'P33', 'U31', 'D34', 'H34', 'E32', 'K18', 'L14', 'L34', 'J12', 'P34', 'U32', 'E33', 'J19', 'K19', 'L15', 'M32', 'R30', 'U33', 'E34', 'A33', 'J22', 'K21', 'L16', 'M33', 'R32', 'F33', 'R34', 'V31', 'B32', 'J32', 'B33', 'F34', 'K22', 'L19', 'N32', 'J34', 'R33', 'C32', 'G14']},{'label': 'uB', 'num': 2, 'pin_nums': ['AK33', 'L1', 'AK34', 'L3', 'AL33', 'M1', 'AL34', 'M2', 'AM32', 'M3', 'AM33', 'N2', 'AN32', 'N3', 'AN33', 'A3', 'P1', 'AN34', 'AA32', 'P2', 'AA33', 'AP32', 'R1', 'AA34', 'B1', 'R2', 'AB29', 'B2', 'R3', 'AB32', 'B3', 'T1', 'AB33', 'C2', 'T3', 'AC32', 'C3', 'T7', 'AK32', 'AC33', 'D1', 'U1', 'AC34', 'D2', 'U2', 'AD32', 'E1', 'U3', 'AD34', 'E2', 'U4', 'AE32', 'E3', 'V32', 'AE33', 'F1', 'V33', 'AE34', 'F3', 'V34', 'AF33', 'G1', 'W28', 'G2', 'AF34', 'W32', 'AG32', 'G3', 'W34', 'AG33', 'H2', 'W8', 'AH32', 'H3', 'Y32', 'AH33', 'J1', 'Y33', 'AH34', 'J2', 'Y34', 'AJ32', 'K1', 'AJ34', 'K2', 'K3']},{'label': 'uC', 'num': 3, 'pin_nums': ['AB1', 'T25', 'AB2', 'E31', 'T26', 'AB3', 'F29', 'T28', 'AB9', 'F30', 'T29', 'AC2', 'F31', 'T30', 'AC3', 'G30', 'T31', 'AC6', 'G31', 'U25', 'AD1', 'H29', 'U26', 'AD2', 'H30', 'U27', 'AE1', 'H31', 'U28', 'AE2', 'J29', 'U30', 'AE3', 'J30', 'V2', 'AF1', 'J31', 'V3', 'AF3', 'K29', 'V4', 'AG1', 'K31', 'W1', 'AG2', 'L29', 'W2', 'AG3', 'L30', 'Y1', 'AH2', 'L31', 'Y2', 'AH3', 'L32', 'Y3', 'AJ1', 'M29', 'Y5', 'AJ2', 'M30', 'AK1', 'M31', 'AK2', 'N29', 'AK3', 'N30', 'AL1', 'P29', 'AL3', 'P30', 'AM1', 'P31', 'AM2', 'R26', 'AM3', 'R27', 'AN2', 'R28', 'AA1', 'AN3', 'E29', 'R29', 'AA3', 'AP2', 'R31']},{'label': 'uD', 'num': 4, 'pin_nums': ['N6', 'AE30', 'W26', 'AE31', 'P3', 'W27', 'AF29', 'P4', 'W29', 'P5', 'AF30', 'W30', 'AF31', 'P6', 'W31', 'R11', 'AG30', 'Y26', 'AG31', 'R4', 'Y27', 'R6', 'AH29', 'Y28', 'AH30', 'R7', 'Y29', 'AH31', 'R8', 'Y31', 'AJ30', 'R9', 'AJ31', 'T10', 'AK31', 'T11', 'E4', 'T4', 'F4', 'T5', 'F5', 'T6', 'G5', 'T8', 'H4', 'T9', 'H5', 'U10', 'J4', 'U11', 'AA29', 'J5', 'U5', 'AA30', 'J6', 'U6', 'AA31', 'K4', 'U7', 'AB30', 'K5', 'U8', 'AB31', 'K6', 'V24', 'AC29', 'L4', 'V25', 'AC30', 'L5', 'V27', 'AD29', 'L6', 'V28', 'AD30', 'M5', 'V29', 'AD31', 'V30', 'M6', 'N5', 'AD33', 'N4', 'W24', 'AE29', 'W25']},{'label': 'uE', 'num': 5, 'pin_nums': ['AH5', 'L28', 'Y9', 'AJ4', 'M25', 'AJ5', 'M26', 'AK4', 'M27', 'B29', 'M28', 'E26', 'N24', 'E27', 'N25', 'E28', 'N27', 'E30', 'N28', 'F25', 'P24', 'F26', 'P25', 'AA4', 'F27', 'P26', 'AA5', 'F28', 'P27', 'AA6', 'G25', 'R24', 'AB5', 'G26', 'T24', 'AB6', 'G27', 'V10', 'AC4', 'G28', 'V5', 'AC5', 'H24', 'V7', 'AD3', 'H25', 'V8', 'AD4', 'H27', 'V9', 'AD5', 'H28', 'W10', 'AD6', 'J24', 'W11', 'AE4', 'J25', 'W4', 'AE6', 'J26', 'W5', 'AF4', 'J27', 'W6', 'AF5', 'K24', 'W7', 'AF6', 'K26', 'W9', 'AF7', 'K27', 'Y11', 'AG4', 'K28', 'Y4', 'AG5', 'L24', 'Y6', 'AG6', 'L25', 'Y7', 'AH4', 'L26', 'Y8']},{'label': 'uF', 'num': 6, 'pin_nums': ['AD20', 'E6', 'AE22', 'K7', 'H8', 'M11', 'P11', 'AE12', 'AE23', 'E7', 'G10', 'H9', 'K8', 'M7', 'P7', 'AC15', 'AE13', 'AF15', 'E8', 'G4', 'J10', 'K9', 'M8', 'P9', 'AC19', 'AE14', 'AF16', 'E9', 'G6', 'J11', 'L10', 'N10', 'AC20', 'AE16', 'AF23', 'F10', 'G7', 'J7', 'L11', 'N7', 'AD15', 'AE17', 'AG23', 'F6', 'G8', 'J8', 'L8', 'N8', 'AD16', 'AE19', 'AH21', 'F7', 'F9', 'H10', 'J9', 'L9', 'N9', 'AD19', 'AE21', 'AL22', 'F8', 'H7', 'K11', 'M10', 'P10']},{'label': 'uG', 'num': 7, 'pin_nums': ['AH8', 'AD27', 'AD7', 'AH9', 'AD9', 'AJ10', 'AA10', 'AJ25', 'AE11', 'AA11', 'AE24', 'AJ26', 'AA24', 'AJ27', 'AE26', 'AA25', 'AE27', 'AJ28', 'AA26', 'AE28', 'AJ29', 'AA28', 'AE7', 'AJ6', 'AA8', 'AE8', 'AJ7', 'AA9', 'AE9', 'AJ8', 'AB10', 'AF10', 'AJ9', 'AB11', 'AF11', 'AK26', 'AB25', 'AF24', 'AK27', 'AB26', 'AF25', 'AK28', 'AB27', 'AF26', 'AK29', 'AB28', 'AF28', 'AK5', 'AB7', 'AF8', 'AK6', 'AB8', 'AF9', 'AK7', 'AC10', 'AG10', 'AK8', 'AC24', 'AG11', 'AK9', 'AC25', 'AG25', 'AL32', 'AC27', 'AG26', 'AM29', 'AC28', 'AG27', 'AN6', 'AC7', 'AG28', 'Y24', 'AC8', 'AG7', 'AC9', 'AG8', 'AD10', 'AH10', 'AD11', 'AH25', 'AD24', 'AH27', 'AD25', 'AH28', 'AD26', 'AH7']},{'label': 'uH', 'num': 8, 'pin_nums': ['B9', 'C6', 'E10', 'C26', 'D23', 'G24']},{'label': 'uI', 'num': 9, 'pin_nums': ['AG24', 'AK25', 'AM9', 'AF27', 'AH11', 'AL12']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AF13', 'AH19', 'G20', 'AG13', 'H19', 'J17', 'AF14', 'AG15', 'AH20', 'G21', 'H20', 'J20', 'AF17', 'AG16', 'AJ19', 'G22', 'H21', 'J21', 'AF18', 'AG17', 'AK15', 'H12', 'H22', 'AF19', 'AG20', 'AK19', 'H13', 'H23', 'AF20', 'AG21', 'E20', 'H14', 'J14', 'AF21', 'AG22', 'F20', 'H15', 'J15', 'AE18', 'AG12', 'AH12', 'G13', 'H18', 'J16']},{'label': 'uK', 'num': 11, 'pin_nums': ['AN16', 'B19', 'F17', 'AM19', 'C16', 'AJ18']},{'label': 'uL', 'num': 12, 'pin_nums': ['N13', 'W17', 'N14', 'W18', 'AD21', 'AA13', 'AD22', 'N22', 'AB13', 'AG14', 'N23', 'AC13', 'L13', 'U17', 'AC14', 'M13', 'U18', 'AC22', 'M22', 'V17', 'AD13', 'M23', 'V18', 'AD14']},{'label': 'uM', 'num': 13, 'pin_nums': ['AB15', 'G9', 'M21', 'R12', 'U15', 'M20', 'AB17', 'M24', 'H1', 'U16', 'R13', 'AB19', 'H11', 'M34', 'R14', 'U19', 'AB21', 'M4', 'H16', 'R15', 'U20', 'AC12', 'H26', 'M9', 'R16', 'U21', 'AC16', 'H6', 'N1', 'R17', 'U22', 'AC18', 'J13', 'N11', 'R18', 'U23', 'AD17', 'J18', 'N12', 'U24', 'R19', 'AD23', 'J23', 'N15', 'R20', 'U9', 'B14', 'J28', 'N16', 'R21', 'V11', 'B24', 'J3', 'N17', 'R22', 'V13', 'B34', 'J33', 'N18', 'R23', 'V15', 'B4', 'K10', 'N19', 'R25', 'V19', 'C1', 'K15', 'N20', 'R5', 'V21', 'C11', 'K20', 'N21', 'T12', 'V23', 'C21', 'K25', 'N26', 'T13', 'W12', 'C31', 'K30', 'N31', 'T14', 'W14', 'D18', 'L12', 'P12', 'T15', 'W16', 'A1', 'D28', 'L17', 'P13', 'T16', 'W20', 'A12', 'D3', 'L18', 'P14', 'T17', 'W22', 'A17', 'D33', 'L2', 'P15', 'T18', 'Y13', 'A2', 'D8', 'L22', 'P16', 'T19', 'Y15', 'A22', 'E15', 'L27', 'P17', 'T2', 'Y17', 'A27', 'E25', 'L7', 'P18', 'T20', 'Y19', 'A32', 'E5', 'M12', 'P19', 'T21', 'Y21', 'A7', 'F12', 'M14', 'P20', 'T22', 'Y23', 'AA12', 'F2', 'M15', 'P21', 'T23', 'AA14', 'F22', 'M16', 'P22', 'T27', 'AA16', 'F32', 'M17', 'P23', 'T32', 'AA18', 'G19', 'M18', 'P28', 'U12', 'AA20', 'G29', 'M19', 'P8', 'U13', 'AA22', 'G34', 'R10', 'U14']},{'label': 'uN', 'num': 14, 'pin_nums': ['AG29', 'AP33', 'AA27', 'AG34', 'AP8', 'AA7', 'AG9', 'U29', 'AB12', 'AH1', 'U34', 'AB14', 'AH16', 'V1', 'AB16', 'AH26', 'V12', 'AB18', 'AH6', 'V14', 'AB20', 'AJ13', 'V16', 'AB22', 'AJ23', 'V20', 'AB24', 'AJ3', 'V22', 'AB34', 'AJ33', 'V26', 'AB4', 'AK10', 'V6', 'AC1', 'AK20', 'W13', 'AC11', 'AK30', 'W15', 'AC17', 'AL17', 'W19', 'AC21', 'AL2', 'W21', 'AC26', 'AL27', 'W23', 'AC31', 'AL7', 'W3', 'AD12', 'AM14', 'W33', 'AD18', 'AM24', 'Y10', 'AD28', 'AM34', 'Y12', 'AD8', 'AM4', 'Y14', 'AE10', 'AN1', 'Y16', 'AE15', 'AN11', 'Y18', 'AE20', 'AN21', 'Y20', 'AE25', 'AN26', 'Y22', 'AE5', 'AN31', 'Y25', 'AA15', 'AF12', 'AP13', 'Y30', 'AA17', 'AF2', 'AP18', 'AA19', 'AF22', 'AP23', 'AA2', 'AA23', 'AF32', 'AP28', 'AA21', 'AG19', 'AP3']}] }),
        Part(**{ 'name':'XC5VLX50-FF324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX50-FF324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX50-FF324\n\nFPGA', 'pins':[
            Pin(num='A13',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='F16',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='A1',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A2',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B4',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='C5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='F6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='M18',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='N15',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P17',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L1N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L1P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='VCCO_18',func=pin_types.PWRIN,unit=3),
            Pin(num='K4',name='IO_L0N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='K5',name='IO_L0P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L3N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L3P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L4P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L2P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L5N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L6N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L6P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L2N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L5P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N10',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N11',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L7P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L7N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='VCCO_18',func=pin_types.PWRIN,unit=3),
            Pin(num='N5',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N6',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='IO_L13P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P10',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P12',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P3',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L15P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P7',name='IO_L13N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='P9',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R15',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L15N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='IO_L17P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R6',name='IO_L17N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='R8',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='R9',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T13',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T14',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T16',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T3',name='IO_L18N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L19P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='VCCO_18',func=pin_types.PWRIN,unit=3),
            Pin(num='T7',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T8',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='T9',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=3),
            Pin(num='U16',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L18P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='U4',name='IO_L19N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L14P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L16P_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L16N_18',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='A10',name='VCCO_3',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A12',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A7',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C10',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='C8',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='VCCO_3',func=pin_types.PWRIN,unit=4),
            Pin(num='D9',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='VCCO_4',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='R11',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='R12',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='T12',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U11',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U12',name='VCCO_4',func=pin_types.PWRIN,unit=4),
            Pin(num='U13',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U14',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U15',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=4),
            Pin(num='U9',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V11',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V12',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V13',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V15',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V6',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='N12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='N13',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P15',name='RDWR_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R16',name='CS_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R18',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='D_IN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T15',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='HSWAPEN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T6',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U18',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='AVDD_0',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='AVSS_0',func=pin_types.PWRIN,unit=6),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T18',name='VBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E12', 'F12', 'G18', 'F8', 'B18', 'D12', 'J14', 'D13', 'E14', 'F13', 'F9', 'A16', 'G8', 'J15', 'A17', 'B7', 'D14', 'E15', 'F14', 'G10', 'C12', 'G9', 'J16', 'C13', 'D15', 'E16', 'F15', 'G11', 'H13', 'J17', 'C14', 'D17', 'E17', 'F16', 'G13', 'H15', 'J18', 'A13', 'A18', 'C15', 'D18', 'E7', 'F17', 'G14', 'C16', 'H16', 'K17', 'B13', 'C17', 'D7', 'E8', 'F18', 'G15', 'H17', 'B14', 'C18', 'B16', 'D8', 'F11', 'F7', 'B15', 'G16', 'H18', 'C6', 'A14']},{'label': 'uB', 'num': 2, 'pin_nums': ['A3', 'C3', 'E2', 'H1', 'F5', 'J5', 'L18', 'N15', 'A4', 'E4', 'F6', 'H2', 'K14', 'M13', 'N16', 'C4', 'E1', 'B1', 'C5', 'E5', 'G1', 'G6', 'H3', 'J4', 'K15', 'M14', 'L17', 'N17', 'B3', 'N14', 'D2', 'E6', 'G2', 'H5', 'K16', 'M15', 'N18', 'B4', 'D3', 'F1', 'G3', 'H6', 'L13', 'M16', 'P17', 'B5', 'D4', 'F2', 'G4', 'J2', 'L14', 'M17', 'P18', 'A1', 'C1', 'D5', 'F3', 'G5', 'J3', 'L16', 'M18', 'R17', 'A2', 'C2', 'F4']},{'label': 'uC', 'num': 3, 'pin_nums': ['R6', 'M6', 'P5', 'T3', 'N6', 'U3', 'V9', 'K2', 'L6', 'N1', 'N7', 'P7', 'R8', 'T4', 'U4', 'K3', 'M1', 'N10', 'P10', 'P9', 'R9', 'T5', 'V1', 'K4', 'M10', 'N11', 'P12', 'R1', 'T1', 'T7', 'V16', 'K5', 'M11', 'N2', 'P13', 'R15', 'T13', 'T8', 'V17', 'L1', 'K1', 'M3', 'N3', 'P2', 'R2', 'T14', 'T9', 'V18', 'L2', 'M4', 'N4', 'P3', 'R4', 'T16', 'U1', 'V2', 'L3', 'M5', 'N5', 'P4', 'R5', 'T2', 'U16', 'V3', 'L4']},{'label': 'uD', 'num': 4, 'pin_nums': ['B10', 'C8', 'U13', 'R10', 'V13', 'A10', 'R11', 'U14', 'V15', 'D10', 'B11', 'A11', 'B6', 'D11', 'R12', 'U15', 'V6', 'A12', 'D9', 'B8', 'T11', 'U8', 'V7', 'C7', 'A6', 'B9', 'E10', 'T12', 'U12', 'U9', 'V12', 'V8', 'A7', 'C10', 'E11', 'U10', 'V10', 'A8', 'C11', 'E9', 'U11', 'V11', 'A9', 'P11']},{'label': 'uE', 'num': 5, 'pin_nums': ['N8', 'K9', 'T6', 'L10', 'U18', 'P15', 'L11', 'P8', 'U5', 'L9', 'R16', 'U6', 'V5', 'M8', 'R18', 'J10', 'M9', 'R7', 'N13', 'J9', 'N12', 'T15', 'T17', 'K10']},{'label': 'uF', 'num': 6, 'pin_nums': ['B12', 'E18', 'J12', 'K18', 'H12', 'L8', 'R13', 'V4', 'H14', 'J13', 'K6', 'M12', 'R3', 'E3', 'B17', 'E13', 'B2', 'F10', 'H4', 'J11', 'J6', 'K13', 'K7', 'M2', 'L7', 'T10', 'P6', 'G12', 'C9', 'H7', 'J7', 'K8', 'M7', 'T18', 'V14', 'D1', 'G17', 'H8', 'J8', 'L12', 'N9', 'U17', 'D16', 'G7', 'H9', 'K11', 'L15', 'P1', 'U2', 'A15', 'D6', 'H10', 'J1', 'K12', 'L5', 'P16', 'U7', 'A5', 'H11']}] }),
        Part(**{ 'name':'XC5VLX50-FF676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX50-FF676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX50-FF676\n\nFPGA', 'pins':[
            Pin(num='C10',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='F22',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC26',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F7',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G24',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='J24',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K25',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M23',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='M24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='N24',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N26',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V26',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA2',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C20',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='C21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E3',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='T2',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='W1',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='Y1',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A12',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A2',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A7',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA19',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA20',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA22',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA23',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA24',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB19',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB20',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB24',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC19',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B12',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C12',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C13',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D3',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='R20',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='R21',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T19',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T20',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T21',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='T22',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T23',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U19',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U20',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U21',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U22',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V19',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V21',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V22',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W20',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W21',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W22',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y20',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y21',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y23',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA3',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AA7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA8',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA9',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB14',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB15',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AB4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC3',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC6',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AD3',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD4',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AE3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T4',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T5',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T7',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U4',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U7',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V3',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V4',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W3',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y3',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB23',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AC20',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AD16',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD21',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD23',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE10',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE15',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE18',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE20',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AE25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE7',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF12',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF13',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF14',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF17',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF18',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF19',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF20',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF22',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF8',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D13',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D14',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D15',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E10',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E11',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E12',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E13',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E14',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E16',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E17',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E18',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F12',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F14',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F17',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F18',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F19',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F8',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AB12',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='VCCO_4',func=pin_types.PWRIN,unit=7),
            Pin(num='AC11',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC12',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC13',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC14',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC16',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC17',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC18',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD13',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD14',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD15',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD18',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD8',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='J10',name='CCLK_0',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='INIT_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='J18',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='DONE_0',func=pin_types.BIDIR,unit=8),
            Pin(num='K11',name='D_IN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='HSWAPEN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N13',name='VREFN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N14',name='VP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N18',name='CS_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P13',name='VN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P14',name='VREFP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P18',name='RDWR_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='R13',name='DXN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='R14',name='DXP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='U11',name='TCK_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V11',name='TDI_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V12',name='TMS_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V18',name='M2_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W10',name='TDO_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W11',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W12',name='VCCO_0',func=pin_types.PWRIN,unit=8),
            Pin(num='W18',name='M0_0',func=pin_types.BIDIR,unit=8),
            Pin(num='Y17',name='M1_0',func=pin_types.BIDIR,unit=8),
            Pin(num='Y9',name='VCCO_0',func=pin_types.PWRIN,unit=8),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='K18',name='VBATT_0',func=pin_types.PWRIN,unit=9),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M13',name='AVSS_0',func=pin_types.PWRIN,unit=9),
            Pin(num='M14',name='AVDD_0',func=pin_types.PWRIN,unit=9),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W16',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E20', 'G10', 'G20', 'H8', 'H16', 'K21', 'M20', 'P20', 'E22', 'G11', 'G21', 'H17', 'H9', 'P21', 'K22', 'M21', 'E21', 'E23', 'G12', 'G22', 'H18', 'J19', 'K23', 'M22', 'P23', 'G14', 'F11', 'G9', 'H19', 'J20', 'L19', 'N19', 'R22', 'C10', 'F13', 'G15', 'H11', 'H21', 'J21', 'L20', 'N21', 'R23', 'F15', 'G16', 'H12', 'H22', 'J22', 'F20', 'L22', 'N22', 'F21', 'G17', 'H13', 'H23', 'J23', 'H14', 'L23', 'N23', 'G19', 'F22', 'H25', 'K20', 'M19', 'P19', 'F23']},{'label': 'uB', 'num': 2, 'pin_nums': ['H7', 'J2', 'N6', 'J24', 'N7', 'J25', 'P24', 'J26', 'P25', 'J4', 'P26', 'AA25', 'J5', 'P3', 'AB25', 'J6', 'P4', 'AB26', 'K25', 'P5', 'AC26', 'K26', 'P6', 'E25', 'K5', 'R24', 'E26', 'K6', 'R25', 'E5', 'K7', 'R26', 'E6', 'L24', 'R3', 'E7', 'L25', 'R5', 'F24', 'L3', 'R6', 'F25', 'L4', 'R7', 'F4', 'L5', 'T24', 'F5', 'L6', 'T25', 'F7', 'L7', 'T3', 'G24', 'M23', 'U24', 'G25', 'M24', 'U25', 'G26', 'M25', 'U26', 'G4', 'M26', 'V26', 'G5', 'M4', 'W25', 'G6', 'M5', 'W26', 'G7', 'M6', 'Y25', 'H24', 'M7', 'Y26', 'H26', 'N20', 'H4', 'N24', 'H5', 'N26', 'N4', 'H6', 'N3']},{'label': 'uC', 'num': 3, 'pin_nums': ['A19', 'M1', 'C20', 'A20', 'M2', 'C21', 'A22', 'C22', 'N1', 'A23', 'N2', 'C23', 'A24', 'C24', 'P1', 'A25', 'R1', 'C26', 'AA2', 'D16', 'R2', 'AB1', 'D18', 'R4', 'AB2', 'D19', 'T2', 'AC1', 'D20', 'U1', 'AC2', 'D21', 'U2', 'AD1', 'D23', 'V1', 'AE1', 'D24', 'V2', 'AE2', 'D25', 'V5', 'AF2', 'D26', 'W1', 'B14', 'W2', 'E1', 'B15', 'E2', 'Y1', 'B16', 'E24', 'Y2', 'B17', 'E3', 'B19', 'F2', 'B20', 'F3', 'B21', 'G1', 'B22', 'G2', 'B23', 'H1', 'B24', 'H2', 'B25', 'H3', 'B26', 'J1', 'A18', 'C14', 'J3', 'A14', 'C16', 'K1', 'A15', 'C17', 'K2', 'A17', 'C18', 'K3', 'C19', 'L2']},{'label': 'uD', 'num': 4, 'pin_nums': ['C8', 'W20', 'AA24', 'C9', 'W21', 'AB19', 'D1', 'W22', 'AB20', 'D10', 'W23', 'AB21', 'D11', 'W24', 'AB22', 'D3', 'Y20', 'AB24', 'D4', 'Y21', 'AC19', 'D5', 'Y22', 'AC21', 'D6', 'Y23', 'AC22', 'D7', 'AC23', 'D8', 'AC24', 'D9', 'AD19', 'E4', 'B1', 'G8', 'B10', 'R20', 'B11', 'R21', 'B12', 'T19', 'B2', 'T20', 'B4', 'T21', 'A10', 'B5', 'T22', 'A12', 'B6', 'T23', 'A13', 'B7', 'U19', 'A2', 'B9', 'U20', 'A3', 'C1', 'U21', 'A4', 'C11', 'U22', 'A5', 'C12', 'V19', 'A7', 'C13', 'V21', 'A8', 'C2', 'V22', 'A9', 'C3', 'V23', 'AA19', 'C4', 'V24', 'AA20', 'AA23', 'C6', 'V25', 'AA22', 'C7', 'W19']},{'label': 'uE', 'num': 5, 'pin_nums': ['Y6', 'AB6', 'AD5', 'AA18', 'AB11', 'AF5', 'V3', 'Y10', 'Y7', 'AA17', 'AB7', 'AD6', 'T4', 'V4', 'AA10', 'AA3', 'AB14', 'Y11', 'AD4', 'Y8', 'AF4', 'AA12', 'AA4', 'AB15', 'AC3', 'AD7', 'T5', 'U7', 'V6', 'W6', 'Y12', 'AA9', 'AA5', 'AA13', 'AB16', 'AC4', 'AE3', 'T7', 'V7', 'Y13', 'AA14', 'AA6', 'AB17', 'AC6', 'AE5', 'U4', 'W3', 'Y18', 'AA15', 'AA7', 'AB3', 'AD17', 'AE6', 'U5', 'W4', 'Y3', 'AA16', 'AA8', 'AB4', 'AD3', 'AF3', 'U6', 'W5', 'Y5', 'AB5']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE13', 'AF13', 'AD23', 'AE23', 'AF23', 'D15', 'E16', 'F18', 'AD24', 'AE15', 'AE24', 'AF14', 'AF24', 'F19', 'D17', 'E17', 'E15', 'AE16', 'AD25', 'AE25', 'AF15', 'AF25', 'E10', 'E18', 'F8', 'AD26', 'AE17', 'AB23', 'AE26', 'AF17', 'AF7', 'E11', 'E8', 'F9', 'AC20', 'AD9', 'AE18', 'AE7', 'AF18', 'AF8', 'E12', 'F10', 'AD16', 'AE10', 'AE20', 'AE8', 'AF19', 'AF9', 'E13', 'F12', 'AD21', 'AD20', 'AE11', 'AE12', 'AE21', 'AE22', 'AF10', 'AF20', 'D13', 'AF12', 'E14', 'F14', 'AF22', 'D14', 'F17']},{'label': 'uG', 'num': 7, 'pin_nums': ['AB9', 'AC18', 'AD15', 'AC7', 'AC10', 'AD18', 'AC11', 'AC8', 'AD8', 'AC12', 'AC9', 'AC13', 'AD10', 'AB10', 'AC14', 'AD11', 'AB12', 'AC16', 'AD13', 'AB13', 'AC17', 'AD14']},{'label': 'uH', 'num': 8, 'pin_nums': ['R14', 'L18', 'W18', 'U11', 'N13', 'Y17', 'N14', 'V11', 'Y9', 'J10', 'N18', 'V12', 'J11', 'P13', 'V18', 'J18', 'P14', 'W10', 'K10', 'P18', 'W11', 'K11', 'R13', 'W12']},{'label': 'uI', 'num': 9, 'pin_nums': ['N15', 'W16', 'D22', 'A6', 'K4', 'N16', 'T15', 'W17', 'E19', 'AA1', 'K8', 'N17', 'T16', 'W7', 'AA11', 'E9', 'K9', 'N25', 'T17', 'W8', 'AA21', 'F1', 'L1', 'N5', 'T26', 'W9', 'AA26', 'F16', 'L10', 'N8', 'T6', 'Y14', 'AB18', 'F26', 'L11', 'N9', 'T8', 'Y15', 'AB8', 'F6', 'L12', 'P10', 'T9', 'Y16', 'AC15', 'G13', 'L13', 'P11', 'U10', 'Y19', 'AC25', 'G18', 'L14', 'P12', 'U12', 'Y24', 'AC5', 'G23', 'L15', 'P15', 'U13', 'Y4', 'AD12', 'G3', 'L16', 'P16', 'U14', 'AD2', 'H10', 'L17', 'P17', 'U15', 'AD22', 'H15', 'L21', 'P2', 'U16', 'AE14', 'H20', 'L26', 'P22', 'U17', 'AE19', 'J12', 'L8', 'P7', 'U18', 'AE4', 'J13', 'L9', 'P8', 'U23', 'AE9', 'J14', 'M10', 'P9', 'U3', 'AF1', 'J15', 'M11', 'R10', 'U8', 'AF11', 'J16', 'M12', 'R11', 'U9', 'AF16', 'J17', 'M13', 'R12', 'V10', 'AF21', 'J7', 'M14', 'R15', 'V13', 'AF26', 'J8', 'M15', 'R16', 'V14', 'AF6', 'J9', 'M16', 'R17', 'V15', 'B13', 'K12', 'M17', 'R19', 'V16', 'B18', 'K13', 'M18', 'R8', 'V17', 'B3', 'K14', 'M3', 'R9', 'D2', 'V20', 'B8', 'K15', 'M8', 'T1', 'V8', 'A1', 'C15', 'K16', 'M9', 'T10', 'V9', 'A11', 'C25', 'K17', 'N10', 'T11', 'W13', 'A16', 'C5', 'K18', 'N11', 'T12', 'T14', 'W14', 'A21', 'D12', 'K19', 'N12', 'T13', 'W15', 'A26', 'K24']}] }),
        Part(**{ 'name':'XC5VLX50T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX50T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX50T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=13),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=13),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=13),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=13),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=13),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=13),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=13),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=13),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=13),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=13),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=13),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=13),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=14),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=14),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=14),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=15),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=15),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=15),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=16)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L21', 'E34', 'J32', 'K23', 'H22', 'P32', 'T34', 'B32', 'F33', 'H23', 'J34', 'K32', 'L33', 'B33', 'P34', 'U31', 'F34', 'C32', 'H32', 'K12', 'K33', 'G14', 'L34', 'R30', 'U32', 'C33', 'G22', 'H33', 'K13', 'K34', 'M32', 'R32', 'U33', 'C34', 'G23', 'H34', 'K14', 'L14', 'M33', 'R33', 'V31', 'D13', 'G32', 'J12', 'K16', 'L15', 'D32', 'N32', 'R34', 'D34', 'G33', 'J15', 'K21', 'L16', 'N33', 'T27', 'E32', 'H12', 'J22', 'K22', 'L20', 'A33', 'E33', 'N34', 'T33']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB29', 'E7', 'R8', 'F5', 'AB32', 'R9', 'AB33', 'F6', 'T10', 'G5', 'AC32', 'T11', 'AC33', 'G6', 'T6', 'AC34', 'G7', 'T7', 'AD32', 'H5', 'T8', 'AD34', 'H7', 'T9', 'AE32', 'J5', 'U10', 'AE33', 'J6', 'U7', 'AE34', 'J7', 'V32', 'AF33', 'K6', 'V33', 'AF34', 'K7', 'V34', 'AG32', 'L4', 'W28', 'AG33', 'L5', 'W32', 'E6', 'AH32', 'L6', 'W34', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6', 'AK34', 'N7', 'N8', 'AL33', 'AL34', 'P10', 'AM32', 'P5', 'AM33', 'P6', 'AN32', 'P7', 'AN33', 'P9', 'AA32', 'AN34', 'R11', 'AA33', 'R6', 'AP32', 'AA34', 'R7']},{'label': 'uC', 'num': 3, 'pin_nums': ['AE30', 'W26', 'AE31', 'W27', 'M31', 'AF29', 'N29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'P33', 'Y28', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'K29', 'V25', 'AC30', 'K31', 'V27', 'AD29', 'L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'AD33', 'L32', 'M30', 'W24', 'AE29', 'M29', 'W25']},{'label': 'uD', 'num': 4, 'pin_nums': ['L25', 'L26', 'AH7', 'L28', 'AJ6', 'AJ7', 'M25', 'M26', 'AK6', 'AK7', 'M27', 'M28', 'E26', 'E27', 'N24', 'E28', 'N25', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'T24', 'G28', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'J24', 'W10', 'AD6', 'J25', 'W11', 'AD7', 'W6', 'J26', 'AE6', 'J27', 'W7', 'AE7', 'J28', 'W8', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AG7', 'L24', 'Y8', 'AH5', 'Y9']},{'label': 'uE', 'num': 5, 'pin_nums': ['F8', 'AF16', 'E11', 'AE17', 'B12', 'H11', 'K8', 'N10', 'A13', 'AE19', 'AF20', 'B13', 'E12', 'F9', 'H8', 'K9', 'N9', 'AD19', 'AE21', 'AF21', 'C12', 'E13', 'G10', 'H9', 'L10', 'AD20', 'AE22', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'D11', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AE16', 'AF15', 'AM19', 'E10', 'F13', 'H10', 'K11', 'M8']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE26', 'AE27', 'AJ28', 'AE28', 'AJ29', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AH28', 'AD25', 'AH8', 'AH9', 'AD26', 'AD27', 'AJ10', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AJ27', 'AE24', 'AJ26']},{'label': 'uG', 'num': 7, 'pin_nums': ['AK25', 'AN26', 'F27', 'C26', 'AL22', 'G24']},{'label': 'uH', 'num': 8, 'pin_nums': ['G15', 'AE18', 'AG18', 'AH17', 'K18', 'AF18', 'AG20', 'AH18', 'G16', 'J14', 'K19', 'AF19', 'AG21', 'AH19', 'H13', 'J16', 'L18', 'AG13', 'AG22', 'AH20', 'H14', 'J17', 'L19', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20', 'AG16', 'AH14', 'D23', 'H18', 'H20', 'J21', 'AG17', 'AH15', 'E20', 'H19', 'K17']},{'label': 'uI', 'num': 9, 'pin_nums': ['AK15', 'B19', 'F17', 'C16', 'AJ18', 'AN16']},{'label': 'uJ', 'num': 10, 'pin_nums': ['V2', 'N2', 'W1', 'P1', 'U2', 'AA1', 'P3', 'W2', 'Y1', 'AB1', 'P4', 'AB2', 'R1', 'Y3', 'T1', 'Y4', 'AC2', 'M2', 'T2', 'N1']},{'label': 'uK', 'num': 11, 'pin_nums': ['AE1', 'K1', 'AJ2', 'F2', 'AE2', 'K2', 'AF1', 'G1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4', 'AD2', 'AH2', 'J1']},{'label': 'uL', 'num': 12, 'pin_nums': ['AL4', 'B4', 'C1', 'AL5', 'AM1', 'D1', 'A2', 'D2', 'AN3', 'A3', 'AN4', 'D4', 'AK2', 'AP2', 'E2', 'AL1', 'AP3', 'E4', 'AL2', 'B3']},{'label': 'uM', 'num': 13, 'pin_nums': ['C3', 'T3', 'AA4', 'AJ3', 'C4', 'J4', 'U3', 'D3', 'K3', 'V3', 'AB3', 'AJ4', 'AC3', 'AK3', 'D5', 'L3', 'V4', 'AD3', 'AH3', 'AK5', 'E3', 'M3', 'V5', 'AE3', 'AL3', 'F3', 'N3', 'W3', 'AM3', 'AG3', 'F4', 'R3', 'AG4', 'AM4', 'G3', 'R4', 'AA3', 'J3']},{'label': 'uN', 'num': 14, 'pin_nums': ['AC14', 'U17', 'AC15', 'M22', 'U18', 'AC22', 'M23', 'V17', 'AD14', 'N14', 'V18', 'AD15', 'N15', 'W17', 'AD21', 'N22', 'W18', 'AA22', 'AD22', 'M15', 'N23', 'AB15', 'AD23', 'P15']},{'label': 'uO', 'num': 15, 'pin_nums': ['T5', 'AC18', 'M18', 'G4', 'P28', 'U12', 'AC20', 'M19', 'G9', 'P8', 'U14', 'M17', 'AD13', 'H16', 'M20', 'R10', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'R15', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'R17', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'C21', 'A12', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'AC16', 'T20', 'AB17', 'F32', 'M12', 'P2', 'T21', 'AB19', 'F7', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'G29', 'M16', 'P22', 'T4', 'G34', 'P23']},{'label': 'uP', 'num': 16, 'pin_nums': ['AA27', 'AF22', 'W23', 'AN21', 'AF27', 'AA7', 'W33', 'AN31', 'AB12', 'AF32', 'AN7', 'W4', 'AG19', 'AB14', 'W5', 'AN8', 'AG2', 'AB16', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14', 'AB22', 'AG34', 'Y16', 'AP23', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AF2', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AE15', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'AE25', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AA19', 'AE5', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'AN11', 'W19', 'AA23', 'AN2', 'W21']}] }),
        Part(**{ 'name':'XC5VLX50T-FF665', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX50T-FF665'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX50T-FF665\n\nFPGA', 'pins':[
            Pin(num='B13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G24',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J25',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='M24',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA23',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA24',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P23',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='P8',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V22',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V23',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V25',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='V26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W23',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y23',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='IO_L13N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='IO_L15N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L14P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A9',name='IO_L4P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='IO_L13P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B11',name='IO_L15P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='IO_L17P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L16P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='IO_L16N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B9',name='IO_L6P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C10',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C11',name='IO_L19P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='IO_L17N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C8',name='IO_L6N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D10',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='IO_L19N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L18P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='IO_L7N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E5',name='IO_L18N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L7P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L5N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='IO_L5P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='F7',name='IO_L1P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F8',name='IO_L1N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F9',name='IO_L2P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L0N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G9',name='IO_L2N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L0P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L3P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='IO_L3N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AA7',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA8',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB23',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AB5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC20',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC26',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC7',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD13',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD14',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD15',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD16',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD18',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD20',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD24',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD26',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE13',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE15',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE16',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE17',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE18',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE20',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE21',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE22',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE24',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE26',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF13',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF14',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF15',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF17',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF18',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF19',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF20',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF22',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF24',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF25',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='D18',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='G21',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W16',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y15',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y16',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y17',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y20',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA20',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB11',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB14',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB15',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC11',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='L1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=7),
            Pin(num='U1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='W2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AC1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AE2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='B2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=8),
            Pin(num='E1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='G2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='Y2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AD3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AE3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='C3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='F3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='H3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='J3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=9),
            Pin(num='N3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='P4',name='MGTRREF_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=9),
            Pin(num='R3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='V3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=9),
            Pin(num='W3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='Y3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='F11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='H12',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J10',name='D_IN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J12',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='J20',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='HSWAPEN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='CS_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M20',name='RDWR_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N14',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N15',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P14',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P15',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R14',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R15',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T20',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U12',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U20',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V12',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V13',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W20',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='VBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='AVSS_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='AVDD_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W10',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y9',name='GND',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['H11', 'J26', 'H25', 'N21', 'F17', 'G16', 'B13', 'F18', 'H13', 'H26', 'K21', 'G17', 'L25', 'N22', 'F22', 'G19', 'H18', 'H9', 'K22', 'M21', 'N23', 'F23', 'E14', 'G20', 'H19', 'J21', 'F24', 'K23', 'M22', 'N24', 'E22', 'E23', 'F25', 'G22', 'H21', 'J22', 'K25', 'M23', 'N26', 'E25', 'G10', 'G24', 'H22', 'J23', 'K26', 'M24', 'E26', 'G11', 'F15', 'G25', 'H23', 'J24', 'L22', 'F13', 'G12', 'L24', 'M25', 'F14', 'G14', 'G26', 'H24', 'J25', 'L23', 'M26', 'G15']},{'label': 'uB', 'num': 2, 'pin_nums': ['K8', 'Y4', 'T5', 'L5', 'Y5', 'T7', 'L6', 'T8', 'Y6', 'L7', 'U21', 'L8', 'U22', 'M6', 'U24', 'M7', 'U25', 'N6', 'U26', 'N7', 'U5', 'N8', 'U6', 'P21', 'U7', 'P23', 'V21', 'P24', 'V22', 'AA22', 'P25', 'V23', 'AA23', 'P26', 'V24', 'AA24', 'P6', 'V25', 'AA25', 'P7', 'V26', 'AB24', 'P8', 'V6', 'AB25', 'R21', 'V7', 'AB26', 'R22', 'W21', 'F5', 'R23', 'W22', 'G4', 'R24', 'W23', 'G5', 'R25', 'W24', 'K7', 'R26', 'G6', 'W25', 'H4', 'R5', 'W26', 'H5', 'R6', 'W4', 'H6', 'R7', 'W5', 'J5', 'R8', 'W6', 'J6', 'T22', 'Y22', 'K5', 'T23', 'Y23', 'K6', 'T24', 'Y25', 'T25', 'Y26']},{'label': 'uC', 'num': 3, 'pin_nums': ['D20', 'B22', 'D21', 'B23', 'D23', 'B24', 'D24', 'A10', 'B25', 'D25', 'A12', 'B26', 'D26', 'A13', 'B4', 'D5', 'A14', 'B5', 'D6', 'A15', 'B6', 'D7', 'A17', 'B7', 'D8', 'A18', 'B9', 'D9', 'A19', 'C10', 'E24', 'A20', 'C11', 'E5', 'A22', 'C12', 'E6', 'A23', 'C13', 'E7', 'A24', 'C14', 'E8', 'A25', 'C16', 'F21', 'A3', 'C17', 'F7', 'A4', 'C18', 'F8', 'A5', 'C19', 'F9', 'A7', 'C21', 'G7', 'A8', 'C22', 'G8', 'A9', 'C23', 'G9', 'B10', 'C24', 'H7', 'B11', 'C26', 'H8', 'B12', 'C6', 'J8', 'B14', 'C7', 'B15', 'C8', 'B16', 'C9', 'B17', 'D10', 'B19', 'B21', 'D11', 'B20', 'D19']},{'label': 'uD', 'num': 4, 'pin_nums': ['AD6', 'AB23', 'AF22', 'AD7', 'AB5', 'AF23', 'AB6', 'AD8', 'AF24', 'AD9', 'AB7', 'AF25', 'AB9', 'AE10', 'AF3', 'AE11', 'AC10', 'AF4', 'AC20', 'AE12', 'AF5', 'AC21', 'AE13', 'AF7', 'AC22', 'AE15', 'AF8', 'AC23', 'AE16', 'AF9', 'AC24', 'AE17', 'V8', 'AC26', 'AE18', 'V9', 'AD5', 'AC6', 'AE20', 'W8', 'AC7', 'AE21', 'W9', 'AC8', 'AE22', 'Y7', 'AC9', 'AE23', 'Y8', 'AD10', 'AE24', 'AD11', 'AE25', 'AD13', 'AE26', 'AD14', 'AE5', 'AD15', 'AE6', 'AD16', 'AE7', 'AD18', 'AE8', 'AD19', 'AF10', 'AD20', 'AF12', 'AD21', 'AF13', 'AA5', 'AD23', 'AF14', 'AA6', 'AF15', 'AD24', 'AA7', 'AD25', 'AF17', 'AA8', 'AD26', 'AF18', 'AA9', 'AD4', 'AF19', 'AB22', 'AF20']},{'label': 'uE', 'num': 5, 'pin_nums': ['D18', 'G21', 'AA18', 'E18', 'Y15', 'AA10', 'AA19', 'E10', 'E20', 'W11', 'Y16', 'AA12', 'AD17', 'E11', 'E21', 'W14', 'Y17', 'AA13', 'D13', 'E12', 'F10', 'W16', 'Y18', 'AA14', 'D14', 'E13', 'F12', 'Y10', 'Y20', 'AA15', 'D15', 'E15', 'F19', 'Y11', 'AA16', 'D16', 'E16', 'F20', 'Y12', 'AA17', 'D17', 'E17', 'G18', 'Y13']},{'label': 'uF', 'num': 6, 'pin_nums': ['AB20', 'AC18', 'AB12', 'AC19', 'AB21', 'AB13', 'AC11', 'AE14', 'AB14', 'AC12', 'Y21', 'AB15', 'AC13', 'AB16', 'AC14', 'AA20', 'AB17', 'AC16', 'AB10', 'AB19', 'AC17', 'AB11']},{'label': 'uG', 'num': 7, 'pin_nums': ['R2', 'K3', 'K4', 'T1', 'L1', 'T3', 'M1', 'T4', 'H2', 'M2', 'U1', 'J1', 'N2', 'V1', 'J2', 'P2', 'V2', 'K1', 'R1', 'W2']},{'label': 'uH', 'num': 8, 'pin_nums': ['AA1', 'F1', 'AE2', 'AA2', 'B2', 'F2', 'G2', 'AB1', 'C1', 'AB3', 'C2', 'Y2', 'AB4', 'D1', 'AC1', 'D3', 'E1', 'AD1', 'D4', 'AD2']},{'label': 'uI', 'num': 9, 'pin_nums': ['H3', 'P5', 'J3', 'AE3', 'R3', 'B3', 'L3', 'U3', 'C3', 'L4', 'U4', 'E3', 'M3', 'V3', 'AA3', 'E4', 'N3', 'W3', 'AC3', 'F3', 'P3', 'Y3', 'AC4', 'G3', 'P4', 'AD3']},{'label': 'uJ', 'num': 10, 'pin_nums': ['H12', 'U12', 'M20', 'J10', 'N14', 'U20', 'J11', 'N15', 'V11', 'J12', 'P14', 'V12', 'J20', 'P15', 'V13', 'K11', 'R14', 'W13', 'K20', 'R15', 'W20', 'F11', 'L20', 'T20']},{'label': 'uK', 'num': 11, 'pin_nums': ['W19', 'AD12', 'H15', 'P10', 'L17', 'T26', 'W7', 'H16', 'AD22', 'P11', 'L18', 'T6', 'Y14', 'AE19', 'H17', 'L19', 'P12', 'T9', 'Y19', 'AE4', 'H20', 'L2', 'P13', 'U10', 'Y24', 'AE9', 'J13', 'L21', 'P16', 'U11', 'Y9', 'AF11', 'J14', 'L26', 'P17', 'U13', 'N9', 'AF16', 'J15', 'L9', 'P18', 'U14', 'AF2', 'J16', 'M10', 'P19', 'U15', 'AF21', 'J17', 'M11', 'P22', 'U16', 'AF26', 'J18', 'M12', 'P9', 'U17', 'AF6', 'J19', 'M13', 'R10', 'U18', 'B18', 'J4', 'M14', 'R11', 'U19', 'B8', 'J7', 'M15', 'R12', 'U2', 'C15', 'K10', 'M16', 'R13', 'U23', 'C20', 'K12', 'M17', 'R16', 'U8', 'A11', 'C25', 'K13', 'M18', 'R17', 'U9', 'A16', 'C4', 'K14', 'M19', 'R18', 'V10', 'A2', 'C5', 'K15', 'M4', 'R19', 'V14', 'A21', 'D12', 'K16', 'M8', 'R4', 'V15', 'A26', 'D2', 'K17', 'M9', 'R9', 'V16', 'A6', 'D22', 'K18', 'N10', 'T10', 'V17', 'AA11', 'E19', 'K19', 'N11', 'T11', 'V18', 'AA21', 'E2', 'K2', 'N12', 'T12', 'V19', 'AA26', 'K24', 'E9', 'N13', 'T13', 'V20', 'AA4', 'F16', 'K9', 'N16', 'T14', 'V4', 'AB18', 'F26', 'L10', 'N17', 'T15', 'V5', 'AB2', 'F4', 'L11', 'N18', 'T16', 'W10', 'AB8', 'F6', 'L12', 'N19', 'T17', 'W12', 'AC15', 'G13', 'L13', 'N20', 'T18', 'W15', 'AC2', 'G23', 'L14', 'N25', 'T19', 'W17', 'L16', 'AC25', 'H10', 'L15', 'N5', 'T2', 'W18', 'AC5', 'H14', 'T21']}] }),
        Part(**{ 'name':'XC5VLX85-FF1153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX85-FF1153'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX85-FF1153\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P33',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V32',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB9',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AC2',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AD1',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF1',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF3',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG2',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG3',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH2',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH3',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ1',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ2',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK3',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL1',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL3',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM2',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM3',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN3',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP2',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H31',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='H5',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='K5',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='L6',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='N6',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='P4',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R11',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R4',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T10',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='T9',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U11',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U7',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA4',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC5',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AD4',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE4',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG4',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AG5',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AG6',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH4',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AH5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ4',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ5',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AK4',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='B29',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='F27',name='VCCO_19',func=pin_types.PWRIN,unit=5),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=5),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=5),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=5),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V8',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W10',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W7',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y9',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC15',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AC20',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD15',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD19',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE19',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AG23',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=6),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='AL22',name='VCCO_2',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E7',name='IO_L5P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L5N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='E9',name='IO_L3N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L3P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F6',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F7',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='F8',name='IO_L7N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L7P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='IO_L1N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G4',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='IO_L14P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='G8',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='IO_L1P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H7',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H8',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L2P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L0N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J7',name='IO_L13N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='IO_L2N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='IO_L0P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L13P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K8',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='K9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L11',name='IO_L4P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='IO_L6N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M11',name='IO_L6P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M7',name='IO_L15N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='M8',name='IO_L15P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='IO_L17N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='IO_L16N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N8',name='IO_L18N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='IO_L17P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P10',name='IO_L19N_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P11',name='IO_L19P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P7',name='IO_L16P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='P9',name='IO_L18P_20',func=pin_types.BIDIR,unit=6),
            Pin(num='AA10',name='IO_L0P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA11',name='IO_L0N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AA8',name='IO_L1P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AA9',name='IO_L1N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB10',name='IO_L2N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB11',name='IO_L2P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='IO_L3N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AB8',name='IO_L3P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L4P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L19P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AD7',name='IO_L6N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AD9',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE11',name='IO_L19N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AE7',name='IO_L6P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE8',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AE9',name='IO_L13P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF10',name='IO_L15P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF11',name='IO_L17N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AF8',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AF9',name='IO_L13N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG10',name='IO_L15N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG11',name='IO_L17P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AG7',name='IO_L7P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AG8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH10',name='IO_L18N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AH7',name='IO_L7N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH8',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AH9',name='IO_L14P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ10',name='IO_L18P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ6',name='IO_L5N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ7',name='IO_L5P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AJ9',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=7),
            Pin(num='AK5',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='AK6',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK7',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK8',name='IO_L16N_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AK9',name='IO_L16P_22',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=7),
            Pin(num='AN6',name='VCCO_22',func=pin_types.PWRIN,unit=7),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=7),
            Pin(num='B9',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='VCCO_24',func=pin_types.PWRIN,unit=8),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=8),
            Pin(num='AF27',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AG24',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AH11',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=9),
            Pin(num='AL12',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AM9',name='VCCO_26',func=pin_types.PWRIN,unit=9),
            Pin(num='AE18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF17',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AF18',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF19',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF20',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AF21',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG13',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG20',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH12',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH19',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AH20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=10),
            Pin(num='AK15',name='VCCO_4',func=pin_types.PWRIN,unit=10),
            Pin(num='AK19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=10),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='F20',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G20',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G21',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='G22',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H12',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H13',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H14',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H15',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H18',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H19',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H20',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H21',name='VCCO_3',func=pin_types.PWRIN,unit=10),
            Pin(num='H22',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='H23',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J14',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J15',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J16',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J17',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J20',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='J21',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AM19',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=11),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=11),
            Pin(num='AA13',name='TCK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AB13',name='TMS_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC13',name='TDI_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC14',name='TDO_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD13',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='AD14',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=12),
            Pin(num='AG14',name='VCCO_0',func=pin_types.PWRIN,unit=12),
            Pin(num='L13',name='INIT_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M13',name='CCLK_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='M23',name='CS_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N13',name='D_IN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N14',name='DONE_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N22',name='HSWAPEN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=12),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=12),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='AD23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N1',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='P22',name='VBATT_0',func=pin_types.PWRIN,unit=13),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=13),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='T27',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=13),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=13),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=13),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AL7',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='AP8',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=14),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=14)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['F33', 'L33', 'B33', 'P33', 'F34', 'J22', 'K18', 'L14', 'L34', 'P34', 'U31', 'U32', 'C32', 'G14', 'L15', 'M32', 'J32', 'K19', 'C33', 'R30', 'U33', 'G32', 'J34', 'K21', 'L16', 'M33', 'C34', 'G33', 'R32', 'V31', 'B32', 'H32', 'D13', 'A33', 'K12', 'K22', 'L19', 'N32', 'R33', 'D32', 'H33', 'K13', 'K23', 'L20', 'N33', 'R34', 'D34', 'E32', 'H34', 'K14', 'K32', 'L21', 'N34', 'T33', 'E33', 'K17', 'J12', 'K16', 'K33', 'L23', 'P32', 'T34', 'E34', 'J19', 'K34']},{'label': 'uB', 'num': 2, 'pin_nums': ['B2', 'R3', 'AB32', 'B3', 'T1', 'AB33', 'C2', 'T3', 'AC32', 'C3', 'T7', 'AC33', 'D1', 'U1', 'AC34', 'D2', 'U2', 'AD32', 'E1', 'U3', 'AD34', 'E2', 'U4', 'AE32', 'E3', 'V32', 'AE33', 'F1', 'V33', 'AE34', 'F3', 'V34', 'AF33', 'G1', 'W28', 'AF34', 'G2', 'W32', 'AG32', 'G3', 'W34', 'AG33', 'H2', 'W8', 'AH32', 'H3', 'Y32', 'AH33', 'J1', 'Y33', 'AH34', 'J2', 'Y34', 'AJ32', 'K1', 'AJ34', 'K2', 'AK32', 'K3', 'AK33', 'L1', 'AK34', 'L3', 'AL33', 'M1', 'AL34', 'M2', 'AM32', 'M3', 'AM33', 'N2', 'AN32', 'N3', 'A3', 'P1', 'AN33', 'AA32', 'AN34', 'P2', 'AA33', 'AB29', 'AP32', 'R1', 'AA34', 'B1', 'R2']},{'label': 'uC', 'num': 3, 'pin_nums': ['V2', 'AF1', 'J31', 'V3', 'AF3', 'K29', 'V4', 'AG1', 'K31', 'W1', 'AG2', 'L29', 'W2', 'AG3', 'L30', 'Y1', 'AH2', 'L31', 'Y2', 'AH3', 'L32', 'Y3', 'AJ1', 'M29', 'Y5', 'AJ2', 'M30', 'AK1', 'M31', 'AK2', 'N29', 'AK3', 'N30', 'AL1', 'P29', 'AL3', 'P30', 'AM1', 'P31', 'AM2', 'R26', 'AM3', 'R27', 'AN2', 'R28', 'AA1', 'AN3', 'R29', 'AA3', 'AP2', 'R31', 'AB1', 'E29', 'T25', 'AB2', 'E31', 'T26', 'AB3', 'F29', 'T28', 'AB9', 'F30', 'T29', 'AC2', 'F31', 'T30', 'AC3', 'G30', 'T31', 'G31', 'AC6', 'U25', 'J30', 'AD1', 'H29', 'U26', 'AD2', 'H30', 'U27', 'AE1', 'H31', 'U28', 'AE2', 'J29', 'U30', 'AE3']},{'label': 'uD', 'num': 4, 'pin_nums': ['AJ31', 'T10', 'T11', 'AK31', 'E4', 'T4', 'T5', 'F4', 'F5', 'T6', 'G5', 'T8', 'T9', 'H4', 'U10', 'H5', 'U11', 'J4', 'AA29', 'J5', 'U5', 'AA30', 'J6', 'U6', 'AA31', 'K4', 'U7', 'AB30', 'K5', 'U8', 'AB31', 'K6', 'V24', 'AC29', 'L4', 'V25', 'AC30', 'L5', 'V27', 'AD29', 'L6', 'V28', 'AD30', 'M5', 'V29', 'AD31', 'M6', 'V30', 'AD33', 'N4', 'W24', 'AE29', 'N5', 'W25', 'AE30', 'N6', 'W26', 'AE31', 'P3', 'W27', 'AF29', 'P4', 'W29', 'AF30', 'P5', 'W30', 'AF31', 'P6', 'W31', 'AG30', 'R11', 'Y26', 'AG31', 'R4', 'Y27', 'AH29', 'R6', 'Y28', 'AH30', 'R7', 'Y29', 'AH31', 'R8', 'Y31', 'AJ30', 'R9']},{'label': 'uE', 'num': 5, 'pin_nums': ['F27', 'F28', 'AA5', 'P27', 'AA6', 'G25', 'R24', 'AB5', 'G26', 'T24', 'AB6', 'G27', 'V10', 'AC4', 'G28', 'V5', 'AC5', 'H24', 'V7', 'AD3', 'H25', 'V8', 'AD4', 'H27', 'V9', 'AD5', 'H28', 'W10', 'AD6', 'J24', 'W11', 'AE4', 'J25', 'W4', 'AE6', 'J26', 'W5', 'AF4', 'J27', 'W6', 'AF5', 'K24', 'W7', 'AF6', 'K26', 'W9', 'AF7', 'K27', 'Y11', 'AG4', 'K28', 'Y4', 'AG5', 'L24', 'Y6', 'AG6', 'L25', 'Y7', 'AH4', 'L26', 'Y8', 'AH5', 'L28', 'Y9', 'AJ4', 'M25', 'AJ5', 'M26', 'AK4', 'M27', 'B29', 'M28', 'E26', 'N24', 'E27', 'N25', 'E28', 'N27', 'E30', 'N28', 'F25', 'P24', 'P26', 'F26', 'P25', 'AA4']},{'label': 'uF', 'num': 6, 'pin_nums': ['L10', 'N10', 'AE14', 'AF16', 'AC20', 'AE16', 'AF23', 'F10', 'G6', 'G7', 'J11', 'J7', 'L11', 'N7', 'AE17', 'AG23', 'F6', 'G8', 'AD15', 'J8', 'L8', 'N8', 'AD16', 'AE19', 'AH21', 'F7', 'H10', 'J9', 'L9', 'N9', 'AE21', 'AD19', 'AL22', 'F8', 'H7', 'K11', 'M10', 'P10', 'AD20', 'AE22', 'E6', 'F9', 'H8', 'K7', 'M11', 'P11', 'AE12', 'AE23', 'E7', 'G10', 'H9', 'K8', 'M7', 'P7', 'AC15', 'AE13', 'AF15', 'E8', 'G4', 'J10', 'K9', 'M8', 'P9', 'AC19', 'E9']},{'label': 'uG', 'num': 7, 'pin_nums': ['AB10', 'AF10', 'AJ9', 'AB11', 'AK26', 'AF11', 'AB25', 'AF24', 'AK27', 'AB26', 'AK28', 'AF25', 'AB27', 'AF26', 'AK29', 'AB28', 'AF28', 'AK5', 'AB7', 'AF8', 'AK6', 'AB8', 'AK7', 'AF9', 'AC10', 'AG10', 'AK8', 'AC24', 'AG11', 'AK9', 'AC25', 'AG25', 'AL32', 'AC27', 'AG26', 'AM29', 'AC28', 'AG27', 'AN6', 'AC7', 'AG28', 'Y24', 'AC8', 'AG7', 'AC9', 'AG8', 'AD10', 'AH10', 'AD11', 'AH25', 'AD24', 'AH27', 'AD25', 'AH28', 'AD26', 'AH7', 'AD27', 'AH8', 'AD7', 'AH9', 'AD9', 'AJ10', 'AA10', 'AE11', 'AJ25', 'AA11', 'AE24', 'AJ26', 'AA24', 'AE26', 'AJ27', 'AA25', 'AE27', 'AJ28', 'AA26', 'AE28', 'AJ29', 'AA28', 'AE7', 'AJ6', 'AA8', 'AE8', 'AJ7', 'AA9', 'AE9', 'AJ8']},{'label': 'uH', 'num': 8, 'pin_nums': ['D23', 'G24', 'C26', 'C6', 'E10', 'B9']},{'label': 'uI', 'num': 9, 'pin_nums': ['AM9', 'AG24', 'AK25', 'AH11', 'AL12', 'AF27']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AK19', 'H23', 'AF19', 'AG20', 'H13', 'J14', 'AG21', 'E20', 'AF20', 'H14', 'AG22', 'AF21', 'F20', 'H15', 'AE18', 'J15', 'AH12', 'AG12', 'G13', 'H18', 'J16', 'AF13', 'AH19', 'AG13', 'G20', 'H19', 'J17', 'AG17', 'AF14', 'AG15', 'AH20', 'G21', 'H12', 'H20', 'H22', 'J20', 'AF17', 'AG16', 'AJ19', 'G22', 'H21', 'J21', 'AF18', 'AK15']},{'label': 'uK', 'num': 11, 'pin_nums': ['AJ18', 'AN16', 'C16', 'AM19', 'B19', 'F17']},{'label': 'uL', 'num': 12, 'pin_nums': ['AC13', 'L13', 'U17', 'AC14', 'M13', 'U18', 'AC22', 'M22', 'V17', 'AD13', 'M23', 'V18', 'AD14', 'N13', 'W17', 'AB13', 'AD21', 'N14', 'AG14', 'W18', 'AA13', 'AD22', 'N22', 'N23']},{'label': 'uM', 'num': 13, 'pin_nums': ['B34', 'N18', 'R23', 'V15', 'B4', 'K10', 'N19', 'V19', 'R25', 'C1', 'K15', 'N20', 'R5', 'V21', 'C11', 'K20', 'N21', 'V23', 'T12', 'C21', 'K25', 'N26', 'T13', 'W12', 'C31', 'K30', 'N31', 'T14', 'W14', 'D18', 'L12', 'P12', 'T15', 'W16', 'A1', 'D28', 'L17', 'P13', 'W20', 'T16', 'A12', 'D3', 'L18', 'P14', 'T17', 'W22', 'A17', 'D33', 'L2', 'P15', 'T18', 'Y13', 'A2', 'D8', 'L22', 'P16', 'T19', 'Y15', 'A22', 'E15', 'L27', 'P17', 'T2', 'Y17', 'A27', 'E25', 'L7', 'P18', 'T20', 'Y19', 'A32', 'E5', 'M12', 'P19', 'T21', 'Y21', 'A7', 'F12', 'M14', 'P20', 'T22', 'Y23', 'AA12', 'F2', 'M15', 'P21', 'T23', 'AA14', 'F22', 'M16', 'P22', 'T27', 'AA16', 'F32', 'M17', 'P23', 'T32', 'AA18', 'G19', 'M18', 'P28', 'U12', 'AA20', 'G29', 'M19', 'P8', 'U13', 'AA22', 'G34', 'M20', 'R10', 'U14', 'AB15', 'G9', 'M21', 'R12', 'U15', 'AB17', 'H1', 'M24', 'R13', 'U16', 'AB19', 'H11', 'M34', 'R14', 'U19', 'AB21', 'H16', 'M4', 'R15', 'U20', 'AC12', 'H26', 'M9', 'R16', 'U21', 'AC16', 'H6', 'N1', 'R17', 'U22', 'AC18', 'J13', 'N11', 'R18', 'U23', 'AD17', 'J18', 'N12', 'R19', 'U24', 'AD23', 'J23', 'N15', 'R20', 'U9', 'B14', 'J28', 'J33', 'N16', 'R21', 'V11', 'B24', 'J3', 'N17', 'R22', 'V13']},{'label': 'uN', 'num': 14, 'pin_nums': ['AK10', 'AK20', 'AC1', 'W13', 'AC11', 'AK30', 'W15', 'AC17', 'AL17', 'W19', 'AC21', 'AL2', 'W21', 'AC26', 'AL27', 'W23', 'AC31', 'AL7', 'W3', 'AD12', 'AM14', 'W33', 'AD18', 'AM24', 'Y10', 'AD28', 'AM34', 'Y12', 'AD8', 'AM4', 'Y14', 'AE10', 'AN1', 'Y16', 'AE15', 'AN11', 'Y18', 'AE20', 'AN21', 'Y20', 'AE25', 'AN26', 'Y22', 'AE5', 'AN31', 'Y25', 'AA15', 'AF12', 'AP13', 'Y30', 'AA17', 'AF2', 'AP18', 'AA19', 'AF22', 'AP23', 'AA2', 'AF32', 'AP28', 'AA21', 'AG19', 'AP3', 'AA23', 'AG29', 'AP33', 'AA27', 'AG34', 'AP8', 'AA7', 'AG9', 'U29', 'AB12', 'AH1', 'U34', 'AB14', 'AH16', 'V1', 'AB16', 'AH26', 'V12', 'AB18', 'AH6', 'V14', 'AB20', 'AJ13', 'V16', 'AB22', 'AJ23', 'V20', 'AB24', 'AJ3', 'V22', 'V6', 'AB34', 'AJ33', 'V26', 'AB4']}] }),
        Part(**{ 'name':'XC5VLX85-FF676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX85-FF676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX85-FF676\n\nFPGA', 'pins':[
            Pin(num='C10',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='F22',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC26',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F7',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G24',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='J24',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K25',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M23',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='M24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='N24',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N26',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V26',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA2',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC2',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C20',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='C21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E3',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='T2',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='W1',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='Y1',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='IO_L6N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A12',name='IO_L3N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L3P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A2',name='IO_L17P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L17N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A7',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='IO_L7N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='IO_L7P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='AA19',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA20',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA22',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA23',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA24',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB19',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB20',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB24',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC19',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L19P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='IO_L5N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='IO_L6P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B12',name='IO_L2N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L15N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L13P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='IO_L13N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='IO_L5P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L18N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='IO_L1P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C12',name='IO_L1N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C13',name='IO_L2P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L16P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L16N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L15P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C6',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='IO_L4P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='IO_L18P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='IO_L0N_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='IO_L0P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D3',name='IO_L14P_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=4),
            Pin(num='E4',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=4),
            Pin(num='R20',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='R21',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T19',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T20',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T21',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='T22',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='T23',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U19',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U20',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U21',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='U22',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V19',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V21',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V22',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V24',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='V25',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W20',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W21',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W22',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='W23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='W24',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y20',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y21',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='Y23',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA3',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA4',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AA7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AA8',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA9',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB14',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB15',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB3',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AB4',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L14P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L15N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC3',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AC6',name='IO_L15P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AD3',name='IO_L13N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD4',name='IO_L13P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD5',name='IO_L17N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD6',name='IO_L17P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=5),
            Pin(num='AE3',name='IO_L16N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE5',name='IO_L19N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AE6',name='IO_L19P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF3',name='IO_L16P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF4',name='IO_L18N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='AF5',name='IO_L18P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T4',name='IO_L1N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T5',name='IO_L1P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='T7',name='IO_L2P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U4',name='IO_L0N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='IO_L3P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='IO_L3N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='U7',name='IO_L2N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V3',name='IO_L0P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V4',name='IO_L4P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V6',name='IO_L6P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L6N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W3',name='IO_L5P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L7P_18',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L7N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y3',name='IO_L5N_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y5',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB23',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AC20',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AD16',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD20',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD21',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD23',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE10',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE12',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE13',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE15',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE16',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE17',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE18',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE20',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE21',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE22',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE23',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AE25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE7',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF12',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF13',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF14',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF15',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF17',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF18',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF19',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF20',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF22',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF23',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF8',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D13',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D14',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D15',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E10',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E11',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E12',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E13',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E14',name='VCCO_3',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E16',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E17',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E18',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='E8',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F12',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F14',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F17',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F18',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F19',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F8',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AB12',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC10',name='VCCO_4',func=pin_types.PWRIN,unit=7),
            Pin(num='AC11',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC12',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC13',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC14',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC16',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC17',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC18',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC7',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC8',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AC9',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD10',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD11',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD13',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD14',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD15',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD18',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=7),
            Pin(num='AD8',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=7),
            Pin(num='J10',name='CCLK_0',func=pin_types.BIDIR,unit=8),
            Pin(num='J11',name='INIT_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='J18',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='K10',name='DONE_0',func=pin_types.BIDIR,unit=8),
            Pin(num='K11',name='D_IN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='HSWAPEN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N13',name='VREFN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N14',name='VP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='N18',name='CS_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P13',name='VN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P14',name='VREFP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='P18',name='RDWR_B_0',func=pin_types.BIDIR,unit=8),
            Pin(num='R13',name='DXN_0',func=pin_types.BIDIR,unit=8),
            Pin(num='R14',name='DXP_0',func=pin_types.BIDIR,unit=8),
            Pin(num='U11',name='TCK_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V11',name='TDI_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V12',name='TMS_0',func=pin_types.BIDIR,unit=8),
            Pin(num='V18',name='M2_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W10',name='TDO_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W11',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=8),
            Pin(num='W12',name='VCCO_0',func=pin_types.PWRIN,unit=8),
            Pin(num='W18',name='M0_0',func=pin_types.BIDIR,unit=8),
            Pin(num='Y17',name='M1_0',func=pin_types.BIDIR,unit=8),
            Pin(num='Y9',name='VCCO_0',func=pin_types.PWRIN,unit=8),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='J8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='K18',name='VBATT_0',func=pin_types.PWRIN,unit=9),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M13',name='AVSS_0',func=pin_types.PWRIN,unit=9),
            Pin(num='M14',name='AVDD_0',func=pin_types.PWRIN,unit=9),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='R8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='T9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='V9',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W16',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='W8',name='VCCAUX',func=pin_types.PWRIN,unit=9),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=9),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G11', 'J20', 'G9', 'L19', 'H19', 'G12', 'N19', 'R22', 'E23', 'N21', 'R23', 'H11', 'H21', 'J21', 'G14', 'L20', 'F11', 'G15', 'H12', 'H22', 'J22', 'L22', 'N22', 'F13', 'G16', 'H18', 'H13', 'H23', 'J23', 'K23', 'F15', 'G17', 'L23', 'M22', 'N23', 'P23', 'E20', 'F20', 'G19', 'H14', 'H25', 'K20', 'M19', 'P19', 'F21', 'G20', 'G10', 'H16', 'H8', 'K21', 'M20', 'E21', 'F22', 'P20', 'E22', 'C10', 'G21', 'F23', 'H17', 'H9', 'K22', 'M21', 'P21', 'G22', 'J19']},{'label': 'uB', 'num': 2, 'pin_nums': ['M7', 'Y26', 'H26', 'N20', 'H4', 'N24', 'H5', 'N26', 'H6', 'N3', 'H7', 'N4', 'J2', 'N6', 'J24', 'N7', 'J25', 'P24', 'J26', 'P25', 'J4', 'P26', 'AA25', 'J5', 'P3', 'AB25', 'J6', 'P4', 'AB26', 'K25', 'P5', 'AC26', 'K26', 'P6', 'E25', 'K5', 'R24', 'E26', 'K6', 'R25', 'E5', 'K7', 'R26', 'E6', 'L24', 'R3', 'E7', 'L25', 'R5', 'F24', 'L3', 'R6', 'F25', 'L4', 'R7', 'F4', 'L5', 'T24', 'F5', 'L6', 'T25', 'F7', 'L7', 'T3', 'G24', 'M23', 'U24', 'G25', 'M24', 'U25', 'G26', 'M25', 'U26', 'G4', 'M26', 'V26', 'G5', 'M4', 'W25', 'G6', 'H24', 'M5', 'W26', 'G7', 'M6', 'Y25']},{'label': 'uC', 'num': 3, 'pin_nums': ['C14', 'J3', 'C16', 'A14', 'K1', 'A15', 'C17', 'K2', 'C18', 'A17', 'K3', 'A18', 'C19', 'L2', 'C20', 'A19', 'M1', 'A20', 'C21', 'M2', 'A22', 'C22', 'N1', 'B26', 'A23', 'C23', 'N2', 'A24', 'C24', 'P1', 'A25', 'C26', 'R1', 'AA2', 'D16', 'R2', 'AB1', 'D18', 'R4', 'AB2', 'D19', 'T2', 'AC1', 'D20', 'U1', 'D21', 'AC2', 'U2', 'AD1', 'D23', 'V1', 'AE1', 'D24', 'V2', 'AE2', 'D25', 'V5', 'AF2', 'D26', 'W1', 'B14', 'E1', 'W2', 'B15', 'E2', 'Y1', 'B16', 'E24', 'Y2', 'E3', 'B17', 'B19', 'F2', 'B20', 'F3', 'B21', 'G1', 'B22', 'G2', 'B23', 'H1', 'B24', 'H2', 'B25', 'H3', 'J1']},{'label': 'uD', 'num': 4, 'pin_nums': ['A8', 'C2', 'V22', 'A9', 'V23', 'C3', 'AA19', 'C4', 'V24', 'AA20', 'V25', 'C6', 'AA22', 'C7', 'W19', 'AA23', 'C8', 'W20', 'AA24', 'C9', 'W21', 'AB19', 'W22', 'D1', 'AB20', 'D10', 'W23', 'AB21', 'D11', 'W24', 'AB22', 'D3', 'Y20', 'AB24', 'D4', 'Y21', 'AC19', 'D5', 'Y22', 'AC21', 'D6', 'Y23', 'AC22', 'D7', 'AC23', 'D8', 'AC24', 'D9', 'AD19', 'E4', 'B1', 'G8', 'B10', 'R20', 'B11', 'R21', 'B12', 'T19', 'B2', 'T20', 'B4', 'T21', 'A10', 'B5', 'T22', 'A12', 'B6', 'T23', 'A13', 'B7', 'U19', 'A2', 'B9', 'U20', 'A3', 'C1', 'U21', 'A4', 'C11', 'U22', 'A5', 'C12', 'V19', 'A7', 'C13', 'V21']},{'label': 'uE', 'num': 5, 'pin_nums': ['AC3', 'T5', 'V6', 'AD7', 'Y12', 'AA13', 'AA5', 'AB16', 'AC4', 'AE3', 'T7', 'V7', 'Y13', 'AA6', 'AA14', 'AB17', 'AC6', 'AE5', 'U4', 'W3', 'Y18', 'AA15', 'AA7', 'AA4', 'AB15', 'AB3', 'AD17', 'AE6', 'U5', 'W4', 'Y3', 'AA16', 'AA8', 'AB4', 'AD3', 'AF3', 'U6', 'W5', 'Y5', 'AA9', 'AA17', 'AB5', 'AD4', 'AF4', 'U7', 'W6', 'Y6', 'AA18', 'AB11', 'AB6', 'AD5', 'AF5', 'V3', 'Y10', 'Y7', 'AB14', 'AA10', 'AA3', 'AB7', 'AD6', 'T4', 'V4', 'Y11', 'Y8', 'AA12']},{'label': 'uF', 'num': 6, 'pin_nums': ['AB23', 'AD26', 'AF17', 'AE17', 'AE26', 'AF7', 'E11', 'E8', 'F9', 'AC20', 'AD9', 'E12', 'F10', 'AF18', 'AE7', 'AE18', 'AF8', 'AE16', 'AD16', 'AE10', 'AE20', 'AE8', 'AF19', 'AF9', 'E13', 'F12', 'AD20', 'AE11', 'AE21', 'AF10', 'AF20', 'D13', 'E14', 'F14', 'AD21', 'AE12', 'AE22', 'AF12', 'AF22', 'D14', 'E15', 'F17', 'AD23', 'AE13', 'AF15', 'AE23', 'AF13', 'AF23', 'AF25', 'D15', 'E10', 'E16', 'F18', 'E18', 'AD24', 'AE15', 'F8', 'AE24', 'AF14', 'AF24', 'D17', 'E17', 'F19', 'AD25', 'AE25']},{'label': 'uG', 'num': 7, 'pin_nums': ['AC12', 'AC13', 'AD10', 'AC14', 'AB10', 'AD11', 'AB12', 'AC16', 'AD13', 'AB13', 'AC17', 'AD14', 'AB9', 'AC18', 'AD15', 'AC10', 'AC7', 'AC9', 'AD18', 'AC11', 'AC8', 'AD8']},{'label': 'uH', 'num': 8, 'pin_nums': ['N14', 'J10', 'V12', 'N18', 'Y9', 'J11', 'P13', 'V18', 'J18', 'P14', 'W10', 'K10', 'P18', 'W11', 'K11', 'R13', 'W12', 'L18', 'R14', 'W18', 'N13', 'U11', 'Y17', 'V11']},{'label': 'uI', 'num': 9, 'pin_nums': ['K15', 'T1', 'V8', 'A1', 'C15', 'K16', 'M9', 'T10', 'V9', 'A11', 'C25', 'K17', 'N10', 'T11', 'W13', 'A16', 'C5', 'K18', 'N11', 'T12', 'W14', 'A21', 'D12', 'K19', 'N12', 'T13', 'W15', 'A26', 'D2', 'K24', 'N15', 'T14', 'W16', 'A6', 'D22', 'K4', 'N16', 'T15', 'W17', 'AA1', 'E19', 'K8', 'N17', 'T16', 'W7', 'AA11', 'E9', 'K9', 'N25', 'T17', 'W8', 'AA21', 'F1', 'L1', 'N5', 'T26', 'W9', 'AA26', 'F16', 'L10', 'N8', 'T6', 'Y14', 'AB18', 'F26', 'L11', 'N9', 'T8', 'Y15', 'AB8', 'F6', 'L12', 'P10', 'T9', 'Y16', 'AC15', 'G13', 'L13', 'P11', 'U10', 'Y19', 'AC25', 'G18', 'L14', 'P12', 'U12', 'Y24', 'AC5', 'G23', 'L15', 'P15', 'U13', 'Y4', 'AD12', 'G3', 'L16', 'P16', 'U14', 'AD2', 'H10', 'L17', 'P17', 'U15', 'AD22', 'H15', 'L21', 'P2', 'U16', 'AE14', 'H20', 'L26', 'P22', 'U17', 'AE19', 'J12', 'L8', 'P7', 'U18', 'AE4', 'J13', 'L9', 'P8', 'U23', 'AE9', 'J14', 'M10', 'P9', 'U3', 'AF1', 'J15', 'M11', 'R10', 'U8', 'AF11', 'J16', 'M12', 'R11', 'U9', 'AF16', 'J17', 'M13', 'R12', 'V10', 'AF21', 'J7', 'M14', 'R15', 'V13', 'AF26', 'J8', 'M15', 'R16', 'V14', 'AF6', 'J9', 'M16', 'R17', 'V15', 'B13', 'K12', 'M17', 'R19', 'V16', 'B18', 'K13', 'M18', 'M8', 'R8', 'V17', 'B3', 'K14', 'M3', 'R9', 'V20', 'B8']}] }),
        Part(**{ 'name':'XC5VLX85T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VLX85T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VLX85T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=13),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=13),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=13),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=13),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=13),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=13),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=13),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=13),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=13),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=13),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=13),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=13),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=14),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=14),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=14),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=15),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=15),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=15),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=16)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G22', 'H33', 'R32', 'K34', 'M32', 'U33', 'C34', 'G23', 'H34', 'K14', 'L14', 'M33', 'R33', 'D13', 'V31', 'A33', 'G32', 'J12', 'D32', 'K16', 'L15', 'N32', 'R34', 'D34', 'G33', 'J15', 'K21', 'L16', 'N33', 'T27', 'E32', 'H12', 'J22', 'E33', 'K22', 'L20', 'N34', 'T33', 'E34', 'H22', 'J32', 'K23', 'L21', 'P32', 'T34', 'B33', 'F33', 'H23', 'J34', 'K13', 'K32', 'L33', 'P34', 'F34', 'U31', 'B32', 'C32', 'H32', 'K12', 'G14', 'K33', 'L34', 'R30', 'U32', 'C33']},{'label': 'uB', 'num': 2, 'pin_nums': ['P7', 'AN32', 'P9', 'AN33', 'AA32', 'AN34', 'R11', 'AA33', 'R6', 'AP32', 'AA34', 'E6', 'R7', 'AB29', 'R8', 'E7', 'AB32', 'F5', 'R9', 'AB33', 'F6', 'T10', 'AC32', 'G5', 'T11', 'AC33', 'G6', 'T6', 'AC34', 'G7', 'T7', 'AD32', 'H5', 'T8', 'AD34', 'H7', 'T9', 'AE32', 'J5', 'U10', 'AE33', 'J6', 'U7', 'AE34', 'J7', 'V32', 'AF33', 'K6', 'V33', 'AF34', 'K7', 'V34', 'AG32', 'L4', 'W28', 'AG33', 'L5', 'W32', 'AH32', 'L6', 'W34', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6', 'AK34', 'N7', 'AL33', 'N8', 'AL34', 'P10', 'AM32', 'P5', 'AM33', 'P6']},{'label': 'uC', 'num': 3, 'pin_nums': ['L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'AD33', 'L32', 'W24', 'AE29', 'M29', 'W25', 'AE30', 'M30', 'W26', 'AE31', 'M31', 'W27', 'AF29', 'N29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'P33', 'Y28', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'AD29', 'K29', 'V25', 'AC30', 'K31', 'V27']},{'label': 'uD', 'num': 4, 'pin_nums': ['W9', 'AF6', 'Y11', 'K26', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AG7', 'L24', 'Y8', 'AH5', 'L25', 'Y9', 'K24', 'AH7', 'L26', 'AJ6', 'L28', 'AJ7', 'M25', 'AK6', 'M26', 'AK7', 'M27', 'E26', 'M28', 'E27', 'N24', 'E28', 'N25', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'J24', 'W10', 'J25', 'AD6', 'W11', 'AD7', 'J26', 'W6', 'AE6', 'J27', 'W7', 'AE7', 'J28', 'W8', 'AF5']},{'label': 'uE', 'num': 5, 'pin_nums': ['AE22', 'AD20', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'E9', 'G12', 'J11', 'L8', 'D10', 'AE13', 'AF13', 'AG23', 'D11', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AE16', 'AF15', 'AM19', 'E10', 'F13', 'H10', 'K11', 'M8', 'AE17', 'AF16', 'B12', 'E11', 'F8', 'H11', 'K8', 'N10', 'E13', 'A13', 'AE19', 'AF20', 'B13', 'E12', 'F9', 'H8', 'H9', 'K9', 'L10', 'N9', 'AD19', 'AE21', 'AF21', 'C12', 'G10']},{'label': 'uF', 'num': 6, 'pin_nums': ['AH9', 'AJ10', 'AD27', 'AJ11', 'AD9', 'AE11', 'AJ25', 'AE24', 'AJ26', 'AE26', 'AJ27', 'AE27', 'AJ28', 'AE28', 'AJ29', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AD26', 'AH28', 'AD25', 'AH8']},{'label': 'uG', 'num': 7, 'pin_nums': ['G24', 'C26', 'AL22', 'AK25', 'F27', 'AN26']},{'label': 'uH', 'num': 8, 'pin_nums': ['H14', 'AG22', 'J17', 'AG13', 'AH20', 'L19', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20', 'AG16', 'AH14', 'D23', 'H18', 'J21', 'AG17', 'AH15', 'E20', 'H19', 'K17', 'AE18', 'AG18', 'AH17', 'G15', 'H20', 'K18', 'AF18', 'AG20', 'AH18', 'G16', 'J14', 'K19', 'AF19', 'AG21', 'AH19', 'H13', 'J16', 'L18']},{'label': 'uI', 'num': 9, 'pin_nums': ['AN16', 'C16', 'AJ18', 'B19', 'AK15', 'F17']},{'label': 'uJ', 'num': 10, 'pin_nums': ['W2', 'AB1', 'Y1', 'P4', 'AB2', 'R1', 'Y3', 'AC2', 'T1', 'Y4', 'M2', 'T2', 'N1', 'U2', 'N2', 'V2', 'P1', 'W1', 'AA1', 'P3']},{'label': 'uK', 'num': 11, 'pin_nums': ['AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4', 'AD2', 'AH2', 'J1', 'AE1', 'AJ2', 'K1', 'AE2', 'F2', 'K2', 'AF1', 'G1', 'L2']},{'label': 'uL', 'num': 12, 'pin_nums': ['D2', 'AN3', 'A2', 'A3', 'D4', 'AN4', 'E2', 'AK2', 'AP2', 'AL1', 'AP3', 'E4', 'B3', 'AL2', 'AL4', 'B4', 'AL5', 'C1', 'AM1', 'D1']},{'label': 'uM', 'num': 13, 'pin_nums': ['D5', 'V4', 'L3', 'AD3', 'AK5', 'E3', 'M3', 'V5', 'AK3', 'AE3', 'AL3', 'F3', 'N3', 'W3', 'AG3', 'AM3', 'F4', 'R3', 'AG4', 'AM4', 'G3', 'R4', 'AA3', 'AH3', 'C3', 'J3', 'T3', 'AA4', 'AJ3', 'C4', 'J4', 'U3', 'AB3', 'AJ4', 'D3', 'K3', 'V3', 'AC3']},{'label': 'uN', 'num': 14, 'pin_nums': ['V18', 'AD14', 'N14', 'N15', 'AD15', 'W17', 'AD21', 'N22', 'W18', 'AA22', 'AD22', 'N23', 'AB15', 'AD23', 'P15', 'AC14', 'M15', 'U17', 'AC15', 'M22', 'U18', 'AC22', 'M23', 'V17']},{'label': 'uO', 'num': 15, 'pin_nums': ['P19', 'F32', 'AB17', 'P2', 'M12', 'T21', 'F7', 'AB19', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'G29', 'AC12', 'M16', 'P22', 'T4', 'AC16', 'G34', 'M17', 'P23', 'T5', 'AC18', 'G4', 'M18', 'P28', 'U12', 'AC20', 'G9', 'M19', 'P8', 'U14', 'AD13', 'H16', 'M20', 'R10', 'F22', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'R15', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'R17', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'J23', 'B34', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'K5', 'D28', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'T20', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'M11']},{'label': 'uP', 'num': 16, 'pin_nums': ['AA17', 'AM24', 'AE4', 'V6', 'AA19', 'AM34', 'AE5', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AN11', 'AF17', 'W19', 'AA23', 'AF2', 'AN2', 'W21', 'AA27', 'AF22', 'AN21', 'W23', 'AA7', 'AF27', 'AN31', 'W33', 'AB12', 'AF32', 'AN7', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14', 'AB22', 'AG34', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'T32', 'AH26', 'Y20', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'AE25', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AM2', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AE15', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'V26']}] }),
        Part(**{ 'name':'XC5VSX240T-FF1738', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VSX240T-FF1738'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VSX240T-FF1738\n\nFPGA', 'pins':[
            Pin(num='AA37',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA38',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA39',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA40',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA41',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA42',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F41',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F42',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G41',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G42',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H41',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J41',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J42',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K42',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L40',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L41',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L42',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M41',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M42',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N40',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N41',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P40',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P41',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P42',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R40',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R42',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T40',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T41',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T42',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U41',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U42',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V37',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='V40',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V41',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W40',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W41',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W42',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y38',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y39',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y40',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y41',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y42',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB35',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB37',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB38',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB39',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB41',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB42',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC39',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC40',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC41',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD39',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AD40',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD41',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD42',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE40',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE42',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF40',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF41',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF42',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG41',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG42',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH40',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH41',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ40',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ41',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ42',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK40',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK42',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL40',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL41',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL42',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM41',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM42',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN41',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP41',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP42',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AR42',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT41',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AT42',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU41',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AU42',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AV41',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA35',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA36',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AB34',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB36',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC34',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC35',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC36',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD35',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD36',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD37',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD38',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE37',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE38',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE39',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF37',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF39',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG37',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG38',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG39',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG40',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH37',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AH38',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH39',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ37',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ38',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK37',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK38',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK39',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK41',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AL37',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AL39',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM37',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM38',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AM39',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN38',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN39',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AN40',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP38',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AP40',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR39',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AR40',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT39',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AT40',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AU39',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AV40',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E39',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E40',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F39',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F40',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G38',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G39',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H38',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H39',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H40',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J38',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J40',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K38',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K39',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K40',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L39',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M38',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M39',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N38',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N39',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P37',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P38',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P39',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R36',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R37',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R38',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R39',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T37',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T39',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U37',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U38',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U39',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U40',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='V38',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V39',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W35',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W36',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W37',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='W38',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y34',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='Y35',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='AA32',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AB11',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD8',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AE7',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AG4',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='D37',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E37',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E38',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F36',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F37',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G36',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G37',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G40',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='H35',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J35',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K41',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='L35',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L38',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T34',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T35',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T36',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U33',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U34',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U36',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V33',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V34',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V35',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='V36',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W32',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='W33',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y32',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='Y33',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ26',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ30',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK12',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK15',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK27',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK28',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK29',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AK30',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL29',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AL30',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM28',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AM29',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AN14',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AV27',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D7',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E5',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E7',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F5',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F6',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F7',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G7',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H8',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J7',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K7',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L7',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P8',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R6',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='R7',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='R9',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T11',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='U9',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AB32',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB33',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC33',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD32',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD33',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE32',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE33',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE34',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE35',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF34',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF35',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF36',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG34',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG36',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH34',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH35',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH36',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ34',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ35',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ36',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK34',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK35',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL34',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL35',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL36',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AL38',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM34',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AM35',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM36',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN34',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN35',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AN36',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP35',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP36',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AP37',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR37',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AR38',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT36',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AT37',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU37',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AU38',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV38',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AV39',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='D39',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='E32',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='F31',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G31',name='IO_L6N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L6P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='IO_L5P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='G34',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L5N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H34',name='IO_L4P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=6),
            Pin(num='J31',name='IO_L7N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=6),
            Pin(num='J33',name='IO_L13N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K32',name='IO_L14P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K33',name='IO_L13P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='K34',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L15N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L15P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='L34',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L2N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L2P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L1N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='M34',name='IO_L1P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L3P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N33',name='IO_L0P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='N34',name='IO_L0N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L3N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L16N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='P33',name='IO_L16P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R32',name='IO_L17N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='R33',name='IO_L17P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T31',name='IO_L19N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='T32',name='IO_L18P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U31',name='IO_L19P_23',func=pin_types.BIDIR,unit=6),
            Pin(num='U32',name='IO_L18N_23',func=pin_types.BIDIR,unit=6),
            Pin(num='AF31',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AF32',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG31',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG32',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AG33',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AH33',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ32',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ33',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK32',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AK33',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL32',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM32',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM33',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN31',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN33',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP32',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP33',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP39',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AR32',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR35',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AT31',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT34',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AT35',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU31',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU36',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AU40',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AV31',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV33',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV34',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV35',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AV36',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='D12',name='IO_L15N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='D13',name='IO_L17P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E10',name='IO_L3P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E12',name='IO_L15P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='IO_L13N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E14',name='IO_L17N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='IO_L19P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='E6',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='F10',name='IO_L3N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F11',name='IO_L2N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F12',name='IO_L2P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F14',name='IO_L13P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='IO_L19N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G10',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='G11',name='IO_L1N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G12',name='IO_L1P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G13',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='IO_L7P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='IO_L0N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='IO_L6N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H15',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='IO_L7N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J11',name='IO_L5N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J12',name='IO_L0P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='J13',name='IO_L6P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K10',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K12',name='IO_L5P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K13',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='K14',name='IO_L4P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L10',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L11',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='L12',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M11',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=7),
            Pin(num='M12',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N10',name='IO_L16N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='IO_L14P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P10',name='IO_L18N_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='IO_L16P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=7),
            Pin(num='R10',name='IO_L18P_24',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L2P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A31',name='IO_L2N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A32',name='IO_L3P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A34',name='IO_L7P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A35',name='IO_L7N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A36',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A37',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A39',name='IO_L15P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A40',name='IO_L15N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='A41',name='IO_L16P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='AG11',name='IO_L1N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG12',name='IO_L1P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG8',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AG9',name='IO_L3P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH10',name='IO_L5P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH11',name='IO_L5N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH7',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AH8',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AH9',name='IO_L3N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ10',name='IO_L7N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ11',name='IO_L7P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AK9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL10',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL6',name='IO_L16P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL7',name='IO_L16N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AL8',name='VCCO_26',func=pin_types.PWRIN,unit=8),
            Pin(num='AL9',name='IO_L14P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM6',name='IO_L18N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM7',name='IO_L19P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM8',name='IO_L19N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AM9',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN4',name='IO_L17P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN5',name='IO_L17N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN6',name='IO_L18P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AN9',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP5',name='IO_L15N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP6',name='IO_L15P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP7',name='IO_L13P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AP8',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR5',name='IO_L2N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR7',name='IO_L0N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AR8',name='IO_L13N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT5',name='IO_L4P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT6',name='IO_L2P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AT7',name='IO_L0P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AU6',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV5',name='IO_L6N_26',func=pin_types.BIDIR,unit=8),
            Pin(num='AV6',name='IO_L6P_26',func=pin_types.BIDIR,unit=8),
            Pin(num='B31',name='IO_L1N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B32',name='IO_L3N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B33',name='IO_L4P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B34',name='IO_L6N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B35',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='B36',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B37',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B38',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B39',name='IO_L14P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B41',name='IO_L16N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='B42',name='IO_L17P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C30',name='IO_L1P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C31',name='IO_L0N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C33',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C34',name='IO_L6P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C35',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C36',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C38',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C39',name='IO_L13P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C40',name='IO_L13N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='C41',name='IO_L17N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D31',name='IO_L0P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D32',name='IO_L5P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D33',name='IO_L5N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D35',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D36',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D38',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D40',name='IO_L18P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D41',name='IO_L18N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='D42',name='IO_L19N_27',func=pin_types.BIDIR,unit=8),
            Pin(num='E42',name='IO_L19P_27',func=pin_types.BIDIR,unit=8),
            Pin(num='F33',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='J34',name='VCCO_27',func=pin_types.PWRIN,unit=8),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AV37',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW31',name='IO_L19N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW32',name='IO_L15N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW33',name='IO_L15P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW34',name='VCCO_29',func=pin_types.PWRIN,unit=9),
            Pin(num='AW35',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW36',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW37',name='IO_L6N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW38',name='IO_L7P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW40',name='IO_L1N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW41',name='IO_L1P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AW42',name='IO_L0N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY30',name='IO_L19P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY32',name='IO_L16P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY33',name='IO_L14P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY34',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY35',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY37',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY38',name='IO_L6P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY39',name='IO_L7N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY40',name='IO_L2P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='AY42',name='IO_L0P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA30',name='IO_L18P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA31',name='IO_L18N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA32',name='IO_L16N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA34',name='IO_L13N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA35',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA36',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA37',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA39',name='IO_L5N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA40',name='IO_L4P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA41',name='IO_L2N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BA42',name='IO_L3P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB31',name='IO_L17N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB32',name='IO_L17P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB33',name='IO_L13P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB34',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB36',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB37',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB38',name='IO_L5P_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB39',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=9),
            Pin(num='BB41',name='IO_L3N_29',func=pin_types.BIDIR,unit=9),
            Pin(num='E26',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='H27',name='VCCO_3',func=pin_types.PWRIN,unit=9),
            Pin(num='J15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J16',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=9),
            Pin(num='J30',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K28',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K29',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='K30',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L27',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L29',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='L30',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M26',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M27',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='M28',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=9),
            Pin(num='A20',name='IO_L2P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A21',name='IO_L2N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A22',name='IO_L3P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A24',name='IO_L6N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A25',name='IO_L13N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A26',name='IO_L13P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A27',name='IO_L14P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='A29',name='IO_L15N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='AU30',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='AV26',name='IO_L11P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV28',name='IO_L10P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV29',name='IO_L5P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AV30',name='IO_L4N_VREF_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW20',name='IO_L19N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW21',name='IO_L19P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW22',name='IO_L15N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW23',name='IO_L15P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW25',name='IO_L9N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW26',name='IO_L11N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW27',name='IO_L10N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW28',name='IO_L5N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AW30',name='IO_L4P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY19',name='IO_L18P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY20',name='IO_L18N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY22',name='IO_L14P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY23',name='IO_L14N_VREF_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY24',name='IO_L9P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY25',name='IO_L3N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY27',name='IO_L6P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY28',name='IO_L6N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY29',name='IO_L7P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='AY31',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='B21',name='IO_L3N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B22',name='IO_L5N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B23',name='IO_L6P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B24',name='IO_L7P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B26',name='IO_L12N_VRP_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B27',name='IO_L14N_VREF_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B28',name='IO_L15P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='B29',name='IO_L18N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='BA19',name='IO_L17N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA20',name='IO_L17P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA21',name='IO_L16N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA22',name='IO_L13N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA24',name='IO_L8N_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA25',name='IO_L3P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA26',name='IO_L2N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA27',name='IO_L1N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BA28',name='VCCO_33',func=pin_types.PWRIN,unit=10),
            Pin(num='BA29',name='IO_L7N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB20',name='IO_L16P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB21',name='IO_L13P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB22',name='IO_L12P_VRN_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB23',name='IO_L12N_VRP_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB24',name='IO_L8P_CC_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB26',name='IO_L2P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB27',name='IO_L1P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB28',name='IO_L0N_33',func=pin_types.BIDIR,unit=10),
            Pin(num='BB29',name='IO_L0P_33',func=pin_types.BIDIR,unit=10),
            Pin(num='C20',name='IO_L1N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C21',name='IO_L1P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C23',name='IO_L5P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C24',name='IO_L7N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C25',name='IO_L12P_VRN_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C26',name='IO_L11N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C28',name='IO_L19P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C29',name='IO_L18P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='C32',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D20',name='IO_L0P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D21',name='IO_L0N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D22',name='IO_L4P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D23',name='IO_L4N_VREF_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D25',name='IO_L9P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D26',name='IO_L9N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D27',name='IO_L11P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D28',name='IO_L19N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='D29',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='D30',name='IO_L17N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E24',name='IO_L8P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E25',name='IO_L8N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E27',name='IO_L10N_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E28',name='IO_L10P_CC_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E29',name='IO_L17P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='E30',name='IO_L16N_31',func=pin_types.BIDIR,unit=10),
            Pin(num='F30',name='IO_L16P_31',func=pin_types.BIDIR,unit=10),
            Pin(num='G30',name='VCCO_31',func=pin_types.PWRIN,unit=10),
            Pin(num='AK17',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL11',name='IO_L1P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AL12',name='IO_L1N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AL15',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL16',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL17',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL26',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AL27',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM11',name='IO_L3P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AM12',name='IO_L3N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AM16',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM17',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM26',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AM27',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN10',name='IO_L5N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AN11',name='IO_L5P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AN15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN28',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN29',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AN30',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP10',name='IO_L7P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP11',name='IO_L9P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP12',name='IO_L9N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AP15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP27',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP28',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP30',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=11),
            Pin(num='AP9',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AR10',name='IO_L10P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR12',name='IO_L12N_VRP_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR13',name='IO_L14P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AR16',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AR9',name='IO_L7N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT10',name='IO_L10N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT11',name='IO_L12P_VRN_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT12',name='IO_L14N_VREF_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AT13',name='VCCO_4',func=pin_types.PWRIN,unit=11),
            Pin(num='AT9',name='IO_L18N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU10',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AU11',name='IO_L13P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU12',name='IO_L13N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU13',name='IO_L15N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU14',name='IO_L15P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU16',name='IO_L4N_VREF_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU17',name='IO_L2N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU7',name='IO_L19N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU8',name='IO_L19P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AU9',name='IO_L18P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV10',name='IO_L17P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV11',name='IO_L11N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV13',name='IO_L8N_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV14',name='IO_L6N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV15',name='IO_L6P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV16',name='IO_L4P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV18',name='IO_L2P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV19',name='IO_L0N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV7',name='VCCO_34',func=pin_types.PWRIN,unit=11),
            Pin(num='AV8',name='IO_L16N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AV9',name='IO_L17N_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW12',name='IO_L11P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW13',name='IO_L8P_CC_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW18',name='IO_L0P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AW7',name='IO_L16P_34',func=pin_types.BIDIR,unit=11),
            Pin(num='AK18',name='IO_L16P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK19',name='IO_L16N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK24',name='IO_L17P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AK25',name='IO_L17N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL19',name='IO_L18N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL24',name='IO_L19N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AL25',name='IO_L19P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM18',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM19',name='IO_L18P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AM24',name='IO_L15P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN18',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN19',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN24',name='IO_L15N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN25',name='IO_L13P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AN26',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP17',name='IO_L7P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP18',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP25',name='IO_L13N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AP26',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR14',name='IO_L1N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR15',name='IO_L3N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR17',name='IO_L7N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR18',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR19',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR27',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR28',name='IO_L0N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR29',name='IO_L0P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AR30',name='IO_L2P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT14',name='IO_L1P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT15',name='IO_L3P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT16',name='IO_L5N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT17',name='IO_L5P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT19',name='IO_L14P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AT26',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT27',name='IO_L6N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT29',name='IO_L4P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AT30',name='IO_L2N_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU28',name='IO_L6P_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AU29',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=12),
            Pin(num='AW24',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=12),
            Pin(num='B25',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='C22',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='E17',name='IO_L1N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='E18',name='IO_L1P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F16',name='IO_L3P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F17',name='IO_L3N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=12),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='F29',name='IO_L17N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G16',name='IO_L5P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G28',name='IO_L15P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='G29',name='IO_L17P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H16',name='IO_L5N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H18',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H26',name='IO_L6P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H28',name='IO_L15N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H29',name='IO_L19P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='H30',name='IO_L19N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J18',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J25',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J26',name='IO_L6N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J27',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='J28',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K25',name='IO_L4P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='K27',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L19',name='IO_L18N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L20',name='IO_L18P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L24',name='IO_L0P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L25',name='IO_L2N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='L26',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M18',name='IO_L16P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M19',name='IO_L14P_5',func=pin_types.BIDIR,unit=12),
            Pin(num='M24',name='IO_L0N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N18',name='IO_L16N_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N19',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=12),
            Pin(num='N20',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=12),
            Pin(num='P20',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=12),
            Pin(num='AJ21',name='IO_L2N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AJ22',name='IO_L2P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK20',name='IO_L3P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK22',name='IO_L1N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AK23',name='IO_L1P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL20',name='IO_L3N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL21',name='IO_L0P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AL22',name='IO_L0N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM21',name='IO_L19N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM22',name='IO_L16P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AM23',name='IO_L16N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AN21',name='IO_L19P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AN23',name='IO_L17P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP19',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AP20',name='IO_L18P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP21',name='IO_L18N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP22',name='IO_L14N_VREF_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AP23',name='IO_L17N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR20',name='IO_L7P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR22',name='IO_L15P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR23',name='IO_L14P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR24',name='IO_L8N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AR25',name='IO_L6P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT20',name='IO_L7N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT21',name='IO_L9N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT22',name='IO_L15N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT24',name='IO_L8P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AT25',name='IO_L6N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU18',name='IO_L5N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU19',name='IO_L5P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU20',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AU21',name='IO_L9P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU22',name='IO_L12N_VRP_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU23',name='IO_L12P_VRN_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU24',name='IO_L11P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU26',name='IO_L4P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AU27',name='IO_L4N_VREF_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV17',name='VCCO_8',func=pin_types.PWRIN,unit=13),
            Pin(num='AV20',name='IO_L10N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV21',name='IO_L10P_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV23',name='IO_L13P_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV24',name='IO_L13N_8',func=pin_types.BIDIR,unit=13),
            Pin(num='AV25',name='IO_L11N_CC_8',func=pin_types.BIDIR,unit=13),
            Pin(num='D18',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=13),
            Pin(num='D19',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='E19',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E20',name='IO_L14P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E22',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='E23',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F19',name='IO_L16P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F20',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F21',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F24',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F25',name='IO_L17N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='F26',name='IO_L17P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G19',name='IO_L16N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G20',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='G21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G22',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G23',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G24',name='IO_L15P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='G26',name='IO_L19N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H17',name='VCCO_7',func=pin_types.PWRIN,unit=13),
            Pin(num='H19',name='IO_L18P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H20',name='IO_L18N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H21',name='IO_L4P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H23',name='IO_L13N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H24',name='IO_L15N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='H25',name='IO_L19P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J20',name='IO_L5P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J21',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J22',name='IO_L7N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='J23',name='IO_L13P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K20',name='IO_L5N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K22',name='IO_L7P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='K23',name='IO_L6N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='L21',name='IO_L1N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='L22',name='IO_L6P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M21',name='IO_L1P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M22',name='IO_L0N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='M23',name='IO_L0P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N21',name='IO_L3N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N22',name='IO_L3P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N23',name='IO_L2N_7',func=pin_types.BIDIR,unit=13),
            Pin(num='N24',name='IO_L2P_7',func=pin_types.BIDIR,unit=13),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=14),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=14),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=14),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=14),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=15),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=15),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=15),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=16),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=16),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=17),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A10',name='MGTRXN0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A11',name='MGTRXP0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A8',name='MGTRXP1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A9',name='MGTRXN1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='AW9',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=18),
            Pin(num='AY9',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=18),
            Pin(num='B11',name='MGTTXN0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B12',name='MGTTXP0_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B7',name='MGTTXP1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='B8',name='MGTTXN1_128',func=pin_types.BIDIR,unit=18),
            Pin(num='BA11',name='MGTTXN1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA12',name='MGTTXP1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA7',name='MGTTXP0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BA8',name='MGTTXN0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB10',name='MGTRXN1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB11',name='MGTRXP1_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB8',name='MGTRXP0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='BB9',name='MGTRXN0_130',func=pin_types.BIDIR,unit=18),
            Pin(num='C10',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=18),
            Pin(num='D10',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=18),
            Pin(num='A14',name='MGTRXP1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A15',name='MGTRXN1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A16',name='MGTRXN0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='A17',name='MGTRXP0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='AW15',name='MGTREFCLKP_134',func=pin_types.BIDIR,unit=19),
            Pin(num='AY15',name='MGTREFCLKN_134',func=pin_types.BIDIR,unit=19),
            Pin(num='B13',name='MGTTXP1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B14',name='MGTTXN1_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B17',name='MGTTXN0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='B18',name='MGTTXP0_132',func=pin_types.BIDIR,unit=19),
            Pin(num='BA13',name='MGTTXP0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA14',name='MGTTXN0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA17',name='MGTTXN1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BA18',name='MGTTXP1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB14',name='MGTRXP0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB15',name='MGTRXN0_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB16',name='MGTRXN1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='BB17',name='MGTRXP1_134',func=pin_types.BIDIR,unit=19),
            Pin(num='C16',name='MGTREFCLKN_132',func=pin_types.BIDIR,unit=19),
            Pin(num='D16',name='MGTREFCLKP_132',func=pin_types.BIDIR,unit=19),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AA5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=20),
            Pin(num='AB3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AE4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=20),
            Pin(num='AH3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AL4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=20),
            Pin(num='AP3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AU4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AW10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AW16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=20),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY1',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY11',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY12',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY13',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY14',name='MGTAVTTRX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY17',name='MGTAVCCPLL_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY18',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=20),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY3',name='MGTAVCC_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=20),
            Pin(num='AY7',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='AY8',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=20),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C11',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C12',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C13',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C14',name='MGTAVCCPLL_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C17',name='MGTAVTTRX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C18',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=20),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C6',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=20),
            Pin(num='C7',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C8',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=20),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=20),
            Pin(num='D15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=20),
            Pin(num='D3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=20),
            Pin(num='D5',name='MGTAVCC_124',func=pin_types.PWRIN,unit=20),
            Pin(num='D9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=20),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=20),
            Pin(num='G4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=20),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=20),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=20),
            Pin(num='K3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=20),
            Pin(num='N4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=20),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=20),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=20),
            Pin(num='T3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=20),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=20),
            Pin(num='W4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=20),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=20),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AF30',name='RSVD_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AG29',name='TCK_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AG30',name='VCCO_0',func=pin_types.PWRIN,unit=21),
            Pin(num='AH14',name='CCLK_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH15',name='TMS_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH16',name='TDI_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH29',name='M0_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AH30',name='M1_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ15',name='TDO_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ16',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AJ28',name='M2_0',func=pin_types.BIDIR,unit=21),
            Pin(num='AL28',name='VCCO_0',func=pin_types.PWRIN,unit=21),
            Pin(num='P15',name='HSWAPEN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='R30',name='RDWR_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=21),
            Pin(num='V31',name='RSVD_0',func=pin_types.BIDIR,unit=21),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A33',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='A38',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AA30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AB31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AC30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AD31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AF15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AF29',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AG14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AG28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AH17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='AJ24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B30',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='C42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='E41',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='H42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L28',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M35',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M40',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N32',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N42',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P30',name='VBATT_0',func=pin_types.PWRIN,unit=22),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R27',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='R28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=22),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='T29',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='U30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='V29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W28',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='W30',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=22),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=22),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y29',name='VCCINT',func=pin_types.PWRIN,unit=22),
            Pin(num='Y31',name='VCCAUX',func=pin_types.PWRIN,unit=22),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AR6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AV42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AY41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='BB40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='R41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='V42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=23)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AA38', 'N28', 'R42', 'M41', 'P25', 'AA39', 'J41', 'V41', 'Y41', 'AA40', 'J42', 'M42', 'N29', 'P26', 'AA41', 'T40', 'W40', 'Y42', 'K42', 'N13', 'N30', 'P27', 'T41', 'AA42', 'W41', 'L40', 'F13', 'N14', 'N40', 'P28', 'L41', 'T42', 'W42', 'F41', 'L42', 'N15', 'N41', 'P40', 'U41', 'Y37', 'F42', 'M13', 'G41', 'N16', 'P13', 'P41', 'AA37', 'U42', 'Y38', 'M14', 'G42', 'N25', 'P17', 'P42', 'V37', 'M16', 'Y39', 'H41', 'M29', 'N26', 'P18', 'R40', 'J14', 'V40', 'Y40']},{'label': 'uB', 'num': 2, 'pin_nums': ['AU41', 'AC40', 'W5', 'AC41', 'AU42', 'W6', 'AD39', 'AV41', 'W7', 'G6', 'AD40', 'W8', 'AD41', 'H5', 'Y10', 'H6', 'AD42', 'Y7', 'AT42', 'AE36', 'J5', 'Y8', 'AE40', 'J6', 'Y9', 'AE42', 'K4', 'AF40', 'K5', 'AF41', 'L5', 'AF42', 'L6', 'AG41', 'M6', 'AG42', 'N5', 'AH40', 'N6', 'AH41', 'P5', 'AJ40', 'P6', 'AJ41', 'R4', 'AA10', 'AJ42', 'R5', 'AA11', 'AK40', 'T4', 'AA6', 'AK42', 'T5', 'AA7', 'AL40', 'T6', 'AA8', 'AL41', 'T7', 'AA9', 'AL42', 'U10', 'AB35', 'AM41', 'U6', 'AB37', 'AM42', 'U7', 'AB38', 'AN41', 'V5', 'AB39', 'AP41', 'V6', 'AB41', 'AP42', 'V7', 'AB42', 'V8', 'AR42', 'AC38', 'AT41', 'W10', 'AC39', 'W11']},{'label': 'uC', 'num': 3, 'pin_nums': ['AH39', 'J38', 'AJ37', 'J40', 'AJ38', 'K38', 'AK37', 'K39', 'AK38', 'K40', 'AK39', 'L39', 'AK41', 'M38', 'AL37', 'M39', 'AL39', 'N38', 'AA34', 'AM37', 'N39', 'AA35', 'AM38', 'P37', 'AA36', 'AM39', 'P38', 'AB34', 'AN38', 'P39', 'AB36', 'AN39', 'R36', 'AC34', 'AN40', 'R37', 'AC35', 'AP38', 'R38', 'AC36', 'AP40', 'R39', 'AD35', 'AR39', 'T37', 'AD36', 'AR40', 'T39', 'AD37', 'AT39', 'U37', 'AD38', 'AT40', 'U38', 'AE37', 'AU39', 'U39', 'AE38', 'AV40', 'U40', 'AE39', 'E39', 'V38', 'AF37', 'E40', 'V39', 'AF39', 'F39', 'W35', 'AG37', 'F40', 'W36', 'AG38', 'G38', 'W37', 'AG39', 'G39', 'W38', 'AG40', 'H38', 'Y34', 'AH37', 'H39', 'Y35', 'AH38', 'H40']},{'label': 'uD', 'num': 4, 'pin_nums': ['M36', 'AB11', 'M37', 'AG6', 'AB6', 'AG7', 'N35', 'AB7', 'AH4', 'N36', 'AB8', 'AH5', 'P35', 'AB9', 'AH6', 'P36', 'AC10', 'AJ5', 'R34', 'AC5', 'AJ6', 'R35', 'AC6', 'AJ7', 'T34', 'AC8', 'AK5', 'T35', 'AC9', 'AK7', 'T36', 'AD10', 'AL5', 'U33', 'AD11', 'D37', 'U34', 'AD5', 'E37', 'U36', 'AD6', 'E38', 'V33', 'AD7', 'F36', 'V34', 'AD8', 'F37', 'V35', 'AD9', 'G36', 'V36', 'AE10', 'G37', 'W32', 'AE5', 'G40', 'W33', 'AG4', 'AE6', 'H35', 'Y32', 'AE7', 'H36', 'Y33', 'AE8', 'J35', 'AE9', 'J36', 'AF10', 'J37', 'AF11', 'K35', 'AF12', 'K37', 'AF5', 'K41', 'AF6', 'L35', 'AF7', 'L36', 'AF9', 'L37', 'AG10', 'L38', 'AA32']},{'label': 'uE', 'num': 5, 'pin_nums': ['AK12', 'AL14', 'AN14', 'H8', 'E9', 'L8', 'P8', 'T9', 'AK13', 'AP13', 'F5', 'H9', 'L9', 'P9', 'U11', 'AL29', 'AN13', 'AK14', 'AL30', 'AR26', 'F6', 'G9', 'J7', 'L7', 'M7', 'R6', 'P7', 'U8', 'AK15', 'T11', 'AM13', 'AV27', 'F7', 'J8', 'M8', 'R7', 'U9', 'AK27', 'AM14', 'D7', 'F9', 'K7', 'M9', 'R8', 'V10', 'AK28', 'AM28', 'E5', 'G7', 'K8', 'N8', 'R9', 'V11', 'AJ26', 'AK29', 'AM29', 'E7', 'G8', 'K9', 'N9', 'T10', 'V9', 'AJ30', 'AK30', 'E8']},{'label': 'uF', 'num': 6, 'pin_nums': ['AU38', 'M33', 'AF34', 'AV38', 'M34', 'AF35', 'AV39', 'N31', 'AF36', 'D39', 'N33', 'AG34', 'E32', 'N34', 'AG36', 'E33', 'P31', 'AH34', 'E34', 'P32', 'AH35', 'E35', 'P33', 'AH36', 'E36', 'R32', 'AJ34', 'F31', 'R33', 'AJ35', 'F32', 'T31', 'AJ36', 'F34', 'T32', 'AK34', 'F35', 'U31', 'AK35', 'G31', 'U32', 'AL34', 'G32', 'AL35', 'G33', 'AL36', 'G34', 'AL38', 'H31', 'AM34', 'H33', 'AM35', 'H34', 'AM36', 'H37', 'AN34', 'J31', 'AN35', 'J32', 'AN36', 'J33', 'AB32', 'AP35', 'K32', 'AB33', 'AP36', 'K33', 'AC33', 'AP37', 'K34', 'AD32', 'AR37', 'L31', 'AD33', 'AR38', 'L32', 'AE32', 'AT36', 'L34', 'AE33', 'AE35', 'AT37', 'M31', 'AE34', 'AU37', 'M32']},{'label': 'uG', 'num': 7, 'pin_nums': ['N11', 'AN33', 'P10', 'E6', 'AP31', 'F10', 'P11', 'AP32', 'F11', 'P12', 'AP33', 'F12', 'R10', 'AP39', 'F14', 'AR32', 'F15', 'AR33', 'G10', 'E15', 'AR34', 'G11', 'AR35', 'G12', 'AR36', 'G13', 'AT31', 'G14', 'AT32', 'H10', 'AT34', 'H11', 'AT35', 'H13', 'AF31', 'AU31', 'H14', 'AF32', 'AU32', 'H15', 'AG31', 'AU33', 'H7', 'AG32', 'AU34', 'J10', 'AG33', 'AU36', 'J11', 'AH31', 'AU40', 'J12', 'AH33', 'AV31', 'J13', 'AJ31', 'AV33', 'K10', 'AJ32', 'AV34', 'K12', 'AJ33', 'AV35', 'K13', 'AK32', 'AV36', 'K14', 'AK33', 'D12', 'L10', 'AL31', 'D13', 'L11', 'AL32', 'E10', 'L12', 'AM31', 'E12', 'M11', 'AM32', 'E13', 'M12', 'AM33', 'E14', 'N10', 'AN31']},{'label': 'uH', 'num': 8, 'pin_nums': ['AL6', 'B37', 'B38', 'AL7', 'AL8', 'B39', 'B41', 'AL9', 'AM6', 'B42', 'A30', 'AM7', 'C30', 'A31', 'AM8', 'C31', 'A32', 'C33', 'AM9', 'A34', 'AN4', 'C34', 'A35', 'AN5', 'C35', 'A36', 'AN6', 'C36', 'A37', 'AN8', 'C38', 'A39', 'AN9', 'C39', 'A40', 'AP5', 'C40', 'A41', 'AP6', 'C41', 'AG11', 'AP7', 'D31', 'AG12', 'AP8', 'D32', 'AG8', 'AR5', 'D33', 'AG9', 'AR7', 'D35', 'AH10', 'AR8', 'D36', 'AH11', 'AT5', 'D38', 'AH7', 'AT6', 'D40', 'AH8', 'AT7', 'D41', 'AH9', 'D42', 'AU6', 'AJ10', 'AV5', 'E42', 'AJ11', 'AV6', 'F33', 'AJ8', 'B31', 'J34', 'AK10', 'B32', 'AK11', 'B33', 'AK8', 'B34', 'AK9', 'B35', 'AL10', 'B36']},{'label': 'uI', 'num': 9, 'pin_nums': ['AW42', 'BA36', 'H27', 'AY39', 'BB33', 'K29', 'L30', 'AW34', 'AY30', 'AY40', 'BA37', 'BB34', 'J15', 'K30', 'M17', 'AW35', 'AY32', 'AY42', 'BA39', 'BB36', 'J16', 'L14', 'M26', 'AW36', 'AY33', 'BA30', 'BA40', 'BB37', 'J17', 'L15', 'M27', 'AT33', 'AW37', 'AY34', 'BA31', 'BA41', 'BB38', 'J30', 'L16', 'M28', 'AV37', 'AW38', 'AY35', 'BA32', 'BA42', 'BB39', 'K15', 'L17', 'AW31', 'AW40', 'AY37', 'BA34', 'BB31', 'BB41', 'K17', 'L27', 'AW32', 'AW41', 'AY38', 'BA35', 'BB32', 'E26', 'K28', 'L29', 'AW33']},{'label': 'uJ', 'num': 10, 'pin_nums': ['B24', 'C32', 'A25', 'B26', 'D20', 'A26', 'B27', 'D21', 'A27', 'B28', 'D22', 'A29', 'B29', 'D23', 'AU30', 'BA19', 'D25', 'AV26', 'BA20', 'D26', 'AV28', 'BA21', 'D27', 'AV29', 'BA22', 'D28', 'AV30', 'BA24', 'D29', 'AW20', 'BA25', 'D30', 'AW21', 'BA26', 'E24', 'AW22', 'BA27', 'E25', 'AW23', 'BA28', 'E27', 'AW25', 'BA29', 'E28', 'AW26', 'BB20', 'E29', 'AW27', 'BB21', 'E30', 'AW28', 'BB22', 'F30', 'AW30', 'BB23', 'G30', 'AY19', 'BB24', 'AY20', 'BB26', 'AY22', 'BB27', 'AY23', 'BB28', 'AY24', 'BB29', 'AY25', 'C20', 'AY27', 'C21', 'C23', 'AY28', 'AY29', 'C24', 'C25', 'AY31', 'A20', 'B21', 'C26', 'A21', 'A24', 'B22', 'C28', 'A22', 'B23', 'C29']},{'label': 'uK', 'num': 11, 'pin_nums': ['AV13', 'AV9', 'AM26', 'AP30', 'AL17', 'AM27', 'AP10', 'AP9', 'AT11', 'AT12', 'AU14', 'AU16', 'AV14', 'AW12', 'AN10', 'AP11', 'AR10', 'AT13', 'AL26', 'AU17', 'AV15', 'AW13', 'AL27', 'AN11', 'AP12', 'AR12', 'AT9', 'AU7', 'AV16', 'AW18', 'AN15', 'AK17', 'AM11', 'AP15', 'AR13', 'AU10', 'AU8', 'AV18', 'AW7', 'AL11', 'AM12', 'AN16', 'AP16', 'AR16', 'AU11', 'AU9', 'AV19', 'AM16', 'AN28', 'AL12', 'AP27', 'AR9', 'AU12', 'AV10', 'AV7', 'AL15', 'AM17', 'AN29', 'AP28', 'AT10', 'AL16', 'AU13', 'AV11', 'AV8', 'AN30']},{'label': 'uL', 'num': 12, 'pin_nums': ['AN19', 'B25', 'L20', 'AN20', 'L24', 'C22', 'AN24', 'E17', 'L25', 'AN25', 'L26', 'E18', 'AN26', 'F16', 'M18', 'AP17', 'F17', 'M19', 'AP18', 'F23', 'M24', 'AP25', 'N18', 'F27', 'AP26', 'F29', 'N19', 'AR14', 'G16', 'N20', 'AR15', 'G17', 'P20', 'AR17', 'G18', 'AR18', 'G27', 'AR19', 'G28', 'AR27', 'G29', 'AR28', 'H16', 'AR29', 'H18', 'AR30', 'H26', 'AT14', 'H28', 'AT15', 'H29', 'AT16', 'H30', 'AK18', 'AT17', 'J18', 'AK19', 'AT19', 'J25', 'AK24', 'AT23', 'J26', 'AK25', 'AT26', 'J27', 'AL19', 'AT27', 'J28', 'AL24', 'AT29', 'K18', 'AL25', 'AT30', 'K19', 'AM18', 'AU28', 'K24', 'AM19', 'AU29', 'K25', 'AM24', 'AW24', 'K27', 'AN18', 'AY21', 'L19']},{'label': 'uM', 'num': 13, 'pin_nums': ['F22', 'AR24', 'F24', 'N24', 'AR25', 'F25', 'AT20', 'F26', 'AT21', 'G19', 'AT22', 'G20', 'AT24', 'G21', 'AT25', 'G22', 'AU18', 'G23', 'AU19', 'G24', 'AU20', 'G26', 'AU21', 'H17', 'AJ21', 'AU22', 'H19', 'AJ22', 'AU23', 'H20', 'AK20', 'AU24', 'H21', 'AK22', 'AU26', 'H23', 'AK23', 'AU27', 'H24', 'AL20', 'AV17', 'H25', 'AL21', 'AV20', 'J20', 'AL22', 'AV21', 'J21', 'AM21', 'AV23', 'J22', 'AM22', 'AV24', 'J23', 'AM23', 'AV25', 'K20', 'AN21', 'D18', 'K22', 'AN23', 'D19', 'K23', 'AP19', 'E19', 'L21', 'AP20', 'E20', 'L22', 'AP21', 'E22', 'M21', 'AP22', 'E23', 'M22', 'AP23', 'F19', 'M23', 'AR20', 'F20', 'N21', 'N23', 'AR22', 'F21', 'N22', 'AR23']},{'label': 'uN', 'num': 14, 'pin_nums': ['AD4', 'V1', 'V3', 'AE1', 'AA2', 'AF1', 'V4', 'AF2', 'W1', 'AB2', 'AD3', 'AC1', 'AG2', 'Y1', 'AC2', 'T2', 'Y2', 'AD1', 'U1', 'U2']},{'label': 'uO', 'num': 15, 'pin_nums': ['K2', 'AJ2', 'P2', 'R2', 'L1', 'AK1', 'AK3', 'L2', 'M1', 'AK4', 'AL1', 'M3', 'AM1', 'M4', 'AJ1', 'AN2', 'AH2', 'AM2', 'N1', 'P1']},{'label': 'uP', 'num': 16, 'pin_nums': ['AT4', 'F1', 'F3', 'AU1', 'AV1', 'F4', 'AP2', 'AV2', 'G1', 'AR1', 'AW2', 'H1', 'AR2', 'D2', 'H2', 'AT1', 'E1', 'J2', 'AT3', 'E2']},{'label': 'uQ', 'num': 17, 'pin_nums': ['B5', 'B6', 'BB5', 'A3', 'C3', 'BA1', 'A4', 'A5', 'BA2', 'C4', 'BA5', 'AW4', 'AY4', 'BA6', 'B1', 'BB2', 'B2', 'BB3', 'A2', 'BB4']},{'label': 'uR', 'num': 18, 'pin_nums': ['BA8', 'AY9', 'BB10', 'B11', 'BA7', 'B12', 'BB11', 'BB8', 'B7', 'A10', 'A11', 'B8', 'BB9', 'BA11', 'C10', 'A8', 'A9', 'BA12', 'D10', 'AW9']},{'label': 'uS', 'num': 19, 'pin_nums': ['A14', 'BB16', 'B17', 'A15', 'B18', 'BB17', 'A16', 'BA13', 'C16', 'A17', 'BA14', 'D16', 'AW15', 'BA17', 'AY15', 'BA18', 'B13', 'BB14', 'B14', 'BB15']},{'label': 'uT', 'num': 20, 'pin_nums': ['AC3', 'AL4', 'AY6', 'AW10', 'AY13', 'C15', 'C9', 'G4', 'R3', 'AW16', 'AY14', 'AY7', 'C17', 'D15', 'AM3', 'H3', 'T3', 'AE3', 'AE4', 'AN3', 'AW3', 'AY16', 'AY8', 'C18', 'D3', 'J3', 'U3', 'AP3', 'AF3', 'AW5', 'AY17', 'C1', 'C2', 'D4', 'K3', 'W3', 'AL3', 'AA3', 'AG3', 'AR3', 'AY1', 'AY12', 'AY18', 'AY5', 'C11', 'C5', 'C14', 'D5', 'W4', 'AA5', 'C8', 'AH3', 'AU3', 'AY10', 'AY2', 'C12', 'C6', 'D9', 'G3', 'N3', 'P3', 'Y3', 'AB3', 'AJ3', 'AU4', 'AY11', 'AY3', 'C13', 'C7', 'E3', 'L3', 'N4', 'AB4', 'AV3']},{'label': 'uU', 'num': 21, 'pin_nums': ['V31', 'AA22', 'AL28', 'AH14', 'AB21', 'AH15', 'P15', 'AB22', 'AH16', 'R14', 'AC21', 'AH29', 'R15', 'AC22', 'AH30', 'R29', 'AF30', 'AJ15', 'R30', 'AG29', 'AJ16', 'T14', 'AA21', 'AG30', 'AJ28', 'T30']},{'label': 'uV', 'num': 22, 'pin_nums': ['T21', 'AG18', 'AC30', 'J9', 'D14', 'P16', 'T23', 'A19', 'W30', 'AG20', 'AD13', 'K11', 'D17', 'P19', 'T25', 'A23', 'Y13', 'AD15', 'AG22', 'D24', 'K16', 'P21', 'T27', 'A28', 'Y15', 'AD17', 'AG24', 'D34', 'K21', 'P22', 'T29', 'A33', 'Y17', 'AD19', 'AG26', 'D6', 'K26', 'P23', 'U12', 'A38', 'Y19', 'AD21', 'AG28', 'D8', 'K31', 'P24', 'U14', 'AA12', 'Y21', 'AD23', 'AH13', 'E11', 'K36', 'AG16', 'P29', 'U16', 'AA14', 'Y22', 'AD25', 'AH17', 'E16', 'K6', 'P30', 'U18', 'AA16', 'Y23', 'AD27', 'AH19', 'E21', 'L13', 'P34', 'U20', 'AA18', 'Y25', 'AD29', 'AH21', 'E31', 'L18', 'P4', 'U22', 'AA20', 'Y27', 'AD31', 'AH23', 'E4', 'L23', 'R11', 'U24', 'AA24', 'Y29', 'AE12', 'AH25', 'E41', 'L28', 'R12', 'U26', 'AA26', 'Y31', 'AE14', 'AH27', 'F18', 'L33', 'R13', 'U28', 'AA28', 'AE16', 'AJ12', 'F2', 'L4', 'R16', 'U30', 'J4', 'AA30', 'AE18', 'AJ18', 'F28', 'M10', 'R17', 'V13', 'AB13', 'AE20', 'AJ20', 'F38', 'M15', 'R18', 'V15', 'AB15', 'AE22', 'AJ24', 'F8', 'M2', 'R19', 'V17', 'AB17', 'AE24', 'B10', 'G15', 'M20', 'R20', 'V19', 'AB19', 'AE26', 'B15', 'G2', 'M25', 'R21', 'V21', 'AB23', 'AE28', 'B16', 'G25', 'M30', 'R22', 'V23', 'AB25', 'AE30', 'B19', 'G35', 'M35', 'R23', 'V25', 'AB27', 'AF13', 'B20', 'G5', 'M40', 'R24', 'V27', 'AB29', 'AF15', 'B3', 'H12', 'M5', 'R25', 'V29', 'AB31', 'AF17', 'B30', 'H22', 'N12', 'R26', 'W12', 'AC12', 'AF19', 'B4', 'H32', 'N17', 'R27', 'W14', 'AC14', 'AF21', 'B40', 'H4', 'N2', 'R28', 'W16', 'AC16', 'AF23', 'B9', 'H42', 'N27', 'R31', 'W18', 'AC18', 'AF25', 'C19', 'J19', 'N32', 'T13', 'W20', 'AC20', 'AF27', 'C27', 'J24', 'N37', 'T15', 'W22', 'AC24', 'AF29', 'C37', 'J29', 'N42', 'T17', 'W24', 'AC26', 'W28', 'AG14', 'C42', 'J39', 'N7', 'T19', 'W26', 'AC28', 'D11', 'P14']},{'label': 'uW', 'num': 23, 'pin_nums': ['AT38', 'V18', 'Y28', 'AB30', 'AE15', 'AG5', 'AL33', 'AT8', 'BB25', 'V2', 'AB40', 'Y30', 'AH12', 'AE17', 'AM10', 'AU15', 'BB30', 'V20', 'AB5', 'Y36', 'AE19', 'AH18', 'AM15', 'AU2', 'BB35', 'V22', 'AC11', 'Y4', 'AE2', 'AH20', 'AM20', 'AU25', 'BB40', 'V24', 'AC13', 'Y6', 'AE21', 'AH22', 'AM25', 'AU35', 'R41', 'V26', 'AC15', 'AE23', 'AH24', 'AM30', 'AU5', 'T12', 'V28', 'AC17', 'AE25', 'AH26', 'AM4', 'AV12', 'T16', 'V30', 'AC19', 'AH28', 'AE27', 'AM40', 'AV22', 'T18', 'V32', 'AC23', 'AE29', 'AH32', 'AM5', 'AV32', 'T20', 'V42', 'AC25', 'AE31', 'AH42', 'AN12', 'AV4', 'T22', 'W13', 'AC27', 'AE41', 'AJ13', 'AN17', 'AV42', 'T24', 'W15', 'AC29', 'AF14', 'AJ14', 'AN22', 'AW11', 'T26', 'W17', 'AC31', 'AF16', 'AJ17', 'AN27', 'AW14', 'T28', 'W19', 'AA13', 'AC32', 'AF18', 'AJ19', 'AN32', 'AW17', 'T33', 'W2', 'AA15', 'AC37', 'AF20', 'AJ23', 'AN37', 'AW19', 'T38', 'W21', 'AC4', 'AA17', 'AF22', 'AJ25', 'AN42', 'AW29', 'T8', 'W23', 'AA19', 'AC42', 'AF24', 'AJ27', 'AN7', 'AW39', 'U13', 'W25', 'AA23', 'AC7', 'AF26', 'AJ29', 'AP14', 'AW6', 'U15', 'W27', 'AA25', 'AD12', 'AF28', 'AJ39', 'AP24', 'AW8', 'U17', 'W29', 'AA27', 'AD14', 'AF33', 'AJ4', 'AP29', 'AY26', 'U19', 'W31', 'AA29', 'AD16', 'AF38', 'AJ9', 'AP34', 'AY36', 'U21', 'W34', 'AA31', 'AD18', 'AF4', 'AK16', 'AP4', 'AY41', 'U23', 'W39', 'AA33', 'AD2', 'AF8', 'AK2', 'AB28', 'AR11', 'BA10', 'U25', 'W9', 'AB10', 'AD20', 'AG13', 'AK21', 'AR21', 'BA15', 'U27', 'Y11', 'AB12', 'AD22', 'AG15', 'AK26', 'AR31', 'BA16', 'U29', 'Y12', 'AB14', 'AD24', 'AG17', 'AK31', 'AR4', 'BA23', 'U35', 'Y14', 'AB16', 'AD26', 'AG19', 'AK36', 'AR41', 'BA3', 'U4', 'Y16', 'AB18', 'AD28', 'AG21', 'AK6', 'AR6', 'BA33', 'U5', 'Y18', 'AB20', 'AD30', 'AG23', 'AL13', 'AT18', 'BA38', 'V12', 'Y20', 'AB24', 'AD34', 'AG25', 'AL18', 'AT2', 'BA4', 'AG35', 'BB19', 'V14', 'Y24', 'AB26', 'AE11', 'AG27', 'AL2', 'AT28', 'BA9', 'V16', 'Y26', 'AE13', 'AL23']}] }),
        Part(**{ 'name':'XC5VSX35T-FF665', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VSX35T-FF665'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VSX35T-FF665\n\nFPGA', 'pins':[
            Pin(num='B13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G24',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J25',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='M24',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA23',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA24',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P23',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='P8',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V22',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V23',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V25',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='V26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W23',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y23',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='IO_L13N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='IO_L15N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L14P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A9',name='IO_L4P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='IO_L13P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B11',name='IO_L15P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='IO_L17P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L16P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='IO_L16N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B9',name='IO_L6P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C10',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C11',name='IO_L19P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='IO_L17N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C8',name='IO_L6N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D10',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='IO_L19N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L18P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='IO_L7N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E5',name='IO_L18N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L7P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L5N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='IO_L5P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='F7',name='IO_L1P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F8',name='IO_L1N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F9',name='IO_L2P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L0N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G9',name='IO_L2N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L0P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L3P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='IO_L3N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AA7',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA8',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB23',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AB5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC20',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC26',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC7',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD13',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD14',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD15',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD16',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD18',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD20',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD24',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD26',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE13',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE15',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE16',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE17',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE18',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE20',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE21',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE22',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE24',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE26',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF13',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF14',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF15',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF17',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF18',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF19',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF20',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF22',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF24',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF25',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='D18',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='G21',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W16',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y15',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y16',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y17',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y20',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA20',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB11',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB14',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB15',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC11',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='L1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=7),
            Pin(num='U1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='W2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AC1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AE2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='B2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=8),
            Pin(num='E1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='G2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='Y2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AD3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AE3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='C3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='F3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='H3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='J3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=9),
            Pin(num='N3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='P4',name='MGTRREF_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=9),
            Pin(num='R3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='V3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=9),
            Pin(num='W3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='Y3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='F11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='H12',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J10',name='D_IN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J12',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='J20',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='HSWAPEN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='CS_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M20',name='RDWR_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N14',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N15',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P14',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P15',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R14',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R15',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T20',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U12',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U20',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V12',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V13',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W20',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='VBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='AVSS_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='AVDD_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W10',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y9',name='GND',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['H22', 'E25', 'G24', 'H23', 'J24', 'K26', 'L22', 'M25', 'B13', 'G10', 'M24', 'G25', 'H24', 'L23', 'M26', 'E26', 'J25', 'G11', 'G26', 'F13', 'G12', 'H25', 'J26', 'L24', 'H11', 'N21', 'F14', 'G14', 'H13', 'H26', 'K21', 'L25', 'F15', 'N22', 'G15', 'F17', 'E23', 'H18', 'H9', 'K22', 'G16', 'M21', 'N23', 'F18', 'G17', 'H19', 'J21', 'K23', 'F22', 'M22', 'N24', 'E14', 'G19', 'F23', 'H21', 'J22', 'K25', 'M23', 'N26', 'F25', 'G20', 'E22', 'F24', 'J23', 'G22']},{'label': 'uB', 'num': 2, 'pin_nums': ['T23', 'T24', 'K6', 'Y25', 'K7', 'T25', 'Y26', 'K8', 'T5', 'Y4', 'L5', 'T7', 'Y5', 'L6', 'T8', 'Y6', 'L7', 'U21', 'L8', 'U22', 'M6', 'U24', 'M7', 'U25', 'N6', 'U26', 'N7', 'U5', 'N8', 'U6', 'P21', 'U7', 'P23', 'V21', 'P24', 'V22', 'AA22', 'P25', 'V23', 'AA23', 'P26', 'V24', 'AA24', 'P6', 'V25', 'AA25', 'P7', 'V26', 'AB24', 'P8', 'V6', 'AB25', 'R21', 'V7', 'AB26', 'R22', 'W21', 'F5', 'R23', 'W22', 'G4', 'R24', 'W23', 'G5', 'R25', 'W24', 'G6', 'R26', 'W25', 'H4', 'R5', 'W26', 'H5', 'R6', 'W4', 'H6', 'R7', 'W5', 'J5', 'R8', 'W6', 'Y23', 'J6', 'T22', 'Y22', 'K5']},{'label': 'uC', 'num': 3, 'pin_nums': ['B19', 'D11', 'B20', 'D19', 'B21', 'D20', 'B22', 'D21', 'B23', 'D23', 'B24', 'D24', 'A10', 'B25', 'D25', 'B26', 'A12', 'D26', 'A13', 'B4', 'D5', 'A14', 'B5', 'D6', 'A15', 'B6', 'D7', 'A17', 'B7', 'D8', 'A18', 'B9', 'D9', 'A19', 'C10', 'E24', 'A20', 'C11', 'E5', 'A22', 'C12', 'E6', 'A23', 'C13', 'E7', 'A24', 'C14', 'E8', 'A25', 'C16', 'F21', 'A3', 'C17', 'F7', 'A4', 'C18', 'F8', 'A5', 'C19', 'F9', 'A7', 'C21', 'G7', 'A8', 'C22', 'G8', 'A9', 'C23', 'G9', 'B10', 'C24', 'H7', 'B11', 'C26', 'H8', 'B17', 'B12', 'C6', 'J8', 'B14', 'C7', 'B15', 'C8', 'B16', 'C9', 'D10']},{'label': 'uD', 'num': 4, 'pin_nums': ['AA8', 'AF18', 'AA9', 'AF19', 'AD4', 'AB22', 'AD5', 'AF20', 'AB23', 'AD6', 'AF22', 'AB5', 'AD7', 'AF23', 'AB6', 'AD8', 'AF24', 'AB7', 'AD9', 'AF25', 'AB9', 'AE10', 'AF3', 'AC10', 'AE11', 'AF4', 'AC20', 'AE12', 'AF5', 'AC21', 'AE13', 'AF7', 'AC22', 'AE15', 'AF8', 'AC23', 'AE16', 'AF9', 'AC24', 'AE17', 'V8', 'AC26', 'AE18', 'V9', 'AC6', 'AE20', 'W8', 'AC7', 'AE21', 'W9', 'AC8', 'AE22', 'Y7', 'AC9', 'AE23', 'Y8', 'AD10', 'AE24', 'AD11', 'AE25', 'AD13', 'AE26', 'AD14', 'AE5', 'AD15', 'AE6', 'AD16', 'AE7', 'AD18', 'AE8', 'AD19', 'AF10', 'AD20', 'AF12', 'AD21', 'AF13', 'AA5', 'AD23', 'AF14', 'AA6', 'AD24', 'AD26', 'AF15', 'AA7', 'AD25', 'AF17']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA16', 'F20', 'Y12', 'D16', 'E16', 'AA17', 'E17', 'G18', 'D17', 'Y13', 'AA18', 'D18', 'E18', 'G21', 'Y15', 'E15', 'AA10', 'AA19', 'E10', 'E20', 'W11', 'Y11', 'Y16', 'AA12', 'AD17', 'E11', 'E21', 'W14', 'Y17', 'AA13', 'D13', 'AA15', 'E12', 'F10', 'W16', 'Y18', 'AA14', 'D14', 'E13', 'F12', 'Y10', 'Y20', 'D15', 'F19']},{'label': 'uF', 'num': 6, 'pin_nums': ['AC16', 'AA20', 'AB17', 'AB10', 'AB19', 'AC17', 'AB11', 'AB20', 'AC18', 'AB12', 'AB21', 'AC19', 'AB13', 'AC11', 'AE14', 'AB14', 'AC12', 'Y21', 'AB15', 'AC13', 'AB16', 'AC14']},{'label': 'uG', 'num': 7, 'pin_nums': ['J2', 'P2', 'V2', 'K1', 'W2', 'R1', 'K3', 'R2', 'J1', 'K4', 'T1', 'L1', 'T3', 'M1', 'T4', 'H2', 'M2', 'U1', 'N2', 'V1']},{'label': 'uH', 'num': 8, 'pin_nums': ['AC1', 'D3', 'D4', 'AD1', 'AD2', 'E1', 'AA1', 'AE2', 'F1', 'AA2', 'B2', 'F2', 'AB1', 'C1', 'G2', 'AB3', 'C2', 'Y2', 'AB4', 'D1']},{'label': 'uI', 'num': 9, 'pin_nums': ['Y3', 'P3', 'AC3', 'F3', 'AC4', 'G3', 'P4', 'AD3', 'H3', 'P5', 'AE3', 'J3', 'R3', 'B3', 'L3', 'U3', 'C3', 'L4', 'U4', 'E3', 'M3', 'V3', 'AA3', 'E4', 'N3', 'W3']},{'label': 'uJ', 'num': 10, 'pin_nums': ['K20', 'R15', 'W20', 'F11', 'T20', 'L20', 'H12', 'M20', 'U12', 'J10', 'U20', 'N14', 'R14', 'J11', 'N15', 'V11', 'J12', 'P14', 'V12', 'J20', 'P15', 'V13', 'K11', 'W13']},{'label': 'uK', 'num': 11, 'pin_nums': ['L14', 'T19', 'W17', 'AC25', 'H10', 'L15', 'N5', 'T2', 'W18', 'AC5', 'H14', 'L16', 'N9', 'T21', 'W19', 'AD12', 'H15', 'L17', 'P10', 'T26', 'W7', 'AD22', 'H16', 'L18', 'P11', 'T6', 'Y14', 'AE19', 'H17', 'L19', 'P12', 'T9', 'Y19', 'AE4', 'H20', 'L2', 'P13', 'U10', 'Y24', 'AE9', 'J13', 'L21', 'P16', 'U11', 'Y9', 'AF11', 'J14', 'L26', 'P17', 'U13', 'AF16', 'J15', 'L9', 'P18', 'U14', 'AF2', 'J16', 'M10', 'P19', 'U15', 'AF21', 'J17', 'M11', 'P22', 'U16', 'AF26', 'J18', 'M12', 'P9', 'U17', 'AF6', 'J19', 'M13', 'R10', 'U18', 'B18', 'J4', 'M14', 'R11', 'U19', 'B8', 'J7', 'M15', 'R12', 'U2', 'C15', 'K10', 'M16', 'R13', 'U23', 'C20', 'K12', 'M17', 'R16', 'U8', 'A11', 'C25', 'K13', 'M18', 'R17', 'U9', 'A16', 'C4', 'K14', 'M19', 'R18', 'V10', 'A2', 'C5', 'K15', 'M4', 'R19', 'V14', 'A21', 'D12', 'K16', 'M8', 'R4', 'V15', 'A26', 'D2', 'K17', 'M9', 'R9', 'V16', 'A6', 'D22', 'K18', 'N10', 'G23', 'T10', 'V17', 'AA11', 'E19', 'K19', 'N11', 'T11', 'V18', 'AA21', 'E2', 'K2', 'N12', 'T12', 'V19', 'AA26', 'E9', 'K24', 'N13', 'T13', 'V20', 'AA4', 'F16', 'K9', 'N16', 'T14', 'V4', 'AB18', 'F26', 'L10', 'N17', 'T15', 'V5', 'AB2', 'F4', 'L11', 'N18', 'T16', 'W10', 'AB8', 'F6', 'L12', 'N19', 'N25', 'T17', 'W12', 'AC15', 'G13', 'L13', 'N20', 'T18', 'W15', 'AC2']}] }),
        Part(**{ 'name':'XC5VSX50T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VSX50T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VSX50T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=13),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=13),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=13),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=13),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=13),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=13),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=13),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=13),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=13),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=13),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=13),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=13),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=13),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=13),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=13),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=13),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=13),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=13),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=14),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=14),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=14),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=14),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=14),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=14),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=14),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=15),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=15),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=15),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=15),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=15),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=15),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=16)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L20', 'T33', 'N34', 'E33', 'H22', 'J32', 'K23', 'L21', 'P32', 'T34', 'E34', 'H23', 'J34', 'B33', 'F33', 'K32', 'L33', 'P34', 'U31', 'B32', 'F34', 'H32', 'K12', 'K33', 'L34', 'R30', 'U32', 'C32', 'G14', 'H33', 'K13', 'C33', 'K34', 'M32', 'R32', 'G22', 'U33', 'H34', 'K14', 'C34', 'G23', 'L14', 'M33', 'R33', 'V31', 'D13', 'G32', 'J12', 'K16', 'L15', 'N32', 'R34', 'E32', 'A33', 'D32', 'G33', 'J15', 'J22', 'K21', 'K22', 'L16', 'N33', 'T27', 'D34', 'H12']},{'label': 'uB', 'num': 2, 'pin_nums': ['AA34', 'E6', 'R7', 'AB29', 'R8', 'E7', 'AB32', 'F5', 'R9', 'AB33', 'T10', 'F6', 'AC32', 'G5', 'T11', 'AC33', 'G6', 'T6', 'AC34', 'G7', 'T7', 'AD32', 'T8', 'H5', 'AD34', 'H7', 'T9', 'AE32', 'J5', 'U10', 'AE33', 'J6', 'U7', 'AE34', 'J7', 'V32', 'AF33', 'K6', 'V33', 'AF34', 'K7', 'V34', 'AG32', 'L4', 'W28', 'AG33', 'L5', 'W32', 'AH32', 'L6', 'W34', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6', 'AK34', 'N7', 'AL33', 'N8', 'AL34', 'P10', 'AM32', 'P5', 'AM33', 'P6', 'AN32', 'P7', 'AN33', 'P9', 'AA32', 'AN34', 'R11', 'AA33', 'AP32', 'R6']},{'label': 'uC', 'num': 3, 'pin_nums': ['M29', 'M30', 'AE30', 'W26', 'AE31', 'M31', 'W27', 'AF29', 'N29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'P33', 'Y28', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'K29', 'V25', 'AC30', 'K31', 'V27', 'AD29', 'L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'W25', 'AD33', 'L32', 'W24', 'AE29']},{'label': 'uD', 'num': 4, 'pin_nums': ['AH5', 'Y9', 'L25', 'AH7', 'L26', 'AJ6', 'L28', 'AJ7', 'M25', 'AK6', 'M26', 'AK7', 'M27', 'E26', 'M28', 'E27', 'N24', 'E28', 'N25', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'J24', 'W10', 'AG7', 'J25', 'AD6', 'W11', 'AD7', 'J26', 'W6', 'AE6', 'J27', 'W7', 'AE7', 'J28', 'W8', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'L24', 'Y8']},{'label': 'uE', 'num': 5, 'pin_nums': ['AE16', 'AM19', 'AF15', 'H10', 'F13', 'K11', 'M8', 'AE17', 'AF16', 'B12', 'E11', 'F8', 'H11', 'K8', 'N10', 'A13', 'AE19', 'AF20', 'B13', 'E12', 'F9', 'H8', 'K9', 'N9', 'AD19', 'AE21', 'AF21', 'C12', 'E13', 'G10', 'H9', 'L10', 'AD20', 'AE22', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'D11', 'E10', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10']},{'label': 'uF', 'num': 6, 'pin_nums': ['AJ26', 'AJ27', 'AE26', 'AJ28', 'AE27', 'AE28', 'AJ29', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AH28', 'AD25', 'AH8', 'AD26', 'AH9', 'AD27', 'AJ10', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AE24']},{'label': 'uG', 'num': 7, 'pin_nums': ['F27', 'AN26', 'AK25', 'C26', 'G24', 'AL22']},{'label': 'uH', 'num': 8, 'pin_nums': ['AG17', 'E20', 'H19', 'K17', 'AH15', 'AE18', 'AG18', 'AH17', 'G15', 'H20', 'K18', 'AF18', 'AG20', 'AH18', 'G16', 'J14', 'K19', 'AF19', 'AG21', 'AH19', 'H13', 'J16', 'L18', 'AG13', 'AG22', 'AH20', 'H14', 'J17', 'L19', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20', 'AG16', 'AH14', 'D23', 'H18', 'J21']},{'label': 'uI', 'num': 9, 'pin_nums': ['AJ18', 'C16', 'B19', 'F17', 'AK15', 'AN16']},{'label': 'uJ', 'num': 10, 'pin_nums': ['N1', 'U2', 'N2', 'V2', 'P1', 'W1', 'AA1', 'P3', 'W2', 'AB1', 'P4', 'Y1', 'AB2', 'R1', 'M2', 'Y3', 'AC2', 'T1', 'Y4', 'T2']},{'label': 'uK', 'num': 11, 'pin_nums': ['AD2', 'J1', 'AH2', 'AJ2', 'AE1', 'K1', 'AE2', 'F2', 'K2', 'AF1', 'G1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4']},{'label': 'uL', 'num': 12, 'pin_nums': ['AL2', 'B3', 'B4', 'AL4', 'AL5', 'C1', 'AM1', 'D1', 'A2', 'AN3', 'D2', 'A3', 'AN4', 'D4', 'AK2', 'AP2', 'E2', 'AL1', 'AP3', 'E4']},{'label': 'uM', 'num': 13, 'pin_nums': ['AA3', 'AH3', 'C3', 'J3', 'T3', 'AA4', 'AJ3', 'AG4', 'J4', 'C4', 'U3', 'AB3', 'AJ4', 'D3', 'K3', 'V3', 'AC3', 'AK3', 'D5', 'L3', 'V4', 'AD3', 'AK5', 'E3', 'M3', 'V5', 'AE3', 'AL3', 'F3', 'N3', 'W3', 'AG3', 'AM3', 'F4', 'R3', 'G3', 'AM4', 'R4']},{'label': 'uN', 'num': 14, 'pin_nums': ['AB15', 'P15', 'AD23', 'M15', 'AC14', 'U17', 'AC15', 'M22', 'U18', 'AC22', 'M23', 'V17', 'AD14', 'N14', 'V18', 'AD15', 'N15', 'W17', 'AD21', 'N22', 'W18', 'AA22', 'AD22', 'N23']},{'label': 'uO', 'num': 15, 'pin_nums': ['P22', 'AC16', 'G34', 'P23', 'M17', 'T5', 'G4', 'AC18', 'P28', 'M18', 'U12', 'AC20', 'G9', 'M19', 'P8', 'U14', 'H16', 'AD13', 'M20', 'R10', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'R15', 'M4', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'R17', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'T20', 'AB17', 'F32', 'M12', 'P2', 'T21', 'G29', 'AB19', 'F7', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'M16', 'T4']},{'label': 'uP', 'num': 16, 'pin_nums': ['AA23', 'AF2', 'AN2', 'W21', 'AA27', 'AN21', 'AF22', 'W23', 'AA7', 'AF27', 'AN31', 'W33', 'AB12', 'AN7', 'AF32', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AP18', 'AG29', 'Y14', 'AB22', 'AG34', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AC11', 'AH4', 'U11', 'Y22', 'AN11', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AA11', 'AE15', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'AE25', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AA19', 'AE5', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'W19']}] }),
        Part(**{ 'name':'XC5VSX50T-FF665', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VSX50T-FF665'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VSX50T-FF665\n\nFPGA', 'pins':[
            Pin(num='B13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E22',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G24',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='J23',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J25',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L22',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='M24',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA23',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA24',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H6',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='L7',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P23',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='P8',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='R25',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V22',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V23',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V25',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='V26',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W23',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y23',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y25',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='IO_L13N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='IO_L15N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A17',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A22',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L14N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L14P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L12N_VRP_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='IO_L10P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='IO_L4N_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A9',name='IO_L4P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='IO_L13P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B11',name='IO_L15P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='IO_L17P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B15',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B19',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='B24',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L16P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='IO_L16N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L12P_VRN_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L10N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B9',name='IO_L6P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C10',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C11',name='IO_L19P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='IO_L17N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C16',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L9N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L9P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C8',name='IO_L6N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='IO_L8P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D10',name='IO_L11N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='IO_L19N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L18P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='IO_L7N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D8',name='IO_L8N_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='IO_L11P_CC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='E5',name='IO_L18N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L7P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L5N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='IO_L5P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F21',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='F7',name='IO_L1P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F8',name='IO_L1N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F9',name='IO_L2P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L0N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G8',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G9',name='IO_L2N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L0P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L3P_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='IO_L3N_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AA7',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA8',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB22',name='IO_L7N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AB23',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AB5',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC20',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AC21',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='IO_L7P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC23',name='IO_L6N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC24',name='IO_L6P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC26',name='IO_L0P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC7',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC9',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD13',name='IO_L19P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD14',name='IO_L19N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD15',name='IO_L16P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD16',name='IO_L15N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD18',name='IO_L13N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD19',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD20',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD21',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='IO_L5N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD24',name='IO_L1N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='IO_L1P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD26',name='IO_L0N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE13',name='IO_L18N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE15',name='IO_L16N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE16',name='IO_L15P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE17',name='IO_L14P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE18',name='IO_L13P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE20',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE21',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE22',name='IO_L5P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE23',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE24',name='VCCO_17',func=pin_types.PWRIN,unit=4),
            Pin(num='AE25',name='IO_L2P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE26',name='IO_L2N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AE5',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF12',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF13',name='IO_L18P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF14',name='IO_L17N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF15',name='IO_L17P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF17',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF18',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF19',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF20',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF22',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='IO_L4P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF24',name='IO_L3N_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF25',name='IO_L3P_17',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W9',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA12',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA14',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA15',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AA17',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD17',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='D13',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D15',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='D18',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E15',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='G21',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W14',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W16',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y12',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y13',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y15',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y16',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y17',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y18',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='Y20',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AA20',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB11',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB13',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AB14',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB15',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB19',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB20',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AB21',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC11',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC12',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC13',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC14',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC16',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AC19',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AE14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='J2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='K4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='L1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='R2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=7),
            Pin(num='T4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=7),
            Pin(num='U1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='V2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='W2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AB4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AC1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AD2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AE2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=8),
            Pin(num='B2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='C2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=8),
            Pin(num='D4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=8),
            Pin(num='E1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='G2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=8),
            Pin(num='Y2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=8),
            Pin(num='AA3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AC4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AD3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=9),
            Pin(num='AE3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='B3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='C3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='E4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=9),
            Pin(num='F3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=9),
            Pin(num='G3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=9),
            Pin(num='H3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='J3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='L4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=9),
            Pin(num='M3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=9),
            Pin(num='N3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='P4',name='MGTRREF_112',func=pin_types.PWRIN,unit=9),
            Pin(num='P5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=9),
            Pin(num='R3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='U4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=9),
            Pin(num='V3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=9),
            Pin(num='W3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=9),
            Pin(num='Y3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=9),
            Pin(num='F11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='H12',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J10',name='D_IN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='J12',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='J20',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='HSWAPEN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='CS_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M20',name='RDWR_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N14',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N15',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P14',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P15',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R14',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='R15',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T20',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U12',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U20',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V12',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V13',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W20',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='VBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='AVSS_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='AVDD_0',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='T9',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='U8',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W10',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='Y9',name='GND',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G26', 'J25', 'L23', 'H24', 'M26', 'F15', 'G15', 'F17', 'H11', 'H25', 'J26', 'L24', 'N21', 'G16', 'F18', 'H13', 'H26', 'K21', 'L25', 'G17', 'N22', 'F22', 'F14', 'G19', 'H18', 'H9', 'K22', 'F23', 'M21', 'N23', 'E14', 'B13', 'F24', 'G20', 'H19', 'E22', 'J21', 'K23', 'M22', 'E23', 'N24', 'F25', 'G22', 'H21', 'J22', 'K25', 'E25', 'M23', 'N26', 'G10', 'G24', 'H22', 'J23', 'K26', 'E26', 'G11', 'M24', 'F13', 'G12', 'G25', 'H23', 'J24', 'L22', 'M25', 'G14']},{'label': 'uB', 'num': 2, 'pin_nums': ['K7', 'T25', 'Y26', 'T5', 'K8', 'Y4', 'L5', 'T7', 'Y5', 'T8', 'L6', 'Y6', 'L7', 'U21', 'L8', 'U22', 'U24', 'M6', 'M7', 'U25', 'N6', 'U26', 'N7', 'U5', 'N8', 'U6', 'P21', 'U7', 'P23', 'V21', 'P24', 'V22', 'AA22', 'P25', 'V23', 'AA23', 'P26', 'V24', 'AA24', 'P6', 'V25', 'AA25', 'P7', 'V26', 'AB24', 'P8', 'V6', 'AB25', 'R21', 'V7', 'AB26', 'R22', 'W21', 'F5', 'R23', 'W22', 'G4', 'R24', 'W23', 'G5', 'R25', 'W24', 'G6', 'R26', 'W25', 'T24', 'H4', 'R5', 'W26', 'H5', 'R6', 'W4', 'H6', 'R7', 'W5', 'J5', 'R8', 'W6', 'J6', 'T22', 'Y22', 'K5', 'T23', 'Y23', 'K6', 'Y25']},{'label': 'uC', 'num': 3, 'pin_nums': ['B20', 'B21', 'D20', 'B22', 'D21', 'B23', 'D23', 'B24', 'D24', 'A10', 'B25', 'D25', 'A12', 'B26', 'D26', 'A13', 'B4', 'D5', 'A14', 'B5', 'D6', 'A15', 'B6', 'D7', 'A17', 'B7', 'D8', 'A18', 'B9', 'D9', 'A19', 'C10', 'E24', 'A20', 'C11', 'E5', 'A22', 'C12', 'E6', 'A23', 'C13', 'E7', 'A24', 'C14', 'E8', 'A25', 'C16', 'F21', 'A3', 'C17', 'F7', 'A4', 'C18', 'F8', 'A5', 'C19', 'F9', 'A7', 'C21', 'G7', 'A8', 'C22', 'G8', 'A9', 'C23', 'G9', 'B10', 'C24', 'H7', 'B11', 'C26', 'H8', 'B12', 'C6', 'J8', 'B14', 'C7', 'B15', 'C8', 'B16', 'C9', 'B17', 'D10', 'D19', 'B19', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['AB22', 'AF20', 'AD5', 'AB23', 'AF22', 'AD6', 'AB5', 'AD7', 'AF23', 'AB6', 'AF24', 'AD8', 'AB7', 'AD9', 'AF25', 'AB9', 'AF3', 'AE10', 'AD4', 'AC10', 'AE11', 'AF4', 'AC20', 'AE12', 'AF5', 'AC21', 'AE13', 'AF7', 'AC22', 'AE15', 'AF8', 'AC23', 'AE16', 'AF9', 'AC24', 'AE17', 'V8', 'AC26', 'AE18', 'V9', 'AC6', 'AE20', 'W8', 'AC7', 'AE21', 'W9', 'AC8', 'AE22', 'Y7', 'AC9', 'AE23', 'Y8', 'AD10', 'AE24', 'AD11', 'AE25', 'AD13', 'AE26', 'AD14', 'AE5', 'AD15', 'AE6', 'AD16', 'AE7', 'AD18', 'AE8', 'AD19', 'AF10', 'AD20', 'AF12', 'AD21', 'AF13', 'AA5', 'AD23', 'AF14', 'AA6', 'AD24', 'AF15', 'AA7', 'AD25', 'AF17', 'AA8', 'AD26', 'AF18', 'AA9', 'AF19']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA17', 'G18', 'E17', 'Y13', 'AA18', 'D18', 'E18', 'G21', 'Y15', 'AA10', 'AA19', 'E10', 'E20', 'W11', 'Y16', 'AA12', 'AD17', 'E11', 'E21', 'W14', 'Y17', 'AA13', 'D13', 'E12', 'F10', 'W16', 'Y18', 'AA14', 'D14', 'E13', 'F12', 'Y10', 'Y20', 'AA15', 'D15', 'D17', 'E15', 'F19', 'Y11', 'AA16', 'D16', 'E16', 'F20', 'Y12']},{'label': 'uF', 'num': 6, 'pin_nums': ['AB19', 'AC17', 'AB11', 'AC18', 'AB20', 'AB12', 'AB21', 'AC19', 'AB13', 'AC11', 'AE14', 'AB14', 'AC12', 'Y21', 'AB15', 'AC13', 'AB16', 'AC14', 'AA20', 'AB17', 'AC16', 'AB10']},{'label': 'uG', 'num': 7, 'pin_nums': ['K1', 'W2', 'K3', 'R2', 'K4', 'T1', 'L1', 'T3', 'M1', 'T4', 'H2', 'M2', 'U1', 'J1', 'N2', 'R1', 'V1', 'J2', 'P2', 'V2']},{'label': 'uH', 'num': 8, 'pin_nums': ['AD2', 'E1', 'AE2', 'F1', 'AA1', 'AD1', 'AA2', 'B2', 'F2', 'AB1', 'C1', 'G2', 'AB3', 'C2', 'Y2', 'AB4', 'D1', 'AC1', 'D3', 'D4']},{'label': 'uI', 'num': 9, 'pin_nums': ['P5', 'AD3', 'H3', 'AE3', 'R3', 'J3', 'B3', 'L3', 'U3', 'C3', 'L4', 'U4', 'G3', 'P4', 'E3', 'M3', 'V3', 'AA3', 'E4', 'N3', 'W3', 'AC3', 'F3', 'P3', 'Y3', 'AC4']},{'label': 'uJ', 'num': 10, 'pin_nums': ['T20', 'H12', 'U12', 'M20', 'J10', 'N14', 'U20', 'J11', 'N15', 'V11', 'J12', 'P14', 'V12', 'J20', 'F11', 'P15', 'V13', 'K11', 'R14', 'W13', 'K20', 'R15', 'W20', 'L20']},{'label': 'uK', 'num': 11, 'pin_nums': ['AC5', 'H14', 'L16', 'N9', 'T21', 'W19', 'AD12', 'L17', 'H15', 'T26', 'P10', 'W7', 'AD22', 'H16', 'L18', 'P11', 'T6', 'Y14', 'AE19', 'H17', 'L19', 'P12', 'T9', 'Y19', 'T2', 'AE4', 'H20', 'L2', 'P13', 'U10', 'Y24', 'AE9', 'J13', 'L21', 'P16', 'U11', 'Y9', 'AF11', 'J14', 'L26', 'P17', 'U13', 'AF16', 'L9', 'J15', 'P18', 'U14', 'AF2', 'J16', 'M10', 'P19', 'U15', 'AF21', 'J17', 'M11', 'P22', 'U16', 'AF26', 'J18', 'M12', 'P9', 'U17', 'AF6', 'J19', 'M13', 'R10', 'U18', 'B18', 'J4', 'M14', 'R11', 'U19', 'B8', 'J7', 'M15', 'R12', 'U2', 'C15', 'K10', 'M16', 'R13', 'U23', 'N5', 'C20', 'K12', 'M17', 'R16', 'U8', 'A11', 'C25', 'K13', 'M18', 'R17', 'U9', 'A16', 'C4', 'K14', 'M19', 'R18', 'V10', 'A2', 'C5', 'K15', 'M4', 'R19', 'V14', 'A21', 'D12', 'K16', 'M8', 'R4', 'V15', 'A26', 'D2', 'K17', 'M9', 'R9', 'V16', 'A6', 'D22', 'K18', 'N10', 'T10', 'V17', 'AA11', 'E19', 'K19', 'N11', 'T11', 'V18', 'AA21', 'E2', 'K2', 'N12', 'T12', 'V19', 'AA26', 'E9', 'K24', 'N13', 'T13', 'V20', 'AA4', 'F16', 'K9', 'N16', 'T14', 'V4', 'AB18', 'F26', 'L10', 'N17', 'T15', 'V5', 'AB2', 'F4', 'L11', 'N18', 'T16', 'W10', 'AB8', 'F6', 'L12', 'N19', 'T17', 'W12', 'AC15', 'G13', 'L13', 'N20', 'T18', 'W15', 'AC2', 'G23', 'L14', 'N25', 'T19', 'W17', 'AC25', 'H10', 'L15', 'W18']}] }),
        Part(**{ 'name':'XC5VSX95T-FF1136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VSX95T-FF1136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VSX95T-FF1136\n\nFPGA', 'pins':[
            Pin(num='A33',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B32',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C32',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C33',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C34',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D32',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='D34',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E33',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='E34',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='F34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G32',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G33',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H32',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H33',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H34',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J32',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='J34',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K32',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K33',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='K34',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L33',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L34',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M32',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='M33',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N32',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N33',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='N34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P32',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='P34',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='R32',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R33',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='R34',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='T33',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T34',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AA32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AA33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB29',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AB32',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD34',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE32',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF34',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH32',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH33',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK32',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK33',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK34',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL33',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL34',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM32',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM33',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN32',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN33',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN34',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AP32',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N5',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='N7',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W28',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='W32',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L11P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA30',name='IO_L11N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA31',name='IO_L9N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB30',name='IO_L10P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AB31',name='IO_L9P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC29',name='IO_L13N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AC30',name='IO_L10N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD29',name='IO_L15N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD30',name='IO_L13P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD31',name='IO_L12P_VRN_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AD33',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE29',name='IO_L15P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AE30',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AE31',name='IO_L12N_VRP_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF29',name='IO_L17P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF30',name='IO_L17N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AF31',name='IO_L14P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG30',name='IO_L19N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AG31',name='IO_L14N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH29',name='IO_L19P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH30',name='IO_L18N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AH31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='AJ30',name='IO_L18P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ31',name='IO_L16P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AK31',name='IO_L16N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L0P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='E31',name='IO_L3N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F29',name='IO_L0N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L1N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='F31',name='IO_L3P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L1P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L5N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L2P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L5P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L2N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L6P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L6N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K29',name='IO_L4N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L9P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L4P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L7P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='IO_L9N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='L32',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M29',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='M30',name='IO_L7N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='M31',name='IO_L11P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N29',name='IO_L8P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='N30',name='IO_L11N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P29',name='IO_L8N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P30',name='IO_L10N_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P31',name='IO_L10P_CC_15',func=pin_types.BIDIR,unit=3),
            Pin(num='P33',name='VCCO_15',func=pin_types.PWRIN,unit=3),
            Pin(num='R26',name='IO_L17P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R27',name='IO_L17N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R28',name='IO_L12P_VRN_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R29',name='IO_L12N_VRP_15',func=pin_types.BIDIR,unit=3),
            Pin(num='R31',name='IO_L13N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T25',name='IO_L19N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T26',name='IO_L18N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T28',name='IO_L15P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T29',name='IO_L15N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T30',name='IO_L14N_VREF_15',func=pin_types.BIDIR,unit=3),
            Pin(num='T31',name='IO_L13P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U25',name='IO_L19P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U26',name='IO_L18P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U27',name='IO_L16P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U28',name='IO_L16N_15',func=pin_types.BIDIR,unit=3),
            Pin(num='U30',name='IO_L14P_15',func=pin_types.BIDIR,unit=3),
            Pin(num='V24',name='IO_L0N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V25',name='IO_L2P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V27',name='IO_L5N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V28',name='IO_L5P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V29',name='IO_L7N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='V30',name='IO_L4P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W24',name='IO_L0P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W25',name='IO_L2N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W26',name='IO_L1N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W27',name='IO_L3N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W29',name='IO_L7P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W30',name='IO_L4N_VREF_17',func=pin_types.BIDIR,unit=3),
            Pin(num='W31',name='IO_L6P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y26',name='IO_L1P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y27',name='IO_L3P_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y28',name='IO_L8P_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y29',name='IO_L8N_CC_17',func=pin_types.BIDIR,unit=3),
            Pin(num='Y31',name='IO_L6N_17',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L2P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AA6',name='IO_L6P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB5',name='IO_L2N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L1P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L1N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AB9',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC4',name='IO_L0P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L0N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L3P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L5P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L5N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L7P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L3N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L7N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L9P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L10N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L9N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L10P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L12N_VRP_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='IO_L12P_VRN_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L14P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L16N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L16P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L18N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L18P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='E26',name='IO_L11P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E27',name='IO_L11N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E28',name='IO_L10P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='E30',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='IO_L7P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F26',name='IO_L7N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L10N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G25',name='IO_L5P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G26',name='IO_L5N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L8P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L9N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H24',name='IO_L6N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='IO_L6P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L8N_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L9P_CC_19',func=pin_types.BIDIR,unit=4),
            Pin(num='H31',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='J24',name='IO_L2P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J25',name='IO_L2N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_19',func=pin_types.PWRIN,unit=4),
            Pin(num='K24',name='IO_L0P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L14N_VREF_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L14P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L24',name='IO_L0N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L25',name='IO_L1P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L1N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L13N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L3P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L3N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L12N_VRP_19',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L15P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N24',name='IO_L17P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L18N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_19',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L15N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P24',name='IO_L17N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L18P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L16P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L16N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='R24',name='IO_L19P_19',func=pin_types.BIDIR,unit=4),
            Pin(num='T24',name='IO_L19N_19',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L17N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L19P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V7',name='IO_L11N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V8',name='IO_L17P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='V9',name='IO_L19N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W10',name='IO_L15P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W11',name='IO_L13N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W6',name='IO_L8P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W7',name='IO_L11P_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='W8',name='VCCO_18',func=pin_types.PWRIN,unit=4),
            Pin(num='W9',name='IO_L15N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y11',name='IO_L13P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y6',name='IO_L8N_CC_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y7',name='IO_L6N_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y8',name='IO_L4P_18',func=pin_types.BIDIR,unit=4),
            Pin(num='Y9',name='IO_L4N_VREF_18',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='IO_L8P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AD19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE12',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE22',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AE23',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF14',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF16',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF20',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AF23',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AG23',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AH21',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='AM19',name='VCCO_2',func=pin_types.PWRIN,unit=5),
            Pin(num='B12',name='IO_L8N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='IO_L11P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='IO_L6N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='C13',name='IO_L11N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='IO_L4N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D11',name='IO_L4P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='IO_L6P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E10',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='IO_L15N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L17P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='IO_L17N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='IO_L0N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='E9',name='IO_L0P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F10',name='IO_L2P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='IO_L15P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='IO_L19P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='IO_L1N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='F9',name='IO_L1P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G10',name='IO_L2N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G11',name='IO_L13P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='IO_L13N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G13',name='IO_L19N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='G8',name='IO_L3P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H10',name='IO_L7P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H11',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='IO_L3N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='H9',name='IO_L7N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J10',name='IO_L9P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J11',name='IO_L5N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='J8',name='VCCO_20',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='IO_L9N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K11',name='IO_L5P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K8',name='IO_L10P_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='IO_L10N_CC_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='IO_L12P_VRN_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L11',name='IO_L12N_VRP_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L8',name='IO_L14N_VREF_20',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='IO_L16N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L16P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='M8',name='IO_L14P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='IO_L18P_20',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L18N_20',func=pin_types.BIDIR,unit=5),
            Pin(num='AA10',name='IO_L1N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA24',name='IO_L2N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA25',name='IO_L0P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA26',name='IO_L0N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA28',name='IO_L5N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AA8',name='IO_L3P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AA9',name='IO_L3N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB10',name='IO_L1P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AB25',name='IO_L3P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB26',name='IO_L3N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB27',name='IO_L1P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB28',name='IO_L5P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AB8',name='IO_L5N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC10',name='IO_L7P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC24',name='IO_L17N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC25',name='IO_L17P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC27',name='IO_L1N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC28',name='IO_L4P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AC8',name='IO_L5P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AC9',name='IO_L7N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD10',name='IO_L10P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD11',name='IO_L10N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AD24',name='IO_L19P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD25',name='IO_L18N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD26',name='IO_L18P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD27',name='IO_L4N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AD9',name='IO_L9N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE11',name='IO_L16N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE24',name='IO_L19N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE26',name='IO_L16N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE27',name='IO_L16P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE28',name='IO_L7P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AE8',name='IO_L9P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AE9',name='IO_L12N_VRP_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF10',name='IO_L14N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF11',name='IO_L16P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF24',name='IO_L13P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF25',name='IO_L15P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF26',name='IO_L15N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF28',name='IO_L7N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AF7',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='IO_L12P_VRN_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AF9',name='IO_L14P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG10',name='IO_L19P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG11',name='IO_L19N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AG25',name='IO_L13N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG26',name='IO_L14N_VREF_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG27',name='IO_L14P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG28',name='IO_L6P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AG8',name='IO_L18P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH10',name='IO_L17N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH11',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AH25',name='IO_L12N_VRP_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH27',name='IO_L11P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH28',name='IO_L6N_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AH8',name='IO_L18N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AH9',name='IO_L17P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ10',name='IO_L15N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ11',name='IO_L11N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ25',name='IO_L12P_VRN_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ26',name='IO_L11N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ27',name='IO_L8N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ28',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ29',name='IO_L9N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ8',name='VCCO_22',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='IO_L15P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK11',name='IO_L11P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK26',name='IO_L8P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK27',name='IO_L10N_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK28',name='IO_L10P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK29',name='IO_L9P_CC_21',func=pin_types.BIDIR,unit=6),
            Pin(num='AK8',name='IO_L13P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AK9',name='IO_L13N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL10',name='IO_L8N_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL11',name='IO_L8P_CC_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AL32',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AM11',name='IO_L6N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM12',name='IO_L6P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM13',name='IO_L2N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AM29',name='VCCO_21',func=pin_types.PWRIN,unit=6),
            Pin(num='AN12',name='IO_L4N_VREF_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN13',name='IO_L2P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AN14',name='IO_L0P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP12',name='IO_L4P_22',func=pin_types.BIDIR,unit=6),
            Pin(num='AP14',name='IO_L0N_22',func=pin_types.BIDIR,unit=6),
            Pin(num='Y24',name='IO_L2P_21',func=pin_types.BIDIR,unit=6),
            Pin(num='A18',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A19',name='IO_L6P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A20',name='IO_L6N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A21',name='IO_L1N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A23',name='IO_L7P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A24',name='IO_L7N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A25',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A26',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A28',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A29',name='IO_L14P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A30',name='IO_L19P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='A31',name='IO_L16N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='AK25',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL22',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AL24',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL25',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL26',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL28',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL29',name='IO_L0P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L0N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AL31',name='IO_L1N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM18',name='IO_L17N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM20',name='IO_L13N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM21',name='IO_L13P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM22',name='IO_L16N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM23',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM25',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM26',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM27',name='IO_L4P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L7N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM30',name='IO_L2N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AM31',name='IO_L1P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN18',name='IO_L17P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN19',name='IO_L19P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN20',name='IO_L15P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN22',name='IO_L16P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN23',name='IO_L14P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN24',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN25',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN26',name='VCCO_25',func=pin_types.PWRIN,unit=7),
            Pin(num='AN27',name='IO_L6N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L7P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L5N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L2P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP19',name='IO_L19N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP20',name='IO_L15N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP21',name='IO_L18N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP22',name='IO_L18P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP24',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP25',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP26',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP27',name='IO_L6P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='IO_L5P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP30',name='IO_L3P_25',func=pin_types.BIDIR,unit=7),
            Pin(num='AP31',name='IO_L3N_25',func=pin_types.BIDIR,unit=7),
            Pin(num='B18',name='IO_L4P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B20',name='IO_L0N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B21',name='IO_L1P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B22',name='IO_L3N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B23',name='IO_L5N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B25',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B26',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B30',name='IO_L19N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='B31',name='IO_L16P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C18',name='IO_L2N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C19',name='IO_L2P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C20',name='IO_L0P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C22',name='IO_L3P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='IO_L5P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C24',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C26',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='C27',name='IO_L13N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C28',name='IO_L15P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C29',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=7),
            Pin(num='C30',name='IO_L17P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D25',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D26',name='IO_L13P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D27',name='IO_L15N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D29',name='IO_L17N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D30',name='IO_L18N_23',func=pin_types.BIDIR,unit=7),
            Pin(num='D31',name='IO_L18P_23',func=pin_types.BIDIR,unit=7),
            Pin(num='F27',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='G24',name='VCCO_23',func=pin_types.PWRIN,unit=7),
            Pin(num='AE18',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF18',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AF19',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG16',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG17',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG21',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AG22',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH12',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH17',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH19',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AH22',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL12',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='VCCO_3',func=pin_types.PWRIN,unit=8),
            Pin(num='G15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=8),
            Pin(num='G16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H13',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H14',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H15',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J14',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J16',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K17',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=8),
            Pin(num='A14',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A15',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A16',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AH23',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AH24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ12',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ14',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ15',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ16',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ17',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ18',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ19',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ20',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ21',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ22',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AJ24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK12',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK13',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK14',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK15',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AK16',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK17',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK18',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK19',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK21',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK22',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AK24',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL13',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL14',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL15',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL16',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL18',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL19',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL20',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL21',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM15',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM16',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM17',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN15',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN16',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN17',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP15',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP16',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP17',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='B15',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B16',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B17',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='B19',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C14',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C15',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='C16',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='C17',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D14',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D15',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D16',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D17',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D19',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D20',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D21',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D22',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='D24',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E14',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E16',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E17',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E21',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E22',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E23',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E24',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F14',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F15',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='F18',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F21',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F23',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F24',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G21',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=10),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=10),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=10),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=10),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=10),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=10),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=11),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=11),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=11),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A3',name='MGTRXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL4',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN4',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP3',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='B3',name='MGTTXN0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='B4',name='MGTTXP0_120',func=pin_types.BIDIR,unit=12),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='D4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=12),
            Pin(num='E4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=12),
            Pin(num='A6',name='MGTRXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A7',name='MGTRXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A8',name='MGTRXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A9',name='MGTRXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AL7',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AM7',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN10',name='MGTTXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN5',name='MGTTXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN6',name='MGTTXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AN9',name='MGTTXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP6',name='MGTRXP0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP7',name='MGTRXN0_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP8',name='MGTRXN1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='AP9',name='MGTRXP1_126',func=pin_types.BIDIR,unit=13),
            Pin(num='B10',name='MGTTXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B5',name='MGTTXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B6',name='MGTTXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B9',name='MGTTXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='C8',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D8',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA4',name='MGTAVCC_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AD3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AG4',name='MGTAVCC_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=14),
            Pin(num='AJ4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AK5',name='MGTAVCC_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AL8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM10',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=14),
            Pin(num='AM5',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM6',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=14),
            Pin(num='AM9',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=14),
            Pin(num='C10',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C4',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='C5',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C6',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='C9',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=14),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D5',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='D7',name='MGTAVCC_124',func=pin_types.PWRIN,unit=14),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=14),
            Pin(num='F3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='F4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=14),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='J4',name='MGTAVCC_116',func=pin_types.PWRIN,unit=14),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=14),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=14),
            Pin(num='M3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='R4',name='MGTAVCC_112',func=pin_types.PWRIN,unit=14),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=14),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=14),
            Pin(num='V5',name='MGTAVTTRXC',func=pin_types.PWRIN,unit=14),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=14),
            Pin(num='AA22',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='AB15',name='TCK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC14',name='TMS_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC15',name='TDI_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AC22',name='M1_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD14',name='TDO_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD15',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD21',name='M0_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD22',name='M2_0',func=pin_types.BIDIR,unit=15),
            Pin(num='AD23',name='VCCO_0',func=pin_types.PWRIN,unit=15),
            Pin(num='M15',name='DONE_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M22',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='M23',name='HSWAPEN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N14',name='INIT_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N15',name='CCLK_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N22',name='CS_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='N23',name='RDWR_B_0',func=pin_types.BIDIR,unit=15),
            Pin(num='P15',name='D_IN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=15),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=15),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L23',name='VBATT_0',func=pin_types.PWRIN,unit=16),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M21',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=16),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=16),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='V23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=16),
            Pin(num='Y23',name='VCCAUX',func=pin_types.PWRIN,unit=16),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AF32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AM34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN31',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AN8',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP28',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='AP33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='T32',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W33',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y25',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=17),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=17)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['F33', 'L33', 'U31', 'P34', 'B33', 'F34', 'H32', 'K12', 'K33', 'L34', 'R30', 'U32', 'G14', 'K13', 'H33', 'C33', 'K34', 'M32', 'R32', 'G22', 'U33', 'H23', 'H34', 'K14', 'C34', 'G23', 'K32', 'L14', 'M33', 'R33', 'V31', 'G32', 'D13', 'J12', 'K16', 'L15', 'N32', 'R34', 'D32', 'B32', 'G33', 'J15', 'K21', 'L16', 'N33', 'T27', 'D34', 'E32', 'H12', 'J22', 'K22', 'C32', 'L20', 'N34', 'T33', 'E33', 'A33', 'H22', 'J32', 'K23', 'L21', 'P32', 'T34', 'E34', 'J34']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB32', 'F5', 'R9', 'AB33', 'T10', 'F6', 'AC32', 'G5', 'T11', 'AC33', 'T6', 'G6', 'AC34', 'G7', 'T7', 'AD32', 'H5', 'T8', 'AD34', 'H7', 'T9', 'AE32', 'U10', 'J5', 'AE33', 'J6', 'U7', 'AE34', 'J7', 'V32', 'AF33', 'K6', 'V33', 'AF34', 'K7', 'V34', 'AG32', 'L4', 'W28', 'AG33', 'L5', 'W32', 'AH32', 'L6', 'W34', 'AH33', 'M5', 'Y32', 'AH34', 'M6', 'Y33', 'AJ32', 'M7', 'Y34', 'AJ34', 'M9', 'AK32', 'N5', 'AK33', 'N6', 'AK34', 'N7', 'AL33', 'N8', 'AL34', 'P10', 'AM32', 'P5', 'AM33', 'P6', 'AN32', 'P7', 'AN33', 'P9', 'AA32', 'AN34', 'R11', 'AA33', 'AP32', 'R6', 'AA34', 'E6', 'R7', 'AB29', 'E7', 'R8']},{'label': 'uC', 'num': 3, 'pin_nums': ['M31', 'N29', 'AF29', 'W29', 'AF30', 'N30', 'W30', 'AF31', 'P29', 'W31', 'AG30', 'P30', 'Y26', 'AG31', 'P31', 'Y27', 'AH29', 'P33', 'Y28', 'AH30', 'R26', 'Y29', 'AH31', 'R27', 'Y31', 'AJ30', 'R28', 'AJ31', 'R29', 'AK31', 'R31', 'E29', 'T25', 'E31', 'T26', 'F29', 'T28', 'F30', 'T29', 'F31', 'T30', 'G30', 'T31', 'G31', 'U25', 'AA29', 'H29', 'U26', 'AA30', 'H30', 'U27', 'AA31', 'J29', 'U28', 'AB30', 'J30', 'U30', 'AB31', 'J31', 'V24', 'AC29', 'K29', 'V25', 'AC30', 'K31', 'V27', 'AD29', 'L29', 'V28', 'AD30', 'L30', 'V29', 'AD31', 'L31', 'V30', 'AD33', 'L32', 'W24', 'AE29', 'M29', 'W25', 'W27', 'AE30', 'M30', 'W26', 'AE31']},{'label': 'uD', 'num': 4, 'pin_nums': ['AJ6', 'L28', 'AJ7', 'M25', 'AK6', 'M26', 'AK7', 'M27', 'E26', 'M28', 'E27', 'N24', 'E28', 'N25', 'E30', 'N27', 'F25', 'N28', 'AA5', 'F26', 'P24', 'AA6', 'F28', 'P25', 'AB5', 'G25', 'P26', 'AB6', 'G26', 'P27', 'AB7', 'G27', 'R24', 'AB9', 'G28', 'T24', 'AC4', 'H24', 'U8', 'AC5', 'H25', 'V10', 'AC6', 'H27', 'V7', 'AC7', 'H28', 'V8', 'AD4', 'H31', 'V9', 'AD5', 'J24', 'W10', 'AD6', 'J25', 'W11', 'AD7', 'J26', 'W6', 'AE6', 'J27', 'W7', 'AE7', 'J28', 'W8', 'AF5', 'K24', 'W9', 'AF6', 'K26', 'Y11', 'AG5', 'K27', 'Y6', 'AG6', 'K28', 'Y7', 'AH7', 'AG7', 'L24', 'Y8', 'AH5', 'L25', 'Y9', 'L26']},{'label': 'uE', 'num': 5, 'pin_nums': ['A13', 'AE19', 'B13', 'AF20', 'F9', 'H8', 'K9', 'N9', 'AD19', 'AE21', 'AF21', 'C12', 'E13', 'G10', 'H9', 'L10', 'AD20', 'AE22', 'AF23', 'C13', 'E8', 'G11', 'J10', 'L11', 'AE12', 'AE23', 'AG12', 'D10', 'E9', 'G12', 'J11', 'L8', 'AE13', 'AF13', 'AG23', 'D11', 'F10', 'G13', 'J8', 'L9', 'AE14', 'AF14', 'AH21', 'D12', 'F11', 'G8', 'J9', 'M10', 'AE16', 'AF15', 'AM19', 'E10', 'E12', 'F13', 'H10', 'K11', 'M8', 'AE17', 'AF16', 'B12', 'E11', 'F8', 'H11', 'K8', 'N10']},{'label': 'uF', 'num': 6, 'pin_nums': ['AJ28', 'AJ29', 'AE28', 'AA10', 'AE8', 'AJ8', 'AA24', 'AE9', 'AJ9', 'AA25', 'AF10', 'AK11', 'AA26', 'AF11', 'AK26', 'AA28', 'AF24', 'AK27', 'AA8', 'AF25', 'AK28', 'AA9', 'AF26', 'AK29', 'AB10', 'AF28', 'AK8', 'AB25', 'AF7', 'AK9', 'AB26', 'AF8', 'AL10', 'AB27', 'AF9', 'AL11', 'AB28', 'AG10', 'AL32', 'AB8', 'AG11', 'AM11', 'AC10', 'AG25', 'AM12', 'AC24', 'AG26', 'AM13', 'AC25', 'AG27', 'AM29', 'AC27', 'AG28', 'AN12', 'AC28', 'AG8', 'AN13', 'AC8', 'AH10', 'AN14', 'AC9', 'AH11', 'AP12', 'AD10', 'AH25', 'AP14', 'AD11', 'AH27', 'Y24', 'AD24', 'AH28', 'AD25', 'AH8', 'AD26', 'AH9', 'AD27', 'AJ10', 'AD9', 'AJ11', 'AE11', 'AJ25', 'AE24', 'AJ26', 'AE26', 'AJ27', 'AE27']},{'label': 'uG', 'num': 7, 'pin_nums': ['A28', 'AN27', 'C25', 'AN28', 'A29', 'C26', 'A30', 'AN29', 'C27', 'AN30', 'A31', 'C28', 'AK25', 'AP19', 'C29', 'AL22', 'AP20', 'C30', 'AL24', 'AP21', 'D25', 'AL25', 'AP22', 'D26', 'AL26', 'AP24', 'D27', 'AL28', 'AP25', 'D29', 'AL29', 'AP26', 'D30', 'AL30', 'AP27', 'D31', 'AL31', 'AP29', 'F27', 'AM18', 'AP30', 'G24', 'AM20', 'AP31', 'AM21', 'B18', 'AM22', 'B20', 'AN26', 'AM23', 'B21', 'AM25', 'B22', 'AM26', 'B23', 'AM27', 'B25', 'AM28', 'B26', 'AM30', 'B27', 'AM31', 'B28', 'A18', 'AN18', 'B30', 'A19', 'AN19', 'B31', 'A20', 'C18', 'AN20', 'A21', 'AN22', 'C19', 'A23', 'AN23', 'C20', 'A24', 'AN24', 'C22', 'A25', 'AN25', 'C23', 'A26', 'C24']},{'label': 'uH', 'num': 8, 'pin_nums': ['AF18', 'AG20', 'J14', 'AH18', 'G16', 'K19', 'AF19', 'AG21', 'AH19', 'H13', 'J16', 'L18', 'AG13', 'AG22', 'AH20', 'H14', 'L19', 'J17', 'AG14', 'AH12', 'AH22', 'H15', 'J19', 'AG15', 'AH13', 'AL12', 'H17', 'J20', 'AG16', 'AH14', 'D23', 'H18', 'J21', 'AG17', 'AH15', 'E20', 'H19', 'K17', 'AE18', 'AG18', 'AH17', 'G15', 'H20', 'K18']},{'label': 'uI', 'num': 9, 'pin_nums': ['AJ12', 'AM15', 'E22', 'AM16', 'AJ14', 'E23', 'AJ15', 'AM17', 'E24', 'AN15', 'AJ16', 'F14', 'AJ17', 'AN16', 'F15', 'AJ18', 'AN17', 'F16', 'AJ19', 'AP15', 'F17', 'AJ20', 'AP16', 'F18', 'AJ21', 'AP17', 'F19', 'AJ22', 'B15', 'F20', 'AJ24', 'B16', 'F21', 'AK12', 'B17', 'F23', 'AK13', 'B19', 'F24', 'AK14', 'C14', 'G17', 'AK15', 'C15', 'G18', 'AK16', 'C16', 'G20', 'AK17', 'C17', 'G21', 'AK18', 'D14', 'AK19', 'D15', 'AK21', 'D16', 'AK22', 'D17', 'AK23', 'D19', 'AK24', 'D20', 'AL13', 'D21', 'AL14', 'D22', 'AL15', 'D24', 'AL16', 'E14', 'AL23', 'A14', 'AL18', 'E16', 'A15', 'AL19', 'E17', 'A16', 'AL20', 'E18', 'AH23', 'AL21', 'E19', 'AH24', 'E21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['V2', 'W1', 'P1', 'W2', 'AA1', 'P3', 'AB1', 'P4', 'Y1', 'Y3', 'AB2', 'R1', 'AC2', 'T1', 'Y4', 'T2', 'M2', 'N1', 'U2', 'N2']},{'label': 'uK', 'num': 11, 'pin_nums': ['AE2', 'K2', 'F2', 'AF1', 'G1', 'L2', 'AF3', 'G2', 'AF4', 'H1', 'AG1', 'H3', 'AH1', 'H4', 'AD2', 'AH2', 'J1', 'AE1', 'AJ2', 'K1']},{'label': 'uL', 'num': 12, 'pin_nums': ['AL5', 'C1', 'D1', 'AM1', 'A2', 'AN3', 'D2', 'A3', 'D4', 'AN4', 'AK2', 'AP2', 'E2', 'AL1', 'AP3', 'E4', 'AL2', 'B3', 'AL4', 'B4']},{'label': 'uM', 'num': 13, 'pin_nums': ['B9', 'C8', 'A8', 'AP6', 'AN9', 'D8', 'A9', 'AP7', 'AL7', 'AP8', 'AM7', 'AP9', 'AN10', 'B10', 'B5', 'AN5', 'A6', 'AN6', 'B6', 'A7']},{'label': 'uN', 'num': 14, 'pin_nums': ['AE3', 'AM9', 'AL3', 'U3', 'J4', 'AG3', 'AL8', 'C10', 'D5', 'K3', 'V3', 'AG4', 'AM10', 'C3', 'D7', 'L3', 'V4', 'AA3', 'AH3', 'AM3', 'C4', 'E3', 'M3', 'V5', 'AA4', 'AJ3', 'AM4', 'C5', 'F3', 'N3', 'W3', 'AB3', 'AJ4', 'AM5', 'C6', 'F4', 'R3', 'AC3', 'AK3', 'AM6', 'C7', 'D3', 'G3', 'R4', 'AD3', 'AK5', 'AM8', 'C9', 'J3', 'T3']},{'label': 'uO', 'num': 15, 'pin_nums': ['AC15', 'U18', 'M22', 'M23', 'V17', 'AC22', 'AD14', 'N14', 'V18', 'AD15', 'N15', 'W17', 'N22', 'W18', 'AD21', 'AA22', 'AD22', 'N23', 'P15', 'AB15', 'AD23', 'AC14', 'U17', 'M15']},{'label': 'uP', 'num': 16, 'pin_nums': ['G4', 'P28', 'U12', 'G9', 'AC20', 'M19', 'P8', 'U14', 'AD13', 'H16', 'M20', 'R10', 'U16', 'AD17', 'H2', 'M21', 'R12', 'U20', 'B1', 'H21', 'M24', 'R13', 'U22', 'B11', 'H26', 'M34', 'R14', 'U24', 'B14', 'H6', 'M4', 'R15', 'V11', 'B2', 'J13', 'N11', 'R16', 'V13', 'B24', 'J18', 'N12', 'R17', 'V15', 'B29', 'J2', 'N13', 'R18', 'V19', 'B34', 'J23', 'N16', 'R19', 'V21', 'B7', 'J33', 'N17', 'R2', 'V23', 'B8', 'K10', 'N18', 'R20', 'W12', 'C11', 'K15', 'N19', 'R21', 'W14', 'A11', 'C2', 'K20', 'N20', 'R22', 'W16', 'A12', 'C21', 'K25', 'N21', 'R23', 'W20', 'A17', 'C31', 'K30', 'N26', 'R25', 'W22', 'A22', 'D18', 'K4', 'N31', 'R5', 'Y13', 'A27', 'D28', 'K5', 'N4', 'T12', 'Y15', 'A32', 'D33', 'L12', 'P11', 'T13', 'Y17', 'AA12', 'D6', 'L13', 'P12', 'T14', 'Y19', 'AA14', 'D9', 'L17', 'P13', 'T15', 'Y21', 'AA16', 'E15', 'L22', 'P14', 'T16', 'Y23', 'AA18', 'E25', 'L23', 'P16', 'T17', 'AA20', 'E5', 'L27', 'P17', 'T18', 'AB11', 'F12', 'L7', 'P18', 'T19', 'AB13', 'F22', 'M11', 'P19', 'T20', 'AB17', 'F32', 'M12', 'P2', 'T21', 'AB19', 'F7', 'M13', 'P20', 'T22', 'AB21', 'G19', 'M14', 'P21', 'T23', 'AC12', 'G29', 'M16', 'M18', 'P22', 'T4', 'AC16', 'G34', 'M17', 'P23', 'T5', 'AC18']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AN21', 'AA7', 'AN31', 'AF27', 'AF22', 'W33', 'AB12', 'AF32', 'AN7', 'W4', 'AB14', 'AG19', 'AN8', 'W5', 'AB16', 'AG2', 'AP11', 'Y10', 'AB18', 'AG24', 'AP13', 'Y12', 'AB20', 'AG29', 'AP18', 'Y14', 'AB22', 'AG34', 'AP23', 'Y16', 'AB24', 'AG9', 'AP28', 'Y18', 'AB34', 'AH16', 'AP33', 'Y2', 'AB4', 'AH26', 'T32', 'Y20', 'AC11', 'AH4', 'U11', 'Y22', 'AC13', 'AH6', 'U13', 'Y25', 'AC17', 'AJ13', 'U15', 'Y30', 'AC19', 'AJ23', 'U19', 'Y5', 'AC21', 'AJ33', 'U21', 'AC26', 'AJ5', 'U23', 'AC31', 'AK10', 'U29', 'AD12', 'AK20', 'U34', 'AD16', 'AK30', 'U6', 'AD18', 'AK4', 'U9', 'AD28', 'AL17', 'V12', 'AD8', 'AL27', 'V14', 'AE10', 'AL6', 'V16', 'AE15', 'AA11', 'AL9', 'V20', 'AA13', 'AE20', 'AM14', 'V22', 'AA15', 'AE25', 'AM2', 'V26', 'AA17', 'AE4', 'AM24', 'V6', 'AA19', 'AE5', 'AM34', 'W13', 'AA2', 'AF12', 'AN1', 'W15', 'AA21', 'AF17', 'AN11', 'W19', 'W23', 'AA23', 'AF2', 'AN2', 'W21', 'AA27']}] }),
        Part(**{ 'name':'XC5VTX150T-FF1156', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VTX150T-FF1156'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VTX150T-FF1156\n\nFPGA', 'pins':[
            Pin(num='AA26',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA28',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA29',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB25',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB27',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB28',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB29',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AB30',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AC27',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC28',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC29',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC30',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD27',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD29',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD30',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AE27',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AE28',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AE29',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AF27',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AF28',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AF29',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AG28',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AH29',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K16',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V25',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V27',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W24',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W27',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W29',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y27',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y28',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y29',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD21',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD22',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD24',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE21',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE22',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE24',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF18',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF20',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF25',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF26',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG20',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG21',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG22',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG23',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG24',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AG25',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG26',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG27',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH19',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH20',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH21',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AH22',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH23',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH24',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH25',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH27',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH28',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ19',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ20',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ21',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ22',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ24',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ25',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ26',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ27',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK19',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK24',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK26',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='E11',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F10',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F11',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F8',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='F9',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G10',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G11',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G12',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G13',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G14',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='G15',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='G8',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H10',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H11',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='H12',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='H9',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J10',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J11',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J12',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='J8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='J9',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K12',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='K9',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='L9',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA8',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AA9',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB16',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AB18',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AB19',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AB8',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AC14',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AC15',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AC16',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AC17',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AC19',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AD13',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AD14',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AD15',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AD16',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AD17',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AD19',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AE13',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AE14',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AE16',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AE17',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AE18',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AE19',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AF14',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AF15',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AF16',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M5',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N10',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='N8',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='N9',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P10',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P7',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='P9',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R7',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R8',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='R9',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='T10',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='T7',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='T8',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='T9',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U10',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='U8',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V10',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V7',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W10',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='W8',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='W9',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AB5',name='IO_L6P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AB6',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AB7',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AC12',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AC5',name='IO_L6N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AC6',name='VCCO_26',func=pin_types.PWRIN,unit=4),
            Pin(num='AC7',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AC8',name='IO_L4P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L18P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AD12',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L2P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L2N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='IO_L0P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='VCCO_26',func=pin_types.PWRIN,unit=4),
            Pin(num='AE11',name='IO_L16P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AE12',name='IO_L18N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L1P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L0N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L5P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AE9',name='IO_L7P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AF10',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='IO_L16N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AF6',name='IO_L1N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='VCCO_26',func=pin_types.PWRIN,unit=4),
            Pin(num='AF8',name='IO_L5N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L7N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AG11',name='IO_L19N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L3P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L3N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AG8',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AH10',name='IO_L19P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AH11',name='VCCO_26',func=pin_types.PWRIN,unit=4),
            Pin(num='AH12',name='IO_L13N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AH8',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AH9',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ10',name='IO_L14P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ11',name='IO_L15P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ12',name='IO_L13P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ7',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ9',name='IO_L17P_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AK11',name='IO_L15N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='AK9',name='IO_L17N_26',func=pin_types.BIDIR,unit=4),
            Pin(num='F28',name='IO_L0P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='G27',name='IO_L2P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='G28',name='IO_L0N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H27',name='IO_L2N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H28',name='IO_L6P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H29',name='IO_L6N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J26',name='IO_L4P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J27',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J28',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='J29',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K26',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K27',name='IO_L13N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K28',name='IO_L13P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K29',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L26',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L28',name='IO_L15N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L29',name='IO_L15P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L30',name='IO_L17N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M25',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M26',name='IO_L14P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M27',name='IO_L19P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M28',name='IO_L19N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M29',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='M30',name='IO_L17P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N25',name='IO_L3P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N26',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='N27',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N28',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N29',name='IO_L18N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P25',name='IO_L1P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P26',name='IO_L3N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P27',name='IO_L5N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P29',name='IO_L18P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R26',name='IO_L1N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R27',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R28',name='IO_L5P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R29',name='IO_L16N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T27',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='T28',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T29',name='IO_L16P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='U27',name='IO_L7N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='U28',name='IO_L7P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='V28',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='V29',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='A18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='B17',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='B18',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='C17',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=5),
            Pin(num='C18',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='D17',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E17',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E19',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='E24',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F15',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F16',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F17',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='F18',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='F19',name='IO_L4P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F20',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F21',name='IO_L2P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F23',name='IO_L6N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F24',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F25',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='F26',name='IO_L13N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='G16',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G17',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G18',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='G20',name='IO_L3N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='G21',name='IO_L2N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='G22',name='IO_L1P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='G23',name='IO_L6P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='G24',name='VCCO_27',func=pin_types.PWRIN,unit=5),
            Pin(num='G25',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='G26',name='IO_L13P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='H17',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='H18',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='H19',name='IO_L3P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='H20',name='IO_L5N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='H21',name='VCCO_27',func=pin_types.PWRIN,unit=5),
            Pin(num='H22',name='IO_L1N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='H23',name='IO_L0N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='H24',name='IO_L0P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='H25',name='IO_L15N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='J17',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='J18',name='VCCO_3',func=pin_types.PWRIN,unit=5),
            Pin(num='J19',name='IO_L7N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='J20',name='IO_L5P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='J21',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='J22',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=5),
            Pin(num='J24',name='IO_L17N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='J25',name='IO_L15P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='K18',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='K19',name='IO_L7P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='K21',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='K22',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=5),
            Pin(num='K23',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=5),
            Pin(num='K24',name='IO_L17P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='K25',name='VCCO_27',func=pin_types.PWRIN,unit=5),
            Pin(num='L19',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=5),
            Pin(num='L20',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='L21',name='IO_L16P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='L22',name='VCCO_27',func=pin_types.PWRIN,unit=5),
            Pin(num='L23',name='IO_L14P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='L24',name='IO_L19P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='L25',name='IO_L19N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='M20',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=5),
            Pin(num='M21',name='IO_L16N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='M22',name='IO_L18N_27',func=pin_types.BIDIR,unit=5),
            Pin(num='N22',name='IO_L18P_27',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AF17',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AG12',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AG13',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AG14',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AG15',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AG16',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AG17',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AG18',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AH13',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AH14',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AH15',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AH17',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AH18',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ14',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ15',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ16',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ17',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AJ18',name='VCCO_4',func=pin_types.PWRIN,unit=6),
            Pin(num='AK16',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AK17',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AK18',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=6),
            Pin(num='AL18',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='M33',name='MGTTXP0_111',func=pin_types.BIDIR,unit=7),
            Pin(num='N1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='N33',name='MGTTXN0_111',func=pin_types.BIDIR,unit=7),
            Pin(num='N34',name='MGTRXP0_111',func=pin_types.BIDIR,unit=7),
            Pin(num='P1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=7),
            Pin(num='P31',name='MGTREFCLKP_111',func=pin_types.BIDIR,unit=7),
            Pin(num='P32',name='MGTREFCLKN_111',func=pin_types.BIDIR,unit=7),
            Pin(num='P34',name='MGTRXN0_111',func=pin_types.BIDIR,unit=7),
            Pin(num='P4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=7),
            Pin(num='R1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='R34',name='MGTRXN1_111',func=pin_types.BIDIR,unit=7),
            Pin(num='T1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='T2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='T33',name='MGTTXN1_111',func=pin_types.BIDIR,unit=7),
            Pin(num='T34',name='MGTRXP1_111',func=pin_types.BIDIR,unit=7),
            Pin(num='U2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=7),
            Pin(num='U33',name='MGTTXP1_111',func=pin_types.BIDIR,unit=7),
            Pin(num='AA1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=8),
            Pin(num='AA34',name='MGTRXN1_113',func=pin_types.BIDIR,unit=8),
            Pin(num='AB1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=8),
            Pin(num='AB2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=8),
            Pin(num='AB33',name='MGTTXN1_113',func=pin_types.BIDIR,unit=8),
            Pin(num='AB34',name='MGTRXP1_113',func=pin_types.BIDIR,unit=8),
            Pin(num='AC2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=8),
            Pin(num='AC33',name='MGTTXP1_113',func=pin_types.BIDIR,unit=8),
            Pin(num='V2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=8),
            Pin(num='V33',name='MGTTXP0_113',func=pin_types.BIDIR,unit=8),
            Pin(num='W1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=8),
            Pin(num='W2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=8),
            Pin(num='W33',name='MGTTXN0_113',func=pin_types.BIDIR,unit=8),
            Pin(num='W34',name='MGTRXP0_113',func=pin_types.BIDIR,unit=8),
            Pin(num='Y1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=8),
            Pin(num='Y3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=8),
            Pin(num='Y31',name='MGTREFCLKP_113',func=pin_types.BIDIR,unit=8),
            Pin(num='Y32',name='MGTREFCLKN_113',func=pin_types.BIDIR,unit=8),
            Pin(num='Y34',name='MGTRXN0_113',func=pin_types.BIDIR,unit=8),
            Pin(num='Y4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=8),
            Pin(num='F2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=9),
            Pin(num='F33',name='MGTTXP0_115',func=pin_types.BIDIR,unit=9),
            Pin(num='G1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=9),
            Pin(num='G2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=9),
            Pin(num='G33',name='MGTTXN0_115',func=pin_types.BIDIR,unit=9),
            Pin(num='G34',name='MGTRXP0_115',func=pin_types.BIDIR,unit=9),
            Pin(num='H1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=9),
            Pin(num='H3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=9),
            Pin(num='H31',name='MGTREFCLKP_115',func=pin_types.BIDIR,unit=9),
            Pin(num='H32',name='MGTREFCLKN_115',func=pin_types.BIDIR,unit=9),
            Pin(num='H34',name='MGTRXN0_115',func=pin_types.BIDIR,unit=9),
            Pin(num='H4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=9),
            Pin(num='J1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=9),
            Pin(num='J34',name='MGTRXN1_115',func=pin_types.BIDIR,unit=9),
            Pin(num='K1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=9),
            Pin(num='K2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=9),
            Pin(num='K33',name='MGTTXN1_115',func=pin_types.BIDIR,unit=9),
            Pin(num='K34',name='MGTRXP1_115',func=pin_types.BIDIR,unit=9),
            Pin(num='L2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=9),
            Pin(num='L33',name='MGTTXP1_115',func=pin_types.BIDIR,unit=9),
            Pin(num='AD2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AD33',name='MGTTXP0_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AE1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AE2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AE33',name='MGTTXN0_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AE34',name='MGTRXP0_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AF1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AF3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AF31',name='MGTREFCLKP_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AF32',name='MGTREFCLKN_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AF34',name='MGTRXN0_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AF4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AG1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AG34',name='MGTRXN1_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AH1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AH2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AH33',name='MGTTXN1_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AH34',name='MGTRXP1_117',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=10),
            Pin(num='AJ33',name='MGTTXP1_117',func=pin_types.BIDIR,unit=10),
            Pin(num='A1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=11),
            Pin(num='A2',name='MGTRXP0_120',func=pin_types.BIDIR,unit=11),
            Pin(num='A33',name='MGTRXP0_119',func=pin_types.BIDIR,unit=11),
            Pin(num='A34',name='MGTRXN0_119',func=pin_types.BIDIR,unit=11),
            Pin(num='B2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=11),
            Pin(num='B3',name='MGTTXP0_120',func=pin_types.BIDIR,unit=11),
            Pin(num='B32',name='MGTTXP0_119',func=pin_types.BIDIR,unit=11),
            Pin(num='B33',name='MGTTXN0_119',func=pin_types.BIDIR,unit=11),
            Pin(num='C1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=11),
            Pin(num='C34',name='MGTRXN1_119',func=pin_types.BIDIR,unit=11),
            Pin(num='D1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=11),
            Pin(num='D2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=11),
            Pin(num='D33',name='MGTTXN1_119',func=pin_types.BIDIR,unit=11),
            Pin(num='D34',name='MGTRXP1_119',func=pin_types.BIDIR,unit=11),
            Pin(num='E2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=11),
            Pin(num='E31',name='MGTREFCLKN_119',func=pin_types.BIDIR,unit=11),
            Pin(num='E33',name='MGTTXP1_119',func=pin_types.BIDIR,unit=11),
            Pin(num='E4',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=11),
            Pin(num='F31',name='MGTREFCLKP_119',func=pin_types.BIDIR,unit=11),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=11),
            Pin(num='AK2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AK30',name='MGTREFCLKP_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AK33',name='MGTTXP0_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AK5',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AL30',name='MGTREFCLKN_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AL33',name='MGTTXN0_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AL34',name='MGTRXP0_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AL5',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AM34',name='MGTRXN0_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AN2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN3',name='MGTTXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AN32',name='MGTTXP1_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AN33',name='MGTTXN1_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AP1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP2',name='MGTRXP1_122',func=pin_types.BIDIR,unit=12),
            Pin(num='AP33',name='MGTRXP1_121',func=pin_types.BIDIR,unit=12),
            Pin(num='AP34',name='MGTRXN1_121',func=pin_types.BIDIR,unit=12),
            Pin(num='A27',name='MGTRXP0_123',func=pin_types.BIDIR,unit=13),
            Pin(num='A28',name='MGTRXN0_123',func=pin_types.BIDIR,unit=13),
            Pin(num='A29',name='MGTRXN1_123',func=pin_types.BIDIR,unit=13),
            Pin(num='A30',name='MGTRXP1_123',func=pin_types.BIDIR,unit=13),
            Pin(num='A5',name='MGTRXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A6',name='MGTRXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A7',name='MGTRXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='A8',name='MGTRXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B26',name='MGTTXP0_123',func=pin_types.BIDIR,unit=13),
            Pin(num='B27',name='MGTTXN0_123',func=pin_types.BIDIR,unit=13),
            Pin(num='B30',name='MGTTXN1_123',func=pin_types.BIDIR,unit=13),
            Pin(num='B31',name='MGTTXP1_123',func=pin_types.BIDIR,unit=13),
            Pin(num='B4',name='MGTTXP1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B5',name='MGTTXN1_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B8',name='MGTTXN0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='B9',name='MGTTXP0_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D27',name='MGTREFCLKP_123',func=pin_types.BIDIR,unit=13),
            Pin(num='D28',name='MGTREFCLKN_123',func=pin_types.BIDIR,unit=13),
            Pin(num='D7',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=13),
            Pin(num='D8',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=13),
            Pin(num='AL28',name='MGTREFCLKP_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AL7',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AM28',name='MGTREFCLKN_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AM7',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AN26',name='MGTTXP1_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AN27',name='MGTTXN1_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AN30',name='MGTTXN0_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AN31',name='MGTTXP0_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AN4',name='MGTTXP0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AN5',name='MGTTXN0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AN8',name='MGTTXN1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AN9',name='MGTTXP1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AP27',name='MGTRXP1_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AP28',name='MGTRXN1_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AP29',name='MGTRXN0_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AP30',name='MGTRXP0_125',func=pin_types.BIDIR,unit=14),
            Pin(num='AP5',name='MGTRXP0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AP6',name='MGTRXN0_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AP7',name='MGTRXN1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='AP8',name='MGTRXP1_126',func=pin_types.BIDIR,unit=14),
            Pin(num='A11',name='MGTRXP1_128',func=pin_types.BIDIR,unit=15),
            Pin(num='A12',name='MGTRXN1_128',func=pin_types.BIDIR,unit=15),
            Pin(num='A13',name='MGTRXN0_128',func=pin_types.BIDIR,unit=15),
            Pin(num='A14',name='MGTRXP0_128',func=pin_types.BIDIR,unit=15),
            Pin(num='A21',name='MGTRXP0_127',func=pin_types.BIDIR,unit=15),
            Pin(num='A22',name='MGTRXN0_127',func=pin_types.BIDIR,unit=15),
            Pin(num='A23',name='MGTRXN1_127',func=pin_types.BIDIR,unit=15),
            Pin(num='A24',name='MGTRXP1_127',func=pin_types.BIDIR,unit=15),
            Pin(num='B10',name='MGTTXP1_128',func=pin_types.BIDIR,unit=15),
            Pin(num='B11',name='MGTTXN1_128',func=pin_types.BIDIR,unit=15),
            Pin(num='B14',name='MGTTXN0_128',func=pin_types.BIDIR,unit=15),
            Pin(num='B15',name='MGTTXP0_128',func=pin_types.BIDIR,unit=15),
            Pin(num='B20',name='MGTTXP0_127',func=pin_types.BIDIR,unit=15),
            Pin(num='B21',name='MGTTXN0_127',func=pin_types.BIDIR,unit=15),
            Pin(num='B24',name='MGTTXN1_127',func=pin_types.BIDIR,unit=15),
            Pin(num='B25',name='MGTTXP1_127',func=pin_types.BIDIR,unit=15),
            Pin(num='D13',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=15),
            Pin(num='D14',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=15),
            Pin(num='D21',name='MGTREFCLKP_127',func=pin_types.BIDIR,unit=15),
            Pin(num='D22',name='MGTREFCLKN_127',func=pin_types.BIDIR,unit=15),
            Pin(num='AL13',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AL22',name='MGTREFCLKP_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AM13',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AM22',name='MGTREFCLKN_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AN10',name='MGTTXP0_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AN11',name='MGTTXN0_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AN14',name='MGTTXN1_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AN15',name='MGTTXP1_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AN20',name='MGTTXP1_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AN21',name='MGTTXN1_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AN24',name='MGTTXN0_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AN25',name='MGTTXP0_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AP11',name='MGTRXP0_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AP12',name='MGTRXN0_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AP13',name='MGTRXN1_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AP14',name='MGTRXP1_130',func=pin_types.BIDIR,unit=16),
            Pin(num='AP21',name='MGTRXP1_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AP22',name='MGTRXN1_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AP23',name='MGTRXN0_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AP24',name='MGTRXP0_129',func=pin_types.BIDIR,unit=16),
            Pin(num='AA3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=17),
            Pin(num='AA32',name='MGTAVCC_113',func=pin_types.PWRIN,unit=17),
            Pin(num='AB3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=17),
            Pin(num='AB32',name='MGTAVCCPLL_113',func=pin_types.PWRIN,unit=17),
            Pin(num='AC3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=17),
            Pin(num='AC32',name='MGTAVTTTX_113',func=pin_types.PWRIN,unit=17),
            Pin(num='AE3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=17),
            Pin(num='AE32',name='MGTAVTTRX_117',func=pin_types.PWRIN,unit=17),
            Pin(num='AG3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=17),
            Pin(num='AG32',name='MGTAVCC_117',func=pin_types.PWRIN,unit=17),
            Pin(num='AH3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=17),
            Pin(num='AH32',name='MGTAVCCPLL_117',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=17),
            Pin(num='AJ32',name='MGTAVTTTX_117',func=pin_types.PWRIN,unit=17),
            Pin(num='AL3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=17),
            Pin(num='AL31',name='MGTAVCC_121',func=pin_types.PWRIN,unit=17),
            Pin(num='AL32',name='MGTAVTTRX_121',func=pin_types.PWRIN,unit=17),
            Pin(num='AL4',name='MGTAVCC_122',func=pin_types.PWRIN,unit=17),
            Pin(num='AM10',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=17),
            Pin(num='AM12',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=17),
            Pin(num='AM14',name='MGTAVCC_130',func=pin_types.PWRIN,unit=17),
            Pin(num='AM15',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=17),
            Pin(num='AM20',name='MGTAVCCPLL_129',func=pin_types.PWRIN,unit=17),
            Pin(num='AM21',name='MGTAVCC_129',func=pin_types.PWRIN,unit=17),
            Pin(num='AM23',name='MGTAVTTRX_129',func=pin_types.PWRIN,unit=17),
            Pin(num='AM25',name='MGTAVTTTX_125',func=pin_types.PWRIN,unit=17),
            Pin(num='AM26',name='MGTAVCCPLL_125',func=pin_types.PWRIN,unit=17),
            Pin(num='AM27',name='MGTAVCC_125',func=pin_types.PWRIN,unit=17),
            Pin(num='AM29',name='MGTAVTTRX_125',func=pin_types.PWRIN,unit=17),
            Pin(num='AM3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=17),
            Pin(num='AM31',name='MGTAVCCPLL_121',func=pin_types.PWRIN,unit=17),
            Pin(num='AM32',name='MGTAVTTTX_121',func=pin_types.PWRIN,unit=17),
            Pin(num='AM4',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=17),
            Pin(num='AM6',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=17),
            Pin(num='AM8',name='MGTAVCC_126',func=pin_types.PWRIN,unit=17),
            Pin(num='AM9',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=17),
            Pin(num='AP16',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=17),
            Pin(num='AP19',name='MGTAVTTTX_129',func=pin_types.PWRIN,unit=17),
            Pin(num='C11',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=17),
            Pin(num='C12',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=17),
            Pin(num='C14',name='MGTAVCC_128',func=pin_types.PWRIN,unit=17),
            Pin(num='C15',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=17),
            Pin(num='C20',name='MGTAVTTRX_127',func=pin_types.PWRIN,unit=17),
            Pin(num='C21',name='MGTAVCC_127',func=pin_types.PWRIN,unit=17),
            Pin(num='C23',name='MGTAVCCPLL_127',func=pin_types.PWRIN,unit=17),
            Pin(num='C24',name='MGTAVTTTX_127',func=pin_types.PWRIN,unit=17),
            Pin(num='C26',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=17),
            Pin(num='C27',name='MGTAVCC_123',func=pin_types.PWRIN,unit=17),
            Pin(num='C29',name='MGTAVCCPLL_123',func=pin_types.PWRIN,unit=17),
            Pin(num='C3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=17),
            Pin(num='C30',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=17),
            Pin(num='C32',name='MGTAVTTRX_119',func=pin_types.PWRIN,unit=17),
            Pin(num='C5',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=17),
            Pin(num='C6',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=17),
            Pin(num='C8',name='MGTAVCC_124',func=pin_types.PWRIN,unit=17),
            Pin(num='C9',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=17),
            Pin(num='D3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=17),
            Pin(num='D31',name='MGTAVCC_119',func=pin_types.PWRIN,unit=17),
            Pin(num='D32',name='MGTAVCCPLL_119',func=pin_types.PWRIN,unit=17),
            Pin(num='D4',name='MGTAVCC_120',func=pin_types.PWRIN,unit=17),
            Pin(num='E3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=17),
            Pin(num='E32',name='MGTAVTTTX_119',func=pin_types.PWRIN,unit=17),
            Pin(num='G3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=17),
            Pin(num='G32',name='MGTAVTTRX_115',func=pin_types.PWRIN,unit=17),
            Pin(num='J3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=17),
            Pin(num='J32',name='MGTAVCC_115',func=pin_types.PWRIN,unit=17),
            Pin(num='K3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=17),
            Pin(num='K32',name='MGTAVCCPLL_115',func=pin_types.PWRIN,unit=17),
            Pin(num='L3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=17),
            Pin(num='L32',name='MGTAVTTTX_115',func=pin_types.PWRIN,unit=17),
            Pin(num='N3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=17),
            Pin(num='N32',name='MGTAVTTRX_111',func=pin_types.PWRIN,unit=17),
            Pin(num='R3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=17),
            Pin(num='R32',name='MGTAVCC_111',func=pin_types.PWRIN,unit=17),
            Pin(num='T3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=17),
            Pin(num='T32',name='MGTAVCCPLL_111',func=pin_types.PWRIN,unit=17),
            Pin(num='U3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=17),
            Pin(num='U31',name='MGTAVTTRXC_L',func=pin_types.PWRIN,unit=17),
            Pin(num='U32',name='MGTAVTTTX_111',func=pin_types.PWRIN,unit=17),
            Pin(num='U4',name='MGTAVTTRXC_R',func=pin_types.PWRIN,unit=17),
            Pin(num='V31',name='MGTRREF_111',func=pin_types.PWRIN,unit=17),
            Pin(num='V4',name='MGTRREF_112',func=pin_types.PWRIN,unit=17),
            Pin(num='W3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=17),
            Pin(num='W32',name='MGTAVTTRX_113',func=pin_types.PWRIN,unit=17),
            Pin(num='AA25',name='CS_B_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AB10',name='TCK_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AB20',name='M0_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AC10',name='TMS_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AC20',name='M2_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AC22',name='VCCO_0',func=pin_types.PWRIN,unit=18),
            Pin(num='AC23',name='RSVD_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AC24',name='RSVD_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AC9',name='TDI_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AD10',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AD20',name='M1_0',func=pin_types.BIDIR,unit=18),
            Pin(num='AD9',name='TDO_0',func=pin_types.BIDIR,unit=18),
            Pin(num='K11',name='D_IN_0',func=pin_types.BIDIR,unit=18),
            Pin(num='L10',name='INIT_B_0',func=pin_types.BIDIR,unit=18),
            Pin(num='L11',name='DONE_0',func=pin_types.BIDIR,unit=18),
            Pin(num='M10',name='CCLK_0',func=pin_types.BIDIR,unit=18),
            Pin(num='M19',name='VCCO_0',func=pin_types.PWRIN,unit=18),
            Pin(num='T25',name='RDWR_B_0',func=pin_types.BIDIR,unit=18),
            Pin(num='T26',name='HSWAPEN_0',func=pin_types.BIDIR,unit=18),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=18),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=18),
            Pin(num='U26',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=18),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=18),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=18),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=18),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=18),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='AA12',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA22',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AB11',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AB21',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C33',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E13',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E23',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E28',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F22',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F27',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F3',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F32',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F34',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G29',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G31',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='H2',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='H26',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='H30',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=19),
            Pin(num='M23',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='N12',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='N24',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='P21',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='P23',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='P24',name='VBATT_0',func=pin_types.PWRIN,unit=19),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='R24',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='T11',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='T17',name='AVSS_0',func=pin_types.PWRIN,unit=19),
            Pin(num='T18',name='AVDD_0',func=pin_types.PWRIN,unit=19),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='T23',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='U24',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='V11',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='Y11',name='VCCAUX',func=pin_types.PWRIN,unit=19),
            Pin(num='Y13',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='Y21',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=19),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AA7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AB31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AB4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AD8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AE30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AF2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AF30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AF33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AF5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AG9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AH6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AJ8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AK8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AL9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AM5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='AP9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='H33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L27',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U29',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V3',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V34',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='V6',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W11',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W28',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W31',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y2',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y22',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y30',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y33',name='GND',func=pin_types.PWRIN,unit=20),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=20)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AB28', 'L12', 'AB29', 'AG28', 'M13', 'AD29', 'N17', 'W27', 'AB30', 'U25', 'W29', 'AH29', 'L13', 'AC25', 'AD30', 'M15', 'AB25', 'AE26', 'AC26', 'H15', 'L14', 'M16', 'V24', 'Y24', 'AE27', 'AF29', 'AC27', 'J15', 'L15', 'M12', 'M17', 'AE28', 'N16', 'V25', 'Y25', 'AC28', 'W26', 'Y29', 'AE29', 'J16', 'L16', 'M18', 'AA29', 'AC29', 'V27', 'Y26', 'AA28', 'AA26', 'AC30', 'AF27', 'K15', 'L18', 'N13', 'W24', 'Y27', 'AB26', 'AD25', 'AF28', 'K16', 'M11', 'N15', 'AD27', 'W25', 'Y28', 'AB27', 'AD26', 'K17']},{'label': 'uB', 'num': 2, 'pin_nums': ['F13', 'K14', 'AG20', 'F14', 'K6', 'AG21', 'F6', 'K7', 'AG22', 'F8', 'K8', 'AG23', 'F9', 'K9', 'AG24', 'G10', 'L6', 'AG25', 'G11', 'L8', 'AG26', 'G12', 'L9', 'AG27', 'G13', 'M8', 'AH19', 'G14', 'AH20', 'G15', 'AH21', 'G6', 'AH22', 'G7', 'AH23', 'G8', 'AH24', 'H10', 'AH25', 'H11', 'AH27', 'H12', 'AD21', 'AH28', 'H13', 'AD22', 'AJ19', 'H14', 'AD24', 'AJ20', 'H7', 'AE20', 'AJ21', 'H8', 'AE21', 'AJ22', 'H9', 'AE22', 'AJ24', 'J10', 'AE23', 'AJ25', 'J11', 'AE24', 'AJ26', 'J12', 'AF18', 'AJ27', 'J14', 'AF19', 'AK19', 'J6', 'AF20', 'AK24', 'J7', 'AF21', 'AK26', 'J8', 'AF23', 'E11', 'J9', 'AF24', 'AF26', 'F10', 'K12', 'AF25', 'F11', 'K13']},{'label': 'uC', 'num': 3, 'pin_nums': ['W9', 'M7', 'AE18', 'AB8', 'AD15', 'P9', 'T7', 'V7', 'Y6', 'AD14', 'AE19', 'N10', 'R10', 'T8', 'V8', 'Y7', 'AC14', 'AA10', 'AD16', 'AA6', 'AC15', 'AD17', 'AF14', 'N7', 'R6', 'T9', 'V9', 'Y8', 'AC16', 'AA8', 'AD19', 'AF15', 'N8', 'R7', 'U10', 'W10', 'Y9', 'AA9', 'AC17', 'AE13', 'AF16', 'N9', 'R8', 'U6', 'W6', 'AB16', 'AC19', 'AE14', 'L5', 'AE17', 'P10', 'R9', 'U7', 'M6', 'W7', 'P7', 'AB18', 'AD13', 'AE16', 'M5', 'P6', 'T10', 'T6', 'U8', 'V10', 'W8', 'AB19']},{'label': 'uD', 'num': 4, 'pin_nums': ['AE9', 'J27', 'T29', 'AF10', 'U27', 'J28', 'AF11', 'J29', 'U28', 'AF6', 'V28', 'K26', 'AF7', 'K27', 'V29', 'AF8', 'K28', 'AF9', 'K29', 'AG10', 'L26', 'AG11', 'L28', 'AG6', 'L29', 'AG7', 'L30', 'AG8', 'M25', 'AH10', 'M26', 'AB5', 'AH11', 'M27', 'AB6', 'AH12', 'M28', 'AB7', 'AH7', 'M29', 'AC12', 'AH8', 'M30', 'AC5', 'AH9', 'N25', 'AC6', 'AJ10', 'N26', 'AC7', 'AJ11', 'N27', 'AC8', 'AJ12', 'N28', 'AD11', 'AJ7', 'N29', 'AD12', 'AJ9', 'P25', 'AD5', 'AK11', 'P26', 'AD6', 'AK9', 'P27', 'AD7', 'F28', 'P29', 'AE10', 'G27', 'R26', 'AE11', 'G28', 'R27', 'AE12', 'H27', 'R28', 'AE6', 'H28', 'R29', 'AE7', 'H29', 'T27', 'AE8', 'J26', 'T28']},{'label': 'uE', 'num': 5, 'pin_nums': ['H19', 'K19', 'L21', 'N22', 'J18', 'C17', 'F15', 'F24', 'G22', 'H20', 'J19', 'K21', 'L22', 'F16', 'F25', 'C18', 'G23', 'H21', 'J20', 'K22', 'L23', 'B18', 'D17', 'F17', 'F23', 'F26', 'G21', 'G24', 'H22', 'J21', 'K23', 'L24', 'E16', 'F18', 'G16', 'G25', 'H23', 'J22', 'K24', 'L25', 'E17', 'F19', 'G17', 'G26', 'H24', 'J24', 'K25', 'M20', 'E18', 'F20', 'A18', 'G18', 'H17', 'H25', 'J25', 'L19', 'M21', 'B17', 'E19', 'F21', 'G20', 'H18', 'J17', 'K18', 'L20', 'M22', 'E24']},{'label': 'uF', 'num': 6, 'pin_nums': ['AG17', 'AJ15', 'AF13', 'AG18', 'AJ16', 'AF17', 'AH13', 'AJ17', 'AG12', 'AH14', 'AJ18', 'AG13', 'AH15', 'AK16', 'AG14', 'AH17', 'AK17', 'AJ14', 'AL18', 'AG15', 'AH18', 'AK18', 'AG16']},{'label': 'uG', 'num': 7, 'pin_nums': ['P3', 'T2', 'T33', 'P31', 'M2', 'M33', 'P32', 'T34', 'N1', 'P34', 'U2', 'N2', 'P4', 'U33', 'N33', 'R1', 'N34', 'R34', 'P1', 'T1']},{'label': 'uH', 'num': 8, 'pin_nums': ['W2', 'AB2', 'Y4', 'AB33', 'W33', 'AB34', 'W34', 'AC2', 'Y1', 'AC33', 'Y3', 'AA1', 'V2', 'Y31', 'AA34', 'V33', 'Y32', 'AB1', 'W1', 'Y34']},{'label': 'uI', 'num': 9, 'pin_nums': ['H3', 'K2', 'H31', 'F2', 'K33', 'F33', 'H32', 'K34', 'G1', 'H34', 'L2', 'K1', 'G2', 'H4', 'L33', 'G33', 'J1', 'G34', 'J34', 'H1']},{'label': 'uJ', 'num': 10, 'pin_nums': ['AJ33', 'AE2', 'AF4', 'AJ2', 'AE33', 'AG1', 'AE34', 'AG34', 'AF1', 'AH1', 'AH2', 'AF3', 'AD2', 'AH33', 'AF31', 'AD33', 'AF32', 'AH34', 'AE1', 'AF34']},{'label': 'uK', 'num': 11, 'pin_nums': ['B32', 'E2', 'E31', 'B33', 'A1', 'C1', 'E33', 'A2', 'C34', 'E4', 'A33', 'D1', 'F31', 'A34', 'D2', 'F4', 'B2', 'D33', 'B3', 'D34']},{'label': 'uL', 'num': 12, 'pin_nums': ['AM1', 'AK33', 'AP33', 'AK5', 'AM34', 'AP34', 'AL1', 'AN2', 'AL2', 'AN3', 'AL30', 'AN32', 'AL33', 'AN33', 'AK2', 'AL34', 'AP1', 'AK30', 'AL5', 'AP2']},{'label': 'uM', 'num': 13, 'pin_nums': ['A7', 'B8', 'A8', 'B9', 'A27', 'D27', 'B26', 'A28', 'B27', 'D28', 'A29', 'D7', 'B30', 'A30', 'B31', 'D8', 'A5', 'B4', 'A6', 'B5']},{'label': 'uN', 'num': 14, 'pin_nums': ['AL7', 'AN5', 'AP6', 'AM28', 'AN8', 'AP7', 'AM7', 'AN9', 'AP8', 'AN26', 'AP27', 'AN27', 'AP28', 'AN30', 'AP29', 'AN31', 'AP30', 'AL28', 'AN4', 'AP5']},{'label': 'uO', 'num': 15, 'pin_nums': ['B21', 'A22', 'B24', 'A23', 'A24', 'B25', 'A11', 'B10', 'D13', 'A12', 'B11', 'D14', 'A13', 'B14', 'D21', 'A14', 'B15', 'D22', 'A21', 'B20']},{'label': 'uP', 'num': 16, 'pin_nums': ['AL22', 'AN21', 'AP22', 'AM13', 'AP23', 'AN24', 'AM22', 'AN25', 'AP24', 'AN10', 'AP11', 'AN11', 'AP12', 'AN14', 'AN20', 'AP13', 'AN15', 'AP14', 'AL13', 'AP21']},{'label': 'uQ', 'num': 17, 'pin_nums': ['AM14', 'AM15', 'C6', 'AM20', 'C8', 'AM21', 'C9', 'AM23', 'D3', 'AM25', 'D31', 'AM26', 'D32', 'AM27', 'D4', 'AM29', 'E3', 'AM3', 'E32', 'AM31', 'G3', 'AM32', 'G32', 'AA3', 'AM4', 'J3', 'AA32', 'AM6', 'J32', 'AB3', 'AM8', 'K3', 'AB32', 'AM9', 'K32', 'AC3', 'AP16', 'L3', 'AC32', 'AP19', 'L32', 'AE3', 'C11', 'N3', 'AE32', 'C12', 'N32', 'AG3', 'C14', 'R3', 'AG32', 'C15', 'R32', 'AH3', 'C20', 'T3', 'AH32', 'C21', 'T32', 'AJ3', 'C23', 'U3', 'AJ32', 'C24', 'U31', 'AL3', 'C26', 'U32', 'AL31', 'C27', 'U4', 'AL32', 'C29', 'V31', 'AL4', 'C3', 'V4', 'AM10', 'C30', 'C5', 'W3', 'AM12', 'C32', 'W32']},{'label': 'uR', 'num': 18, 'pin_nums': ['M19', 'AC9', 'W17', 'AA25', 'AD10', 'T25', 'AB10', 'W18', 'T26', 'AB20', 'AD20', 'AC10', 'AD9', 'U17', 'AC20', 'U18', 'K11', 'AC24', 'AC22', 'L10', 'U26', 'V18', 'L11', 'AC23', 'V17', 'M10']},{'label': 'uS', 'num': 19, 'pin_nums': ['B7', 'G29', 'Y23', 'R24', 'A25', 'C10', 'E13', 'G30', 'T11', 'A26', 'C13', 'E14', 'G31', 'T13', 'A3', 'C16', 'E15', 'G4', 'T15', 'A31', 'C19', 'E20', 'G5', 'T17', 'A32', 'C2', 'E21', 'G9', 'T18', 'A4', 'C22', 'E22', 'H16', 'T19', 'A9', 'C25', 'E23', 'H2', 'T21', 'AA12', 'C28', 'E25', 'H26', 'T23', 'AA14', 'C31', 'E26', 'H30', 'U12', 'AA16', 'C33', 'E27', 'H5', 'U14', 'AA18', 'C4', 'E28', 'H6', 'U16', 'AA20', 'C7', 'E29', 'M23', 'U20', 'AA22', 'D10', 'E30', 'N12', 'U22', 'AA24', 'D11', 'E34', 'N14', 'U24', 'AB11', 'D12', 'E5', 'N18', 'V11', 'AB15', 'D15', 'E6', 'N20', 'V13', 'AB17', 'D16', 'E7', 'N24', 'V15', 'AB21', 'D18', 'E8', 'P11', 'V19', 'AB23', 'D19', 'E9', 'P13', 'V21', 'AC18', 'D20', 'F1', 'P15', 'V23', 'B1', 'D23', 'F12', 'P17', 'W12', 'B12', 'D24', 'F22', 'P19', 'W14', 'B13', 'D25', 'F27', 'P21', 'W16', 'B16', 'D26', 'F29', 'P23', 'W20', 'B19', 'D29', 'F3', 'P24', 'W22', 'B22', 'D30', 'F30', 'R12', 'Y11', 'A10', 'B23', 'D5', 'F32', 'R14', 'Y13', 'A15', 'B28', 'D6', 'F34', 'R16', 'Y15', 'A16', 'B29', 'D9', 'F5', 'R18', 'Y17', 'A17', 'B34', 'E1', 'E12', 'F7', 'R20', 'Y19', 'A19', 'B6', 'E10', 'G19', 'R22', 'Y21', 'A20']},{'label': 'uT', 'num': 20, 'pin_nums': ['AH31', 'AM30', 'N30', 'J23', 'T14', 'V5', 'AD28', 'AH4', 'AK34', 'AM33', 'N31', 'J30', 'V6', 'T16', 'AA11', 'AD3', 'AH5', 'AK4', 'AM5', 'J31', 'N4', 'AA13', 'T20', 'W11', 'AD31', 'AH6', 'AK6', 'AN1', 'J33', 'N5', 'AA15', 'T22', 'W13', 'AD32', 'AJ1', 'AK7', 'AN12', 'J4', 'N6', 'AA17', 'T24', 'W15', 'AD34', 'AJ13', 'AK8', 'AN13', 'J5', 'P12', 'AA19', 'T30', 'W19', 'AD4', 'AJ23', 'AL10', 'AN16', 'K10', 'P14', 'AA2', 'T31', 'W21', 'AD8', 'AJ28', 'AL11', 'AN17', 'P16', 'K20', 'T4', 'AA21', 'W23', 'AE15', 'AJ29', 'AL12', 'AN18', 'K30', 'P18', 'AA23', 'T5', 'W28', 'AE25', 'AJ30', 'AL14', 'AN19', 'K31', 'P2', 'AA27', 'U1', 'W30', 'AE30', 'AJ31', 'AL15', 'AN22', 'K4', 'P20', 'AA30', 'U11', 'W31', 'AE31', 'AJ34', 'AL16', 'AN23', 'K5', 'P22', 'AA31', 'U13', 'W4', 'AE4', 'AJ4', 'AL17', 'AN28', 'L1', 'P28', 'AA33', 'U15', 'W5', 'AE5', 'AJ5', 'AL19', 'AN29', 'L17', 'P30', 'AA4', 'U19', 'Y10', 'AF12', 'AJ6', 'AL20', 'AN34', 'L27', 'P33', 'AA5', 'U21', 'Y12', 'AF2', 'AJ8', 'AD23', 'AL21', 'AN6', 'L31', 'P5', 'AA7', 'U23', 'Y14', 'AF22', 'AK1', 'AL23', 'AN7', 'L34', 'P8', 'AB14', 'U29', 'Y16', 'AF30', 'AK10', 'AL24', 'AP10', 'L4', 'R11', 'AB22', 'U30', 'Y18', 'AF33', 'AK12', 'AL25', 'AP15', 'L7', 'R13', 'AB24', 'U34', 'Y2', 'AF5', 'AK13', 'AL26', 'AP17', 'M1', 'R15', 'AB31', 'U5', 'Y20', 'AG19', 'AK14', 'AL27', 'AP18', 'M14', 'R17', 'AB4', 'U9', 'Y22', 'AG2', 'AK15', 'AL29', 'AP20', 'M24', 'R19', 'AB9', 'V1', 'Y30', 'AG29', 'AK20', 'AL6', 'AP25', 'M3', 'R2', 'AC1', 'V12', 'Y33', 'AG30', 'AK21', 'AL8', 'AP26', 'M31', 'R21', 'AC11', 'V14', 'Y5', 'AG31', 'AK22', 'AL9', 'AP3', 'M32', 'R23', 'AC13', 'V16', 'AG33', 'AK23', 'AM11', 'AP31', 'M34', 'R25', 'AC21', 'V20', 'AG4', 'AK25', 'AM16', 'AP32', 'M4', 'R30', 'AC31', 'V22', 'AG5', 'AK27', 'AM17', 'AP4', 'M9', 'R31', 'AC34', 'V26', 'AG9', 'AK28', 'AM18', 'AP9', 'N11', 'R33', 'AC4', 'V3', 'N23', 'AH16', 'AK29', 'AM19', 'H33', 'N19', 'R4', 'AD1', 'V30', 'AH26', 'AK3', 'AK32', 'AM2', 'J13', 'N21', 'R5', 'AD18', 'V32', 'AH30', 'AK31', 'AM24', 'J2', 'T12', 'V34']}] }),
        Part(**{ 'name':'XC5VTX150T-FF1759', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VTX150T-FF1759'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VTX150T-FF1759\n\nFPGA', 'pins':[
            Pin(num='AA30',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA31',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA32',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA34',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA35',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA36',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA37',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB34',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB35',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AB36',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB37',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC36',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R27',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T35',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T36',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T37',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U31',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U36',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U37',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V33',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V35',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V36',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W30',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W31',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W32',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W34',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='W35',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W36',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W37',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y29',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y30',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y33',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y34',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y35',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC30',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC31',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AC33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC35',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD30',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD31',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD33',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD35',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD36',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD37',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AE32',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE35',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE37',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF31',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF32',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AF34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF35',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF36',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF37',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG31',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG36',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG37',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG38',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH36',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH37',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AH38',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ36',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ37',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK37',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL36',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL37',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM37',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AM38',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y7',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD6',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD7',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE10',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE7',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AE8',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE9',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF10',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF11',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF12',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF5',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF6',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF7',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF9',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AG11',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG12',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG6',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG7',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG8',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG9',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH10',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH11',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH17',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AH5',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH6',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH7',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AH8',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH9',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ17',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ18',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ6',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ7',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ8',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK17',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK18',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK19',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK27',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK28',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK7',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK8',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK9',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL17',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL18',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AL19',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL27',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL28',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AL6',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL7',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL8',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AL9',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM17',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM18',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM19',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM27',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM5',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM6',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM7',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN26',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AN5',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AP25',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AP26',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AP27',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AP5',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP6',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AR25',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AR27',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L3P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='E8',name='IO_L3N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='IO_L5N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='F7',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='G37',name='IO_L4P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='G6',name='IO_L5P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='G7',name='IO_L1P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='G8',name='IO_L1N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='H34',name='IO_L0N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H35',name='IO_L2P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L2N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='H38',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H5',name='IO_L7N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='H6',name='IO_L7P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J33',name='IO_L0P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J34',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='J35',name='IO_L15N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L15P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J38',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L14P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J7',name='IO_L18P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J8',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K33',name='IO_L6N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K34',name='IO_L6P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L19N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L17P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K38',name='IO_L17N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K5',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K7',name='IO_L19P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K8',name='IO_L18N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=4),
            Pin(num='L34',name='IO_L19P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L35',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L16N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L6',name='IO_L4P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='L7',name='IO_L19N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='L8',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M34',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M35',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L16P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L17N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M7',name='IO_L17P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M8',name='IO_L15P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M9',name='IO_L16N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='N33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N34',name='IO_L14P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L7N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N8',name='IO_L15N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='N9',name='IO_L16P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='P33',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L7P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L5N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P37',name='IO_L1N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P38',name='IO_L3N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='R32',name='IO_L13N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R33',name='IO_L13P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L5P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R36',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='R37',name='IO_L1P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R38',name='IO_L3P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='T10',name='IO_L13N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L13P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='T31',name='IO_L18P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T32',name='IO_L18N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T33',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='T34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T9',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='IO_L2N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U12',name='IO_L0N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L6N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U9',name='IO_L6P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L2P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='V11',name='IO_L0P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='AH33',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AH34',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AH35',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ10',name='IO_L4P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ11',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ12',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ31',name='IO_L3P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ32',name='IO_L3N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ33',name='IO_L0P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ34',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ35',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK10',name='IO_L2N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AK12',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AK32',name='IO_L13P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK33',name='IO_L13N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK34',name='IO_L0N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK35',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL10',name='IO_L2P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AL11',name='IO_L7N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AL12',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL32',name='IO_L19N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL34',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL35',name='IO_L18P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM11',name='IO_L7P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM12',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L18P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM31',name='IO_L17P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM32',name='IO_L17N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM34',name='IO_L6P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM35',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AM36',name='IO_L18N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM8',name='IO_L17N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM9',name='IO_L17P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN10',name='IO_L6N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN11',name='IO_L3N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN12',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AN13',name='IO_L18N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN31',name='IO_L15P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN32',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AN33',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN34',name='IO_L6N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN35',name='IO_L16N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN36',name='IO_L16P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN8',name='IO_L15N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN9',name='IO_L6P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP10',name='IO_L3P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP11',name='IO_L5P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP12',name='IO_L5N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L16P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP31',name='IO_L15N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP33',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP35',name='IO_L7N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP36',name='IO_L7P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP37',name='IO_L14P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP38',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP7',name='IO_L19N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP8',name='IO_L15P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP9',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AR10',name='IO_L1P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR12',name='IO_L16N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR35',name='IO_L4P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AR37',name='IO_L5N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AR6',name='IO_L19P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR7',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR8',name='IO_L0P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR9',name='IO_L0N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT11',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AT35',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AT36',name='IO_L1P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AT37',name='IO_L5P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AT6',name='IO_L13N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT7',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT9',name='IO_L1N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU11',name='IO_L14P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU36',name='IO_L2N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AU37',name='IO_L1N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AU6',name='IO_L13P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU7',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AU8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AV11',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AV36',name='IO_L2P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AV7',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='E13',name='IO_L4N_VREF_28',func=pin_types.BIDIR,unit=6),
            Pin(num='E14',name='IO_L15P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='E29',name='IO_L16P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E30',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='IO_L4P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E37',name='IO_L6P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L0P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F11',name='IO_L2N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F12',name='IO_L11N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F13',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='F14',name='IO_L15N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F15',name='IO_L17P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F29',name='IO_L16N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F30',name='IO_L14P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F31',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L5N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L3P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L2P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F36',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='F37',name='IO_L6N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L0N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='IO_L2P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G12',name='IO_L11P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G13',name='IO_L13N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G14',name='IO_L17N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G29',name='IO_L18P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G30',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='G31',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L5P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='G34',name='IO_L3N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G36',name='IO_L2N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G9',name='IO_L3P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='IO_L1N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H11',name='IO_L8P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H13',name='IO_L13P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H14',name='IO_L19P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H15',name='IO_L19N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H29',name='IO_L18N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H30',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L1N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L3N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L5P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L1P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J12',name='IO_L8N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J13',name='IO_L6N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J30',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='J31',name='IO_L7N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L1P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='K10',name='IO_L5N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='IO_L7N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K13',name='IO_L7P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K14',name='IO_L6P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K29',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='K30',name='IO_L0N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='K31',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='K32',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='IO_L10P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='L11',name='IO_L10N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='IO_L9P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='L29',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L30',name='IO_L0P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='M11',name='IO_L14P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='M12',name='IO_L9N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='M13',name='IO_L12N_VRP_28',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L13P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L13N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='IO_L14N_VREF_28',func=pin_types.BIDIR,unit=6),
            Pin(num='N11',name='IO_L16N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='IO_L12P_VRN_28',func=pin_types.BIDIR,unit=6),
            Pin(num='N30',name='IO_L15N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L15P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='N32',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='IO_L16P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='P12',name='IO_L18P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='P30',name='IO_L19P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L17P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L17N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='R12',name='IO_L18N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='R30',name='IO_L19N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='AH29',name='IO_L0N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AH30',name='IO_L0P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L2P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ30',name='IO_L2N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AK29',name='IO_L4P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AK30',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AK31',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AL29',name='IO_L17P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L17N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AM29',name='IO_L15P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L1P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L15N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AP28',name='IO_L1N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AP30',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR28',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR29',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR30',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR32',name='IO_L13P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT25',name='IO_L3N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT26',name='IO_L3P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT27',name='IO_L7N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT29',name='IO_L14P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT30',name='IO_L19P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT31',name='IO_L19N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L13N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AT34',name='IO_L6N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU26',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AU27',name='IO_L7P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU28',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU29',name='IO_L16P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU30',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AU31',name='IO_L18N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV25',name='IO_L5N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV26',name='IO_L5P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV30',name='IO_L16N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV31',name='IO_L18P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='J14',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='J15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=7),
            Pin(num='J16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=7),
            Pin(num='K15',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=7),
            Pin(num='K27',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='K28',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L15',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L17',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L18',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='L19',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L25',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L26',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L27',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L28',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='M17',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M18',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M19',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M24',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M25',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='M26',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M27',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M28',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='N24',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='AG13',name='IO_L3N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L5P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L1N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ13',name='IO_L5N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ14',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ15',name='IO_L1P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ24',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ25',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK13',name='IO_L7P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK14',name='IO_L7N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK15',name='IO_L19P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK20',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK21',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AK23',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK24',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK25',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL14',name='IO_L16N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AL15',name='IO_L19N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AL16',name='IO_L4P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AL20',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL21',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL24',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL25',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL26',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AM14',name='IO_L16P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AM15',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AM16',name='IO_L4N_VREF_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AM21',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AM24',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AM25',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AM26',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AN14',name='IO_L10P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN15',name='IO_L10N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN16',name='IO_L11P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN18',name='IO_L2P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN19',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AN20',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AN25',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AP15',name='IO_L14P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP16',name='IO_L15N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP17',name='IO_L11N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP18',name='IO_L2N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP19',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AP20',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AP21',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AR13',name='IO_L9N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR14',name='IO_L14N_VREF_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR15',name='IO_L15P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR16',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AR17',name='IO_L8N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR18',name='IO_L0N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR19',name='IO_L0P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR20',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AT12',name='IO_L9P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT13',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AT14',name='IO_L12N_VRP_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT15',name='IO_L17N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT16',name='IO_L13P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT17',name='IO_L8P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT20',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AU12',name='IO_L18P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU13',name='IO_L12P_VRN_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU14',name='IO_L17P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU16',name='IO_L13N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU17',name='IO_L6N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU18',name='IO_L6P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AV13',name='IO_L18N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK22',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL22',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM22',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM23',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN21',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN22',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN23',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN24',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP22',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP23',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AR22',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AR23',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AR24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT19',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT21',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT22',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AT24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU19',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU20',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AU21',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU22',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU23',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU24',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV18',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV19',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV21',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV24',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW20',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW21',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW22',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW23',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AY20',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AY22',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AY23',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BA20',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BA21',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BA22',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BB21',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BB22',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BB23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E20',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F26',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G16',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G19',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='G24',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G26',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G28',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H16',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='H18',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H19',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H20',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H23',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H24',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H25',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H26',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H27',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='H28',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J23',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J24',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='J25',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J26',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J27',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J28',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K23',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K25',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L24',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A20',name='IO_L14P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='A21',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=10),
            Pin(num='A22',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='B21',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='B22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='B23',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='C20',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=10),
            Pin(num='C21',name='IO_L6P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='C22',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='C23',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D20',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D21',name='IO_L6N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D22',name='IO_L4P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D23',name='IO_L3P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E22',name='IO_L3N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E23',name='IO_L17N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E24',name='IO_L17P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E25',name='IO_L19N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F22',name='IO_L5P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F23',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='F24',name='IO_L13N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F25',name='IO_L19P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='G21',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='G22',name='IO_L5N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='G23',name='IO_L13P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='H21',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='J20',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='J21',name='IO_L0N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='J22',name='IO_L0P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='IO_L16N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='K21',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='K22',name='IO_L7P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='IO_L16P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='L21',name='IO_L7N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='L22',name='IO_L2N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='M21',name='IO_L1N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='M22',name='IO_L2P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='M23',name='IO_L15P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='N21',name='IO_L1P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='N22',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='N23',name='IO_L15N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='P21',name='IO_L18P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='P22',name='IO_L18N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='AA41',name='MGTTXP1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='T41',name='MGTTXP0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='U41',name='MGTTXN0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='U42',name='MGTRXP0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V39',name='MGTREFCLKP_111',func=pin_types.BIDIR,unit=11),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V40',name='MGTREFCLKN_111',func=pin_types.BIDIR,unit=11),
            Pin(num='V42',name='MGTRXN0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='W42',name='MGTRXN1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='Y41',name='MGTTXN1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='Y42',name='MGTRXP1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AB41',name='MGTTXP0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AC41',name='MGTTXN0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AC42',name='MGTRXP0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AD39',name='MGTREFCLKP_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AD40',name='MGTREFCLKN_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AD42',name='MGTRXN0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AE42',name='MGTRXN1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AF41',name='MGTTXN1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AF42',name='MGTRXP1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AG41',name='MGTTXP1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='K41',name='MGTTXP0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='L41',name='MGTTXN0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='L42',name='MGTRXP0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=13),
            Pin(num='M39',name='MGTREFCLKP_115',func=pin_types.BIDIR,unit=13),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=13),
            Pin(num='M40',name='MGTREFCLKN_115',func=pin_types.BIDIR,unit=13),
            Pin(num='M42',name='MGTRXN0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='N42',name='MGTRXN1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='P41',name='MGTTXN1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='P42',name='MGTRXP1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='R41',name='MGTTXP1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AH41',name='MGTTXP0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ41',name='MGTTXN0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ42',name='MGTRXP0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK39',name='MGTREFCLKP_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK40',name='MGTREFCLKN_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AK42',name='MGTRXN0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AL42',name='MGTRXN1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AM41',name='MGTTXN1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AM42',name='MGTRXP1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AN41',name='MGTTXP1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='D41',name='MGTTXP0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='E41',name='MGTTXN0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='E42',name='MGTRXP0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F39',name='MGTREFCLKP_119',func=pin_types.BIDIR,unit=15),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F40',name='MGTREFCLKN_119',func=pin_types.BIDIR,unit=15),
            Pin(num='F42',name='MGTRXN0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='G42',name='MGTRXN1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='H41',name='MGTTXN1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='H42',name='MGTRXP1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='J41',name='MGTTXP1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AP41',name='MGTTXP0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR41',name='MGTTXN0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AR42',name='MGTRXP0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT39',name='MGTREFCLKP_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT40',name='MGTREFCLKN_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AT42',name='MGTRXN0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU42',name='MGTRXN1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV41',name='MGTTXN1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AV42',name='MGTRXP1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW41',name='MGTTXP1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A38',name='MGTRXP0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A39',name='MGTRXN0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A40',name='MGTRXN1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A41',name='MGTRXP1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B37',name='MGTTXP0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B38',name='MGTTXN0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B41',name='MGTTXN1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B42',name='MGTTXP1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C39',name='MGTREFCLKP_123',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C40',name='MGTREFCLKN_123',func=pin_types.BIDIR,unit=17),
            Pin(num='AW39',name='MGTREFCLKP_125',func=pin_types.BIDIR,unit=18),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=18),
            Pin(num='AY39',name='MGTREFCLKN_125',func=pin_types.BIDIR,unit=18),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA37',name='MGTTXP1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA38',name='MGTTXN1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA41',name='MGTTXN0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA42',name='MGTTXP0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB38',name='MGTRXP1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB39',name='MGTRXN1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB40',name='MGTRXN0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB41',name='MGTRXP0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='A10',name='MGTRXN0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='A11',name='MGTRXP0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='A32',name='MGTRXP0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A33',name='MGTRXN0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A34',name='MGTRXN1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A35',name='MGTRXP1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A8',name='MGTRXP1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='A9',name='MGTRXN1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B11',name='MGTTXN0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B12',name='MGTTXP0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B31',name='MGTTXP0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B32',name='MGTTXN0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B35',name='MGTTXN1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B36',name='MGTTXP1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B7',name='MGTTXP1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B8',name='MGTTXN1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='C10',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=19),
            Pin(num='C33',name='MGTREFCLKN_127',func=pin_types.BIDIR,unit=19),
            Pin(num='D10',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=19),
            Pin(num='D33',name='MGTREFCLKP_127',func=pin_types.BIDIR,unit=19),
            Pin(num='AW34',name='MGTREFCLKP_129',func=pin_types.BIDIR,unit=20),
            Pin(num='AW9',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=20),
            Pin(num='AY34',name='MGTREFCLKN_129',func=pin_types.BIDIR,unit=20),
            Pin(num='AY9',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA11',name='MGTTXN1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA12',name='MGTTXP1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA31',name='MGTTXP1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA32',name='MGTTXN1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA35',name='MGTTXN0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA36',name='MGTTXP0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA7',name='MGTTXP0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA8',name='MGTTXN0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB10',name='MGTRXN1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB11',name='MGTRXP1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB32',name='MGTRXP1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB33',name='MGTRXN1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB34',name='MGTRXN0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB35',name='MGTRXP0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB8',name='MGTRXP0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB9',name='MGTRXN0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=21),
            Pin(num='AA39',name='MGTAVTTRXC_L',func=pin_types.PWRIN,unit=21),
            Pin(num='AA4',name='MGTAVTTRXC_R',func=pin_types.PWRIN,unit=21),
            Pin(num='AA40',name='MGTAVTTTX_111',func=pin_types.PWRIN,unit=21),
            Pin(num='AB39',name='MGTRREF_111',func=pin_types.PWRIN,unit=21),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=21),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=21),
            Pin(num='AC40',name='MGTAVTTRX_113',func=pin_types.PWRIN,unit=21),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=21),
            Pin(num='AE40',name='MGTAVCC_113',func=pin_types.PWRIN,unit=21),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=21),
            Pin(num='AF40',name='MGTAVCCPLL_113',func=pin_types.PWRIN,unit=21),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=21),
            Pin(num='AG40',name='MGTAVTTTX_113',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=21),
            Pin(num='AJ40',name='MGTAVTTRX_117',func=pin_types.PWRIN,unit=21),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=21),
            Pin(num='AL40',name='MGTAVCC_117',func=pin_types.PWRIN,unit=21),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=21),
            Pin(num='AM40',name='MGTAVCCPLL_117',func=pin_types.PWRIN,unit=21),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=21),
            Pin(num='AN40',name='MGTAVTTTX_117',func=pin_types.PWRIN,unit=21),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=21),
            Pin(num='AR40',name='MGTAVTTRX_121',func=pin_types.PWRIN,unit=21),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=21),
            Pin(num='AU40',name='MGTAVCC_121',func=pin_types.PWRIN,unit=21),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=21),
            Pin(num='AV40',name='MGTAVCCPLL_121',func=pin_types.PWRIN,unit=21),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=21),
            Pin(num='AW38',name='MGTAVCC_125',func=pin_types.PWRIN,unit=21),
            Pin(num='AW40',name='MGTAVTTTX_121',func=pin_types.PWRIN,unit=21),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=21),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=21),
            Pin(num='AY11',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=21),
            Pin(num='AY12',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=21),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=21),
            Pin(num='AY31',name='MGTAVTTTX_129',func=pin_types.PWRIN,unit=21),
            Pin(num='AY32',name='MGTAVCCPLL_129',func=pin_types.PWRIN,unit=21),
            Pin(num='AY33',name='MGTAVCC_129',func=pin_types.PWRIN,unit=21),
            Pin(num='AY35',name='MGTAVTTRX_129',func=pin_types.PWRIN,unit=21),
            Pin(num='AY37',name='MGTAVTTTX_125',func=pin_types.PWRIN,unit=21),
            Pin(num='AY38',name='MGTAVCCPLL_125',func=pin_types.PWRIN,unit=21),
            Pin(num='AY41',name='MGTAVTTRX_125',func=pin_types.PWRIN,unit=21),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=21),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=21),
            Pin(num='AY8',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=21),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=21),
            Pin(num='C11',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=21),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=21),
            Pin(num='C32',name='MGTAVTTRX_127',func=pin_types.PWRIN,unit=21),
            Pin(num='C34',name='MGTAVCC_127',func=pin_types.PWRIN,unit=21),
            Pin(num='C35',name='MGTAVCCPLL_127',func=pin_types.PWRIN,unit=21),
            Pin(num='C36',name='MGTAVTTTX_127',func=pin_types.PWRIN,unit=21),
            Pin(num='C38',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=21),
            Pin(num='C41',name='MGTAVCCPLL_123',func=pin_types.PWRIN,unit=21),
            Pin(num='C42',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=21),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=21),
            Pin(num='C7',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=21),
            Pin(num='C8',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=21),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=21),
            Pin(num='D39',name='MGTAVCC_123',func=pin_types.PWRIN,unit=21),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=21),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=21),
            Pin(num='E40',name='MGTAVTTRX_119',func=pin_types.PWRIN,unit=21),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=21),
            Pin(num='G40',name='MGTAVCC_119',func=pin_types.PWRIN,unit=21),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=21),
            Pin(num='H40',name='MGTAVCCPLL_119',func=pin_types.PWRIN,unit=21),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=21),
            Pin(num='J40',name='MGTAVTTTX_119',func=pin_types.PWRIN,unit=21),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=21),
            Pin(num='L40',name='MGTAVTTRX_115',func=pin_types.PWRIN,unit=21),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=21),
            Pin(num='N40',name='MGTAVCC_115',func=pin_types.PWRIN,unit=21),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=21),
            Pin(num='P40',name='MGTAVCCPLL_115',func=pin_types.PWRIN,unit=21),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=21),
            Pin(num='R40',name='MGTAVTTTX_115',func=pin_types.PWRIN,unit=21),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=21),
            Pin(num='U40',name='MGTAVTTRX_111',func=pin_types.PWRIN,unit=21),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=21),
            Pin(num='W40',name='MGTAVCC_111',func=pin_types.PWRIN,unit=21),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=21),
            Pin(num='Y40',name='MGTAVCCPLL_111',func=pin_types.PWRIN,unit=21),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AF15',name='TMS_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AF16',name='TCK_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AG16',name='TDI_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AG29',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AH16',name='TDO_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AH28',name='M2_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AJ16',name='CCLK_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AJ27',name='M1_0',func=pin_types.BIDIR,unit=22),
            Pin(num='AJ28',name='M0_0',func=pin_types.BIDIR,unit=22),
            Pin(num='P13',name='VCCO_0',func=pin_types.PWRIN,unit=22),
            Pin(num='P15',name='RDWR_B_0',func=pin_types.BIDIR,unit=22),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=22),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=22),
            Pin(num='R16',name='VCCO_0',func=pin_types.PWRIN,unit=22),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=22),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=22),
            Pin(num='T29',name='HSWAPEN_0',func=pin_types.BIDIR,unit=22),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=22),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA28',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AB29',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD13',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AD29',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AG28',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AG30',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ22',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D19',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D29',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D30',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D36',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D37',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D40',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D42',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E26',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E27',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E32',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E34',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E39',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F33',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F41',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G38',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=23),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='R28',name='VBATT_0',func=pin_types.PWRIN,unit=23),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='U28',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='V13',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='V29',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='W28',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='Y13',name='VCCAUX',func=pin_types.PWRIN,unit=23),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=23),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=23),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=23),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB3',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AD5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF30',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH3',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH40',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ21',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AL5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AM39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP40',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AP42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='G39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='G41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='H39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K3',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K40',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='R42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T3',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T40',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T42',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V37',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W41',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y38',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y39',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=24),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AR38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AR39',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AR5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT41',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU10',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU39',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU41',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV10',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV14',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV16',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV17',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV27',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV29',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV33',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV34',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV35',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV37',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV39',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV8',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AV9',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW1',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW10',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW12',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW13',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW16',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW26',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW27',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW30',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW32',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW33',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW35',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW36',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW37',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW42',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW7',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY1',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY13',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY3',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY30',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY40',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY42',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AY7',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA27',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA34',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA39',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA40',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB12',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB13',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB20',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB36',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB37',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='BB7',name='GND',func=pin_types.PWRIN,unit=25)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AB31', 'P17', 'M29', 'U33', 'R26', 'V36', 'W37', 'Y37', 'AB32', 'N14', 'P18', 'N29', 'R27', 'U34', 'W30', 'AB34', 'N15', 'Y29', 'AB35', 'P19', 'M16', 'N16', 'T35', 'U36', 'W31', 'Y30', 'AA30', 'AB36', 'N18', 'P25', 'T36', 'U37', 'W32', 'Y31', 'AA31', 'AB37', 'N19', 'P26', 'AC36', 'T37', 'V31', 'W33', 'N25', 'Y32', 'AA34', 'U32', 'L14', 'AA32', 'P27', 'V35', 'N26', 'U30', 'V33', 'W34', 'AA35', 'W36', 'Y33', 'Y35', 'M14', 'N28', 'P28', 'U31', 'V34', 'W35', 'Y34', 'AA36', 'M15', 'P29', 'AA37']},{'label': 'uB', 'num': 2, 'pin_nums': ['AM38', 'AD8', 'AN38', 'AA10', 'AD9', 'N6', 'AA11', 'AE32', 'P5', 'AA6', 'AE33', 'P6', 'AA7', 'AE34', 'P7', 'AA8', 'AE35', 'R5', 'AA9', 'AE36', 'R6', 'AB11', 'AE37', 'R7', 'AB33', 'AF31', 'T5', 'AB6', 'AF32', 'T6', 'AB7', 'AF33', 'T7', 'AB8', 'AF34', 'U6', 'AB9', 'AF35', 'U7', 'AC10', 'AF36', 'V6', 'AC11', 'AF37', 'V7', 'AC30', 'AG31', 'V8', 'AC31', 'AG32', 'V9', 'AC32', 'AG33', 'W10', 'AC33', 'AG34', 'W11', 'AC34', 'AG36', 'W6', 'AC35', 'AG37', 'W7', 'AC6', 'AG38', 'W8', 'AC8', 'AH36', 'Y10', 'AC9', 'AH37', 'Y11', 'AD11', 'AH38', 'Y7', 'AD30', 'AJ36', 'Y8', 'AD31', 'AJ37', 'Y9', 'AD32', 'AK37', 'AD33', 'AL36', 'AD35', 'AD37', 'AL37', 'AD36', 'AM37']},{'label': 'uC', 'num': 3, 'pin_nums': ['AL18', 'AM17', 'AE7', 'AF7', 'AG9', 'AH9', 'AK19', 'AL19', 'AM18', 'AN5', 'AN6', 'AR26', 'AR27', 'AK27', 'AF9', 'AE8', 'AH10', 'AJ17', 'AL27', 'AM19', 'AP25', 'AE10', 'AE9', 'AG10', 'AH11', 'AJ18', 'AK28', 'AL28', 'AM27', 'AP26', 'AF10', 'AG11', 'AH17', 'AJ6', 'AK7', 'AL6', 'AM5', 'AP27', 'AD10', 'AG12', 'AF11', 'AH5', 'AJ7', 'AK8', 'AL7', 'AM6', 'AP5', 'AD6', 'AF12', 'AG6', 'AH6', 'AH8', 'AJ8', 'AK9', 'AL8', 'AM7', 'AP6', 'AD7', 'AG7', 'AF5', 'AH7', 'AK17', 'AL17', 'AL9', 'AN26', 'AR25', 'AF6', 'AG8', 'AK18']},{'label': 'uD', 'num': 4, 'pin_nums': ['K37', 'P37', 'K38', 'P38', 'E7', 'K5', 'P8', 'E8', 'K7', 'P9', 'F6', 'K8', 'R10', 'F7', 'K9', 'R32', 'G37', 'L34', 'R33', 'G6', 'L35', 'R34', 'G7', 'L36', 'R35', 'G8', 'L37', 'R36', 'H34', 'L6', 'R37', 'H35', 'L7', 'R38', 'H36', 'L8', 'R8', 'H37', 'L9', 'R9', 'H38', 'M34', 'T10', 'H5', 'M35', 'T11', 'H6', 'M36', 'T31', 'H7', 'M37', 'T32', 'H8', 'M6', 'T33', 'J33', 'M7', 'T34', 'J34', 'M8', 'T9', 'J35', 'M9', 'U10', 'J36', 'N33', 'U11', 'J37', 'N34', 'U12', 'J38', 'N35', 'U8', 'J5', 'N36', 'U9', 'J6', 'N8', 'V10', 'J7', 'N9', 'V11', 'J8', 'P10', 'K33', 'P33', 'K34', 'P35', 'K35', 'P36']},{'label': 'uE', 'num': 5, 'pin_nums': ['AR6', 'AJ11', 'AR7', 'AN10', 'AJ12', 'AN11', 'AR8', 'AJ31', 'AN12', 'AR9', 'AM9', 'AJ32', 'AN13', 'AT10', 'AJ33', 'AN31', 'AT11', 'AJ34', 'AN32', 'AT35', 'AJ35', 'AN33', 'AT36', 'AK10', 'AN34', 'AT37', 'AK11', 'AN35', 'AT6', 'AK12', 'AN36', 'AT7', 'AK32', 'AN8', 'AT9', 'AK33', 'AN9', 'AU11', 'AK34', 'AP10', 'AU36', 'AK35', 'AP11', 'AU37', 'AL10', 'AP12', 'AU6', 'AL11', 'AP13', 'AU7', 'AL12', 'AP31', 'AU8', 'AL31', 'AP32', 'AU9', 'AL32', 'AP33', 'AV11', 'AL34', 'AP35', 'AV36', 'AL35', 'AP36', 'AV7', 'AM11', 'AP37', 'AM12', 'AP38', 'AM13', 'AP7', 'AM31', 'AP8', 'AM32', 'AP9', 'AM33', 'AR10', 'AM34', 'AR12', 'AH33', 'AM35', 'AR35', 'AH34', 'AM36', 'AR36', 'AH35', 'AM8', 'AR37', 'AJ10']},{'label': 'uF', 'num': 6, 'pin_nums': ['H30', 'F12', 'M33', 'F13', 'H31', 'N10', 'F14', 'H33', 'N11', 'H9', 'F15', 'N12', 'F29', 'J10', 'N13', 'J11', 'F30', 'N30', 'F31', 'J12', 'N31', 'F32', 'J13', 'N32', 'F34', 'J30', 'P11', 'F35', 'J31', 'P12', 'F36', 'J32', 'P30', 'F37', 'K10', 'P31', 'H29', 'F9', 'K11', 'P32', 'G10', 'K12', 'R12', 'G11', 'K13', 'R30', 'G12', 'K14', 'G13', 'K29', 'G14', 'K30', 'G29', 'K31', 'G30', 'K32', 'G31', 'L10', 'G32', 'L11', 'E12', 'G33', 'L12', 'E13', 'G34', 'L29', 'E14', 'G36', 'L30', 'E29', 'G9', 'L31', 'E30', 'H10', 'L32', 'E35', 'M11', 'H11', 'E36', 'H13', 'M12', 'E37', 'H14', 'M13', 'F10', 'H15', 'M31', 'F11', 'M32']},{'label': 'uG', 'num': 7, 'pin_nums': ['AT26', 'AP30', 'AU26', 'AH29', 'AL30', 'AU34', 'K15', 'L25', 'M25', 'AH30', 'AM28', 'AR28', 'AT27', 'L26', 'M26', 'AU27', 'AV25', 'K27', 'AH31', 'AM29', 'AR29', 'AT29', 'AU28', 'AV26', 'K28', 'L27', 'M27', 'AJ30', 'AN28', 'AR30', 'AT30', 'AU29', 'AV30', 'L15', 'L28', 'M28', 'AK29', 'AN29', 'AR32', 'AT31', 'AU30', 'AV31', 'L16', 'M17', 'N24', 'AK30', 'AN30', 'AR33', 'AT32', 'AU31', 'J14', 'L17', 'M18', 'AK31', 'AP28', 'AR34', 'AT33', 'AU32', 'J15', 'L18', 'M19', 'M24', 'AL29', 'AP29', 'AT25', 'AT34', 'L19', 'AU33', 'J16']},{'label': 'uH', 'num': 8, 'pin_nums': ['AR17', 'AU18', 'AT16', 'AK14', 'AL15', 'AH15', 'AK15', 'AL16', 'AM16', 'AN16', 'AN18', 'AP18', 'AP19', 'AR18', 'AT17', 'AV13', 'AK20', 'AL20', 'AJ13', 'AM21', 'AN19', 'AP20', 'AR19', 'AT20', 'AJ14', 'AK21', 'AL21', 'AM24', 'AN20', 'AP21', 'AR20', 'AU12', 'AK23', 'AJ15', 'AL24', 'AM25', 'AN25', 'AR13', 'AT12', 'AU13', 'AJ24', 'AK24', 'AL25', 'AM26', 'AP15', 'AR14', 'AT13', 'AU14', 'AJ25', 'AK25', 'AG13', 'AL26', 'AN14', 'AP16', 'AR15', 'AT14', 'AU16', 'AH13', 'AH14', 'AK13', 'AL14', 'AM14', 'AN15', 'AP17', 'AR16', 'AT15', 'AU17', 'AM15']},{'label': 'uI', 'num': 9, 'pin_nums': ['AN23', 'BA20', 'H26', 'AN24', 'H27', 'BA21', 'AP22', 'BA22', 'H28', 'AP23', 'J17', 'BB21', 'AR22', 'BB22', 'J18', 'AR23', 'BB23', 'J23', 'AR24', 'E18', 'J24', 'AT19', 'J25', 'E19', 'AT21', 'E20', 'J26', 'AT22', 'F16', 'J27', 'AT23', 'F17', 'J28', 'AT24', 'F19', 'K17', 'AU19', 'F20', 'K18', 'AU20', 'F26', 'K19', 'AU21', 'F27', 'K23', 'AU22', 'G16', 'K24', 'AU23', 'G17', 'K25', 'AU24', 'G18', 'L24', 'AV18', 'G19', 'AV19', 'G20', 'AV20', 'G24', 'AV21', 'G26', 'AV23', 'G27', 'AV24', 'G28', 'AW20', 'H16', 'AW21', 'H17', 'AK22', 'AW22', 'H18', 'AL22', 'AW23', 'H19', 'AM22', 'AY20', 'H20', 'AM23', 'AY21', 'H23', 'AN21', 'AY22', 'H24', 'AN22', 'AY23', 'H25']},{'label': 'uJ', 'num': 10, 'pin_nums': ['C20', 'K20', 'M23', 'E22', 'F25', 'C21', 'G21', 'K21', 'E23', 'N21', 'D23', 'A20', 'C22', 'E24', 'G22', 'K22', 'N22', 'A21', 'C23', 'E25', 'G23', 'L20', 'N23', 'A22', 'D20', 'F21', 'H21', 'L21', 'P21', 'B21', 'D21', 'F22', 'J20', 'L22', 'P22', 'B22', 'D22', 'F23', 'J21', 'M21', 'F24', 'M22', 'B23', 'J22']},{'label': 'uK', 'num': 11, 'pin_nums': ['AA41', 'V3', 'Y2', 'T2', 'V39', 'Y41', 'T41', 'V4', 'Y42', 'U1', 'V40', 'U2', 'V42', 'U41', 'W1', 'U42', 'W42', 'AA2', 'V1', 'Y1']},{'label': 'uL', 'num': 12, 'pin_nums': ['AC42', 'AE42', 'AD1', 'AF1', 'AD3', 'AF2', 'AB2', 'AD39', 'AF41', 'AB41', 'AD4', 'AF42', 'AC1', 'AD40', 'AG2', 'AC2', 'AD42', 'AG41', 'AC41', 'AE1']},{'label': 'uM', 'num': 13, 'pin_nums': ['M4', 'K41', 'P42', 'L1', 'M40', 'R2', 'L2', 'M42', 'R41', 'M39', 'L41', 'N1', 'P41', 'L42', 'N42', 'M1', 'P1', 'P2', 'M3', 'K2']},{'label': 'uN', 'num': 14, 'pin_nums': ['AJ41', 'AL1', 'AL42', 'AJ42', 'AK1', 'AM1', 'AK3', 'AM2', 'AH2', 'AK39', 'AM41', 'AH41', 'AK4', 'AM42', 'AJ1', 'AK40', 'AN2', 'AJ2', 'AK42', 'AN41']},{'label': 'uO', 'num': 15, 'pin_nums': ['D2', 'F39', 'H41', 'D41', 'F4', 'H42', 'E1', 'F40', 'J2', 'E2', 'F42', 'J41', 'E41', 'G1', 'E42', 'G42', 'F1', 'H1', 'F3', 'H2']},{'label': 'uP', 'num': 16, 'pin_nums': ['AU1', 'AR41', 'AR42', 'AU42', 'AT1', 'AV1', 'AT3', 'AV2', 'AV41', 'AP2', 'AT39', 'AP41', 'AT4', 'AV42', 'AR1', 'AT40', 'AW2', 'AR2', 'AW41', 'AT42']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A5', 'B6', 'A2', 'C3', 'B1', 'A3', 'B2', 'C39', 'A38', 'B37', 'C4', 'A39', 'B38', 'C40', 'A4', 'B41', 'A40', 'B42', 'A41', 'B5']},{'label': 'uR', 'num': 18, 'pin_nums': ['AY4', 'BA6', 'BB5', 'BA1', 'BB2', 'BA2', 'BB3', 'BA37', 'BB38', 'BA38', 'BB39', 'AW39', 'BA41', 'BB4', 'AW4', 'BA42', 'BB40', 'AY39', 'BA5', 'BB41']},{'label': 'uS', 'num': 19, 'pin_nums': ['B8', 'A9', 'A10', 'C10', 'B11', 'C33', 'A11', 'B12', 'A8', 'A32', 'B31', 'D10', 'A33', 'B32', 'D33', 'B35', 'A34', 'A35', 'B36', 'B7']},{'label': 'uT', 'num': 20, 'pin_nums': ['AY34', 'BB8', 'BA7', 'BA8', 'AY9', 'BB9', 'BA11', 'BB10', 'BA12', 'BB11', 'BA31', 'BB32', 'BA32', 'BB33', 'AW34', 'BA35', 'BB34', 'AW9', 'BA36', 'BB35']},{'label': 'uU', 'num': 21, 'pin_nums': ['AR3', 'C41', 'C42', 'AR40', 'AU3', 'C5', 'C7', 'AU40', 'AV3', 'C8', 'AV40', 'C9', 'D39', 'AW3', 'D4', 'AW38', 'E3', 'AW40', 'AW5', 'E40', 'AA3', 'AY10', 'G3', 'AA39', 'AY11', 'G40', 'AA4', 'AY12', 'H3', 'AA40', 'AY2', 'H40', 'AB39', 'AY31', 'J3', 'AB4', 'AY32', 'J40', 'AC3', 'AY33', 'L3', 'AC40', 'AY35', 'L40', 'AE3', 'AY37', 'N3', 'AE40', 'AY38', 'N40', 'AF3', 'AY41', 'P3', 'AF40', 'AY5', 'P40', 'AG3', 'AY6', 'R3', 'AG40', 'AY8', 'R40', 'AJ3', 'C1', 'U3', 'AJ40', 'C11', 'U40', 'AL3', 'C2', 'W3', 'AL40', 'C32', 'W40', 'AM3', 'C34', 'Y3', 'AM40', 'C35', 'Y40', 'AN3', 'C36', 'AN40', 'C38']},{'label': 'uV', 'num': 22, 'pin_nums': ['AG29', 'R14', 'R15', 'AH16', 'AB21', 'AB22', 'AH28', 'R16', 'AC21', 'AJ16', 'R29', 'AC22', 'AJ27', 'T14', 'AF15', 'AJ28', 'T29', 'AF16', 'P13', 'T30', 'AA21', 'AG16', 'P15', 'AA22']},{'label': 'uW', 'num': 23, 'pin_nums': ['W18', 'A36', 'AH25', 'AD21', 'D14', 'E26', 'R22', 'W20', 'A37', 'AH27', 'AD23', 'E27', 'D15', 'R24', 'W22', 'A6', 'AD25', 'AJ20', 'D17', 'E28', 'AH23', 'R28', 'W24', 'A7', 'AD27', 'AJ22', 'D18', 'E31', 'T13', 'W26', 'AA12', 'AD29', 'AJ26', 'D19', 'E32', 'T15', 'W28', 'AA14', 'AE12', 'B10', 'D24', 'E33', 'T17', 'Y13', 'AA16', 'AE14', 'B15', 'D25', 'E34', 'T19', 'Y15', 'AA18', 'AE16', 'B16', 'E38', 'D26', 'T21', 'Y17', 'AA20', 'AE18', 'B19', 'D28', 'E39', 'T23', 'Y19', 'AA24', 'AE20', 'B20', 'D29', 'E4', 'T25', 'Y21', 'E21', 'AA26', 'AE22', 'B24', 'D3', 'E5', 'T27', 'Y22', 'AA28', 'AE24', 'B27', 'D30', 'E6', 'U14', 'Y23', 'AB13', 'AE26', 'B28', 'D31', 'E9', 'U16', 'Y25', 'AB15', 'AE28', 'B3', 'D32', 'F18', 'U18', 'Y27', 'AB17', 'AE30', 'B33', 'D34', 'F2', 'U20', 'AB19', 'AF13', 'B34', 'D35', 'F28', 'U22', 'AB23', 'AF17', 'B39', 'D36', 'F33', 'U24', 'AB25', 'AF19', 'B4', 'D37', 'F38', 'U26', 'AB27', 'AF21', 'B40', 'D38', 'F41', 'U28', 'AB29', 'AF23', 'B9', 'D40', 'F5', 'V13', 'AC12', 'AF25', 'C12', 'D42', 'F8', 'V15', 'AC14', 'AF27', 'C18', 'D5', 'G15', 'V17', 'AC16', 'AG18', 'C19', 'D6', 'G2', 'V19', 'A12', 'AC18', 'AG20', 'C24', 'D7', 'G25', 'V21', 'A13', 'AC20', 'AG22', 'C25', 'D8', 'G35', 'V23', 'A18', 'AC24', 'AG24', 'C31', 'D9', 'G38', 'V25', 'A19', 'AC26', 'AG26', 'C37', 'E10', 'G4', 'V27', 'A23', 'AC28', 'AG28', 'C6', 'E11', 'G5', 'V29', 'A24', 'AD13', 'AG30', 'D1', 'E15', 'N20', 'W12', 'A25', 'AD15', 'AH19', 'D11', 'E16', 'P23', 'W14', 'A30', 'AD17', 'AH21', 'D12', 'E17', 'R18', 'W16', 'A31', 'AD19', 'D13', 'R20']},{'label': 'uX', 'num': 24, 'pin_nums': ['K26', 'T40', 'AD22', 'W13', 'AB16', 'AF30', 'AJ21', 'AN27', 'K3', 'P16', 'T42', 'AD24', 'AB18', 'W15', 'AJ23', 'AF38', 'AN37', 'K36', 'P20', 'T8', 'AB20', 'AD26', 'W17', 'AF39', 'AJ29', 'AN39', 'K39', 'P24', 'U13', 'AB24', 'AD28', 'W19', 'AF4', 'AJ38', 'AN4', 'K4', 'P34', 'U15', 'AB26', 'AD34', 'W2', 'AF8', 'AJ39', 'AN42', 'K40', 'P39', 'U17', 'AB28', 'AD38', 'W21', 'AG1', 'AJ4', 'AN7', 'K42', 'P4', 'U19', 'AB3', 'AD41', 'W23', 'AG15', 'AJ5', 'AP1', 'K6', 'R1', 'U21', 'AB30', 'W25', 'AD5', 'AJ9', 'AG17', 'AP14', 'L13', 'R11', 'U23', 'AB38', 'AE11', 'W27', 'AG19', 'AK16', 'AP24', 'L23', 'R13', 'U25', 'AB40', 'AE13', 'W29', 'AG21', 'AK2', 'AP3', 'L33', 'R17', 'U27', 'AB42', 'AE15', 'W38', 'AG23', 'AK26', 'AP34', 'L38', 'R19', 'U35', 'AB5', 'AE17', 'W39', 'AG25', 'AK36', 'AP39', 'L39', 'R21', 'U38', 'AC13', 'AE19', 'W4', 'AG27', 'AK38', 'AP4', 'L4', 'R23', 'U39', 'AC15', 'AE2', 'W41', 'AG35', 'AK41', 'AP40', 'L5', 'R25', 'U4', 'AC17', 'AE21', 'W5', 'AG39', 'AK5', 'AP42', 'M10', 'AA1', 'R31', 'U5', 'AC19', 'AE23', 'W9', 'AG4', 'AK6', 'G39', 'M2', 'AA13', 'R39', 'V12', 'AC23', 'AE25', 'Y12', 'AG42', 'AL13', 'G41', 'M20', 'AA15', 'R4', 'V14', 'AC25', 'AE27', 'Y14', 'AG5', 'AL2', 'H12', 'M30', 'AA17', 'R42', 'V16', 'AC27', 'AE29', 'Y16', 'AH1', 'AL23', 'AD20', 'H22', 'M38', 'AA19', 'T1', 'V18', 'AC29', 'AE31', 'Y18', 'AH12', 'AL33', 'H32', 'M41', 'AA23', 'T12', 'V2', 'AC37', 'AE38', 'Y20', 'AH18', 'AL38', 'H39', 'M5', 'AA25', 'T16', 'V20', 'AC38', 'AE39', 'Y24', 'AH20', 'AL39', 'H4', 'N17', 'AA27', 'T18', 'V22', 'AC39', 'AE4', 'Y26', 'AH22', 'AL4', 'J1', 'N2', 'AA29', 'T20', 'V24', 'AC4', 'AE41', 'Y28', 'AH24', 'AL41', 'J19', 'N27', 'AA33', 'T22', 'V26', 'AC5', 'AE5', 'Y36', 'AH26', 'AL5', 'J29', 'N37', 'AA38', 'T24', 'V28', 'AC7', 'AE6', 'Y38', 'AH3', 'AM10', 'J39', 'N38', 'AJ19', 'AA42', 'T26', 'V30', 'AD12', 'AF18', 'Y39', 'AH32', 'AM20', 'J4', 'N39', 'AA5', 'T28', 'V32', 'AD14', 'AF20', 'Y4', 'AH39', 'AM30', 'J42', 'N4', 'AB1', 'T3', 'V37', 'AD16', 'AF22', 'Y5', 'AH4', 'AM39', 'J9', 'N41', 'AB10', 'T38', 'V38', 'AD18', 'AF24', 'Y6', 'AH40', 'AM4', 'K1', 'N5', 'AB12', 'P14', 'T39', 'V41', 'AD2', 'AF26', 'AH42', 'AN1', 'K16', 'N7', 'AB14', 'T4', 'V5', 'AF28', 'AN17']},{'label': 'uY', 'num': 25, 'pin_nums': ['AW35', 'AR31', 'AV32', 'AW36', 'BB13', 'AR38', 'AV33', 'AW37', 'BB18', 'AR39', 'AV34', 'AW42', 'BB19', 'AR4', 'AV35', 'AW6', 'BB20', 'AR5', 'AV37', 'AW7', 'BB24', 'AT18', 'AV38', 'AW8', 'BB25', 'AT2', 'AV39', 'AY1', 'BB30', 'AT28', 'AV4', 'AY13', 'BB31', 'AT38', 'AV5', 'AY19', 'BB36', 'AT41', 'AV6', 'AY24', 'BB37', 'AT5', 'AV8', 'AY3', 'BB6', 'AT8', 'AV9', 'AY30', 'AR21', 'BB7', 'AU10', 'AW1', 'AY36', 'AU15', 'AW10', 'AY40', 'AU2', 'AW11', 'AY42', 'AU25', 'AW12', 'AY7', 'AU35', 'AW13', 'BA10', 'AU38', 'AW14', 'BA15', 'AU39', 'AW16', 'BA16', 'AU4', 'AW17', 'BA19', 'AU41', 'AW18', 'BA23', 'AU5', 'AW19', 'BA24', 'AV10', 'AW24', 'BA27', 'AV12', 'AW25', 'BA28', 'AV14', 'AW26', 'BA3', 'AV15', 'AW27', 'BA33', 'AV16', 'AW29', 'BA34', 'AV17', 'AW30', 'BA39', 'AV22', 'AW31', 'BA4', 'AV27', 'AW32', 'BA40', 'BB12', 'AR11', 'AV28', 'AW33', 'BA9', 'AV29']}] }),
        Part(**{ 'name':'XC5VTX240T-FF1759', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC5VTX240T-FF1759'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Virtex5.kicad_sym\nXC5VTX240T-FF1759\n\nFPGA', 'pins':[
            Pin(num='AA30',name='IO_L11P_CC_SM14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA31',name='IO_L11N_CC_SM14N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA32',name='IO_L6N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA34',name='IO_L17N_SM11N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA35',name='IO_L13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA36',name='IO_L4P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA37',name='IO_L2P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB31',name='IO_L19N_SM9N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB32',name='IO_L19P_SM9P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB34',name='IO_L17P_SM11P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB35',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='AB36',name='IO_L15N_SM13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AB37',name='IO_L4N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC36',name='IO_L15P_SM13P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L5P_A9_D25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L5N_A8_D24_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L7P_A5_D21_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M29',name='IO_L6P_A7_D23_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L9N_CC_A0_D16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L9P_CC_A1_D17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_A4_D20_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L3P_A13_D29_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L1P_A17_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L2N_A14_D30_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L2P_A15_D31_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L4P_A11_D27_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L6N_A6_D22_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L3N_A12_D28_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L1N_A16_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P25',name='IO_L0N_A18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L0P_A19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L4N_VREF_A10_D26_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L8P_CC_A3_D19_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R27',name='IO_L8N_CC_A2_D18_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T35',name='IO_L12P_VRN_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T36',name='IO_L12N_VRP_11',func=pin_types.BIDIR,unit=1),
            Pin(num='T37',name='IO_L9N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U30',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U31',name='IO_L18P_SM10P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U32',name='IO_L16P_SM12P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U33',name='IO_L14P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U34',name='IO_L14N_VREF_11',func=pin_types.BIDIR,unit=1),
            Pin(num='U36',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='U37',name='IO_L9P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V31',name='IO_L18N_SM10N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V33',name='IO_L16N_SM12N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V34',name='IO_L7N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V35',name='IO_L7P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='V36',name='IO_L3N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W30',name='IO_L10P_CC_SM15P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W31',name='IO_L10N_CC_SM15N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W32',name='IO_L5N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W33',name='IO_L5P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W34',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='W35',name='IO_L1P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W36',name='IO_L1N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='W37',name='IO_L3P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y29',name='IO_L0N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y30',name='IO_L0P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y31',name='VCCO_11',func=pin_types.PWRIN,unit=1),
            Pin(num='Y32',name='IO_L6P_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y33',name='IO_L8P_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y34',name='IO_L8N_CC_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y35',name='IO_L13N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y37',name='IO_L2N_11',func=pin_types.BIDIR,unit=1),
            Pin(num='AA10',name='IO_L10N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L10P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L5N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L5P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L3P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L18N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB33',name='IO_L2P_SM6P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L7P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L9N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L9P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L12N_VRP_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='IO_L16N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC11',name='IO_L18P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC30',name='IO_L8N_CC_SM1N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC31',name='IO_L8P_CC_SM1P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AC33',name='IO_L2N_SM6N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L0N_SM8N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC35',name='IO_L0P_SM8P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L7N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC8',name='IO_L12P_VRN_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L14P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L16P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD30',name='IO_L16N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD31',name='IO_L16P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD32',name='IO_L15P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD33',name='IO_L15N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD35',name='IO_L6P_SM3P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD36',name='IO_L4N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD37',name='IO_L4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L14N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='AE32',name='IO_L12N_VRP_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE33',name='IO_L12P_VRN_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE34',name='IO_L10N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE35',name='IO_L6N_SM3N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AE36',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AE37',name='IO_L11N_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF31',name='IO_L5N_SM4N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF32',name='IO_L5P_SM4P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF33',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AF34',name='IO_L10P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF35',name='IO_L17N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF36',name='IO_L17P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AF37',name='IO_L11P_CC_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG31',name='IO_L1N_SM7N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG32',name='IO_L1P_SM7P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG33',name='IO_L3N_SM5N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG34',name='IO_L3P_SM5P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG36',name='IO_L19P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG37',name='IO_L19N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AG38',name='IO_L13N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH36',name='IO_L18N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AH37',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AH38',name='IO_L13P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ36',name='IO_L18P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ37',name='IO_L14N_VREF_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AK37',name='IO_L14P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL36',name='IO_L7N_SM2N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AL37',name='IO_L7P_SM2P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AM37',name='VCCO_13',func=pin_types.PWRIN,unit=2),
            Pin(num='AM38',name='IO_L9P_CC_SM0P_13',func=pin_types.BIDIR,unit=2),
            Pin(num='AN38',name='IO_L9N_CC_SM0N_13',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L19N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L0N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L17N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L0P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L17P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L2N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L2P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L11N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L4N_VREF_12',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L11P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L4P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='V8',name='IO_L15P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L15N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L13N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L13P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L8N_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L8P_CC_12',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L6P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L3N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='VCCO_12',func=pin_types.PWRIN,unit=2),
            Pin(num='Y7',name='IO_L1P_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L1N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L6N_12',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L17P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD6',name='IO_L1N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AD7',name='IO_L1P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE10',name='IO_L17N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE7',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AE8',name='IO_L3P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AE9',name='IO_L16N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF10',name='IO_L8P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF11',name='IO_L2P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF12',name='IO_L0N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF5',name='IO_L5P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF6',name='IO_L5N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF7',name='IO_L3N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AF9',name='IO_L16P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG10',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AG11',name='IO_L2N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG12',name='IO_L0P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG6',name='IO_L7P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG7',name='IO_L9P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG8',name='IO_L10P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AG9',name='IO_L8N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH10',name='IO_L4N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH11',name='IO_L4P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH17',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AH5',name='IO_L7N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH6',name='IO_L9N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH7',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AH8',name='IO_L10N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AH9',name='IO_L13P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ17',name='IO_L0P_CC_RS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ18',name='IO_L2N_A22_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ6',name='IO_L12P_VRN_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ7',name='IO_L12N_VRP_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AJ8',name='IO_L13N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK17',name='IO_L0N_CC_RS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK18',name='IO_L2P_A23_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK19',name='IO_L8N_D2_FS2_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK27',name='IO_L1N_CC_A24_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK28',name='IO_L1P_CC_A25_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AK7',name='IO_L14P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK8',name='IO_L11P_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AK9',name='IO_L6P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL17',name='IO_L4P_FCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL18',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AL19',name='IO_L8P_D3_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL27',name='IO_L3P_A21_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AL28',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AL6',name='IO_L14N_VREF_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL7',name='IO_L11N_CC_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AL8',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AL9',name='IO_L6N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM17',name='IO_L4N_VREF_FOE_B_MOSI_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM18',name='IO_L6P_D7_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM19',name='IO_L6N_D6_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM27',name='IO_L3N_A20_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AM5',name='IO_L18P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM6',name='IO_L19P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AM7',name='IO_L19N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN26',name='IO_L7N_D4_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AN5',name='IO_L18N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AN6',name='VCCO_14',func=pin_types.PWRIN,unit=3),
            Pin(num='AP25',name='IO_L9P_D1_FS1_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AP26',name='IO_L7P_D5_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AP27',name='IO_L5N_CSO_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AP5',name='IO_L15P_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AP6',name='IO_L15N_14',func=pin_types.BIDIR,unit=3),
            Pin(num='AR25',name='IO_L9N_D0_FS0_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AR26',name='VCCO_2',func=pin_types.PWRIN,unit=3),
            Pin(num='AR27',name='IO_L5P_FWE_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L3P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='E8',name='IO_L3N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='IO_L5N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='F7',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='G37',name='IO_L4P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='G6',name='IO_L5P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='G7',name='IO_L1P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='G8',name='IO_L1N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='H34',name='IO_L0N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H35',name='IO_L2P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H36',name='IO_L2N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H37',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='H38',name='IO_L4N_VREF_23',func=pin_types.BIDIR,unit=4),
            Pin(num='H5',name='IO_L7N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='H6',name='IO_L7P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='H7',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='IO_L9N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J33',name='IO_L0P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J34',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='J35',name='IO_L15N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J36',name='IO_L15P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J37',name='IO_L8P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J38',name='IO_L8N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L14N_VREF_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L14P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J7',name='IO_L18P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='J8',name='IO_L9P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K33',name='IO_L6N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K34',name='IO_L6P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K35',name='IO_L19N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K37',name='IO_L17P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K38',name='IO_L17N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='K5',name='IO_L4N_VREF_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K7',name='IO_L19P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K8',name='IO_L18N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='IO_L12P_VRN_24',func=pin_types.BIDIR,unit=4),
            Pin(num='L34',name='IO_L19P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L35',name='IO_L12P_VRN_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L36',name='IO_L12N_VRP_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L37',name='IO_L16N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='L6',name='IO_L4P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='L7',name='IO_L19N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='L8',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='IO_L12N_VRP_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M34',name='IO_L14N_VREF_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M35',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='M36',name='IO_L10N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M37',name='IO_L16P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L17N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M7',name='IO_L17P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M8',name='IO_L15P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='M9',name='IO_L16N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='N33',name='IO_L11N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N34',name='IO_L14P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N35',name='IO_L7N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N36',name='IO_L10P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='N8',name='IO_L15N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='N9',name='IO_L16P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='IO_L10P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='P33',name='IO_L11P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P35',name='IO_L7P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P36',name='IO_L5N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P37',name='IO_L1N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P38',name='IO_L3N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='IO_L11N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='IO_L10N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='R32',name='IO_L13N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R33',name='IO_L13P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R34',name='IO_L9P_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R35',name='IO_L5P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R36',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='R37',name='IO_L1P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R38',name='IO_L3P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L8P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='IO_L11P_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='T10',name='IO_L13N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='T11',name='IO_L13P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='T31',name='IO_L18P_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T32',name='IO_L18N_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T33',name='VCCO_23',func=pin_types.PWRIN,unit=4),
            Pin(num='T34',name='IO_L9N_CC_23',func=pin_types.BIDIR,unit=4),
            Pin(num='T9',name='IO_L8N_CC_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U10',name='VCCO_24',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='IO_L2N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U12',name='IO_L0N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U8',name='IO_L6N_24',func=pin_types.BIDIR,unit=4),
            Pin(num='U9',name='IO_L6P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='V10',name='IO_L2P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='V11',name='IO_L0P_24',func=pin_types.BIDIR,unit=4),
            Pin(num='AH33',name='IO_L10N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AH34',name='IO_L10P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AH35',name='IO_L12P_VRN_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ10',name='IO_L4P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ11',name='IO_L4N_VREF_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ12',name='IO_L9P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ31',name='IO_L3P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ32',name='IO_L3N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ33',name='IO_L0P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ34',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AJ35',name='IO_L12N_VRP_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK10',name='IO_L2N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AK11',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AK12',name='IO_L9N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AK32',name='IO_L13P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK33',name='IO_L13N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK34',name='IO_L0N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AK35',name='IO_L9N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL10',name='IO_L2P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AL11',name='IO_L7N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AL12',name='IO_L10N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AL31',name='IO_L19P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL32',name='IO_L19N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL34',name='IO_L9P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AL35',name='IO_L18P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM11',name='IO_L7P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM12',name='IO_L10P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM13',name='IO_L18P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM31',name='IO_L17P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM32',name='IO_L17N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM33',name='IO_L8N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM34',name='IO_L6P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM35',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AM36',name='IO_L18N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AM8',name='IO_L17N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AM9',name='IO_L17P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN10',name='IO_L6N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN11',name='IO_L3N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN12',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AN13',name='IO_L18N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN31',name='IO_L15P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN32',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AN33',name='IO_L8P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN34',name='IO_L6N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN35',name='IO_L16N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN36',name='IO_L16P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AN8',name='IO_L15N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AN9',name='IO_L6P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP10',name='IO_L3P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP11',name='IO_L5P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP12',name='IO_L5N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP13',name='IO_L16P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP31',name='IO_L15N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP32',name='IO_L11P_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP33',name='IO_L11N_CC_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP35',name='IO_L7N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP36',name='IO_L7P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP37',name='IO_L14P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP38',name='IO_L14N_VREF_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AP7',name='IO_L19N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP8',name='IO_L15P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AP9',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AR10',name='IO_L1P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR12',name='IO_L16N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR35',name='IO_L4P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AR36',name='VCCO_25',func=pin_types.PWRIN,unit=5),
            Pin(num='AR37',name='IO_L5N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AR6',name='IO_L19P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR7',name='IO_L8P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR8',name='IO_L0P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AR9',name='IO_L0N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT10',name='IO_L12N_VRP_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT11',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AT35',name='IO_L4N_VREF_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AT36',name='IO_L1P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AT37',name='IO_L5P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AT6',name='IO_L13N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT7',name='IO_L8N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AT9',name='IO_L1N_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU11',name='IO_L14P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU36',name='IO_L2N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AU37',name='IO_L1N_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AU6',name='IO_L13P_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU7',name='VCCO_26',func=pin_types.PWRIN,unit=5),
            Pin(num='AU8',name='IO_L11P_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AU9',name='IO_L12P_VRN_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AV11',name='IO_L14N_VREF_26',func=pin_types.BIDIR,unit=5),
            Pin(num='AV36',name='IO_L2P_25',func=pin_types.BIDIR,unit=5),
            Pin(num='AV7',name='IO_L11N_CC_26',func=pin_types.BIDIR,unit=5),
            Pin(num='E12',name='IO_L4P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='E13',name='IO_L4N_VREF_28',func=pin_types.BIDIR,unit=6),
            Pin(num='E14',name='IO_L15P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='E29',name='IO_L16P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E30',name='IO_L14N_VREF_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E35',name='IO_L4N_VREF_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E36',name='IO_L4P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='E37',name='IO_L6P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F10',name='IO_L0P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F11',name='IO_L2N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F12',name='IO_L11N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F13',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='F14',name='IO_L15N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F15',name='IO_L17P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='F29',name='IO_L16N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F30',name='IO_L14P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F31',name='IO_L12N_VRP_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F32',name='IO_L5N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F34',name='IO_L3P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F35',name='IO_L2P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F36',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='F37',name='IO_L6N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='F9',name='IO_L0N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='IO_L2P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G12',name='IO_L11P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G13',name='IO_L13N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G14',name='IO_L17N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='G29',name='IO_L18P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G30',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='G31',name='IO_L12P_VRN_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G32',name='IO_L5P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G33',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='G34',name='IO_L3N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G36',name='IO_L2N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='G9',name='IO_L3P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H10',name='IO_L1N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H11',name='IO_L8P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H13',name='IO_L13P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H14',name='IO_L19P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H15',name='IO_L19N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='H29',name='IO_L18N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H30',name='IO_L10N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H31',name='IO_L7P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H33',name='IO_L1N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L3N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L5P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L1P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J12',name='IO_L8N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J13',name='IO_L6N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='J30',name='IO_L10P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='J31',name='IO_L7N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='J32',name='IO_L1P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='K10',name='IO_L5N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='IO_L7N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K13',name='IO_L7P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K14',name='IO_L6P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='K29',name='IO_L9P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='K30',name='IO_L0N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='K31',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='K32',name='IO_L8N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='IO_L10P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='L11',name='IO_L10N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='IO_L9P_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='L29',name='IO_L9N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L30',name='IO_L0P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L31',name='IO_L8P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='L32',name='IO_L11N_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='M11',name='IO_L14P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='M12',name='IO_L9N_CC_28',func=pin_types.BIDIR,unit=6),
            Pin(num='M13',name='IO_L12N_VRP_28',func=pin_types.BIDIR,unit=6),
            Pin(num='M31',name='IO_L13P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='M32',name='IO_L13N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='M33',name='IO_L11P_CC_27',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='IO_L14N_VREF_28',func=pin_types.BIDIR,unit=6),
            Pin(num='N11',name='IO_L16N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='VCCO_28',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='IO_L12P_VRN_28',func=pin_types.BIDIR,unit=6),
            Pin(num='N30',name='IO_L15N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='N31',name='IO_L15P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='N32',name='VCCO_27',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='IO_L16P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='P12',name='IO_L18P_28',func=pin_types.BIDIR,unit=6),
            Pin(num='P30',name='IO_L19P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='P31',name='IO_L17P_27',func=pin_types.BIDIR,unit=6),
            Pin(num='P32',name='IO_L17N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='R12',name='IO_L18N_28',func=pin_types.BIDIR,unit=6),
            Pin(num='R30',name='IO_L19N_27',func=pin_types.BIDIR,unit=6),
            Pin(num='AH29',name='IO_L0N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AH30',name='IO_L0P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AH31',name='IO_L2P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ30',name='IO_L2N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AK29',name='IO_L4P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AK30',name='IO_L4N_VREF_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AK31',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AL29',name='IO_L17P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AL30',name='IO_L17N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AM28',name='IO_L9P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AM29',name='IO_L15P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AN28',name='IO_L1P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AN29',name='IO_L9N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AN30',name='IO_L15N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AP28',name='IO_L1N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AP29',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AP30',name='IO_L12N_VRP_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR28',name='IO_L10P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR29',name='IO_L10N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR30',name='IO_L12P_VRN_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR32',name='IO_L13P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR33',name='IO_L8N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AR34',name='IO_L8P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT25',name='IO_L3N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT26',name='IO_L3P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT27',name='IO_L7N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT29',name='IO_L14P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT30',name='IO_L19P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT31',name='IO_L19N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT32',name='IO_L13N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AT33',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AT34',name='IO_L6N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU26',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AU27',name='IO_L7P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU28',name='IO_L14N_VREF_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU29',name='IO_L16P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU30',name='VCCO_29',func=pin_types.PWRIN,unit=7),
            Pin(num='AU31',name='IO_L18N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU32',name='IO_L11P_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU33',name='IO_L11N_CC_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AU34',name='IO_L6P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV25',name='IO_L5N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV26',name='IO_L5P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV30',name='IO_L16N_29',func=pin_types.BIDIR,unit=7),
            Pin(num='AV31',name='IO_L18P_29',func=pin_types.BIDIR,unit=7),
            Pin(num='J14',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='J15',name='IO_L2P_GC_VRN_3',func=pin_types.BIDIR,unit=7),
            Pin(num='J16',name='IO_L2N_GC_VRP_3',func=pin_types.BIDIR,unit=7),
            Pin(num='K15',name='IO_L4N_GC_VREF_3',func=pin_types.BIDIR,unit=7),
            Pin(num='K27',name='IO_L7P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='K28',name='IO_L7N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L15',name='IO_L4P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L16',name='IO_L8P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L17',name='IO_L8N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L18',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='L19',name='IO_L0P_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L25',name='IO_L3N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L26',name='IO_L5P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L27',name='IO_L5N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='L28',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='M17',name='IO_L6P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M18',name='IO_L6N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M19',name='IO_L0N_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M24',name='IO_L1N_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M25',name='VCCO_3',func=pin_types.PWRIN,unit=7),
            Pin(num='M26',name='IO_L3P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M27',name='IO_L9N_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='M28',name='IO_L9P_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='N24',name='IO_L1P_CC_GC_3',func=pin_types.BIDIR,unit=7),
            Pin(num='AG13',name='IO_L3N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AH13',name='IO_L5P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AH14',name='IO_L3P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AH15',name='IO_L1N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ13',name='IO_L5N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ14',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ15',name='IO_L1P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ24',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ25',name='IO_L4P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK13',name='IO_L7P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK14',name='IO_L7N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK15',name='IO_L19P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK20',name='IO_L9P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK21',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AK23',name='IO_L8P_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK24',name='IO_L8N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AK25',name='IO_L4N_GC_VREF_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL14',name='IO_L16N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AL15',name='IO_L19N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AL16',name='IO_L4P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AL20',name='IO_L9N_CC_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL21',name='IO_L7P_GC_VRN_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL24',name='IO_L6N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL25',name='IO_L6P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AL26',name='IO_L0P_GC_D15_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AM14',name='IO_L16P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AM15',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AM16',name='IO_L4N_VREF_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AM21',name='IO_L7N_GC_VRP_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AM24',name='IO_L2N_GC_D10_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AM25',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AM26',name='IO_L0N_GC_D14_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AN14',name='IO_L10P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN15',name='IO_L10N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN16',name='IO_L11P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN18',name='IO_L2P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AN19',name='IO_L1N_GC_D12_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AN20',name='IO_L1P_GC_D13_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AN25',name='IO_L2P_GC_D11_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AP15',name='IO_L14P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP16',name='IO_L15N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP17',name='IO_L11N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP18',name='IO_L2N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AP19',name='VCCO_4',func=pin_types.PWRIN,unit=8),
            Pin(num='AP20',name='IO_L5N_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AP21',name='IO_L5P_GC_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AR13',name='IO_L9N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR14',name='IO_L14N_VREF_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR15',name='IO_L15P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR16',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AR17',name='IO_L8N_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR18',name='IO_L0N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR19',name='IO_L0P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AR20',name='IO_L3P_GC_D9_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AT12',name='IO_L9P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT13',name='VCCO_30',func=pin_types.PWRIN,unit=8),
            Pin(num='AT14',name='IO_L12N_VRP_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT15',name='IO_L17N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT16',name='IO_L13P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT17',name='IO_L8P_CC_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AT20',name='IO_L3N_GC_D8_4',func=pin_types.BIDIR,unit=8),
            Pin(num='AU12',name='IO_L18P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU13',name='IO_L12P_VRN_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU14',name='IO_L17P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU16',name='IO_L13N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU17',name='IO_L6N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AU18',name='IO_L6P_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AV13',name='IO_L18N_30',func=pin_types.BIDIR,unit=8),
            Pin(num='AK22',name='IO_L12N_VRP_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AL22',name='IO_L12P_VRN_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM22',name='IO_L10N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AM23',name='IO_L8P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN21',name='IO_L10P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN22',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AN23',name='IO_L13P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AN24',name='IO_L8N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP22',name='IO_L17N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AP23',name='IO_L13N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AR22',name='IO_L17P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AR23',name='IO_L15P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AR24',name='IO_L0P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT19',name='IO_L7P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT21',name='IO_L19N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT22',name='IO_L15N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AT23',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AT24',name='IO_L0N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU19',name='IO_L7N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU20',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AU21',name='IO_L19P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU22',name='IO_L18N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU23',name='IO_L6N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AU24',name='IO_L2N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV18',name='IO_L1P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV19',name='IO_L1N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV20',name='IO_L9P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV21',name='IO_L18P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV23',name='IO_L6P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AV24',name='IO_L2P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW20',name='IO_L9N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW21',name='IO_L16P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW22',name='IO_L16N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AW23',name='IO_L11P_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AY20',name='IO_L14N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AY21',name='VCCO_6',func=pin_types.PWRIN,unit=9),
            Pin(num='AY22',name='IO_L5N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='AY23',name='IO_L11N_CC_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BA20',name='IO_L14P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BA21',name='IO_L5P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BA22',name='IO_L3P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BB21',name='IO_L3N_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BB22',name='IO_L4P_6',func=pin_types.BIDIR,unit=9),
            Pin(num='BB23',name='IO_L4N_VREF_6',func=pin_types.BIDIR,unit=9),
            Pin(num='E18',name='IO_L14N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E19',name='IO_L14P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='E20',name='IO_L1P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F16',name='IO_L16N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F17',name='IO_L16P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F19',name='IO_L5P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F20',name='IO_L1N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F26',name='IO_L8P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='F27',name='IO_L13N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G16',name='IO_L18N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G17',name='IO_L7N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G18',name='IO_L7P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G19',name='IO_L5N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G20',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='G24',name='IO_L6P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G26',name='IO_L8N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G27',name='IO_L13P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='G28',name='IO_L17N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H16',name='IO_L18P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H17',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='H18',name='IO_L12N_VRP_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H19',name='IO_L3N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H20',name='IO_L3P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H23',name='IO_L4P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H24',name='IO_L4N_VREF_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H25',name='IO_L6N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H26',name='IO_L15N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='H27',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='H28',name='IO_L17P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J17',name='IO_L9P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J18',name='IO_L12P_VRN_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J23',name='IO_L0N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J24',name='VCCO_5',func=pin_types.PWRIN,unit=9),
            Pin(num='J25',name='IO_L11N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J26',name='IO_L15P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J27',name='IO_L19N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='J28',name='IO_L19P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K17',name='IO_L9N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K18',name='IO_L10P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K19',name='IO_L10N_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K23',name='IO_L0P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K24',name='IO_L2P_5',func=pin_types.BIDIR,unit=9),
            Pin(num='K25',name='IO_L11P_CC_5',func=pin_types.BIDIR,unit=9),
            Pin(num='L24',name='IO_L2N_5',func=pin_types.BIDIR,unit=9),
            Pin(num='A20',name='IO_L14P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='A21',name='IO_L14N_VREF_7',func=pin_types.BIDIR,unit=10),
            Pin(num='A22',name='IO_L11N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='B21',name='IO_L11P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='B22',name='IO_L8P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='B23',name='IO_L8N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='C20',name='IO_L12N_VRP_7',func=pin_types.BIDIR,unit=10),
            Pin(num='C21',name='IO_L6P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='C22',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='C23',name='IO_L4N_VREF_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D20',name='IO_L12P_VRN_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D21',name='IO_L6N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D22',name='IO_L4P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='D23',name='IO_L3P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E22',name='IO_L3N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E23',name='IO_L17N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E24',name='IO_L17P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='E25',name='IO_L19N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F21',name='IO_L9P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F22',name='IO_L5P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F23',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='F24',name='IO_L13N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='F25',name='IO_L19P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='G21',name='IO_L9N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='G22',name='IO_L5N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='G23',name='IO_L13P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='H21',name='IO_L10N_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='J20',name='IO_L10P_CC_7',func=pin_types.BIDIR,unit=10),
            Pin(num='J21',name='IO_L0N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='J22',name='IO_L0P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='K20',name='IO_L16N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='K21',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='K22',name='IO_L7P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='L20',name='IO_L16P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='L21',name='IO_L7N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='L22',name='IO_L2N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='M21',name='IO_L1N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='M22',name='IO_L2P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='M23',name='IO_L15P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='N21',name='IO_L1P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='N22',name='VCCO_7',func=pin_types.PWRIN,unit=10),
            Pin(num='N23',name='IO_L15N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='P21',name='IO_L18P_7',func=pin_types.BIDIR,unit=10),
            Pin(num='P22',name='IO_L18N_7',func=pin_types.BIDIR,unit=10),
            Pin(num='AA2',name='MGTTXP1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='AA41',name='MGTTXP1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='T2',name='MGTTXP0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='T41',name='MGTTXP0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='U1',name='MGTRXP0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='U2',name='MGTTXN0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='U41',name='MGTTXN0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='U42',name='MGTRXP0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='V1',name='MGTRXN0_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V3',name='MGTREFCLKN_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V39',name='MGTREFCLKP_111',func=pin_types.BIDIR,unit=11),
            Pin(num='V4',name='MGTREFCLKP_112',func=pin_types.BIDIR,unit=11),
            Pin(num='V40',name='MGTREFCLKN_111',func=pin_types.BIDIR,unit=11),
            Pin(num='V42',name='MGTRXN0_111',func=pin_types.BIDIR,unit=11),
            Pin(num='W1',name='MGTRXN1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='W42',name='MGTRXN1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='Y1',name='MGTRXP1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='Y2',name='MGTTXN1_112',func=pin_types.BIDIR,unit=11),
            Pin(num='Y41',name='MGTTXN1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='Y42',name='MGTRXP1_111',func=pin_types.BIDIR,unit=11),
            Pin(num='AB2',name='MGTTXP0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AB41',name='MGTTXP0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AC1',name='MGTRXP0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AC2',name='MGTTXN0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AC41',name='MGTTXN0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AC42',name='MGTRXP0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AD1',name='MGTRXN0_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AD3',name='MGTREFCLKN_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AD39',name='MGTREFCLKP_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AD4',name='MGTREFCLKP_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AD40',name='MGTREFCLKN_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AD42',name='MGTRXN0_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AE1',name='MGTRXN1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AE42',name='MGTRXN1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AF1',name='MGTRXP1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AF2',name='MGTTXN1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AF41',name='MGTTXN1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AF42',name='MGTRXP1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='AG2',name='MGTTXP1_114',func=pin_types.BIDIR,unit=12),
            Pin(num='AG41',name='MGTTXP1_113',func=pin_types.BIDIR,unit=12),
            Pin(num='K2',name='MGTTXP0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='K41',name='MGTTXP0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='L1',name='MGTRXP0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='L2',name='MGTTXN0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='L41',name='MGTTXN0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='L42',name='MGTRXP0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='M1',name='MGTRXN0_116',func=pin_types.BIDIR,unit=13),
            Pin(num='M3',name='MGTREFCLKN_116',func=pin_types.BIDIR,unit=13),
            Pin(num='M39',name='MGTREFCLKP_115',func=pin_types.BIDIR,unit=13),
            Pin(num='M4',name='MGTREFCLKP_116',func=pin_types.BIDIR,unit=13),
            Pin(num='M40',name='MGTREFCLKN_115',func=pin_types.BIDIR,unit=13),
            Pin(num='M42',name='MGTRXN0_115',func=pin_types.BIDIR,unit=13),
            Pin(num='N1',name='MGTRXN1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='N42',name='MGTRXN1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='P1',name='MGTRXP1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='P2',name='MGTTXN1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='P41',name='MGTTXN1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='P42',name='MGTRXP1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='R2',name='MGTTXP1_116',func=pin_types.BIDIR,unit=13),
            Pin(num='R41',name='MGTTXP1_115',func=pin_types.BIDIR,unit=13),
            Pin(num='AH2',name='MGTTXP0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AH41',name='MGTTXP0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ1',name='MGTRXP0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ2',name='MGTTXN0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ41',name='MGTTXN0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AJ42',name='MGTRXP0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AK1',name='MGTRXN0_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK3',name='MGTREFCLKN_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK39',name='MGTREFCLKP_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AK4',name='MGTREFCLKP_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AK40',name='MGTREFCLKN_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AK42',name='MGTRXN0_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AL1',name='MGTRXN1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AL42',name='MGTRXN1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AM1',name='MGTRXP1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AM2',name='MGTTXN1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AM41',name='MGTTXN1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AM42',name='MGTRXP1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='AN2',name='MGTTXP1_118',func=pin_types.BIDIR,unit=14),
            Pin(num='AN41',name='MGTTXP1_117',func=pin_types.BIDIR,unit=14),
            Pin(num='D2',name='MGTTXP0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='D41',name='MGTTXP0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='E1',name='MGTRXP0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='E2',name='MGTTXN0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='E41',name='MGTTXN0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='E42',name='MGTRXP0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='F1',name='MGTRXN0_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F3',name='MGTREFCLKN_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F39',name='MGTREFCLKP_119',func=pin_types.BIDIR,unit=15),
            Pin(num='F4',name='MGTREFCLKP_120',func=pin_types.BIDIR,unit=15),
            Pin(num='F40',name='MGTREFCLKN_119',func=pin_types.BIDIR,unit=15),
            Pin(num='F42',name='MGTRXN0_119',func=pin_types.BIDIR,unit=15),
            Pin(num='G1',name='MGTRXN1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='G42',name='MGTRXN1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='H1',name='MGTRXP1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='H2',name='MGTTXN1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='H41',name='MGTTXN1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='H42',name='MGTRXP1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='J2',name='MGTTXP1_120',func=pin_types.BIDIR,unit=15),
            Pin(num='J41',name='MGTTXP1_119',func=pin_types.BIDIR,unit=15),
            Pin(num='AP2',name='MGTTXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AP41',name='MGTTXP0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AR1',name='MGTRXP0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR2',name='MGTTXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AR41',name='MGTTXN0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AR42',name='MGTRXP0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AT1',name='MGTRXN0_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT3',name='MGTREFCLKN_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT39',name='MGTREFCLKP_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AT4',name='MGTREFCLKP_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AT40',name='MGTREFCLKN_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AT42',name='MGTRXN0_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AU1',name='MGTRXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AU42',name='MGTRXN1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AV1',name='MGTRXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV2',name='MGTTXN1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AV41',name='MGTTXN1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AV42',name='MGTRXP1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='AW2',name='MGTTXP1_122',func=pin_types.BIDIR,unit=16),
            Pin(num='AW41',name='MGTTXP1_121',func=pin_types.BIDIR,unit=16),
            Pin(num='A2',name='MGTRXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A3',name='MGTRXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A38',name='MGTRXP0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A39',name='MGTRXN0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A4',name='MGTRXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='A40',name='MGTRXN1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A41',name='MGTRXP1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='A5',name='MGTRXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B1',name='MGTTXP1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B2',name='MGTTXN1_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B37',name='MGTTXP0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B38',name='MGTTXN0_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B41',name='MGTTXN1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B42',name='MGTTXP1_123',func=pin_types.BIDIR,unit=17),
            Pin(num='B5',name='MGTTXN0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='B6',name='MGTTXP0_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C3',name='MGTREFCLKN_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C39',name='MGTREFCLKP_123',func=pin_types.BIDIR,unit=17),
            Pin(num='C4',name='MGTREFCLKP_124',func=pin_types.BIDIR,unit=17),
            Pin(num='C40',name='MGTREFCLKN_123',func=pin_types.BIDIR,unit=17),
            Pin(num='AW39',name='MGTREFCLKP_125',func=pin_types.BIDIR,unit=18),
            Pin(num='AW4',name='MGTREFCLKP_126',func=pin_types.BIDIR,unit=18),
            Pin(num='AY39',name='MGTREFCLKN_125',func=pin_types.BIDIR,unit=18),
            Pin(num='AY4',name='MGTREFCLKN_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA1',name='MGTTXP0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA2',name='MGTTXN0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA37',name='MGTTXP1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA38',name='MGTTXN1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA41',name='MGTTXN0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA42',name='MGTTXP0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BA5',name='MGTTXN1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BA6',name='MGTTXP1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB2',name='MGTRXP0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB3',name='MGTRXN0_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB38',name='MGTRXP1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB39',name='MGTRXN1_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB4',name='MGTRXN1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='BB40',name='MGTRXN0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB41',name='MGTRXP0_125',func=pin_types.BIDIR,unit=18),
            Pin(num='BB5',name='MGTRXP1_126',func=pin_types.BIDIR,unit=18),
            Pin(num='A10',name='MGTRXN0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='A11',name='MGTRXP0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='A32',name='MGTRXP0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A33',name='MGTRXN0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A34',name='MGTRXN1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A35',name='MGTRXP1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='A8',name='MGTRXP1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='A9',name='MGTRXN1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B11',name='MGTTXN0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B12',name='MGTTXP0_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B31',name='MGTTXP0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B32',name='MGTTXN0_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B35',name='MGTTXN1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B36',name='MGTTXP1_127',func=pin_types.BIDIR,unit=19),
            Pin(num='B7',name='MGTTXP1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='B8',name='MGTTXN1_128',func=pin_types.BIDIR,unit=19),
            Pin(num='C10',name='MGTREFCLKN_128',func=pin_types.BIDIR,unit=19),
            Pin(num='C33',name='MGTREFCLKN_127',func=pin_types.BIDIR,unit=19),
            Pin(num='D10',name='MGTREFCLKP_128',func=pin_types.BIDIR,unit=19),
            Pin(num='D33',name='MGTREFCLKP_127',func=pin_types.BIDIR,unit=19),
            Pin(num='AW34',name='MGTREFCLKP_129',func=pin_types.BIDIR,unit=20),
            Pin(num='AW9',name='MGTREFCLKP_130',func=pin_types.BIDIR,unit=20),
            Pin(num='AY34',name='MGTREFCLKN_129',func=pin_types.BIDIR,unit=20),
            Pin(num='AY9',name='MGTREFCLKN_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA11',name='MGTTXN1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA12',name='MGTTXP1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA31',name='MGTTXP1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA32',name='MGTTXN1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA35',name='MGTTXN0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA36',name='MGTTXP0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BA7',name='MGTTXP0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BA8',name='MGTTXN0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB10',name='MGTRXN1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB11',name='MGTRXP1_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB32',name='MGTRXP1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB33',name='MGTRXN1_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB34',name='MGTRXN0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB35',name='MGTRXP0_129',func=pin_types.BIDIR,unit=20),
            Pin(num='BB8',name='MGTRXP0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='BB9',name='MGTRXN0_130',func=pin_types.BIDIR,unit=20),
            Pin(num='A14',name='MGTRXP1_132',func=pin_types.BIDIR,unit=21),
            Pin(num='A15',name='MGTRXN1_132',func=pin_types.BIDIR,unit=21),
            Pin(num='A16',name='MGTRXN0_132',func=pin_types.BIDIR,unit=21),
            Pin(num='A17',name='MGTRXP0_132',func=pin_types.BIDIR,unit=21),
            Pin(num='A26',name='MGTRXP0_131',func=pin_types.BIDIR,unit=21),
            Pin(num='A27',name='MGTRXN0_131',func=pin_types.BIDIR,unit=21),
            Pin(num='A28',name='MGTRXN1_131',func=pin_types.BIDIR,unit=21),
            Pin(num='A29',name='MGTRXP1_131',func=pin_types.BIDIR,unit=21),
            Pin(num='B13',name='MGTTXP1_132',func=pin_types.BIDIR,unit=21),
            Pin(num='B14',name='MGTTXN1_132',func=pin_types.BIDIR,unit=21),
            Pin(num='B17',name='MGTTXN0_132',func=pin_types.BIDIR,unit=21),
            Pin(num='B18',name='MGTTXP0_132',func=pin_types.BIDIR,unit=21),
            Pin(num='B25',name='MGTTXP0_131',func=pin_types.BIDIR,unit=21),
            Pin(num='B26',name='MGTTXN0_131',func=pin_types.BIDIR,unit=21),
            Pin(num='B29',name='MGTTXN1_131',func=pin_types.BIDIR,unit=21),
            Pin(num='B30',name='MGTTXP1_131',func=pin_types.BIDIR,unit=21),
            Pin(num='C16',name='MGTREFCLKN_132',func=pin_types.BIDIR,unit=21),
            Pin(num='C27',name='MGTREFCLKN_131',func=pin_types.BIDIR,unit=21),
            Pin(num='D16',name='MGTREFCLKP_132',func=pin_types.BIDIR,unit=21),
            Pin(num='D27',name='MGTREFCLKP_131',func=pin_types.BIDIR,unit=21),
            Pin(num='AW15',name='MGTREFCLKP_134',func=pin_types.BIDIR,unit=22),
            Pin(num='AW28',name='MGTREFCLKP_133',func=pin_types.BIDIR,unit=22),
            Pin(num='AY15',name='MGTREFCLKN_134',func=pin_types.BIDIR,unit=22),
            Pin(num='AY28',name='MGTREFCLKN_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BA13',name='MGTTXP0_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BA14',name='MGTTXN0_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BA17',name='MGTTXN1_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BA18',name='MGTTXP1_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BA25',name='MGTTXP1_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BA26',name='MGTTXN1_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BA29',name='MGTTXN0_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BA30',name='MGTTXP0_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BB14',name='MGTRXP0_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BB15',name='MGTRXN0_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BB16',name='MGTRXN1_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BB17',name='MGTRXP1_134',func=pin_types.BIDIR,unit=22),
            Pin(num='BB26',name='MGTRXP1_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BB27',name='MGTRXN1_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BB28',name='MGTRXN0_133',func=pin_types.BIDIR,unit=22),
            Pin(num='BB29',name='MGTRXP0_133',func=pin_types.BIDIR,unit=22),
            Pin(num='AA3',name='MGTAVTTTX_112',func=pin_types.PWRIN,unit=23),
            Pin(num='AA39',name='MGTAVTTRXC_L',func=pin_types.PWRIN,unit=23),
            Pin(num='AA4',name='MGTAVTTRXC_R',func=pin_types.PWRIN,unit=23),
            Pin(num='AA40',name='MGTAVTTTX_111',func=pin_types.PWRIN,unit=23),
            Pin(num='AB39',name='MGTRREF_111',func=pin_types.PWRIN,unit=23),
            Pin(num='AB4',name='MGTRREF_112',func=pin_types.PWRIN,unit=23),
            Pin(num='AC3',name='MGTAVTTRX_114',func=pin_types.PWRIN,unit=23),
            Pin(num='AC40',name='MGTAVTTRX_113',func=pin_types.PWRIN,unit=23),
            Pin(num='AE3',name='MGTAVCC_114',func=pin_types.PWRIN,unit=23),
            Pin(num='AE40',name='MGTAVCC_113',func=pin_types.PWRIN,unit=23),
            Pin(num='AF3',name='MGTAVCCPLL_114',func=pin_types.PWRIN,unit=23),
            Pin(num='AF40',name='MGTAVCCPLL_113',func=pin_types.PWRIN,unit=23),
            Pin(num='AG3',name='MGTAVTTTX_114',func=pin_types.PWRIN,unit=23),
            Pin(num='AG40',name='MGTAVTTTX_113',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ3',name='MGTAVTTRX_118',func=pin_types.PWRIN,unit=23),
            Pin(num='AJ40',name='MGTAVTTRX_117',func=pin_types.PWRIN,unit=23),
            Pin(num='AL3',name='MGTAVCC_118',func=pin_types.PWRIN,unit=23),
            Pin(num='AL40',name='MGTAVCC_117',func=pin_types.PWRIN,unit=23),
            Pin(num='AM3',name='MGTAVCCPLL_118',func=pin_types.PWRIN,unit=23),
            Pin(num='AM40',name='MGTAVCCPLL_117',func=pin_types.PWRIN,unit=23),
            Pin(num='AN3',name='MGTAVTTTX_118',func=pin_types.PWRIN,unit=23),
            Pin(num='AN40',name='MGTAVTTTX_117',func=pin_types.PWRIN,unit=23),
            Pin(num='AR3',name='MGTAVTTRX_122',func=pin_types.PWRIN,unit=23),
            Pin(num='AR40',name='MGTAVTTRX_121',func=pin_types.PWRIN,unit=23),
            Pin(num='AU3',name='MGTAVCC_122',func=pin_types.PWRIN,unit=23),
            Pin(num='AU40',name='MGTAVCC_121',func=pin_types.PWRIN,unit=23),
            Pin(num='AV3',name='MGTAVCCPLL_122',func=pin_types.PWRIN,unit=23),
            Pin(num='AV40',name='MGTAVCCPLL_121',func=pin_types.PWRIN,unit=23),
            Pin(num='AW3',name='MGTAVTTTX_122',func=pin_types.PWRIN,unit=23),
            Pin(num='AW38',name='MGTAVCC_125',func=pin_types.PWRIN,unit=23),
            Pin(num='AW40',name='MGTAVTTTX_121',func=pin_types.PWRIN,unit=23),
            Pin(num='AW5',name='MGTAVCC_126',func=pin_types.PWRIN,unit=23),
            Pin(num='AY10',name='MGTAVCC_130',func=pin_types.PWRIN,unit=23),
            Pin(num='AY11',name='MGTAVCCPLL_130',func=pin_types.PWRIN,unit=23),
            Pin(num='AY12',name='MGTAVTTTX_130',func=pin_types.PWRIN,unit=23),
            Pin(num='AY14',name='MGTAVTTRX_134',func=pin_types.PWRIN,unit=23),
            Pin(num='AY16',name='MGTAVCC_134',func=pin_types.PWRIN,unit=23),
            Pin(num='AY17',name='MGTAVCCPLL_134',func=pin_types.PWRIN,unit=23),
            Pin(num='AY18',name='MGTAVTTTX_134',func=pin_types.PWRIN,unit=23),
            Pin(num='AY2',name='MGTAVTTRX_126',func=pin_types.PWRIN,unit=23),
            Pin(num='AY25',name='MGTAVTTTX_133',func=pin_types.PWRIN,unit=23),
            Pin(num='AY26',name='MGTAVCCPLL_133',func=pin_types.PWRIN,unit=23),
            Pin(num='AY27',name='MGTAVCC_133',func=pin_types.PWRIN,unit=23),
            Pin(num='AY29',name='MGTAVTTRX_133',func=pin_types.PWRIN,unit=23),
            Pin(num='AY31',name='MGTAVTTTX_129',func=pin_types.PWRIN,unit=23),
            Pin(num='AY32',name='MGTAVCCPLL_129',func=pin_types.PWRIN,unit=23),
            Pin(num='AY33',name='MGTAVCC_129',func=pin_types.PWRIN,unit=23),
            Pin(num='AY35',name='MGTAVTTRX_129',func=pin_types.PWRIN,unit=23),
            Pin(num='AY37',name='MGTAVTTTX_125',func=pin_types.PWRIN,unit=23),
            Pin(num='AY38',name='MGTAVCCPLL_125',func=pin_types.PWRIN,unit=23),
            Pin(num='AY41',name='MGTAVTTRX_125',func=pin_types.PWRIN,unit=23),
            Pin(num='AY5',name='MGTAVCCPLL_126',func=pin_types.PWRIN,unit=23),
            Pin(num='AY6',name='MGTAVTTTX_126',func=pin_types.PWRIN,unit=23),
            Pin(num='AY8',name='MGTAVTTRX_130',func=pin_types.PWRIN,unit=23),
            Pin(num='C1',name='MGTAVTTTX_124',func=pin_types.PWRIN,unit=23),
            Pin(num='C11',name='MGTAVTTRX_128',func=pin_types.PWRIN,unit=23),
            Pin(num='C13',name='MGTAVTTTX_132',func=pin_types.PWRIN,unit=23),
            Pin(num='C14',name='MGTAVCCPLL_132',func=pin_types.PWRIN,unit=23),
            Pin(num='C15',name='MGTAVCC_132',func=pin_types.PWRIN,unit=23),
            Pin(num='C17',name='MGTAVTTRX_132',func=pin_types.PWRIN,unit=23),
            Pin(num='C2',name='MGTAVCCPLL_124',func=pin_types.PWRIN,unit=23),
            Pin(num='C26',name='MGTAVTTRX_131',func=pin_types.PWRIN,unit=23),
            Pin(num='C28',name='MGTAVCC_131',func=pin_types.PWRIN,unit=23),
            Pin(num='C29',name='MGTAVCCPLL_131',func=pin_types.PWRIN,unit=23),
            Pin(num='C30',name='MGTAVTTTX_131',func=pin_types.PWRIN,unit=23),
            Pin(num='C32',name='MGTAVTTRX_127',func=pin_types.PWRIN,unit=23),
            Pin(num='C34',name='MGTAVCC_127',func=pin_types.PWRIN,unit=23),
            Pin(num='C35',name='MGTAVCCPLL_127',func=pin_types.PWRIN,unit=23),
            Pin(num='C36',name='MGTAVTTTX_127',func=pin_types.PWRIN,unit=23),
            Pin(num='C38',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=23),
            Pin(num='C41',name='MGTAVCCPLL_123',func=pin_types.PWRIN,unit=23),
            Pin(num='C42',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=23),
            Pin(num='C5',name='MGTAVTTRX_124',func=pin_types.PWRIN,unit=23),
            Pin(num='C7',name='MGTAVTTTX_128',func=pin_types.PWRIN,unit=23),
            Pin(num='C8',name='MGTAVCCPLL_128',func=pin_types.PWRIN,unit=23),
            Pin(num='C9',name='MGTAVCC_128',func=pin_types.PWRIN,unit=23),
            Pin(num='D39',name='MGTAVCC_123',func=pin_types.PWRIN,unit=23),
            Pin(num='D4',name='MGTAVCC_124',func=pin_types.PWRIN,unit=23),
            Pin(num='E3',name='MGTAVTTRX_120',func=pin_types.PWRIN,unit=23),
            Pin(num='E40',name='MGTAVTTRX_119',func=pin_types.PWRIN,unit=23),
            Pin(num='G3',name='MGTAVCC_120',func=pin_types.PWRIN,unit=23),
            Pin(num='G40',name='MGTAVCC_119',func=pin_types.PWRIN,unit=23),
            Pin(num='H3',name='MGTAVCCPLL_120',func=pin_types.PWRIN,unit=23),
            Pin(num='H40',name='MGTAVCCPLL_119',func=pin_types.PWRIN,unit=23),
            Pin(num='J3',name='MGTAVTTTX_120',func=pin_types.PWRIN,unit=23),
            Pin(num='J40',name='MGTAVTTTX_119',func=pin_types.PWRIN,unit=23),
            Pin(num='L3',name='MGTAVTTRX_116',func=pin_types.PWRIN,unit=23),
            Pin(num='L40',name='MGTAVTTRX_115',func=pin_types.PWRIN,unit=23),
            Pin(num='N3',name='MGTAVCC_116',func=pin_types.PWRIN,unit=23),
            Pin(num='N40',name='MGTAVCC_115',func=pin_types.PWRIN,unit=23),
            Pin(num='P3',name='MGTAVCCPLL_116',func=pin_types.PWRIN,unit=23),
            Pin(num='P40',name='MGTAVCCPLL_115',func=pin_types.PWRIN,unit=23),
            Pin(num='R3',name='MGTAVTTTX_116',func=pin_types.PWRIN,unit=23),
            Pin(num='R40',name='MGTAVTTTX_115',func=pin_types.PWRIN,unit=23),
            Pin(num='U3',name='MGTAVTTRX_112',func=pin_types.PWRIN,unit=23),
            Pin(num='U40',name='MGTAVTTRX_111',func=pin_types.PWRIN,unit=23),
            Pin(num='W3',name='MGTAVCC_112',func=pin_types.PWRIN,unit=23),
            Pin(num='W40',name='MGTAVCC_111',func=pin_types.PWRIN,unit=23),
            Pin(num='Y3',name='MGTAVCCPLL_112',func=pin_types.PWRIN,unit=23),
            Pin(num='Y40',name='MGTAVCCPLL_111',func=pin_types.PWRIN,unit=23),
            Pin(num='AA21',name='VREFN_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AA22',name='VP_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AB21',name='VN_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AB22',name='VREFP_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AC21',name='DXN_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AC22',name='DXP_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AF15',name='TMS_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AF16',name='TCK_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AG16',name='TDI_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AG29',name='D_OUT_BUSY_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AH16',name='TDO_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AH28',name='M2_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AJ16',name='CCLK_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AJ27',name='M1_0',func=pin_types.BIDIR,unit=24),
            Pin(num='AJ28',name='M0_0',func=pin_types.BIDIR,unit=24),
            Pin(num='P13',name='VCCO_0',func=pin_types.PWRIN,unit=24),
            Pin(num='P15',name='RDWR_B_0',func=pin_types.BIDIR,unit=24),
            Pin(num='R14',name='DONE_0',func=pin_types.BIDIR,unit=24),
            Pin(num='R15',name='D_IN_0',func=pin_types.BIDIR,unit=24),
            Pin(num='R16',name='VCCO_0',func=pin_types.PWRIN,unit=24),
            Pin(num='R29',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=24),
            Pin(num='T14',name='INIT_B_0',func=pin_types.BIDIR,unit=24),
            Pin(num='T29',name='HSWAPEN_0',func=pin_types.BIDIR,unit=24),
            Pin(num='T30',name='CS_B_0',func=pin_types.BIDIR,unit=24),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A23',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A36',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A37',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='AA12',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AA14',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA28',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AB13',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB15',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB17',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AB29',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AC12',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AC14',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AC16',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AC18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AC20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AC24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AC26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AC28',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD13',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AD15',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD17',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD21',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AD29',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AE12',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE16',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE22',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE28',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AE30',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AF13',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AF17',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AF19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AF21',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AF23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AF25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AF27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AG18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AG20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AG22',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AG24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AG26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AG28',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AG30',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='AH19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AH21',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AH23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AH25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AH27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AJ20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AJ22',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AJ26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B27',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B33',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B39',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B40',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C37',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D19',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D24',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D26',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D29',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D30',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D32',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D34',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D35',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D36',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D37',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D40',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D42',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E26',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E27',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E31',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E32',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E33',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E34',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E39',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F18',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F28',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F33',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F41',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G25',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G35',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G38',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=25),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='P23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='R22',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='R24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='R28',name='VBATT_0',func=pin_types.PWRIN,unit=25),
            Pin(num='T13',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='T21',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='T23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='T25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='T27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U22',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='U28',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='V13',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V21',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='V29',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='W12',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='W14',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W18',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W22',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W24',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W26',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='W28',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='Y13',name='VCCAUX',func=pin_types.PWRIN,unit=25),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='Y17',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='Y21',name='AVSS_0',func=pin_types.PWRIN,unit=25),
            Pin(num='Y22',name='AVDD_0',func=pin_types.PWRIN,unit=25),
            Pin(num='Y23',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='Y25',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='Y27',name='VCCINT',func=pin_types.PWRIN,unit=25),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA15',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA29',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA33',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB28',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB3',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB30',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB40',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC29',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC37',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD14',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD22',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD28',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD34',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AD5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE11',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE21',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE29',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE31',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF28',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF30',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG21',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG35',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AG5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH22',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH3',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH32',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH40',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AH42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ21',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ29',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK36',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AK6',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL33',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AL5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AM10',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AM20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AM30',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AM39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AM4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN37',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AN7',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP3',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP34',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP40',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AP42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='G39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='G41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='H32',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='H39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J29',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K3',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K36',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K40',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L33',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M30',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N37',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P34',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='P4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R21',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R31',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='R42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T28',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T3',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T40',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T42',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='T8',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U35',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='U5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V28',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V30',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V32',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V37',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W21',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W25',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W27',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W29',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W41',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='W9',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y16',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y20',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y24',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y26',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y28',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y36',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y38',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y39',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='Y6',name='GND',func=pin_types.PWRIN,unit=26),
            Pin(num='AR11',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AR21',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AR31',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AR38',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AR39',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AR4',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AR5',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT18',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT2',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT28',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT38',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT41',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT5',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AT8',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU10',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU15',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU2',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU25',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU35',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU38',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU39',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU4',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU41',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AU5',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV10',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV12',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV14',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV15',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV16',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV17',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV22',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV27',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV28',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV29',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV32',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV33',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV34',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV35',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV37',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV38',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV39',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV4',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV5',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV6',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV8',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AV9',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW1',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW10',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW11',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW12',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW13',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW14',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW16',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW17',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW18',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW19',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW24',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW25',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW26',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW27',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW29',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW30',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW31',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW32',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW33',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW35',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW36',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW37',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW42',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW6',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW7',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AW8',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY1',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY13',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY19',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY24',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY3',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY30',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY36',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY40',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY42',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='AY7',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA10',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA15',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA16',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA19',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA23',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA24',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA27',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA28',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA3',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA33',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA34',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA39',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA4',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA40',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BA9',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB12',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB13',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB18',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB19',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB20',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB24',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB25',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB30',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB31',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB36',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB37',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB6',name='GND',func=pin_types.PWRIN,unit=27),
            Pin(num='BB7',name='GND',func=pin_types.PWRIN,unit=27)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N14', 'AA32', 'AB32', 'T35', 'P19', 'U36', 'W31', 'Y30', 'AB34', 'N15', 'AA34', 'P25', 'T36', 'U37', 'AB35', 'W32', 'Y31', 'N16', 'AB36', 'P26', 'T37', 'V31', 'N18', 'W33', 'Y32', 'AB37', 'AA30', 'N19', 'P27', 'U30', 'V33', 'W34', 'Y33', 'AC36', 'AA31', 'N25', 'P28', 'U31', 'V34', 'W35', 'L14', 'Y34', 'N26', 'AA35', 'M14', 'P29', 'U32', 'V35', 'N28', 'W36', 'Y35', 'AA36', 'M15', 'N29', 'R26', 'U33', 'V36', 'W37', 'Y37', 'M29', 'AA37', 'M16', 'P17', 'R27', 'U34', 'W30', 'Y29', 'AB31', 'P18']},{'label': 'uB', 'num': 2, 'pin_nums': ['AE32', 'AA11', 'P5', 'AE33', 'AA6', 'P6', 'AA7', 'AE34', 'P7', 'AE35', 'AA8', 'R5', 'AA9', 'AE36', 'R6', 'AE37', 'AB11', 'R7', 'AB33', 'AF31', 'T5', 'AB6', 'AF32', 'T6', 'AB7', 'AF33', 'T7', 'AB8', 'AF34', 'U6', 'AB9', 'AF35', 'U7', 'AC10', 'AF36', 'V6', 'AC11', 'AF37', 'V7', 'AC30', 'AG31', 'V8', 'AC31', 'AG32', 'V9', 'AC32', 'AG33', 'W10', 'AC33', 'AG34', 'W11', 'AC34', 'AG36', 'W6', 'AC35', 'AG37', 'W7', 'AC6', 'AG38', 'W8', 'AC8', 'AH36', 'Y10', 'AC9', 'AH37', 'Y11', 'AD11', 'AH38', 'Y7', 'AD30', 'AJ36', 'Y8', 'AD31', 'AJ37', 'Y9', 'AD32', 'AK37', 'AD33', 'AL36', 'AD35', 'AL37', 'AD36', 'AM37', 'AM38', 'AD37', 'AD9', 'AD8', 'AN38', 'AA10', 'N6']},{'label': 'uC', 'num': 3, 'pin_nums': ['AJ18', 'AH11', 'AE9', 'AG10', 'AK28', 'AL28', 'AM27', 'AP26', 'AF10', 'AG11', 'AH17', 'AJ6', 'AL6', 'AM5', 'AP27', 'AK7', 'AD10', 'AF11', 'AG12', 'AH5', 'AJ7', 'AK8', 'AL7', 'AM6', 'AP5', 'AD6', 'AF12', 'AG6', 'AH6', 'AJ8', 'AK9', 'AL8', 'AM7', 'AP6', 'AD7', 'AF5', 'AG7', 'AH7', 'AK17', 'AL17', 'AL9', 'AN26', 'AR25', 'AE10', 'AF6', 'AG8', 'AH8', 'AK18', 'AL18', 'AM17', 'AN5', 'AR26', 'AE7', 'AF7', 'AG9', 'AH9', 'AK19', 'AL19', 'AM18', 'AM19', 'AN6', 'AP25', 'AR27', 'AE8', 'AF9', 'AH10', 'AJ17', 'AL27', 'AK27']},{'label': 'uD', 'num': 4, 'pin_nums': ['P8', 'E8', 'P9', 'K7', 'F6', 'K8', 'R10', 'F7', 'K9', 'R32', 'G37', 'L34', 'R33', 'G6', 'L35', 'R34', 'G7', 'L36', 'R35', 'G8', 'L37', 'R36', 'H34', 'L6', 'R37', 'H35', 'L7', 'R38', 'K5', 'H36', 'L8', 'R8', 'H37', 'L9', 'R9', 'H38', 'M34', 'T10', 'H5', 'M35', 'T11', 'H6', 'M36', 'T31', 'H7', 'M37', 'T32', 'H8', 'M6', 'T33', 'J33', 'M7', 'T34', 'J34', 'M8', 'T9', 'J35', 'M9', 'U10', 'J36', 'N33', 'U11', 'J37', 'N34', 'U12', 'J38', 'N35', 'U8', 'J5', 'N36', 'U9', 'J6', 'N8', 'V10', 'J7', 'N9', 'V11', 'J8', 'P10', 'K33', 'P33', 'K34', 'P35', 'K35', 'P36', 'K37', 'P37', 'K38', 'P38', 'E7']},{'label': 'uE', 'num': 5, 'pin_nums': ['AJ31', 'AN12', 'AR9', 'AN13', 'AJ32', 'AT10', 'AJ33', 'AN31', 'AT11', 'AN32', 'AJ34', 'AT35', 'AJ35', 'AN33', 'AT36', 'AK10', 'AN34', 'AT37', 'AK11', 'AN35', 'AT6', 'AK12', 'AN36', 'AT7', 'AK32', 'AN8', 'AT9', 'AK33', 'AN9', 'AU11', 'AK34', 'AP10', 'AU36', 'AK35', 'AP11', 'AU37', 'AL10', 'AP12', 'AU6', 'AL11', 'AP13', 'AU7', 'AL12', 'AP31', 'AU8', 'AL31', 'AP32', 'AU9', 'AL32', 'AP33', 'AV11', 'AN11', 'AL34', 'AP35', 'AV36', 'AL35', 'AP36', 'AV7', 'AM11', 'AP37', 'AM12', 'AP38', 'AM13', 'AP7', 'AM31', 'AP8', 'AM32', 'AP9', 'AM33', 'AR10', 'AM34', 'AR12', 'AH33', 'AR35', 'AM35', 'AH34', 'AM36', 'AR36', 'AH35', 'AM8', 'AR37', 'AJ10', 'AM9', 'AR6', 'AJ11', 'AN10', 'AR7', 'AJ12', 'AR8']},{'label': 'uF', 'num': 6, 'pin_nums': ['F14', 'H33', 'N11', 'F15', 'N12', 'H9', 'F29', 'J10', 'N13', 'F30', 'N30', 'J11', 'F31', 'J12', 'N31', 'F32', 'J13', 'N32', 'F34', 'J30', 'P11', 'F35', 'P12', 'J31', 'F36', 'J32', 'P30', 'F37', 'K10', 'P31', 'F9', 'K11', 'P32', 'G10', 'K12', 'R12', 'G11', 'K13', 'R30', 'G12', 'K14', 'G13', 'K29', 'G14', 'K30', 'G29', 'K31', 'G30', 'K32', 'G31', 'L10', 'G32', 'L11', 'E12', 'G33', 'L12', 'E13', 'G34', 'L29', 'E14', 'G36', 'L30', 'E29', 'G9', 'L31', 'E30', 'H10', 'L32', 'E35', 'H11', 'M11', 'E36', 'H13', 'M12', 'E37', 'H14', 'M13', 'F10', 'H15', 'M31', 'F11', 'H29', 'M32', 'F12', 'H30', 'M33', 'F13', 'H31', 'N10']},{'label': 'uG', 'num': 7, 'pin_nums': ['AT29', 'AV26', 'L27', 'AU28', 'K28', 'M27', 'AJ30', 'AN28', 'AR30', 'AT30', 'AU29', 'AV30', 'L15', 'L28', 'M28', 'AN29', 'AK29', 'AR32', 'AT31', 'AU30', 'AV31', 'L16', 'M17', 'N24', 'AK30', 'AN30', 'AR33', 'AT32', 'AU31', 'J14', 'L17', 'M18', 'AK31', 'AP28', 'AR34', 'AT33', 'AU32', 'J15', 'L18', 'M19', 'AP29', 'AL29', 'AM29', 'AR29', 'AT25', 'AT34', 'AU33', 'J16', 'L19', 'M24', 'AH29', 'AL30', 'AP30', 'AT26', 'AU26', 'AU34', 'K15', 'L25', 'M25', 'AR28', 'AH30', 'AM28', 'AT27', 'AU27', 'AV25', 'K27', 'L26', 'M26', 'AH31']},{'label': 'uH', 'num': 8, 'pin_nums': ['AJ14', 'AK21', 'AL21', 'AN20', 'AM24', 'AP21', 'AR20', 'AU12', 'AJ15', 'AL24', 'AM25', 'AN25', 'AR13', 'AT12', 'AU13', 'AK23', 'AJ24', 'AK24', 'AL25', 'AM26', 'AP15', 'AR14', 'AT13', 'AU14', 'AG13', 'AJ25', 'AK25', 'AL26', 'AN14', 'AP16', 'AR15', 'AT14', 'AU16', 'AL20', 'AH13', 'AK13', 'AL14', 'AM14', 'AN15', 'AN19', 'AP17', 'AP20', 'AR16', 'AT15', 'AR19', 'AU17', 'AH14', 'AK14', 'AT20', 'AL15', 'AM15', 'AN16', 'AP18', 'AR17', 'AT16', 'AU18', 'AH15', 'AK15', 'AL16', 'AM16', 'AN18', 'AP19', 'AR18', 'AT17', 'AV13', 'AJ13', 'AK20', 'AM21']},{'label': 'uI', 'num': 9, 'pin_nums': ['BA22', 'BB21', 'AP23', 'J17', 'AR22', 'BB22', 'J18', 'AR23', 'BB23', 'J23', 'AR24', 'E18', 'J24', 'AT19', 'E19', 'J25', 'AT21', 'E20', 'J26', 'AT22', 'F16', 'J27', 'AT23', 'F17', 'J28', 'AT24', 'F19', 'K17', 'AU19', 'F20', 'K18', 'AU20', 'F26', 'K19', 'AU21', 'F27', 'K23', 'AU22', 'G16', 'K24', 'AU23', 'G17', 'K25', 'AU24', 'G18', 'L24', 'AV18', 'G19', 'AV19', 'G20', 'AV20', 'G24', 'AV21', 'G26', 'AV23', 'G27', 'AV24', 'G28', 'AW20', 'H16', 'AW21', 'H17', 'AK22', 'AW22', 'H18', 'AL22', 'AW23', 'H19', 'AM22', 'AY20', 'H20', 'AM23', 'AY21', 'H23', 'AN21', 'AY22', 'H24', 'AN22', 'AY23', 'H25', 'AN23', 'BA20', 'H26', 'H28', 'AN24', 'BA21', 'H27', 'AP22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['E24', 'K22', 'A20', 'C22', 'G22', 'N22', 'A21', 'C23', 'E25', 'G23', 'L20', 'N23', 'A22', 'D20', 'F21', 'H21', 'L21', 'P21', 'B21', 'D21', 'F22', 'J20', 'L22', 'P22', 'B22', 'D22', 'F23', 'J21', 'M21', 'B23', 'D23', 'F24', 'J22', 'M22', 'C20', 'E22', 'F25', 'K20', 'M23', 'C21', 'E23', 'G21', 'K21', 'N21']},{'label': 'uK', 'num': 11, 'pin_nums': ['U1', 'V40', 'V42', 'U2', 'U41', 'W1', 'U42', 'W42', 'AA2', 'Y1', 'V1', 'V4', 'AA41', 'V3', 'Y2', 'T2', 'V39', 'Y41', 'T41', 'Y42']},{'label': 'uL', 'num': 12, 'pin_nums': ['AD3', 'AF2', 'AB2', 'AD39', 'AF41', 'AB41', 'AD4', 'AF42', 'AC1', 'AD40', 'AG2', 'AC2', 'AD42', 'AG41', 'AC41', 'AE1', 'AC42', 'AE42', 'AD1', 'AF1']},{'label': 'uM', 'num': 13, 'pin_nums': ['M42', 'L2', 'R41', 'L41', 'N1', 'L42', 'N42', 'M1', 'P1', 'M3', 'P2', 'K2', 'M39', 'P41', 'K41', 'M4', 'P42', 'L1', 'M40', 'R2']},{'label': 'uN', 'num': 14, 'pin_nums': ['AK3', 'AM2', 'AH2', 'AM41', 'AK39', 'AH41', 'AM42', 'AK4', 'AJ1', 'AK40', 'AN2', 'AJ2', 'AK42', 'AN41', 'AJ41', 'AL1', 'AJ42', 'AL42', 'AK1', 'AM1']},{'label': 'uO', 'num': 15, 'pin_nums': ['E1', 'F40', 'J2', 'F42', 'E2', 'J41', 'E41', 'G1', 'E42', 'G42', 'F1', 'H1', 'F3', 'H2', 'D2', 'F39', 'H41', 'D41', 'F4', 'H42']},{'label': 'uP', 'num': 16, 'pin_nums': ['AV1', 'AT1', 'AV2', 'AT3', 'AP2', 'AT39', 'AV41', 'AP41', 'AT4', 'AV42', 'AR1', 'AT40', 'AW2', 'AR2', 'AT42', 'AW41', 'AR41', 'AU1', 'AR42', 'AU42']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A38', 'B37', 'C4', 'A39', 'C40', 'B38', 'B2', 'A4', 'B41', 'A40', 'B42', 'A41', 'B5', 'A5', 'B6', 'A2', 'B1', 'C3', 'A3', 'C39']},{'label': 'uR', 'num': 18, 'pin_nums': ['BA2', 'BB3', 'BB38', 'BA37', 'BA38', 'BB39', 'AW39', 'BA41', 'BB4', 'AW4', 'BA42', 'BB40', 'AY39', 'BA5', 'BB41', 'AY4', 'BA6', 'BB5', 'BA1', 'BB2']},{'label': 'uS', 'num': 19, 'pin_nums': ['C33', 'A11', 'B12', 'A32', 'B31', 'D10', 'A33', 'B32', 'D33', 'A34', 'B35', 'A35', 'B36', 'A8', 'B7', 'A9', 'B8', 'A10', 'B11', 'C10']},{'label': 'uT', 'num': 20, 'pin_nums': ['BA12', 'BB11', 'BA31', 'BB32', 'BA32', 'BB33', 'AW34', 'BA35', 'BB34', 'AW9', 'BA36', 'BB35', 'AY34', 'BA7', 'BB8', 'AY9', 'BA8', 'BB9', 'BA11', 'BB10']},{'label': 'uU', 'num': 21, 'pin_nums': ['A14', 'C16', 'B13', 'A15', 'B14', 'C27', 'A16', 'B17', 'D16', 'A17', 'B18', 'D27', 'A26', 'B25', 'A27', 'B26', 'A28', 'B29', 'A29', 'B30']},{'label': 'uV', 'num': 22, 'pin_nums': ['BA13', 'BB14', 'BB15', 'BA14', 'BA17', 'BB16', 'BA18', 'BB17', 'AW15', 'BA25', 'BB26', 'AW28', 'BA26', 'BB27', 'AY15', 'BA29', 'BB28', 'AY28', 'BA30', 'BB29']},{'label': 'uW', 'num': 23, 'pin_nums': ['AY37', 'AL3', 'G3', 'AY38', 'AL40', 'G40', 'AM3', 'AY41', 'H3', 'AY5', 'AM40', 'H40', 'AN3', 'AY6', 'J3', 'AY8', 'AN40', 'J40', 'AR3', 'C1', 'L3', 'AR40', 'C11', 'L40', 'AU3', 'C13', 'N3', 'AU40', 'C14', 'N40', 'AY35', 'AV3', 'C15', 'P3', 'AV40', 'C17', 'P40', 'AW3', 'C2', 'R3', 'AW38', 'C26', 'R40', 'AW40', 'C28', 'U3', 'AW5', 'C29', 'U40', 'AA3', 'AY10', 'C30', 'W3', 'AA39', 'AY11', 'C32', 'W40', 'AA4', 'AY12', 'C34', 'Y3', 'AA40', 'AY14', 'C35', 'Y40', 'AB39', 'AY16', 'C36', 'AB4', 'AY17', 'C38', 'AC3', 'AY18', 'C41', 'AC40', 'AY2', 'C42', 'AE3', 'AY25', 'C5', 'AE40', 'AY26', 'C7', 'AF3', 'AY27', 'C8', 'AF40', 'AY29', 'C9', 'AG3', 'AY31', 'D39', 'AG40', 'AY32', 'D4', 'AJ3', 'AY33', 'E3', 'AJ40', 'E40']},{'label': 'uX', 'num': 24, 'pin_nums': ['AH28', 'AB22', 'R16', 'AJ16', 'AC21', 'R29', 'AC22', 'AJ27', 'T14', 'AF15', 'AJ28', 'T29', 'AF16', 'P13', 'T30', 'AA21', 'AG16', 'P15', 'AA22', 'AG29', 'R14', 'AB21', 'AH16', 'R15']},{'label': 'uY', 'num': 25, 'pin_nums': ['D29', 'T25', 'Y21', 'AA26', 'AE22', 'B24', 'D3', 'E5', 'T27', 'Y22', 'AE24', 'AA28', 'B27', 'D30', 'E6', 'U14', 'Y23', 'AB13', 'AE26', 'B28', 'D31', 'E9', 'U16', 'Y25', 'AB15', 'AE28', 'B3', 'D32', 'F18', 'U18', 'Y27', 'AB17', 'AE30', 'B33', 'D34', 'F2', 'U20', 'AB19', 'AF13', 'B34', 'D35', 'F28', 'U22', 'AB23', 'AF17', 'B39', 'D36', 'F33', 'U24', 'AF19', 'AB25', 'B4', 'D37', 'F38', 'U26', 'AB27', 'AF21', 'B40', 'D38', 'F41', 'U28', 'AB29', 'AF23', 'B9', 'D40', 'F5', 'V13', 'AC12', 'AF25', 'C12', 'D42', 'F8', 'V15', 'AC14', 'AF27', 'C18', 'D5', 'G15', 'V17', 'AC16', 'AG18', 'C19', 'D6', 'G2', 'V19', 'A12', 'AC18', 'AG20', 'C24', 'D7', 'G25', 'V21', 'A13', 'AC20', 'AG22', 'C25', 'D8', 'G35', 'V23', 'A18', 'AC24', 'AG24', 'C31', 'D9', 'G38', 'V25', 'A19', 'AC26', 'AG26', 'C37', 'E10', 'G4', 'V27', 'A23', 'AC28', 'AG28', 'C6', 'E11', 'G5', 'V29', 'A24', 'AD13', 'AG30', 'D1', 'E15', 'N20', 'W12', 'A25', 'AD15', 'AH19', 'D11', 'E16', 'AE20', 'P23', 'W14', 'A30', 'AD17', 'AH21', 'D12', 'E17', 'R18', 'W16', 'A31', 'AD19', 'AH23', 'D13', 'E21', 'R20', 'W18', 'A36', 'AD21', 'AH25', 'D14', 'E26', 'R22', 'W20', 'A37', 'AD23', 'AH27', 'D15', 'E27', 'R24', 'W22', 'A6', 'AD25', 'AJ20', 'D17', 'E28', 'R28', 'W24', 'A7', 'AD27', 'AJ22', 'D18', 'E31', 'T13', 'W26', 'AA12', 'AD29', 'AJ26', 'D19', 'E32', 'T15', 'W28', 'AA14', 'AE12', 'B10', 'D24', 'E33', 'T17', 'Y13', 'AA16', 'AE14', 'B15', 'D25', 'E34', 'T19', 'Y15', 'AA18', 'AE16', 'B16', 'D26', 'E38', 'E4', 'T21', 'Y17', 'AA20', 'AE18', 'B19', 'D28', 'E39', 'T23', 'Y19', 'AA24', 'B20']},{'label': 'uZ', 'num': 26, 'pin_nums': ['AG21', 'AP3', 'R17', 'L33', 'AB42', 'U27', 'W38', 'AE15', 'AG23', 'AK26', 'AP34', 'R19', 'L38', 'W39', 'U35', 'AB5', 'AE17', 'AG25', 'AK36', 'AP39', 'L39', 'R21', 'AC13', 'U38', 'W4', 'AE19', 'AG27', 'AK38', 'AP4', 'L4', 'R23', 'AC15', 'U39', 'W41', 'AE2', 'AG35', 'AK41', 'AP40', 'L5', 'R25', 'AC17', 'U4', 'W5', 'AE21', 'AG39', 'AK5', 'AP42', 'M10', 'R31', 'AA1', 'AC19', 'U5', 'W9', 'AE23', 'AG4', 'AB40', 'AK6', 'G39', 'M2', 'R39', 'AA13', 'AC23', 'V12', 'Y12', 'AE25', 'AG42', 'AL13', 'G41', 'R4', 'M20', 'V14', 'Y14', 'AA15', 'AC25', 'AE27', 'AG5', 'AL2', 'H12', 'M30', 'R42', 'AA17', 'AC27', 'V16', 'Y16', 'AE29', 'AH1', 'AL23', 'H22', 'M38', 'T1', 'AA19', 'AC29', 'V18', 'Y18', 'AE31', 'AH12', 'AL33', 'H32', 'M41', 'T12', 'AA23', 'AC37', 'V2', 'Y20', 'AE38', 'AH18', 'AL38', 'H39', 'M5', 'T16', 'AA25', 'AC38', 'V20', 'Y24', 'AE39', 'AH20', 'AL39', 'H4', 'N17', 'T18', 'AA27', 'AC39', 'V22', 'Y26', 'AE4', 'AH22', 'AL4', 'J1', 'N2', 'T20', 'AA29', 'AC4', 'V24', 'Y28', 'AE41', 'AH24', 'AL41', 'J19', 'N27', 'T22', 'AA33', 'AC5', 'V26', 'Y36', 'AE5', 'AH26', 'AL5', 'J29', 'N37', 'T24', 'AA38', 'AC7', 'V28', 'Y38', 'AE6', 'AH3', 'AM10', 'J39', 'N38', 'T26', 'AA42', 'AD12', 'V30', 'Y39', 'AF18', 'AH32', 'AM20', 'J4', 'N39', 'T28', 'AA5', 'AD14', 'V32', 'Y4', 'AF20', 'AH39', 'AM30', 'J42', 'N4', 'T3', 'AB1', 'AD16', 'V37', 'Y5', 'AF22', 'AH4', 'R13', 'AM39', 'J9', 'N41', 'T38', 'AB10', 'AD18', 'V38', 'Y6', 'AF24', 'AH40', 'AM4', 'K1', 'N5', 'T39', 'AB12', 'AD2', 'V41', 'AF26', 'AH42', 'AN1', 'K16', 'N7', 'T4', 'AB14', 'AD20', 'V5', 'AF28', 'AJ19', 'AN17', 'K26', 'P14', 'T40', 'AB16', 'AD22', 'W13', 'AF30', 'AJ21', 'AN27', 'K3', 'P16', 'T42', 'AB18', 'AD24', 'W15', 'AF38', 'AJ23', 'AN37', 'K36', 'P20', 'T8', 'AB20', 'AD26', 'W17', 'AF39', 'AJ29', 'AN39', 'K39', 'P24', 'U13', 'AB24', 'AD28', 'W19', 'AF4', 'AJ38', 'W29', 'AN4', 'K4', 'P34', 'U15', 'AB26', 'AD34', 'W2', 'AF8', 'AJ39', 'AN42', 'K40', 'P39', 'U17', 'AB28', 'AD38', 'W21', 'AG1', 'AJ4', 'AN7', 'K42', 'P4', 'U19', 'AB3', 'AD41', 'W23', 'AG15', 'AJ5', 'AP1', 'K6', 'R1', 'U21', 'AD5', 'AB30', 'W25', 'AG17', 'AJ9', 'AK2', 'AP14', 'L13', 'R11', 'U23', 'AB38', 'AE11', 'W27', 'AG19', 'AK16', 'AP24', 'L23', 'U25', 'AE13']},{'label': 'uAA', 'num': 27, 'pin_nums': ['AV6', 'AY24', 'BB37', 'AT5', 'AV8', 'BB6', 'AY3', 'AT8', 'AV9', 'AY30', 'BB7', 'AU10', 'AW1', 'AY36', 'AU15', 'AW10', 'AY40', 'AU2', 'AW11', 'AY42', 'AU25', 'AW12', 'AY7', 'AU35', 'AW13', 'BA10', 'AU38', 'AW14', 'BA15', 'AU39', 'AW16', 'BA16', 'AU4', 'AW17', 'BA19', 'AU41', 'AW18', 'BA23', 'AU5', 'AW19', 'BA24', 'AV10', 'AW24', 'BA27', 'AV12', 'AW25', 'BA28', 'AV14', 'AW26', 'BA3', 'AV15', 'AW27', 'BA33', 'AV16', 'AW29', 'BA34', 'AV17', 'AW30', 'BA39', 'AV22', 'AW31', 'BA4', 'AV27', 'AW32', 'BA40', 'AR11', 'AV28', 'AW33', 'BA9', 'AR21', 'AV29', 'AW35', 'BB12', 'AR31', 'AV32', 'AW36', 'BB13', 'AR38', 'AV33', 'AW37', 'BB18', 'AR39', 'AV34', 'AW42', 'BB19', 'AR4', 'AV35', 'AW6', 'BB20', 'AR5', 'AV37', 'AW7', 'BB24', 'AT18', 'AV38', 'AW8', 'BB25', 'AT2', 'AV39', 'AY1', 'BB30', 'AT28', 'AT41', 'AV4', 'AY13', 'BB31', 'AT38', 'AV5', 'AY19', 'BB36']}] })])