from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

CPU_NXP_IMX = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MCIMX6QP5EYM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6QP5EYM'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPCEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6QP5EYM\n\nQuad-Core ARM Cortex A9 SOC', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L10', 'AA7', 'T17', 'K9', 'AB24', 'N18', 'T19', 'AB3', 'G9', 'N8', 'L11', 'T8', 'AD10', 'H10', 'H12', 'L12', 'N9', 'T9', 'AD13', 'H11', 'L13', 'P10', 'U10', 'AD16', 'L14', 'P11', 'U11', 'AD19', 'H13', 'H15', 'L15', 'P12', 'U12', 'AD22', 'H14', 'L16', 'P13', 'U13', 'AD4', 'H8', 'L17', 'P14', 'H17', 'H18', 'U14', 'AD7', 'H16', 'L18', 'P15', 'U15', 'AE1', 'L2', 'P16', 'J10', 'U16', 'H9', 'AE25', 'L5', 'P17', 'J11', 'U17', 'B4', 'J12', 'L8', 'P18', 'U19', 'C1', 'J13', 'L9', 'P8', 'U8', 'C10', 'J14', 'M10', 'P9', 'U9', 'C4', 'J15', 'M11', 'R11', 'V19', 'C6', 'J16', 'M12', 'R10', 'V8', 'D3', 'J17', 'M13', 'R12', 'W10', 'D6', 'J18', 'M14', 'R13', 'W11', 'D8', 'J2', 'M15', 'R14', 'W12', 'E5', 'J8', 'M16', 'R15', 'W13', 'E6', 'J9', 'M17', 'R16', 'W15', 'E7', 'K10', 'M18', 'R17', 'W16', 'K11', 'F5', 'M8', 'R8', 'W17', 'E8', 'K12', 'A25', 'M9', 'R9', 'W18', 'A13', 'F6', 'K13', 'N10', 'T10', 'W19', 'A4', 'F7', 'K14', 'N11', 'T11', 'W3', 'F8', 'K15', 'A8', 'T12', 'N13', 'W7', 'AA10', 'K16', 'G10', 'N12', 'T13', 'W8', 'AA13', 'F9', 'K17', 'N14', 'T14', 'W9', 'AA16', 'K18', 'G19', 'N15', 'T15', 'AA19', 'Y24', 'G11', 'K8', 'AA22', 'N16', 'T16', 'Y5', 'G3', 'N17']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'B5', 'A5', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['C11', 'E11', 'F12', 'D12', 'C12', 'F11', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['A11', 'B10', 'C7', 'D7', 'A9', 'A10', 'B11', 'C5', 'D5', 'B9']},{'label': 'uE', 'num': 5, 'pin_nums': ['H4', 'D4', 'K7', 'F4', 'E1', 'G1', 'E2', 'G2', 'E3', 'G4', 'E4', 'H1', 'F1', 'H2', 'F2', 'D1', 'H3', 'F3', 'D2']},{'label': 'uF', 'num': 6, 'pin_nums': ['M3', 'N5', 'M4', 'N6', 'L1', 'M5', 'N7', 'L3', 'M6', 'P1', 'L4', 'N1', 'P2', 'L6', 'N2', 'P3', 'M1', 'N3', 'P4', 'M2', 'N4']},{'label': 'uG', 'num': 7, 'pin_nums': ['T20', 'P24', 'U24', 'N20', 'P25', 'T21', 'N21', 'U25', 'R20', 'N25', 'T22', 'V24', 'P19', 'R21', 'T23', 'V25', 'P20', 'R22', 'T24', 'W24', 'P23', 'R25', 'P21', 'R23', 'T25', 'U23', 'R24', 'P22', 'U22', 'N19']},{'label': 'uH', 'num': 8, 'pin_nums': ['F24', 'J20', 'L22', 'K21', 'H19', 'M23', 'E22', 'F25', 'H20', 'J21', 'K22', 'L23', 'M24', 'E23', 'G20', 'H21', 'J22', 'K23', 'L24', 'M25', 'E24', 'G21', 'H22', 'J23', 'K24', 'L25', 'N22', 'E25', 'G22', 'H23', 'J24', 'K25', 'M19', 'N23', 'F21', 'G23', 'H24', 'J25', 'L19', 'M20', 'N24', 'C25', 'F22', 'G24', 'H25', 'K19', 'L20', 'M21', 'D24', 'F23', 'G25', 'J19', 'K20', 'L21', 'M22', 'D25']},{'label': 'uI', 'num': 9, 'pin_nums': ['V23', 'W21', 'R19', 'U21', 'V21', 'W23', 'V20', 'U20', 'V22', 'W20', 'W22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['W5', 'T6', 'R5', 'R4', 'T5', 'P5', 'R6', 'T7', 'W6', 'U5', 'P6', 'R7', 'P7', 'T1', 'U6', 'T2', 'U7', 'R1', 'R2', 'T3', 'V5', 'T4', 'R3', 'V6', 'W4']},{'label': 'uK', 'num': 11, 'pin_nums': ['K5', 'J3', 'J5', 'K1', 'K3', 'L7', 'J1', 'J6', 'J4', 'K2', 'K4', 'K6', 'M7']},{'label': 'uL', 'num': 12, 'pin_nums': ['C2', 'G5', 'H5', 'J7', 'C3', 'H6', 'G6']},{'label': 'uM', 'num': 13, 'pin_nums': ['AA2', 'U4', 'Y1', 'AA1', 'AA3', 'U3', 'V1', 'Y2', 'AA4', 'V2', 'Y3', 'AB1', 'V3', 'Y4', 'AB2', 'V4', 'U1', 'V7', 'U2', 'W1', 'W2']},{'label': 'uN', 'num': 14, 'pin_nums': ['A19', 'E15', 'C16', 'A20', 'C17', 'E16', 'B16', 'C18', 'E17', 'B17', 'C19', 'E18', 'B18', 'D16', 'F15', 'A16', 'B19', 'D17', 'F16', 'A17', 'B20', 'D18', 'F17', 'A18', 'C15', 'D19', 'G15']},{'label': 'uO', 'num': 15, 'pin_nums': ['B3', 'G8', 'A2', 'B1', 'B2', 'G7', 'H7', 'A3']},{'label': 'uP', 'num': 16, 'pin_nums': ['B6', 'D10', 'E10', 'A6', 'B8', 'F10', 'E9']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A24', 'C22', 'C24', 'B23', 'B25', 'C23', 'D21', 'D22', 'D23', 'E21', 'F20', 'G18', 'B24']},{'label': 'uR', 'num': 18, 'pin_nums': ['B21', 'D20', 'F18', 'A21', 'C20', 'E19', 'G16']},{'label': 'uS', 'num': 19, 'pin_nums': ['A22', 'B22', 'E20', 'G17', 'C21', 'F19', 'A23']},{'label': 'uT', 'num': 20, 'pin_nums': ['C13', 'D14', 'E13', 'F13', 'B13', 'G14', 'B15', 'D13', 'D15', 'E14', 'F14', 'A15']},{'label': 'uU', 'num': 21, 'pin_nums': ['AA23', 'U18', 'AD24', 'V10', 'AA24', 'AC14', 'AD25', 'V11', 'AA25', 'AC15', 'AD3', 'V12', 'AA5', 'AC16', 'AD5', 'V13', 'AA6', 'AC17', 'AD6', 'V14', 'AA8', 'AC18', 'AD8', 'V15', 'AA9', 'AC19', 'AD9', 'V16', 'AB10', 'AC2', 'AE10', 'V17', 'AB11', 'AC20', 'AE11', 'V18', 'AB12', 'AC21', 'AE12', 'V9', 'AB13', 'AC22', 'AE13', 'AB14', 'AC23', 'AE14', 'W14', 'AB15', 'AC24', 'AE15', 'W25', 'AB16', 'AC25', 'AE16', 'Y10', 'AB17', 'AC3', 'AE17', 'Y11', 'AB18', 'AC4', 'AE18', 'Y12', 'AB19', 'AC5', 'AE19', 'Y13', 'AB20', 'AC6', 'AE2', 'Y14', 'AB21', 'AC7', 'AE20', 'Y15', 'AB22', 'AC8', 'AE21', 'Y16', 'AB23', 'AC9', 'AE22', 'Y17', 'AB25', 'AD1', 'AE23', 'Y18', 'AB4', 'AD11', 'AE24', 'Y19', 'AB5', 'AD12', 'AE3', 'Y20', 'AA11', 'AB6', 'AD14', 'AE4', 'Y21', 'AA12', 'AB7', 'AD15', 'AE5', 'Y22', 'AA14', 'AB8', 'AD17', 'AE6', 'Y23', 'AA15', 'AB9', 'AD18', 'AE7', 'Y25', 'AA17', 'AC1', 'AD2', 'AE8', 'Y6', 'AA18', 'AC10', 'AD20', 'AE9', 'T18', 'Y7', 'AA20', 'AC11', 'AC13', 'AD21', 'R18', 'Y8', 'AA21', 'AC12', 'AD23', 'Y9']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['A12', 'B12', 'C14', 'G13', 'B14', 'A14', 'G12']}] }),
        Part(**{ 'name':'MCIMX6QP7CVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6QP7CVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC Industrial', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPIEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6QP7CVT\n\nQuad-Core ARM Cortex A9 SOC Industrial', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N9', 'H15', 'H14', 'L13', 'AD10', 'P10', 'U10', 'L14', 'U11', 'P11', 'AD13', 'H16', 'L15', 'AD16', 'H18', 'P12', 'U12', 'L16', 'H17', 'AD19', 'P13', 'U13', 'H8', 'L17', 'AD22', 'P14', 'U14', 'B4', 'A13', 'L18', 'AD4', 'J10', 'P15', 'U15', 'A25', 'H9', 'L2', 'AD7', 'P16', 'U16', 'L5', 'J11', 'P17', 'U17', 'AE1', 'J12', 'L8', 'AE25', 'P18', 'U19', 'C4', 'J13', 'L9', 'C10', 'P8', 'U8', 'J14', 'M10', 'A4', 'C6', 'P9', 'U9', 'D3', 'J15', 'M11', 'V19', 'R11', 'D6', 'J16', 'M12', 'R10', 'V8', 'D8', 'J17', 'M13', 'E5', 'R12', 'W10', 'E6', 'J18', 'M14', 'R13', 'W11', 'E7', 'J2', 'M15', 'R14', 'W12', 'F5', 'J8', 'M16', 'R15', 'W13', 'E8', 'J9', 'M17', 'R16', 'W15', 'AB3', 'F6', 'K10', 'M18', 'R17', 'W16', 'F7', 'K11', 'M8', 'R8', 'W17', 'F8', 'K12', 'M9', 'R9', 'W18', 'G10', 'K13', 'N10', 'T10', 'W19', 'C1', 'F9', 'K14', 'N11', 'T11', 'W3', 'AA10', 'K15', 'G19', 'N13', 'T12', 'W7', 'G11', 'K16', 'N12', 'T13', 'W8', 'A8', 'G3', 'K17', 'N14', 'AA16', 'T14', 'W9', 'AA13', 'K18', 'N15', 'T15', 'Y24', 'G9', 'K8', 'N16', 'T16', 'Y5', 'AA19', 'H10', 'H12', 'N17', 'L10', 'T17', 'AA22', 'H11', 'K9', 'N18', 'T19', 'AA7', 'AB24', 'L11', 'N8', 'T8', 'H13', 'L12', 'T9']},{'label': 'uB', 'num': 2, 'pin_nums': ['A5', 'E12', 'C8', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'C12', 'F11', 'D11', 'C11', 'E11', 'F12']},{'label': 'uD', 'num': 4, 'pin_nums': ['A11', 'B10', 'B9', 'C5', 'D5', 'A9', 'B11', 'C7', 'D7', 'A10']},{'label': 'uE', 'num': 5, 'pin_nums': ['E2', 'G2', 'E3', 'G4', 'E4', 'H1', 'F1', 'H2', 'D1', 'F2', 'H3', 'D2', 'F3', 'H4', 'D4', 'F4', 'K7', 'E1', 'G1']},{'label': 'uF', 'num': 6, 'pin_nums': ['M6', 'L3', 'P1', 'L4', 'N1', 'P2', 'L6', 'N2', 'P3', 'M1', 'N3', 'P4', 'M2', 'N4', 'M3', 'N5', 'M4', 'N6', 'L1', 'M5', 'N7']},{'label': 'uG', 'num': 7, 'pin_nums': ['T23', 'V25', 'P19', 'R21', 'R20', 'T22', 'P20', 'R22', 'T24', 'W24', 'P21', 'R23', 'T25', 'P22', 'R24', 'U22', 'N19', 'P23', 'R25', 'U23', 'N20', 'P24', 'T20', 'U24', 'N21', 'T21', 'P25', 'U25', 'N25', 'V24']},{'label': 'uH', 'num': 8, 'pin_nums': ['J23', 'E24', 'G21', 'H22', 'L25', 'N22', 'E25', 'G22', 'H23', 'J24', 'K25', 'M19', 'N23', 'F21', 'G23', 'H24', 'J25', 'L19', 'M20', 'N24', 'C25', 'F22', 'G24', 'H25', 'K19', 'L20', 'M21', 'D24', 'F23', 'G25', 'J19', 'K20', 'L21', 'M22', 'D25', 'F24', 'H19', 'J20', 'K21', 'L22', 'M23', 'E22', 'F25', 'H20', 'J21', 'K22', 'K24', 'L23', 'M24', 'E23', 'G20', 'H21', 'J22', 'K23', 'L24', 'M25']},{'label': 'uI', 'num': 9, 'pin_nums': ['R19', 'U20', 'V20', 'V22', 'V21', 'V23', 'W20', 'W21', 'W22', 'W23', 'U21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['U6', 'P7', 'T1', 'T2', 'U7', 'R1', 'R2', 'T3', 'V5', 'R3', 'T4', 'V6', 'R4', 'T5', 'W4', 'R5', 'T6', 'W5', 'R7', 'U5', 'P5', 'R6', 'T7', 'W6', 'P6']},{'label': 'uK', 'num': 11, 'pin_nums': ['J1', 'J4', 'J6', 'K2', 'K4', 'K6', 'M7', 'J3', 'J5', 'K1', 'K3', 'K5', 'L7']},{'label': 'uL', 'num': 12, 'pin_nums': ['C3', 'G6', 'H6', 'C2', 'H5', 'J7', 'G5']},{'label': 'uM', 'num': 13, 'pin_nums': ['Y4', 'AB1', 'V3', 'AB2', 'V4', 'U1', 'V7', 'AA4', 'U2', 'W1', 'V2', 'AA1', 'U3', 'W2', 'Y1', 'AA2', 'U4', 'AA3', 'V1', 'Y2', 'Y3']},{'label': 'uN', 'num': 14, 'pin_nums': ['B17', 'E18', 'C19', 'B18', 'D16', 'F15', 'A16', 'B19', 'D17', 'F16', 'A17', 'B20', 'D18', 'F17', 'A18', 'C15', 'D19', 'G15', 'A19', 'C16', 'E15', 'A20', 'C17', 'E16', 'B16', 'C18', 'E17']},{'label': 'uO', 'num': 15, 'pin_nums': ['A3', 'B1', 'G7', 'H7', 'B2', 'G8', 'A2', 'B3']},{'label': 'uP', 'num': 16, 'pin_nums': ['A6', 'B8', 'E10', 'F10', 'B6', 'D10', 'E9']},{'label': 'uQ', 'num': 17, 'pin_nums': ['D21', 'B25', 'D23', 'B23', 'C23', 'F20', 'C22', 'A24', 'B24', 'C24', 'D22', 'E21', 'G18']},{'label': 'uR', 'num': 18, 'pin_nums': ['A21', 'C20', 'E19', 'G16', 'F18', 'B21', 'D20']},{'label': 'uS', 'num': 19, 'pin_nums': ['A22', 'B22', 'G17', 'C21', 'A23', 'F19', 'E20']},{'label': 'uT', 'num': 20, 'pin_nums': ['B13', 'C13', 'E13', 'F13', 'G14', 'D13', 'A15', 'B15', 'D15', 'E14', 'F14', 'D14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AC16', 'AD5', 'V13', 'AA6', 'AC17', 'V14', 'AD6', 'AA8', 'AC18', 'AD8', 'V15', 'AA9', 'AC19', 'V16', 'AD9', 'AB10', 'AC2', 'AE10', 'V17', 'AB11', 'AC20', 'AE11', 'V18', 'AB12', 'AC21', 'AE12', 'V9', 'AB13', 'AC22', 'AE13', 'AB14', 'AC23', 'AE14', 'W14', 'AB15', 'AC24', 'AE15', 'W25', 'AB16', 'AC25', 'AE16', 'Y10', 'AB17', 'AC3', 'AE17', 'Y11', 'AB18', 'AC4', 'AE18', 'Y12', 'AB19', 'AC5', 'AE19', 'Y13', 'AB20', 'AC6', 'AE2', 'Y14', 'AB21', 'AC7', 'AE20', 'Y15', 'AB22', 'AC8', 'AE21', 'Y16', 'AB23', 'AC9', 'AE22', 'Y17', 'AB25', 'AD1', 'AE23', 'Y18', 'AB4', 'AD11', 'AE24', 'Y19', 'AB5', 'AD12', 'AE3', 'Y20', 'AA11', 'AB6', 'AD14', 'AE4', 'Y21', 'AA12', 'AB7', 'AD15', 'AE5', 'Y22', 'AA14', 'AB8', 'AD17', 'AE6', 'Y23', 'AA15', 'AB9', 'AD18', 'AE7', 'Y25', 'AA17', 'AC1', 'AD2', 'AE8', 'Y6', 'AA18', 'AC10', 'AD20', 'AE9', 'Y7', 'T18', 'AA20', 'AC11', 'AD21', 'R18', 'Y8', 'AA21', 'AC12', 'AD23', 'U18', 'Y9', 'AA23', 'AC13', 'AD24', 'V10', 'AA24', 'AA5', 'AC14', 'AD25', 'V11', 'AA25', 'AC15', 'AD3', 'V12']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['A14', 'G12', 'B14', 'C14', 'B12', 'A12', 'G13']}] }),
        Part(**{ 'name':'MCIMX6D4AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6D4AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6D4AVT\n\nDual-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L9', 'U10', 'P13', 'R14', 'D3', 'J14', 'M10', 'R13', 'U11', 'D6', 'J15', 'M11', 'U12', 'D8', 'J16', 'M12', 'U13', 'E5', 'P12', 'J17', 'M13', 'P11', 'U14', 'E6', 'J18', 'M14', 'U15', 'E7', 'J2', 'M15', 'U16', 'E8', 'J8', 'M16', 'U17', 'P10', 'F5', 'N9', 'J9', 'M17', 'U19', 'F6', 'K10', 'M18', 'U8', 'F7', 'K11', 'M8', 'U9', 'F8', 'N8', 'K12', 'M9', 'V19', 'F9', 'K13', 'N10', 'V8', 'G10', 'K14', 'N11', 'R12', 'W10', 'G11', 'K15', 'N12', 'W11', 'G19', 'N13', 'K16', 'W12', 'G3', 'K17', 'N14', 'W13', 'G9', 'K18', 'N15', 'W15', 'H10', 'R11', 'K8', 'N16', 'R10', 'W16', 'H11', 'A13', 'K9', 'N18', 'N17', 'R8', 'W17', 'A25', 'H12', 'A4', 'L10', 'R9', 'A8', 'W18', 'H13', 'AA10', 'L11', 'J13', 'AA7', 'T10', 'W19', 'H14', 'P9', 'AA13', 'L12', 'P8', 'AA16', 'T11', 'W3', 'AA19', 'H15', 'L13', 'AA22', 'T12', 'AB24', 'W7', 'H16', 'R17', 'L14', 'AB3', 'T13', 'W8', 'AD10', 'H17', 'L15', 'AD13', 'P18', 'T14', 'P17', 'W9', 'AD16', 'H18', 'L16', 'AD19', 'T15', 'Y24', 'AD22', 'H8', 'L17', 'AD4', 'T16', 'Y5', 'AD7', 'H9', 'L18', 'T17', 'AE1', 'P16', 'J10', 'AE25', 'P15', 'L2', 'R16', 'T19', 'P14', 'B4', 'R15', 'J11', 'C1', 'L5', 'T8', 'C10', 'J12', 'C4', 'L8', 'T9', 'C6']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'B5', 'A5', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['E11', 'F12', 'C11', 'D11', 'C12', 'F11', 'D12']},{'label': 'uD', 'num': 4, 'pin_nums': ['A11', 'B10', 'B9', 'C7', 'D7', 'A9', 'B11', 'C5', 'D5', 'A10']},{'label': 'uE', 'num': 5, 'pin_nums': ['F1', 'H2', 'D1', 'F2', 'H3', 'D2', 'F3', 'H4', 'D4', 'F4', 'K7', 'E1', 'G1', 'E2', 'G2', 'E3', 'G4', 'E4', 'H1']},{'label': 'uF', 'num': 6, 'pin_nums': ['N3', 'M1', 'P4', 'M2', 'N4', 'N5', 'M3', 'N2', 'M4', 'N6', 'P3', 'L1', 'M5', 'N7', 'M6', 'L3', 'P1', 'L4', 'N1', 'P2', 'L6']},{'label': 'uG', 'num': 7, 'pin_nums': ['U22', 'P22', 'R24', 'R25', 'U23', 'P23', 'N19', 'P24', 'T20', 'U24', 'N20', 'P25', 'T21', 'U25', 'N21', 'P21', 'T25', 'R20', 'N25', 'T22', 'V24', 'P19', 'R21', 'T23', 'V25', 'P20', 'R22', 'T24', 'W24', 'R23']},{'label': 'uH', 'num': 8, 'pin_nums': ['L20', 'G24', 'K19', 'M21', 'H25', 'D24', 'F23', 'G25', 'J19', 'K20', 'L21', 'M22', 'D25', 'H19', 'F24', 'K21', 'L22', 'J20', 'M23', 'E22', 'F25', 'H20', 'J21', 'K22', 'L23', 'M24', 'E23', 'G20', 'H21', 'J22', 'K23', 'L24', 'M25', 'E24', 'C25', 'G21', 'H22', 'J23', 'K24', 'L25', 'N22', 'E25', 'G22', 'H23', 'J24', 'K25', 'M19', 'N23', 'F21', 'G23', 'H24', 'J25', 'L19', 'M20', 'N24', 'F22']},{'label': 'uI', 'num': 9, 'pin_nums': ['V21', 'W21', 'U21', 'R19', 'V23', 'W23', 'V20', 'U20', 'V22', 'W20', 'W22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R3', 'V6', 'T4', 'T5', 'R4', 'W4', 'R5', 'W5', 'T6', 'P5', 'R6', 'T7', 'W6', 'P6', 'U5', 'R7', 'P7', 'T1', 'U6', 'R1', 'T2', 'U7', 'R2', 'T3', 'V5']},{'label': 'uK', 'num': 11, 'pin_nums': ['K4', 'J1', 'J6', 'J4', 'K2', 'K6', 'M7', 'K1', 'J3', 'K5', 'J5', 'K3', 'L7']},{'label': 'uL', 'num': 12, 'pin_nums': ['G6', 'C3', 'H6', 'H5', 'G5', 'C2', 'J7']},{'label': 'uM', 'num': 13, 'pin_nums': ['U3', 'W2', 'AA1', 'AA2', 'U4', 'Y1', 'AA3', 'V1', 'Y2', 'AA4', 'V2', 'Y3', 'AB1', 'V3', 'Y4', 'AB2', 'V4', 'U1', 'V7', 'U2', 'W1']},{'label': 'uN', 'num': 14, 'pin_nums': ['A19', 'C16', 'E15', 'E16', 'C17', 'A20', 'C15', 'B16', 'C18', 'E17', 'G15', 'C19', 'E18', 'B17', 'B18', 'D16', 'F15', 'A16', 'B19', 'D17', 'F16', 'A17', 'B20', 'D18', 'F17', 'A18', 'D19']},{'label': 'uO', 'num': 15, 'pin_nums': ['B3', 'A2', 'B1', 'G8', 'B2', 'G7', 'H7', 'A3']},{'label': 'uP', 'num': 16, 'pin_nums': ['E10', 'F10', 'A6', 'B8', 'B6', 'E9', 'D10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['B23', 'B25', 'C23', 'D21', 'D23', 'F20', 'A24', 'C22', 'C24', 'D22', 'E21', 'G18', 'B24']},{'label': 'uR', 'num': 18, 'pin_nums': ['A21', 'E19', 'G16', 'C20', 'B21', 'D20', 'F18']},{'label': 'uS', 'num': 19, 'pin_nums': ['A23', 'C21', 'F19', 'E20', 'A22', 'B22', 'G17']},{'label': 'uT', 'num': 20, 'pin_nums': ['F14', 'B15', 'D13', 'D15', 'E14', 'A15', 'B13', 'D14', 'E13', 'F13', 'G14', 'C13']},{'label': 'uU', 'num': 21, 'pin_nums': ['AE12', 'V18', 'AB13', 'AE13', 'AC22', 'V9', 'AB14', 'AC23', 'AE14', 'W14', 'AB15', 'AC24', 'AE15', 'W25', 'AB16', 'AC25', 'AE16', 'Y10', 'AB17', 'AC3', 'AE17', 'Y11', 'AB18', 'AC4', 'AE18', 'Y12', 'AB19', 'AC5', 'AE19', 'Y13', 'AB20', 'AC6', 'AE2', 'Y14', 'AB21', 'AC7', 'AE20', 'Y15', 'AB22', 'AC8', 'AE21', 'Y16', 'AB23', 'AC9', 'AE22', 'Y17', 'AB25', 'AD1', 'AE23', 'Y18', 'AB4', 'AD11', 'AE24', 'Y19', 'AB5', 'AD12', 'AE3', 'Y20', 'AA11', 'AB6', 'AD14', 'AE4', 'Y21', 'AA12', 'AB7', 'AD15', 'AE5', 'Y22', 'AA14', 'AB8', 'AD17', 'AE6', 'Y23', 'AA15', 'AB9', 'AD18', 'AE7', 'AB12', 'Y25', 'AA17', 'AC1', 'AD2', 'AE8', 'Y6', 'AA18', 'AC10', 'AD20', 'AE9', 'Y7', 'AA20', 'AC11', 'AD21', 'R18', 'Y8', 'AA21', 'AC12', 'T18', 'AD23', 'Y9', 'AA23', 'AC13', 'U18', 'AD24', 'AA24', 'AC14', 'V10', 'AD25', 'AA25', 'AC15', 'V11', 'AD3', 'AC16', 'AA5', 'V12', 'AD5', 'AA6', 'AC17', 'V13', 'AD6', 'AA8', 'AC18', 'V14', 'AD8', 'AA9', 'AC19', 'V15', 'AD9', 'AB10', 'AC2', 'V16', 'AE10', 'AB11', 'AC20', 'V17', 'AE11', 'AC21']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['A14', 'G12', 'B14', 'C14', 'B12', 'G13', 'A12']}] }),
        Part(**{ 'name':'MCIMX6D5EYM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6D5EYM'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQCEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6D5EYM\n\nDual-Core ARM Cortex A9 SOC', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['J9', 'U16', 'AE1', 'AE25', 'N17', 'U17', 'B4', 'K10', 'N18', 'C1', 'K11', 'U19', 'C10', 'N8', 'U8', 'C4', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'E8', 'P15', 'K8', 'W13', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'U15', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'H8', 'T14', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'T17', 'AA7', 'J11', 'M18', 'AA13', 'T19', 'J12', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'J8', 'N16']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'A5', 'C8', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'F12', 'C12', 'E11', 'D11', 'F11', 'C11']},{'label': 'uD', 'num': 4, 'pin_nums': ['B11', 'C7', 'A9', 'B9', 'A10', 'D5', 'D7', 'B10', 'C5', 'A11']},{'label': 'uE', 'num': 5, 'pin_nums': ['F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3']},{'label': 'uF', 'num': 6, 'pin_nums': ['N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3']},{'label': 'uG', 'num': 7, 'pin_nums': ['U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21']},{'label': 'uH', 'num': 8, 'pin_nums': ['M19', 'E23', 'J19', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'M21', 'G24', 'E25', 'J21', 'K25', 'G25', 'M22', 'E22', 'J22', 'F21', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'F23', 'L21', 'H21', 'M25', 'F24', 'J25', 'L22', 'H22', 'N22', 'C25', 'F25', 'K19', 'K22', 'L23', 'H23', 'N23', 'D24', 'G20', 'K20', 'L24', 'H24', 'N24', 'D25', 'K21', 'G21', 'L25', 'H25', 'G22']},{'label': 'uI', 'num': 9, 'pin_nums': ['V23', 'W22', 'U20', 'V21', 'W20', 'W21', 'U21', 'W23', 'V22', 'R19', 'V20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5']},{'label': 'uK', 'num': 11, 'pin_nums': ['J4', 'K6', 'K1', 'J1', 'J5', 'K4', 'L7', 'K2', 'K3', 'J3', 'K5', 'J6', 'M7']},{'label': 'uL', 'num': 12, 'pin_nums': ['G5', 'H6', 'C2', 'G6', 'J7', 'C3', 'H5']},{'label': 'uM', 'num': 13, 'pin_nums': ['Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3']},{'label': 'uN', 'num': 14, 'pin_nums': ['B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15']},{'label': 'uO', 'num': 15, 'pin_nums': ['B2', 'G8', 'A3', 'B3', 'H7', 'B1', 'G7', 'A2']},{'label': 'uP', 'num': 16, 'pin_nums': ['D10', 'F10', 'B6', 'E10', 'B8', 'E9', 'A6']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C22', 'G18', 'D21', 'B24', 'C23', 'E21', 'B23', 'A24', 'D22', 'B25', 'C24', 'D23', 'F20']},{'label': 'uR', 'num': 18, 'pin_nums': ['E19', 'C20', 'F18', 'A21', 'D20', 'G16', 'B21']},{'label': 'uS', 'num': 19, 'pin_nums': ['F19', 'A22', 'C21', 'G17', 'A23', 'E20', 'B22']},{'label': 'uT', 'num': 20, 'pin_nums': ['D15', 'B13', 'F13', 'E14', 'D13', 'E13', 'C13', 'B15', 'F14', 'D14', 'A15', 'G14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AE6', 'AA8', 'AC5', 'AA9', 'AE7', 'AC6', 'AE8', 'AB10', 'AC7', 'AB11', 'AE9', 'AA6', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'AB18', 'V13', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AE5', 'AC4']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['B14', 'G13', 'A14', 'C14', 'A12', 'B12', 'G12']}] }),
        Part(**{ 'name':'MCIMX6D6AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6D6AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6D6AVT\n\nDual-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N13', 'AD19', 'J18', 'U13', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'U17', 'K10', 'N18', 'C1', 'U19', 'C10', 'K11', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'D3', 'K13', 'P10', 'D6', 'V19', 'K14', 'P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'U12', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'H8', 'A13', 'T14', 'M15', 'H9', 'A25', 'T15', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'T17', 'J11', 'AA7', 'M18', 'T19', 'J12', 'AA13', 'AA16', 'M8', 'T8', 'J13', 'AA19', 'M9', 'AA22', 'T9', 'J14', 'AB24', 'N10', 'U10', 'J15', 'AB3', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'J17', 'AD16']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'B5', 'A5', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['F11', 'C11', 'D12', 'F12', 'C12', 'E11', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['C5', 'A11', 'D7', 'B11', 'A10', 'C7', 'A9', 'B9', 'D5', 'B10']},{'label': 'uE', 'num': 5, 'pin_nums': ['F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4']},{'label': 'uF', 'num': 6, 'pin_nums': ['M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3']},{'label': 'uG', 'num': 7, 'pin_nums': ['P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22']},{'label': 'uH', 'num': 8, 'pin_nums': ['F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'G20', 'L24', 'H24', 'K21', 'N24', 'D25', 'G21', 'L25', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'L19', 'H19', 'M23', 'N22', 'C25', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'F23', 'L21', 'H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'K19']},{'label': 'uI', 'num': 9, 'pin_nums': ['W21', 'R19', 'V20', 'V23', 'U20', 'W22', 'V21', 'W20', 'W23', 'V22', 'U21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6']},{'label': 'uK', 'num': 11, 'pin_nums': ['J3', 'J6', 'M7', 'K3', 'J4', 'K6', 'K1', 'J1', 'K4', 'J5', 'L7', 'K2', 'K5']},{'label': 'uL', 'num': 12, 'pin_nums': ['G5', 'H6', 'C2', 'G6', 'J7', 'C3', 'H5']},{'label': 'uM', 'num': 13, 'pin_nums': ['W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2']},{'label': 'uN', 'num': 14, 'pin_nums': ['D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'B16', 'A19', 'F16', 'C19', 'A20', 'F17', 'D16', 'G15']},{'label': 'uO', 'num': 15, 'pin_nums': ['G7', 'A2', 'B2', 'G8', 'A3', 'B3', 'H7', 'B1']},{'label': 'uP', 'num': 16, 'pin_nums': ['E9', 'A6', 'D10', 'F10', 'B6', 'E10', 'B8']},{'label': 'uQ', 'num': 17, 'pin_nums': ['B25', 'C24', 'B23', 'D23', 'C22', 'G18', 'A24', 'D21', 'E21', 'B24', 'C23', 'D22', 'F20']},{'label': 'uR', 'num': 18, 'pin_nums': ['B21', 'E19', 'C20', 'F18', 'A21', 'D20', 'G16']},{'label': 'uS', 'num': 19, 'pin_nums': ['B22', 'F19', 'A22', 'C21', 'G17', 'A23', 'E20']},{'label': 'uT', 'num': 20, 'pin_nums': ['C13', 'G14', 'D15', 'F13', 'B13', 'E14', 'D13', 'E13', 'B15', 'F14', 'D14', 'A15']},{'label': 'uU', 'num': 21, 'pin_nums': ['AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AE7', 'AA9', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'AB4', 'W14', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'AA24', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AE24']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['G12', 'A12', 'B14', 'G13', 'A14', 'C14', 'B12']}] }),
        Part(**{ 'name':'MCIMX6D7CVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6D7CVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC Industrial', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQIEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6D7CVT\n\nDual-Core ARM Cortex A9 SOC Industrial', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['Y5', 'AB24', 'H11', 'N17', 'K9', 'AB3', 'T17', 'H12', 'AD10', 'N18', 'L10', 'AD13', 'T19', 'AD16', 'H13', 'L11', 'N8', 'T8', 'H14', 'AD19', 'N9', 'L12', 'T9', 'H15', 'AD22', 'L13', 'P10', 'U10', 'H16', 'AD4', 'P11', 'L14', 'AA22', 'U11', 'H17', 'AD7', 'L15', 'P12', 'U12', 'AE1', 'H18', 'L16', 'P13', 'U13', 'H8', 'AE25', 'L17', 'P14', 'U14', 'B4', 'H9', 'L18', 'P15', 'U15', 'J10', 'C1', 'L2', 'P16', 'U16', 'J11', 'C10', 'L5', 'P17', 'U17', 'N16', 'J12', 'C4', 'L8', 'P18', 'U19', 'J13', 'C6', 'L9', 'P8', 'K8', 'U8', 'J14', 'D3', 'M10', 'P9', 'U9', 'D6', 'J15', 'M11', 'R10', 'V19', 'J16', 'D8', 'R11', 'M12', 'V8', 'J17', 'E5', 'M13', 'R12', 'W10', 'E6', 'J18', 'M14', 'R13', 'W11', 'E7', 'J2', 'M15', 'R14', 'W12', 'J8', 'E8', 'M16', 'R15', 'W13', 'F5', 'J9', 'M17', 'R16', 'W15', 'F6', 'K10', 'M18', 'R17', 'W16', 'F7', 'K11', 'M8', 'R8', 'W17', 'F8', 'K12', 'M9', 'R9', 'W18', 'K13', 'F9', 'N10', 'T10', 'W19', 'G10', 'K14', 'N11', 'T11', 'W3', 'A13', 'K15', 'G11', 'T12', 'N12', 'A25', 'W7', 'A4', 'G19', 'K16', 'N13', 'T13', 'A8', 'W8', 'AA10', 'G3', 'K17', 'N14', 'T14', 'AA7', 'W9', 'AA13', 'AA16', 'K18', 'G9', 'N15', 'T15', 'Y24', 'AA19', 'H10', 'T16']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'C8', 'A5', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'F11', 'C12', 'C11', 'D11', 'E11', 'F12']},{'label': 'uD', 'num': 4, 'pin_nums': ['D5', 'A10', 'A9', 'B11', 'C5', 'A11', 'B10', 'B9', 'C7', 'D7']},{'label': 'uE', 'num': 5, 'pin_nums': ['D4', 'F4', 'K7', 'E1', 'G1', 'E2', 'G2', 'E3', 'G4', 'E4', 'H1', 'F1', 'H2', 'D1', 'F2', 'H3', 'D2', 'F3', 'H4']},{'label': 'uF', 'num': 6, 'pin_nums': ['M4', 'N6', 'N7', 'M5', 'L1', 'P1', 'M6', 'L3', 'N1', 'L4', 'P2', 'L6', 'N2', 'P3', 'M1', 'N3', 'P4', 'M2', 'N4', 'M3', 'N5']},{'label': 'uG', 'num': 7, 'pin_nums': ['T21', 'U25', 'N21', 'P25', 'R20', 'T22', 'N25', 'V24', 'R21', 'P19', 'T23', 'V25', 'P20', 'R22', 'T24', 'W24', 'P21', 'R23', 'T25', 'P22', 'R24', 'U22', 'N19', 'P23', 'R25', 'U23', 'N20', 'P24', 'T20', 'U24']},{'label': 'uH', 'num': 8, 'pin_nums': ['F25', 'H20', 'J22', 'G20', 'H21', 'E23', 'K23', 'L24', 'M25', 'J21', 'L23', 'M24', 'G21', 'H22', 'J23', 'L25', 'K24', 'N22', 'E24', 'E25', 'G22', 'H23', 'J24', 'K25', 'M19', 'N23', 'G23', 'H24', 'J25', 'L19', 'M20', 'F21', 'N24', 'C25', 'F22', 'G24', 'H25', 'K19', 'L20', 'M21', 'D24', 'F23', 'G25', 'J19', 'K20', 'L21', 'M22', 'D25', 'F24', 'H19', 'J20', 'K21', 'L22', 'M23', 'E22', 'K22']},{'label': 'uI', 'num': 9, 'pin_nums': ['R19', 'V21', 'V23', 'W21', 'W23', 'U21', 'U20', 'V20', 'V22', 'W20', 'W22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['U5', 'P6', 'R7', 'P7', 'T1', 'U6', 'U7', 'T2', 'R1', 'R2', 'T3', 'V5', 'T4', 'V6', 'R3', 'R4', 'T5', 'W4', 'W5', 'T6', 'R5', 'W6', 'R6', 'P5', 'T7']},{'label': 'uK', 'num': 11, 'pin_nums': ['K1', 'K5', 'L7', 'J6', 'K2', 'K4', 'J1', 'J4', 'K6', 'M7', 'K3', 'J3', 'J5']},{'label': 'uL', 'num': 12, 'pin_nums': ['C2', 'H5', 'J7', 'G6', 'C3', 'H6', 'G5']},{'label': 'uM', 'num': 13, 'pin_nums': ['AB1', 'V3', 'V2', 'Y4', 'Y3', 'AB2', 'V4', 'U1', 'V7', 'U2', 'W1', 'W2', 'AA1', 'U3', 'AA2', 'U4', 'Y1', 'V1', 'AA3', 'Y2', 'AA4']},{'label': 'uN', 'num': 14, 'pin_nums': ['B17', 'E18', 'C19', 'B18', 'D16', 'F15', 'A16', 'B19', 'D17', 'F16', 'A17', 'B20', 'D18', 'F17', 'A18', 'C15', 'D19', 'G15', 'A19', 'C16', 'E15', 'A20', 'C17', 'E16', 'B16', 'C18', 'E17']},{'label': 'uO', 'num': 15, 'pin_nums': ['H7', 'A3', 'B2', 'G7', 'B1', 'G8', 'A2', 'B3']},{'label': 'uP', 'num': 16, 'pin_nums': ['B6', 'D10', 'E9', 'A6', 'B8', 'F10', 'E10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['D22', 'A24', 'B24', 'C22', 'C24', 'E21', 'G18', 'D23', 'D21', 'B23', 'B25', 'C23', 'F20']},{'label': 'uR', 'num': 18, 'pin_nums': ['F18', 'B21', 'D20', 'A21', 'C20', 'E19', 'G16']},{'label': 'uS', 'num': 19, 'pin_nums': ['A22', 'E20', 'B22', 'G17', 'A23', 'C21', 'F19']},{'label': 'uT', 'num': 20, 'pin_nums': ['F13', 'G14', 'E13', 'B13', 'C13', 'D14', 'D13', 'A15', 'B15', 'D15', 'E14', 'F14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AA8', 'AC18', 'AD8', 'V14', 'AA9', 'AD9', 'AC19', 'V15', 'AB10', 'AC2', 'AE10', 'V16', 'AB11', 'AE11', 'AC20', 'V17', 'AB12', 'AC21', 'AE12', 'V18', 'AB13', 'AC22', 'AE13', 'V9', 'AB14', 'AC23', 'AE14', 'W14', 'AB15', 'AE15', 'AC24', 'W25', 'AB16', 'AC25', 'AE16', 'Y10', 'AB17', 'AC3', 'AE17', 'Y11', 'AB18', 'AC4', 'AE18', 'Y12', 'AB19', 'AC5', 'AE19', 'Y13', 'AB20', 'AC6', 'AE2', 'Y14', 'AB21', 'AC7', 'AE20', 'Y15', 'AB22', 'AC8', 'AE21', 'Y16', 'AD6', 'AB23', 'AC9', 'AE22', 'Y17', 'AB25', 'AD1', 'AE23', 'Y18', 'AB4', 'AD11', 'AE24', 'Y19', 'AB5', 'AD12', 'AE3', 'Y20', 'AA11', 'AB6', 'AD14', 'AE4', 'Y21', 'AA12', 'AB7', 'AD15', 'AE5', 'Y22', 'AA14', 'AB8', 'AD17', 'AE6', 'Y23', 'AA15', 'AB9', 'AD18', 'AE7', 'Y25', 'AA17', 'AC1', 'AD2', 'AE8', 'Y6', 'AA18', 'AC10', 'AD20', 'AE9', 'Y7', 'AA20', 'AC11', 'AD21', 'R18', 'Y8', 'AA21', 'AC12', 'T18', 'AD23', 'Y9', 'AA23', 'AC13', 'U18', 'AD24', 'AA24', 'AC14', 'V10', 'AD25', 'AA25', 'AC15', 'V11', 'AD3', 'AC16', 'AA5', 'AD5', 'V12', 'AA6', 'AC17', 'V13']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['A12', 'B12', 'G13', 'G12', 'B14', 'A14', 'C14']}] }),
        Part(**{ 'name':'MCIMX6DP4AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6DP4AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6DP4AVT\n\nDual-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['U10', 'AB3', 'N11', 'J16', 'AD10', 'U11', 'AD13', 'N12', 'U12', 'J17', 'AD16', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'U14', 'J2', 'AD4', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'J9', 'AE25', 'N17', 'U17', 'B4', 'K10', 'N18', 'C1', 'U19', 'K11', 'C10', 'N8', 'U8', 'C4', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'H8', 'T14', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'AA7', 'T17', 'J11', 'M18', 'AA13', 'T19', 'J12', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'J15']},{'label': 'uB', 'num': 2, 'pin_nums': ['B5', 'A5', 'C8', 'E12']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'F12', 'C12', 'E11', 'D11', 'F11', 'C11']},{'label': 'uD', 'num': 4, 'pin_nums': ['D7', 'B11', 'A9', 'C7', 'A11', 'A10', 'B9', 'B10', 'D5', 'C5']},{'label': 'uE', 'num': 5, 'pin_nums': ['H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2']},{'label': 'uF', 'num': 6, 'pin_nums': ['M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1']},{'label': 'uG', 'num': 7, 'pin_nums': ['P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25']},{'label': 'uH', 'num': 8, 'pin_nums': ['J24', 'M24', 'F23', 'L21', 'H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'G20', 'L24', 'H24', 'N24', 'D25', 'K21', 'G21', 'L25', 'E22', 'H25', 'K22', 'G22', 'M19', 'E23', 'J19', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'H20']},{'label': 'uI', 'num': 9, 'pin_nums': ['V23', 'U20', 'W22', 'V21', 'W20', 'U21', 'W23', 'W21', 'V22', 'R19', 'V20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7']},{'label': 'uK', 'num': 11, 'pin_nums': ['K3', 'J4', 'K6', 'J1', 'K1', 'K4', 'J5', 'L7', 'J6', 'J3', 'K2', 'K5', 'M7']},{'label': 'uL', 'num': 12, 'pin_nums': ['G5', 'H6', 'C2', 'G6', 'J7', 'C3', 'H5']},{'label': 'uM', 'num': 13, 'pin_nums': ['AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4']},{'label': 'uN', 'num': 14, 'pin_nums': ['C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19']},{'label': 'uO', 'num': 15, 'pin_nums': ['B2', 'G8', 'A3', 'B3', 'H7', 'B1', 'G7', 'A2']},{'label': 'uP', 'num': 16, 'pin_nums': ['D10', 'F10', 'B6', 'E10', 'B8', 'E9', 'A6']},{'label': 'uQ', 'num': 17, 'pin_nums': ['D23', 'C22', 'G18', 'D21', 'B24', 'E21', 'B23', 'A24', 'C23', 'B25', 'D22', 'F20', 'C24']},{'label': 'uR', 'num': 18, 'pin_nums': ['E19', 'C20', 'F18', 'A21', 'D20', 'G16', 'B21']},{'label': 'uS', 'num': 19, 'pin_nums': ['F19', 'A22', 'C21', 'G17', 'A23', 'E20', 'B22']},{'label': 'uT', 'num': 20, 'pin_nums': ['D15', 'B13', 'F13', 'D13', 'E14', 'E13', 'B15', 'F14', 'D14', 'A15', 'C13', 'G14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AE22', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AE5', 'AA6', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AA21']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['A12', 'B14', 'G13', 'A14', 'C14', 'B12', 'G12']}] }),
        Part(**{ 'name':'MCIMX6DP5EVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6DP5EVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPCEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6DP5EVT\n\nDual-Core ARM Cortex A9 SOC', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AA13', 'AA16', 'J12', 'T19', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'K10', 'U17', 'N18', 'C1', 'U19', 'C10', 'K11', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'D3', 'K13', 'P10', 'D6', 'V19', 'K14', 'P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'H8', 'A13', 'T14', 'M15', 'H9', 'A25', 'T15', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'T17', 'J11', 'AA7', 'M18']},{'label': 'uB', 'num': 2, 'pin_nums': ['A5', 'C8', 'E12', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['D11', 'F11', 'C11', 'D12', 'F12', 'C12', 'E11']},{'label': 'uD', 'num': 4, 'pin_nums': ['B10', 'A10', 'C5', 'D7', 'A11', 'B11', 'C7', 'A9', 'B9', 'D5']},{'label': 'uE', 'num': 5, 'pin_nums': ['D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1']},{'label': 'uF', 'num': 6, 'pin_nums': ['N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6']},{'label': 'uG', 'num': 7, 'pin_nums': ['R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25']},{'label': 'uH', 'num': 8, 'pin_nums': ['G24', 'M21', 'J21', 'K25', 'E25', 'G25', 'J22', 'M22', 'F21', 'L19', 'H19', 'J23', 'M23', 'F22', 'L20', 'H20', 'M24', 'J24', 'F23', 'L21', 'H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'G20', 'L24', 'H24', 'K21', 'N24', 'D25', 'G21', 'L25', 'H25', 'E24', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'M20', 'J20', 'K24']},{'label': 'uI', 'num': 9, 'pin_nums': ['V22', 'R19', 'W21', 'V20', 'V23', 'U20', 'W22', 'V21', 'U21', 'W20', 'W23']},{'label': 'uJ', 'num': 10, 'pin_nums': ['P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5']},{'label': 'uK', 'num': 11, 'pin_nums': ['K5', 'J3', 'M7', 'J6', 'K3', 'J4', 'K6', 'J5', 'K1', 'J1', 'K4', 'L7', 'K2']},{'label': 'uL', 'num': 12, 'pin_nums': ['H5', 'G5', 'H6', 'C2', 'G6', 'J7', 'C3']},{'label': 'uM', 'num': 13, 'pin_nums': ['AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1']},{'label': 'uN', 'num': 14, 'pin_nums': ['E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15']},{'label': 'uO', 'num': 15, 'pin_nums': ['B1', 'G7', 'A2', 'B2', 'G8', 'A3', 'B3', 'H7']},{'label': 'uP', 'num': 16, 'pin_nums': ['B8', 'E9', 'A6', 'D10', 'F10', 'B6', 'E10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['B25', 'F20', 'A24', 'C24', 'B23', 'D23', 'C22', 'G18', 'D21', 'E21', 'B24', 'C23', 'D22']},{'label': 'uR', 'num': 18, 'pin_nums': ['G16', 'B21', 'E19', 'C20', 'F18', 'A21', 'D20']},{'label': 'uS', 'num': 19, 'pin_nums': ['B22', 'F19', 'A22', 'C21', 'G17', 'A23', 'E20']},{'label': 'uT', 'num': 20, 'pin_nums': ['A15', 'E14', 'C13', 'G14', 'D15', 'B13', 'F13', 'D13', 'E13', 'B15', 'F14', 'D14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AA17', 'AE2', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AA20', 'AE21', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AE7', 'AA9', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'AC19', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'Y25']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['B12', 'G12', 'A12', 'B14', 'G13', 'A14', 'C14']}] }),
        Part(**{ 'name':'MCIMX6DP5EYM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6DP5EYM'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPCEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6DP5EYM\n\nDual-Core ARM Cortex A9 SOC', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A25', 'T15', 'H9', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'J11', 'T17', 'AA7', 'M18', 'T19', 'J12', 'AA13', 'AA16', 'M8', 'T8', 'J13', 'AA19', 'M9', 'AA22', 'T9', 'J14', 'AB24', 'N10', 'U10', 'J15', 'H8', 'AB3', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'U12', 'J17', 'AD16', 'N13', 'AD19', 'U13', 'J18', 'N14', 'AD22', 'J2', 'U14', 'AD4', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'J9', 'AE25', 'N17', 'U17', 'B4', 'K10', 'N18', 'C1', 'U19', 'K11', 'C10', 'N8', 'U8', 'C4', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'T14', 'M15']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'B5', 'A5', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['D11', 'C11', 'F11', 'D12', 'F12', 'C12', 'E11']},{'label': 'uD', 'num': 4, 'pin_nums': ['B9', 'A10', 'D5', 'B10', 'C5', 'A11', 'D7', 'B11', 'C7', 'A9']},{'label': 'uE', 'num': 5, 'pin_nums': ['F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2']},{'label': 'uF', 'num': 6, 'pin_nums': ['L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1']},{'label': 'uG', 'num': 7, 'pin_nums': ['R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19']},{'label': 'uH', 'num': 8, 'pin_nums': ['K21', 'G20', 'L25', 'G21', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'K23', 'E23', 'H24', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'D25', 'F23', 'L21', 'H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'L24', 'N24']},{'label': 'uI', 'num': 9, 'pin_nums': ['U21', 'W23', 'V22', 'R19', 'W21', 'V20', 'V23', 'U20', 'W22', 'V21', 'W20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['T1', 'P5', 'V6', 'T2', 'P6', 'W4', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5']},{'label': 'uK', 'num': 11, 'pin_nums': ['J5', 'L7', 'K2', 'J3', 'K5', 'J6', 'M7', 'K3', 'J1', 'J4', 'K6', 'K1', 'K4']},{'label': 'uL', 'num': 12, 'pin_nums': ['J7', 'C3', 'H5', 'G5', 'H6', 'C2', 'G6']},{'label': 'uM', 'num': 13, 'pin_nums': ['U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1']},{'label': 'uN', 'num': 14, 'pin_nums': ['D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18']},{'label': 'uO', 'num': 15, 'pin_nums': ['H7', 'B1', 'G7', 'A2', 'B2', 'G8', 'A3', 'B3']},{'label': 'uP', 'num': 16, 'pin_nums': ['B8', 'A6', 'E9', 'D10', 'B6', 'E10', 'F10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C23', 'A24', 'D22', 'B25', 'F20', 'C24', 'B23', 'D23', 'C22', 'G18', 'E21', 'D21', 'B24']},{'label': 'uR', 'num': 18, 'pin_nums': ['A21', 'D20', 'G16', 'B21', 'E19', 'C20', 'F18']},{'label': 'uS', 'num': 19, 'pin_nums': ['A23', 'E20', 'B22', 'F19', 'A22', 'C21', 'G17']},{'label': 'uT', 'num': 20, 'pin_nums': ['B15', 'F14', 'D14', 'E14', 'A15', 'C13', 'G14', 'D15', 'F13', 'B13', 'D13', 'E13']},{'label': 'uU', 'num': 21, 'pin_nums': ['AA12', 'AE17', 'Y22', 'AC17', 'AE18', 'AA14', 'AC16', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AE16', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AA11', 'Y21']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['C14', 'B12', 'G12', 'A12', 'B14', 'G13', 'A14']}] }),
        Part(**{ 'name':'MCIMX6DP6AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6DP6AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6DP6AVT\n\nDual-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T12', 'H17', 'M13', 'T13', 'H18', 'M14', 'A13', 'T14', 'H8', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'AA7', 'T17', 'J11', 'M18', 'AA13', 'T19', 'J12', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'J16', 'U11', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'U17', 'K10', 'N18', 'C1', 'U19', 'C10', 'K11', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'D3', 'K13', 'P10', 'D6', 'V19', 'K14', 'P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12']},{'label': 'uB', 'num': 2, 'pin_nums': ['A5', 'E12', 'C8', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['E11', 'D11', 'F11', 'C11', 'D12', 'F12', 'C12']},{'label': 'uD', 'num': 4, 'pin_nums': ['B9', 'A10', 'D5', 'B10', 'C5', 'A11', 'D7', 'B11', 'C7', 'A9']},{'label': 'uE', 'num': 5, 'pin_nums': ['E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3']},{'label': 'uF', 'num': 6, 'pin_nums': ['M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2']},{'label': 'uG', 'num': 7, 'pin_nums': ['P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24']},{'label': 'uH', 'num': 8, 'pin_nums': ['F24', 'H22', 'L22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'G20', 'H24', 'L24', 'K21', 'N24', 'D25', 'G21', 'L25', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'J20', 'M20', 'E24', 'K24', 'G24', 'J21', 'M21', 'E25', 'K25', 'G25', 'M25', 'J22', 'M22', 'F21', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'F23', 'L21', 'H21', 'J25']},{'label': 'uI', 'num': 9, 'pin_nums': ['W20', 'U20', 'W23', 'U21', 'V22', 'W21', 'R19', 'V20', 'V23', 'W22', 'V21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5']},{'label': 'uK', 'num': 11, 'pin_nums': ['J5', 'L7', 'J1', 'K2', 'K5', 'J3', 'J6', 'M7', 'K3', 'J4', 'K6', 'K1', 'K4']},{'label': 'uL', 'num': 12, 'pin_nums': ['J7', 'C3', 'H5', 'G5', 'H6', 'C2', 'G6']},{'label': 'uM', 'num': 13, 'pin_nums': ['W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1']},{'label': 'uN', 'num': 14, 'pin_nums': ['D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20']},{'label': 'uO', 'num': 15, 'pin_nums': ['B3', 'H7', 'B1', 'G7', 'A2', 'B2', 'G8', 'A3']},{'label': 'uP', 'num': 16, 'pin_nums': ['E10', 'B8', 'E9', 'A6', 'D10', 'F10', 'B6']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C23', 'A24', 'D22', 'E21', 'B25', 'F20', 'C24', 'B23', 'D23', 'C22', 'G18', 'D21', 'B24']},{'label': 'uR', 'num': 18, 'pin_nums': ['A21', 'D20', 'G16', 'B21', 'E19', 'C20', 'F18']},{'label': 'uS', 'num': 19, 'pin_nums': ['A23', 'E20', 'B22', 'F19', 'A22', 'C21', 'G17']},{'label': 'uT', 'num': 20, 'pin_nums': ['B15', 'F14', 'D14', 'E14', 'A15', 'C13', 'G14', 'D15', 'F13', 'B13', 'D13', 'E13']},{'label': 'uU', 'num': 21, 'pin_nums': ['AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AA11', 'AE16', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'Y23', 'AC18', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AE23', 'AA23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y18', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'AC13']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['C14', 'B12', 'G12', 'A12', 'B14', 'G13', 'A14']}] }),
        Part(**{ 'name':'MCIMX6DP7CVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6DP7CVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Dual-Core ARM Cortex A9 SOC Industrial', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPIEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6DP7CVT\n\nDual-Core ARM Cortex A9 SOC Industrial', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['R9', 'H14', 'M10', 'T10', 'H15', 'M11', 'T11', 'H16', 'M12', 'H17', 'T12', 'R8', 'M13', 'H18', 'T13', 'M14', 'H8', 'A13', 'T14', 'M15', 'A25', 'H9', 'T15', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'J11', 'T17', 'AA7', 'M18', 'J12', 'AA13', 'T19', 'AA16', 'M8', 'T8', 'J13', 'AA19', 'M9', 'AA22', 'J14', 'T9', 'AB24', 'N10', 'U10', 'J15', 'AB3', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'U12', 'J17', 'AD16', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'U14', 'J2', 'AD4', 'N15', 'U15', 'AD7', 'J8', 'AE1', 'N16', 'U16', 'J9', 'AE25', 'N17', 'B4', 'U17', 'K10', 'C1', 'N18', 'U19', 'K11', 'C10', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'W15', 'K9', 'P17', 'F6', 'W16', 'L10', 'P18', 'F7', 'W17', 'L11', 'P8', 'F8', 'W18', 'L12', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'R14', 'G9', 'L18', 'Y24', 'R15', 'H10', 'L2', 'Y5', 'R16', 'H11', 'L5', 'R17', 'H12', 'L8', 'H13', 'L9']},{'label': 'uB', 'num': 2, 'pin_nums': ['A5', 'B5', 'E12', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['F12', 'C12', 'E11', 'D11', 'F11', 'C11', 'D12']},{'label': 'uD', 'num': 4, 'pin_nums': ['C7', 'A11', 'A9', 'B9', 'D5', 'A10', 'B10', 'C5', 'D7', 'B11']},{'label': 'uE', 'num': 5, 'pin_nums': ['G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4']},{'label': 'uF', 'num': 6, 'pin_nums': ['M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6']},{'label': 'uG', 'num': 7, 'pin_nums': ['P20', 'R25', 'P21', 'V24', 'T20', 'P22', 'V25', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25']},{'label': 'uH', 'num': 8, 'pin_nums': ['J22', 'L19', 'F21', 'M23', 'H19', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'L21', 'F23', 'H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'K25', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'G25', 'D24', 'K20', 'G20', 'L24', 'H24', 'N24', 'D25', 'K21', 'G21', 'L25', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'M22']},{'label': 'uI', 'num': 9, 'pin_nums': ['V21', 'W20', 'U20', 'W23', 'U21', 'V22', 'R19', 'W21', 'V20', 'V23', 'W22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'R1', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'P7', 'W5', 'T4', 'W6', 'T5']},{'label': 'uK', 'num': 11, 'pin_nums': ['K1', 'K4', 'J1', 'J5', 'L7', 'K2', 'J3', 'K5', 'J6', 'M7', 'J4', 'K3', 'K6']},{'label': 'uL', 'num': 12, 'pin_nums': ['C2', 'G6', 'J7', 'C3', 'H5', 'G5', 'H6']},{'label': 'uM', 'num': 13, 'pin_nums': ['AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2']},{'label': 'uN', 'num': 14, 'pin_nums': ['C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17']},{'label': 'uO', 'num': 15, 'pin_nums': ['A3', 'B3', 'B1', 'H7', 'G7', 'A2', 'B2', 'G8']},{'label': 'uP', 'num': 16, 'pin_nums': ['F10', 'B6', 'E10', 'B8', 'E9', 'A6', 'D10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['D21', 'D23', 'E21', 'B24', 'C23', 'A24', 'D22', 'B25', 'F20', 'C24', 'B23', 'C22', 'G18']},{'label': 'uR', 'num': 18, 'pin_nums': ['C20', 'F18', 'A21', 'D20', 'G16', 'B21', 'E19']},{'label': 'uS', 'num': 19, 'pin_nums': ['C21', 'G17', 'A23', 'E20', 'B22', 'F19', 'A22']},{'label': 'uT', 'num': 20, 'pin_nums': ['D13', 'E13', 'B15', 'F14', 'D14', 'A15', 'E14', 'C13', 'G14', 'D15', 'F13', 'B13']},{'label': 'uU', 'num': 21, 'pin_nums': ['AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'Y19', 'AC14', 'AE15', 'Y20', 'AC15', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'Y6', 'AC2', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'Y15', 'AE22', 'AA21', 'AC22', 'Y9', 'AE23', 'AA23', 'AC23', 'AE24', 'AA24', 'AC24', 'AE3', 'AA25', 'AC25', 'AE4', 'AA5', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'AB14', 'U18', 'AD11', 'AB15', 'V10', 'AD12', 'AB16', 'V11', 'AD14', 'AB17', 'V12', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'AB21', 'V16', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'AC10']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['G13', 'A14', 'C14', 'B12', 'G12', 'A12', 'B14']}] }),
        Part(**{ 'name':'MCIMX6Q4AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6Q4AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6Q4AVT\n\nQuad-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L2', 'Y5', 'R16', 'H11', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'T10', 'H15', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'H8', 'T14', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'T17', 'AA7', 'J11', 'M18', 'AA13', 'T19', 'J12', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'U17', 'K10', 'N18', 'C1', 'U19', 'C10', 'K11', 'H10', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'D3', 'K13', 'P10', 'D6', 'V19', 'K14', 'P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'R15']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'A5', 'C8', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'F12', 'C12', 'E11', 'D11', 'F11', 'C11']},{'label': 'uD', 'num': 4, 'pin_nums': ['B11', 'C7', 'A9', 'D7', 'B9', 'A10', 'D5', 'B10', 'C5', 'A11']},{'label': 'uE', 'num': 5, 'pin_nums': ['F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3']},{'label': 'uF', 'num': 6, 'pin_nums': ['N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3']},{'label': 'uG', 'num': 7, 'pin_nums': ['U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21']},{'label': 'uH', 'num': 8, 'pin_nums': ['M19', 'J19', 'E23', 'G23', 'K23', 'J20', 'M20', 'E24', 'E22', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'J22', 'M22', 'F21', 'H19', 'L19', 'M23', 'J23', 'F22', 'H20', 'L20', 'M24', 'J24', 'F23', 'H21', 'L21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'G20', 'L24', 'H24', 'K21', 'N24', 'D25', 'G21', 'L25', 'H25', 'K22', 'G22']},{'label': 'uI', 'num': 9, 'pin_nums': ['V23', 'U20', 'W22', 'W21', 'V21', 'W20', 'U21', 'W23', 'V22', 'R19', 'V20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5']},{'label': 'uK', 'num': 11, 'pin_nums': ['J4', 'K6', 'K1', 'J1', 'K4', 'J5', 'L7', 'K2', 'J6', 'K5', 'J3', 'M7', 'K3']},{'label': 'uL', 'num': 12, 'pin_nums': ['H6', 'C2', 'G6', 'J7', 'C3', 'H5', 'G5']},{'label': 'uM', 'num': 13, 'pin_nums': ['Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3']},{'label': 'uN', 'num': 14, 'pin_nums': ['B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15']},{'label': 'uO', 'num': 15, 'pin_nums': ['B2', 'G8', 'A3', 'B3', 'H7', 'B1', 'G7', 'A2']},{'label': 'uP', 'num': 16, 'pin_nums': ['D10', 'F10', 'B6', 'E10', 'B8', 'E9', 'A6']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C22', 'G18', 'D21', 'B23', 'B24', 'E21', 'C23', 'A24', 'D22', 'B25', 'F20', 'C24', 'D23']},{'label': 'uR', 'num': 18, 'pin_nums': ['C20', 'F18', 'A21', 'D20', 'G16', 'B21', 'E19']},{'label': 'uS', 'num': 19, 'pin_nums': ['A22', 'C21', 'G17', 'A23', 'E20', 'B22', 'F19']},{'label': 'uT', 'num': 20, 'pin_nums': ['B13', 'D15', 'F13', 'D13', 'E13', 'B15', 'F14', 'D14', 'A15', 'C13', 'G14', 'E14']},{'label': 'uU', 'num': 21, 'pin_nums': ['Y12', 'AB8', 'AD8', 'AB9', 'Y13', 'AD9', 'AC1', 'Y14', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'AC12', 'Y17', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'Y22', 'AC17', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AE5', 'AA6', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'AB18', 'V13', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['B14', 'G13', 'A14', 'C14', 'B12', 'G12', 'A12']}] }),
        Part(**{ 'name':'MCIMX6Q5EYM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6Q5EYM'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQCEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6Q5EYM\n\nQuad-Core ARM Cortex A9 SOC', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G3', 'R13', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'R15', 'H10', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'L16', 'M13', 'H18', 'T13', 'M14', 'H8', 'A13', 'T14', 'R12', 'M15', 'H9', 'A25', 'T15', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'T17', 'J11', 'AA7', 'M18', 'T19', 'J12', 'AA13', 'AA16', 'M8', 'T8', 'J13', 'AA19', 'M9', 'AA22', 'T9', 'J14', 'AB24', 'N10', 'U10', 'J15', 'AB3', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'U12', 'J17', 'AD16', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'U14', 'J2', 'AD4', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'J9', 'AE25', 'N17', 'U17', 'B4', 'K10', 'N18', 'C1', 'U19', 'K11', 'C10', 'N8', 'U8', 'C4', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'G19', 'W8']},{'label': 'uB', 'num': 2, 'pin_nums': ['C8', 'E12', 'B5', 'A5']},{'label': 'uC', 'num': 3, 'pin_nums': ['C11', 'D12', 'F12', 'C12', 'E11', 'D11', 'F11']},{'label': 'uD', 'num': 4, 'pin_nums': ['A11', 'D7', 'B11', 'C7', 'A9', 'B9', 'A10', 'D5', 'B10', 'C5']},{'label': 'uE', 'num': 5, 'pin_nums': ['F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4']},{'label': 'uF', 'num': 6, 'pin_nums': ['P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6']},{'label': 'uG', 'num': 7, 'pin_nums': ['P25', 'N19', 'T24', 'R20', 'N20', 'T25', 'R21', 'N21', 'U22', 'R22', 'N25', 'U23', 'R23', 'P19', 'U24', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23']},{'label': 'uH', 'num': 8, 'pin_nums': ['H23', 'N23', 'K20', 'D24', 'L23', 'G20', 'L24', 'H24', 'N24', 'K21', 'D25', 'G21', 'L25', 'H25', 'K22', 'E22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'M24', 'H20', 'J24', 'F23', 'L21', 'H21', 'M25', 'J25', 'K19', 'F24', 'L22', 'H22', 'N22', 'C25', 'F25']},{'label': 'uI', 'num': 9, 'pin_nums': ['V23', 'U20', 'W22', 'V21', 'W21', 'W20', 'U21', 'W23', 'V22', 'R19', 'V20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'P6', 'W4', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6']},{'label': 'uK', 'num': 11, 'pin_nums': ['K3', 'K6', 'J4', 'K5', 'K1', 'J1', 'K4', 'J6', 'J5', 'L7', 'K2', 'J3', 'M7']},{'label': 'uL', 'num': 12, 'pin_nums': ['G5', 'H6', 'C2', 'G6', 'J7', 'C3', 'H5']},{'label': 'uM', 'num': 13, 'pin_nums': ['U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2']},{'label': 'uN', 'num': 14, 'pin_nums': ['B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17']},{'label': 'uO', 'num': 15, 'pin_nums': ['B2', 'G8', 'A3', 'B3', 'A2', 'H7', 'B1', 'G7']},{'label': 'uP', 'num': 16, 'pin_nums': ['A6', 'D10', 'F10', 'B6', 'E10', 'B8', 'E9']},{'label': 'uQ', 'num': 17, 'pin_nums': ['B23', 'D23', 'B25', 'G18', 'C22', 'D21', 'E21', 'B24', 'C23', 'A24', 'D22', 'F20', 'C24']},{'label': 'uR', 'num': 18, 'pin_nums': ['E19', 'C20', 'F18', 'A21', 'D20', 'G16', 'B21']},{'label': 'uS', 'num': 19, 'pin_nums': ['F19', 'A22', 'C21', 'G17', 'A23', 'E20', 'B22']},{'label': 'uT', 'num': 20, 'pin_nums': ['D15', 'C13', 'F13', 'B13', 'D13', 'E13', 'E14', 'B15', 'F14', 'D14', 'A15', 'G14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AD3', 'AB6', 'Y10', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'Y19', 'AC14', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'W25', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'AB5']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['A12', 'B14', 'G13', 'A14', 'C14', 'B12', 'G12']}] }),
        Part(**{ 'name':'MCIMX6Q6AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6Q6AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6Q6AVT\n\nQuad-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L13', 'W19', 'G10', 'R10', 'L14', 'W3', 'R11', 'G11', 'W7', 'L15', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'H8', 'T14', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'AA7', 'T17', 'J11', 'M18', 'AA13', 'T19', 'J12', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'J14', 'T9', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'U17', 'K10', 'N18', 'C1', 'P9', 'U19', 'C10', 'K11', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'D3', 'K13', 'P10', 'D6', 'V19', 'K14', 'P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'F9']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'A5', 'B5', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['F11', 'C11', 'D12', 'F12', 'C12', 'E11', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['C5', 'A11', 'D7', 'B11', 'C7', 'A9', 'A10', 'B9', 'D5', 'B10']},{'label': 'uE', 'num': 5, 'pin_nums': ['E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1']},{'label': 'uF', 'num': 6, 'pin_nums': ['M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7']},{'label': 'uG', 'num': 7, 'pin_nums': ['T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21']},{'label': 'uH', 'num': 8, 'pin_nums': ['H20', 'L20', 'M24', 'M23', 'J24', 'F23', 'H21', 'L21', 'M25', 'F24', 'J25', 'L22', 'H22', 'C25', 'N22', 'F25', 'K19', 'L23', 'H23', 'N23', 'D24', 'G20', 'K20', 'L24', 'H24', 'N24', 'D25', 'K21', 'G21', 'L25', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'J20', 'M20', 'E24', 'K24', 'G24', 'J21', 'M21', 'E25', 'K25', 'G25', 'J22', 'M22', 'F21', 'H19', 'L19', 'J23', 'F22']},{'label': 'uI', 'num': 9, 'pin_nums': ['R19', 'W21', 'V20', 'U21', 'V23', 'U20', 'W22', 'V21', 'W20', 'W23', 'V22']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6']},{'label': 'uK', 'num': 11, 'pin_nums': ['J6', 'M7', 'K3', 'K6', 'J4', 'J3', 'K1', 'J1', 'K4', 'J5', 'L7', 'K2', 'K5']},{'label': 'uL', 'num': 12, 'pin_nums': ['G5', 'H6', 'C2', 'G6', 'J7', 'C3', 'H5']},{'label': 'uM', 'num': 13, 'pin_nums': ['V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3']},{'label': 'uN', 'num': 14, 'pin_nums': ['F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18']},{'label': 'uO', 'num': 15, 'pin_nums': ['G7', 'A2', 'B2', 'G8', 'A3', 'B3', 'H7', 'B1']},{'label': 'uP', 'num': 16, 'pin_nums': ['E9', 'A6', 'D10', 'F10', 'B6', 'E10', 'B8']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C24', 'D23', 'B23', 'G18', 'C22', 'B25', 'D21', 'E21', 'B24', 'A24', 'C23', 'D22', 'F20']},{'label': 'uR', 'num': 18, 'pin_nums': ['B21', 'E19', 'C20', 'F18', 'A21', 'D20', 'G16']},{'label': 'uS', 'num': 19, 'pin_nums': ['B22', 'A22', 'F19', 'C21', 'G17', 'A23', 'E20']},{'label': 'uT', 'num': 20, 'pin_nums': ['E14', 'A15', 'G14', 'C13', 'D15', 'F13', 'B13', 'D13', 'E13', 'F14', 'D14', 'B15']},{'label': 'uU', 'num': 21, 'pin_nums': ['V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'AB4', 'W14', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'AB7', 'Y11', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'AC11', 'Y16', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'Y8', 'AC21', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['G12', 'A12', 'B14', 'G13', 'A14', 'C14', 'B12']}] }),
        Part(**{ 'name':'MCIMX6Q7CVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6Q7CVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC Industrial', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQIEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6Q7CVT\n\nQuad-Core ARM Cortex A9 SOC Industrial', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='A9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B11',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='B9',name='NC',func=pin_types.NOCONNECT,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['L10', 'W16', 'P18', 'F7', 'W17', 'L11', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'R14', 'G9', 'L18', 'Y24', 'R15', 'H10', 'L2', 'Y5', 'R16', 'H11', 'L5', 'R17', 'H12', 'L8', 'R8', 'H13', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'P17', 'M13', 'H18', 'T13', 'M14', 'H8', 'A13', 'T14', 'M15', 'A25', 'H9', 'T15', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'J11', 'T17', 'AA7', 'M18', 'J12', 'AA13', 'T19', 'AA16', 'M8', 'J13', 'AA19', 'T8', 'M9', 'AA22', 'J14', 'T9', 'AB24', 'N10', 'U10', 'J15', 'AB3', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'U12', 'J17', 'AD16', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'U14', 'J2', 'AD4', 'N15', 'U15', 'AD7', 'J8', 'AE1', 'N16', 'U16', 'J9', 'AE25', 'N17', 'U17', 'B4', 'K10', 'C1', 'N18', 'U19', 'K11', 'C10', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'W15', 'K9', 'F6']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'B5', 'A5', 'C8']},{'label': 'uC', 'num': 3, 'pin_nums': ['D11', 'F11', 'C11', 'D12', 'F12', 'C12', 'E11']},{'label': 'uD', 'num': 4, 'pin_nums': ['D5', 'A10', 'B10', 'C5', 'A11', 'D7', 'B11', 'C7', 'A9', 'B9']},{'label': 'uE', 'num': 5, 'pin_nums': ['D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1']},{'label': 'uF', 'num': 6, 'pin_nums': ['L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4']},{'label': 'uG', 'num': 7, 'pin_nums': ['R23', 'P19', 'U24', 'R24', 'P20', 'U25', 'U23', 'R25', 'P21', 'V24', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'N19', 'T24', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'N25']},{'label': 'uH', 'num': 8, 'pin_nums': ['E24', 'K24', 'M21', 'G24', 'J21', 'G23', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'L19', 'M23', 'H19', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'F23', 'L21', 'H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'D24', 'K20', 'G20', 'L24', 'H24', 'N24', 'D25', 'K21', 'G21', 'L25', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'M20', 'J20']},{'label': 'uI', 'num': 9, 'pin_nums': ['V22', 'W21', 'R19', 'V20', 'V23', 'W23', 'U20', 'W22', 'V21', 'W20', 'U21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3']},{'label': 'uK', 'num': 11, 'pin_nums': ['K2', 'J3', 'K5', 'J1', 'J6', 'M7', 'K3', 'J4', 'K6', 'K1', 'K4', 'J5', 'L7']},{'label': 'uL', 'num': 12, 'pin_nums': ['C3', 'H5', 'G5', 'H6', 'C2', 'G6', 'J7']},{'label': 'uM', 'num': 13, 'pin_nums': ['V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4']},{'label': 'uN', 'num': 14, 'pin_nums': ['E17', 'A16', 'C16', 'A17', 'E18', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15']},{'label': 'uO', 'num': 15, 'pin_nums': ['H7', 'B1', 'G7', 'A2', 'B2', 'G8', 'A3', 'B3']},{'label': 'uP', 'num': 16, 'pin_nums': ['B8', 'E9', 'A6', 'D10', 'F10', 'B6', 'E10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['A24', 'D22', 'B25', 'F20', 'B24', 'C24', 'B23', 'D23', 'C22', 'G18', 'D21', 'E21', 'C23']},{'label': 'uR', 'num': 18, 'pin_nums': ['D20', 'G16', 'B21', 'E19', 'C20', 'F18', 'A21']},{'label': 'uS', 'num': 19, 'pin_nums': ['E20', 'B22', 'F19', 'A22', 'C21', 'G17', 'A23']},{'label': 'uT', 'num': 20, 'pin_nums': ['D14', 'B15', 'A15', 'E14', 'C13', 'G14', 'D15', 'B13', 'F13', 'D13', 'E13', 'F14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AB20', 'V15', 'AD2', 'AB21', 'V16', 'AD20', 'AB22', 'V17', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'AB9', 'Y13', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'Y19', 'AC14', 'AE15', 'Y20', 'AC15', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AA15', 'AE19', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AE23', 'AA23', 'AC23', 'AE24', 'AA24', 'AC24', 'AE3', 'AA25', 'AC25', 'AE4', 'AA5', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'AB14', 'U18', 'AD11', 'AB15', 'V10', 'AD12', 'AB16', 'V11', 'AD14', 'AB17', 'V12', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['B12', 'G12', 'A12', 'B14', 'G13', 'A14', 'C14']}] }),
        Part(**{ 'name':'MCIMX6QP4AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6QP4AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6QP4AVT\n\nQuad-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['K18', 'W12', 'E8', 'P15', 'W13', 'K8', 'P16', 'F5', 'W15', 'K9', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'G3', 'R13', 'W9', 'L17', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'H8', 'T14', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'T17', 'AA7', 'J11', 'M18', 'AA13', 'T19', 'J12', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'U17', 'K10', 'N18', 'C1', 'U19', 'C10', 'K11', 'P14', 'N8', 'C4', 'U8', 'K12', 'N9', 'C6', 'U9', 'D3', 'K13', 'P10', 'W11', 'D6', 'V19', 'K14', 'P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'P13', 'E6', 'K17', 'E7']},{'label': 'uB', 'num': 2, 'pin_nums': ['A5', 'C8', 'E12', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['E11', 'D11', 'F11', 'C11', 'D12', 'F12', 'C12']},{'label': 'uD', 'num': 4, 'pin_nums': ['B9', 'A10', 'D5', 'B10', 'C5', 'A11', 'D7', 'B11', 'C7', 'A9']},{'label': 'uE', 'num': 5, 'pin_nums': ['F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2']},{'label': 'uF', 'num': 6, 'pin_nums': ['L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1']},{'label': 'uG', 'num': 7, 'pin_nums': ['N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24']},{'label': 'uH', 'num': 8, 'pin_nums': ['N24', 'D25', 'G21', 'K21', 'L25', 'E22', 'H25', 'K22', 'G22', 'G20', 'M19', 'E23', 'J19', 'G23', 'K23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'H19', 'L19', 'M23', 'J23', 'F22', 'H20', 'L20', 'M24', 'J24', 'F23', 'H21', 'L21', 'L24', 'M25', 'F24', 'J25', 'L22', 'H22', 'N22', 'C25', 'F25', 'K19', 'L23', 'H23', 'N23', 'D24', 'K20', 'H24']},{'label': 'uI', 'num': 9, 'pin_nums': ['W20', 'W23', 'U21', 'V22', 'U20', 'W21', 'R19', 'V20', 'V23', 'W22', 'V21']},{'label': 'uJ', 'num': 10, 'pin_nums': ['V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7']},{'label': 'uK', 'num': 11, 'pin_nums': ['J5', 'L7', 'K2', 'J3', 'K5', 'J1', 'J6', 'M7', 'K3', 'J4', 'K6', 'K1', 'K4']},{'label': 'uL', 'num': 12, 'pin_nums': ['C3', 'J7', 'H5', 'G5', 'C2', 'G6', 'H6']},{'label': 'uM', 'num': 13, 'pin_nums': ['U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1']},{'label': 'uN', 'num': 14, 'pin_nums': ['B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18']},{'label': 'uO', 'num': 15, 'pin_nums': ['B3', 'H7', 'B1', 'G7', 'A2', 'B2', 'G8', 'A3']},{'label': 'uP', 'num': 16, 'pin_nums': ['E10', 'B8', 'E9', 'A6', 'D10', 'F10', 'B6']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C23', 'A24', 'D22', 'B25', 'F20', 'C24', 'E21', 'B23', 'D23', 'C22', 'G18', 'D21', 'B24']},{'label': 'uR', 'num': 18, 'pin_nums': ['A21', 'D20', 'B21', 'G16', 'E19', 'C20', 'F18']},{'label': 'uS', 'num': 19, 'pin_nums': ['G17', 'A23', 'E20', 'B22', 'F19', 'A22', 'C21']},{'label': 'uT', 'num': 20, 'pin_nums': ['E13', 'F13', 'F14', 'B15', 'D14', 'E14', 'A15', 'C13', 'G14', 'D15', 'B13', 'D13']},{'label': 'uU', 'num': 21, 'pin_nums': ['AB17', 'V12', 'AD15', 'V11', 'V13', 'AB18', 'AD17', 'AB19', 'V14', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'AB6', 'Y10', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'V10', 'AB15', 'AD12', 'AB16', 'AD14']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['C14', 'B12', 'G12', 'A12', 'B14', 'G13', 'A14']}] }),
        Part(**{ 'name':'MCIMX6QP5EVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6QP5EVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPCEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6QP5EVT\n\nQuad-Core ARM Cortex A9 SOC', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['P11', 'D8', 'V8', 'E5', 'K15', 'P12', 'W10', 'K16', 'E6', 'P13', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'P18', 'F7', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'K14', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'V19', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'H8', 'A13', 'T14', 'M15', 'H9', 'A25', 'T15', 'A4', 'M16', 'J10', 'A8', 'T16', 'M17', 'AA10', 'T17', 'J11', 'AA7', 'M18', 'T19', 'J12', 'AA13', 'AA16', 'M8', 'T8', 'J13', 'AA19', 'M9', 'AA22', 'T9', 'J14', 'AB24', 'N10', 'U10', 'J15', 'AB3', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'U12', 'J17', 'AD16', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'U14', 'J2', 'AD4', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'J9', 'AE25', 'N17', 'U17', 'B4', 'K10', 'N18', 'C1', 'U19', 'K11', 'C10', 'N8', 'U8', 'C4', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'D6']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'A5', 'C8', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['F12', 'C12', 'E11', 'D11', 'F11', 'C11', 'D12']},{'label': 'uD', 'num': 4, 'pin_nums': ['C7', 'A9', 'A11', 'B9', 'A10', 'D5', 'B10', 'C5', 'D7', 'B11']},{'label': 'uE', 'num': 5, 'pin_nums': ['E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2', 'D4', 'G4', 'E1', 'H1', 'E2', 'H2']},{'label': 'uF', 'num': 6, 'pin_nums': ['P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5', 'M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4']},{'label': 'uG', 'num': 7, 'pin_nums': ['T21', 'W24', 'V25', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'N20', 'T25', 'R21', 'U22', 'N21', 'R22', 'N25', 'U23', 'R23', 'U24', 'P19', 'R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'P22']},{'label': 'uH', 'num': 8, 'pin_nums': ['H21', 'M25', 'J25', 'F24', 'L22', 'H22', 'N22', 'C25', 'K19', 'F25', 'L23', 'H23', 'N23', 'K20', 'D24', 'F23', 'G20', 'L24', 'H24', 'N24', 'K21', 'D25', 'G21', 'L25', 'H25', 'E22', 'K22', 'G22', 'M19', 'J19', 'E23', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'M21', 'J21', 'E25', 'K25', 'G25', 'M22', 'J22', 'F21', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'L21']},{'label': 'uI', 'num': 9, 'pin_nums': ['V21', 'W22', 'U21', 'W20', 'W23', 'V22', 'R19', 'W21', 'V20', 'V23', 'U20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6', 'R1', 'T5', 'R2', 'T6', 'R3', 'T7']},{'label': 'uK', 'num': 11, 'pin_nums': ['K1', 'J4', 'K4', 'J1', 'J5', 'L7', 'K2', 'K5', 'J3', 'J6', 'M7', 'K3', 'K6']},{'label': 'uL', 'num': 12, 'pin_nums': ['C2', 'G6', 'J7', 'C3', 'H5', 'G5', 'H6']},{'label': 'uM', 'num': 13, 'pin_nums': ['AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1', 'V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7']},{'label': 'uN', 'num': 14, 'pin_nums': ['A20', 'F17', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16', 'E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'A19', 'F16', 'C19']},{'label': 'uO', 'num': 15, 'pin_nums': ['G8', 'A3', 'B3', 'H7', 'B1', 'G7', 'A2', 'B2']},{'label': 'uP', 'num': 16, 'pin_nums': ['F10', 'B6', 'E10', 'B8', 'E9', 'A6', 'D10']},{'label': 'uQ', 'num': 17, 'pin_nums': ['D21', 'E21', 'B24', 'C22', 'B23', 'C23', 'A24', 'D22', 'B25', 'F20', 'C24', 'D23', 'G18']},{'label': 'uR', 'num': 18, 'pin_nums': ['C20', 'F18', 'A21', 'D20', 'G16', 'B21', 'E19']},{'label': 'uS', 'num': 19, 'pin_nums': ['C21', 'G17', 'A23', 'E20', 'B22', 'F19', 'A22']},{'label': 'uT', 'num': 20, 'pin_nums': ['D13', 'E13', 'B13', 'B15', 'F14', 'D14', 'E14', 'A15', 'C13', 'G14', 'D15', 'F13']},{'label': 'uU', 'num': 21, 'pin_nums': ['AD1', 'AB14', 'U18', 'AD11', 'V10', 'AB15', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'AB18', 'V13', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AB13', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'Y14', 'AC1', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AB10', 'AE8', 'AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'T18']},{'label': 'uV', 'num': 22, 'pin_nums': ['A7', 'B7']},{'label': 'uW', 'num': 23, 'pin_nums': ['C9', 'D9']},{'label': 'uX', 'num': 24, 'pin_nums': ['G13', 'A14', 'C14', 'B12', 'G12', 'A12', 'B14']}] }),
        Part(**{ 'name':'MCIMX6QP6AVT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCIMX6QP6AVT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm'], 'footprint':'Package_BGA:BGA-624_21.0x21.0mm_Layout25x25_P0.8mm', 'keywords':'Quad-Core ARM Cortex A9 SOC Automotive', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/IMX6DQPAEC.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_IMX.kicad_sym\nMCIMX6QP6AVT\n\nQuad-Core ARM Cortex A9 SOC Automotive', 'pins':[
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='NVCC_PLL_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD_USB_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD_SNVS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD_SNVS_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='VDD_HIGH_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H11',name='VDD_ARM23_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD_ARM_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H14',name='VDD_ARM_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H16',name='VDD_SOC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='VDD_PU_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VDD_HIGH_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VDD_HIGH_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='J18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD_HIGH_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='K18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD_ARM23_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='L17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='L18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='M17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDD_CACHE_CAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='P17',name='VDD_PU_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='P18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='VDD_SOC_CAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R11',name='VDD_ARM23_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='VDD_ARM_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='VDD_ARM_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='R17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='T17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U13',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U14',name='VDD_SOC_CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='U15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U16',name='VDD_SOC_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U9',name='VDD_ARM23_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='V19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='FA_ANA',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='VDD_FA',func=pin_types.PASSIVE,unit=2),
            Pin(num='C8',name='GPANAIO',func=pin_types.PASSIVE,unit=2),
            Pin(num='E12',name='TEST_MODE',func=pin_types.PASSIVE,unit=2),
            Pin(num='C11',name='POR_B',func=pin_types.INPUT,unit=3),
            Pin(num='C12',name='BOOT_MODE0',func=pin_types.INPUT,unit=3),
            Pin(num='D11',name='PMIC_ON_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='D12',name='ONOFF',func=pin_types.INPUT,unit=3),
            Pin(num='E11',name='TAMPER',func=pin_types.INPUT,unit=3),
            Pin(num='F11',name='PMIC_STBY_REQ',func=pin_types.OUTPUT,unit=3),
            Pin(num='F12',name='BOOT_MODE1',func=pin_types.INPUT,unit=3),
            Pin(num='A10',name='MLB_DP',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MLB_CN',func=pin_types.INPUT,unit=4),
            Pin(num='A9',name='MLB_SN',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MLB_DN',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MLB_CP',func=pin_types.INPUT,unit=4),
            Pin(num='B9',name='MLB_SP',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='CLK2_N',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='CLK1_N',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='CLK2_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='CLK1_P',func=pin_types.BIDIR,unit=4),
            Pin(num='D1',name='CSI_D1M',func=pin_types.INPUT,unit=5),
            Pin(num='D2',name='CSI_D1P',func=pin_types.INPUT,unit=5),
            Pin(num='D4',name='CSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='E1',name='CSI_D2M',func=pin_types.INPUT,unit=5),
            Pin(num='E2',name='CSI_D2P',func=pin_types.INPUT,unit=5),
            Pin(num='E3',name='CSI_D0P',func=pin_types.INPUT,unit=5),
            Pin(num='E4',name='CSI_D0M',func=pin_types.INPUT,unit=5),
            Pin(num='F1',name='CSI_D3P',func=pin_types.INPUT,unit=5),
            Pin(num='F2',name='CSI_D3M',func=pin_types.INPUT,unit=5),
            Pin(num='F3',name='CSI_CLK0P',func=pin_types.INPUT,unit=5),
            Pin(num='F4',name='CSI_CLK0M',func=pin_types.INPUT,unit=5),
            Pin(num='G1',name='DSI_D0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='G2',name='DSI_D0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='G4',name='DSI_REXT',func=pin_types.PASSIVE,unit=5),
            Pin(num='H1',name='DSI_D1P',func=pin_types.OUTPUT,unit=5),
            Pin(num='H2',name='DSI_D1M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H3',name='DSI_CLK0M',func=pin_types.OUTPUT,unit=5),
            Pin(num='H4',name='DSI_CLK0P',func=pin_types.OUTPUT,unit=5),
            Pin(num='K7',name='NVCC_MIPI',func=pin_types.PWRIN,unit=5),
            Pin(num='L1',name='CSI0_DAT13',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='CSI0_DAT17',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='CSI0_DAT16',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='CSI0_DAT19',func=pin_types.BIDIR,unit=6),
            Pin(num='M1',name='CSI0_DAT10',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='CSI0_DAT12',func=pin_types.BIDIR,unit=6),
            Pin(num='M3',name='CSI0_DAT11',func=pin_types.BIDIR,unit=6),
            Pin(num='M4',name='CSI0_DAT14',func=pin_types.BIDIR,unit=6),
            Pin(num='M5',name='CSI0_DAT15',func=pin_types.BIDIR,unit=6),
            Pin(num='M6',name='CSI0_DAT18',func=pin_types.BIDIR,unit=6),
            Pin(num='N1',name='CSI0_DAT4',func=pin_types.BIDIR,unit=6),
            Pin(num='N2',name='CSI0_VSYNC',func=pin_types.BIDIR,unit=6),
            Pin(num='N3',name='CSI0_DAT7',func=pin_types.BIDIR,unit=6),
            Pin(num='N4',name='CSI0_DAT6',func=pin_types.BIDIR,unit=6),
            Pin(num='N5',name='CSI0_DAT9',func=pin_types.BIDIR,unit=6),
            Pin(num='N6',name='CSI0_DAT8',func=pin_types.BIDIR,unit=6),
            Pin(num='N7',name='NVCC_CSI',func=pin_types.PWRIN,unit=6),
            Pin(num='P1',name='CSI0_PIXCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='P2',name='CSI0_DAT5',func=pin_types.BIDIR,unit=6),
            Pin(num='P3',name='CSI0_DATA_EN',func=pin_types.BIDIR,unit=6),
            Pin(num='P4',name='CSI0_MCLK',func=pin_types.BIDIR,unit=6),
            Pin(num='N19',name='DI0_DISP_CLK',func=pin_types.BIDIR,unit=7),
            Pin(num='N20',name='DI0_PIN3',func=pin_types.BIDIR,unit=7),
            Pin(num='N21',name='DI0_PIN15',func=pin_types.BIDIR,unit=7),
            Pin(num='N25',name='DI0_PIN2',func=pin_types.BIDIR,unit=7),
            Pin(num='P19',name='NVCC_LCD',func=pin_types.PWRIN,unit=7),
            Pin(num='P20',name='DISP0_DAT4',func=pin_types.BIDIR,unit=7),
            Pin(num='P21',name='DISP0_DAT3',func=pin_types.BIDIR,unit=7),
            Pin(num='P22',name='DISP0_DAT1',func=pin_types.BIDIR,unit=7),
            Pin(num='P23',name='DISP0_DAT2',func=pin_types.BIDIR,unit=7),
            Pin(num='P24',name='DISP0_DAT0',func=pin_types.BIDIR,unit=7),
            Pin(num='P25',name='DI0_PIN4',func=pin_types.BIDIR,unit=7),
            Pin(num='R20',name='DISP0_DAT13',func=pin_types.BIDIR,unit=7),
            Pin(num='R21',name='DISP0_DAT10',func=pin_types.BIDIR,unit=7),
            Pin(num='R22',name='DISP0_DAT8',func=pin_types.BIDIR,unit=7),
            Pin(num='R23',name='DISP0_DAT6',func=pin_types.BIDIR,unit=7),
            Pin(num='R24',name='DISP0_DAT7',func=pin_types.BIDIR,unit=7),
            Pin(num='R25',name='DISP0_DAT5',func=pin_types.BIDIR,unit=7),
            Pin(num='T20',name='DISP0_DAT21',func=pin_types.BIDIR,unit=7),
            Pin(num='T21',name='DISP0_DAT16',func=pin_types.BIDIR,unit=7),
            Pin(num='T22',name='DISP0_DAT15',func=pin_types.BIDIR,unit=7),
            Pin(num='T23',name='DISP0_DAT11',func=pin_types.BIDIR,unit=7),
            Pin(num='T24',name='DISP0_DAT12',func=pin_types.BIDIR,unit=7),
            Pin(num='T25',name='DISP0_DAT9',func=pin_types.BIDIR,unit=7),
            Pin(num='U22',name='DISP0_DAT20',func=pin_types.BIDIR,unit=7),
            Pin(num='U23',name='DISP0_DAT19',func=pin_types.BIDIR,unit=7),
            Pin(num='U24',name='DISP0_DAT17',func=pin_types.BIDIR,unit=7),
            Pin(num='U25',name='DISP0_DAT14',func=pin_types.BIDIR,unit=7),
            Pin(num='V24',name='DISP0_DAT22',func=pin_types.BIDIR,unit=7),
            Pin(num='V25',name='DISP0_DAT18',func=pin_types.BIDIR,unit=7),
            Pin(num='W24',name='DISP0_DAT23',func=pin_types.BIDIR,unit=7),
            Pin(num='C25',name='EIM_D16',func=pin_types.BIDIR,unit=8),
            Pin(num='D24',name='EIM_D18',func=pin_types.BIDIR,unit=8),
            Pin(num='D25',name='EIM_D23',func=pin_types.BIDIR,unit=8),
            Pin(num='E22',name='EIM_EB2',func=pin_types.BIDIR,unit=8),
            Pin(num='E23',name='EIM_D22',func=pin_types.BIDIR,unit=8),
            Pin(num='E24',name='EIM_D26',func=pin_types.BIDIR,unit=8),
            Pin(num='E25',name='EIM_D27',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='EIM_D17',func=pin_types.BIDIR,unit=8),
            Pin(num='F22',name='EIM_D24',func=pin_types.BIDIR,unit=8),
            Pin(num='F23',name='EIM_EB3',func=pin_types.BIDIR,unit=8),
            Pin(num='F24',name='EIM_A22',func=pin_types.BIDIR,unit=8),
            Pin(num='F25',name='EIM_A24',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='EIM_D20',func=pin_types.BIDIR,unit=8),
            Pin(num='G21',name='EIM_D19',func=pin_types.BIDIR,unit=8),
            Pin(num='G22',name='EIM_D25',func=pin_types.BIDIR,unit=8),
            Pin(num='G23',name='EIM_D28',func=pin_types.BIDIR,unit=8),
            Pin(num='G24',name='EIM_A17',func=pin_types.BIDIR,unit=8),
            Pin(num='G25',name='EIM_A19',func=pin_types.BIDIR,unit=8),
            Pin(num='H19',name='EIM_A25',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='EIM_D21',func=pin_types.BIDIR,unit=8),
            Pin(num='H21',name='EIM_D31',func=pin_types.BIDIR,unit=8),
            Pin(num='H22',name='EIM_A20',func=pin_types.BIDIR,unit=8),
            Pin(num='H23',name='EIM_A21',func=pin_types.BIDIR,unit=8),
            Pin(num='H24',name='EIM_CS0',func=pin_types.BIDIR,unit=8),
            Pin(num='H25',name='EIM_A16',func=pin_types.BIDIR,unit=8),
            Pin(num='J19',name='EIM_D29',func=pin_types.BIDIR,unit=8),
            Pin(num='J20',name='EIM_D30',func=pin_types.BIDIR,unit=8),
            Pin(num='J21',name='EIM_A23',func=pin_types.BIDIR,unit=8),
            Pin(num='J22',name='EIM_A18',func=pin_types.BIDIR,unit=8),
            Pin(num='J23',name='EIM_CS1',func=pin_types.BIDIR,unit=8),
            Pin(num='J24',name='EIM_OE',func=pin_types.BIDIR,unit=8),
            Pin(num='J25',name='EIM_DA1',func=pin_types.BIDIR,unit=8),
            Pin(num='K19',name='NVCC_EIM0',func=pin_types.PWRIN,unit=8),
            Pin(num='K20',name='EIM_RW',func=pin_types.BIDIR,unit=8),
            Pin(num='K21',name='EIM_EB0',func=pin_types.BIDIR,unit=8),
            Pin(num='K22',name='EIM_LBA',func=pin_types.BIDIR,unit=8),
            Pin(num='K23',name='EIM_EB1',func=pin_types.BIDIR,unit=8),
            Pin(num='K24',name='EIM_DA3',func=pin_types.BIDIR,unit=8),
            Pin(num='K25',name='EIM_DA6',func=pin_types.BIDIR,unit=8),
            Pin(num='L19',name='NVCC_EIM1',func=pin_types.PWRIN,unit=8),
            Pin(num='L20',name='EIM_DA0',func=pin_types.BIDIR,unit=8),
            Pin(num='L21',name='EIM_DA2',func=pin_types.BIDIR,unit=8),
            Pin(num='L22',name='EIM_DA4',func=pin_types.BIDIR,unit=8),
            Pin(num='L23',name='EIM_DA5',func=pin_types.BIDIR,unit=8),
            Pin(num='L24',name='EIM_DA8',func=pin_types.BIDIR,unit=8),
            Pin(num='L25',name='EIM_DA7',func=pin_types.BIDIR,unit=8),
            Pin(num='M19',name='NVCC_EIM2',func=pin_types.PWRIN,unit=8),
            Pin(num='M20',name='EIM_DA11',func=pin_types.BIDIR,unit=8),
            Pin(num='M21',name='EIM_DA9',func=pin_types.BIDIR,unit=8),
            Pin(num='M22',name='EIM_DA10',func=pin_types.BIDIR,unit=8),
            Pin(num='M23',name='EIM_DA13',func=pin_types.BIDIR,unit=8),
            Pin(num='M24',name='EIM_DA12',func=pin_types.BIDIR,unit=8),
            Pin(num='M25',name='EIM_WAIT',func=pin_types.BIDIR,unit=8),
            Pin(num='N22',name='EIM_BCLK',func=pin_types.BIDIR,unit=8),
            Pin(num='N23',name='EIM_DA14',func=pin_types.BIDIR,unit=8),
            Pin(num='N24',name='EIM_DA15',func=pin_types.BIDIR,unit=8),
            Pin(num='R19',name='NVCC_ENET',func=pin_types.PWRIN,unit=9),
            Pin(num='U20',name='ENET_TXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='U21',name='ENET_CRS_DV',func=pin_types.BIDIR,unit=9),
            Pin(num='V20',name='ENET_MDC',func=pin_types.BIDIR,unit=9),
            Pin(num='V21',name='ENET_TX_EN',func=pin_types.BIDIR,unit=9),
            Pin(num='V22',name='ENET_REF_CLK',func=pin_types.BIDIR,unit=9),
            Pin(num='V23',name='ENET_MDIO',func=pin_types.BIDIR,unit=9),
            Pin(num='W20',name='ENET_TXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W21',name='ENET_RXD0',func=pin_types.BIDIR,unit=9),
            Pin(num='W22',name='ENET_RXD1',func=pin_types.BIDIR,unit=9),
            Pin(num='W23',name='ENET_RX_ER',func=pin_types.BIDIR,unit=9),
            Pin(num='P5',name='GPIO_19',func=pin_types.BIDIR,unit=10),
            Pin(num='P6',name='GPIO_18',func=pin_types.BIDIR,unit=10),
            Pin(num='P7',name='NVCC_GPIO',func=pin_types.PWRIN,unit=10),
            Pin(num='R1',name='GPIO_17',func=pin_types.BIDIR,unit=10),
            Pin(num='R2',name='GPIO_16',func=pin_types.BIDIR,unit=10),
            Pin(num='R3',name='GPIO_7',func=pin_types.BIDIR,unit=10),
            Pin(num='R4',name='GPIO_5',func=pin_types.BIDIR,unit=10),
            Pin(num='R5',name='GPIO_8',func=pin_types.BIDIR,unit=10),
            Pin(num='R6',name='GPIO_4',func=pin_types.BIDIR,unit=10),
            Pin(num='R7',name='GPIO_3',func=pin_types.BIDIR,unit=10),
            Pin(num='T1',name='GPIO_2',func=pin_types.BIDIR,unit=10),
            Pin(num='T2',name='GPIO_9',func=pin_types.BIDIR,unit=10),
            Pin(num='T3',name='GPIO_6',func=pin_types.BIDIR,unit=10),
            Pin(num='T4',name='GPIO_1',func=pin_types.BIDIR,unit=10),
            Pin(num='T5',name='GPIO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T6',name='KEY_COL4',func=pin_types.BIDIR,unit=10),
            Pin(num='T7',name='KEY_ROW3',func=pin_types.BIDIR,unit=10),
            Pin(num='U5',name='KEY_COL3',func=pin_types.BIDIR,unit=10),
            Pin(num='U6',name='KEY_ROW1',func=pin_types.BIDIR,unit=10),
            Pin(num='U7',name='KEY_COL1',func=pin_types.BIDIR,unit=10),
            Pin(num='V5',name='KEY_ROW4',func=pin_types.BIDIR,unit=10),
            Pin(num='V6',name='KEY_ROW0',func=pin_types.BIDIR,unit=10),
            Pin(num='W4',name='KEY_ROW2',func=pin_types.BIDIR,unit=10),
            Pin(num='W5',name='KEY_COL0',func=pin_types.BIDIR,unit=10),
            Pin(num='W6',name='KEY_COL2',func=pin_types.BIDIR,unit=10),
            Pin(num='J1',name='HDMI_REF',func=pin_types.PASSIVE,unit=11),
            Pin(num='J3',name='HDMI_D1M',func=pin_types.OUTPUT,unit=11),
            Pin(num='J4',name='HDMI_D1P',func=pin_types.OUTPUT,unit=11),
            Pin(num='J5',name='HDMI_CLKM',func=pin_types.OUTPUT,unit=11),
            Pin(num='J6',name='HDMI_CLKP',func=pin_types.OUTPUT,unit=11),
            Pin(num='K1',name='HDMI_HPD',func=pin_types.INPUT,unit=11),
            Pin(num='K2',name='HDMI_DDCCEC',func=pin_types.PASSIVE,unit=11),
            Pin(num='K3',name='HDMI_D2M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K4',name='HDMI_D2P',func=pin_types.OUTPUT,unit=11),
            Pin(num='K5',name='HDMI_D0M',func=pin_types.OUTPUT,unit=11),
            Pin(num='K6',name='HDMI_D0P',func=pin_types.OUTPUT,unit=11),
            Pin(num='L7',name='HDMI_VP',func=pin_types.PWRIN,unit=11),
            Pin(num='M7',name='HDMI_VPH',func=pin_types.PWRIN,unit=11),
            Pin(num='C2',name='JTAG_TRSTB',func=pin_types.BIDIR,unit=12),
            Pin(num='C3',name='JTAG_TMS',func=pin_types.BIDIR,unit=12),
            Pin(num='G5',name='JTAG_TDI',func=pin_types.BIDIR,unit=12),
            Pin(num='G6',name='JTAG_TDO',func=pin_types.BIDIR,unit=12),
            Pin(num='H5',name='JTAG_TCK',func=pin_types.BIDIR,unit=12),
            Pin(num='H6',name='JTAG_MOD',func=pin_types.INPUT,unit=12),
            Pin(num='J7',name='NVCC_JTAG',func=pin_types.PWRIN,unit=12),
            Pin(num='AA1',name='LVDS1_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA2',name='LVDS1_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA3',name='LVDS1_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AA4',name='LVDS1_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB1',name='LVDS1_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='AB2',name='LVDS1_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U1',name='LVDS0_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U2',name='LVDS0_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='U3',name='LVDS0_TX1_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='U4',name='LVDS0_TX1_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V1',name='LVDS0_TX2_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V2',name='LVDS0_TX2_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V3',name='LVDS0_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='V4',name='LVDS0_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='V7',name='NVCC_LVDS2P5',func=pin_types.PWRIN,unit=13),
            Pin(num='W1',name='LVDS0_TX3_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='W2',name='LVDS0_TX3_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y1',name='LVDS1_TX0_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y2',name='LVDS1_TX0_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y3',name='LVDS1_CLK_N',func=pin_types.OUTPUT,unit=13),
            Pin(num='Y4',name='LVDS1_CLK_P',func=pin_types.OUTPUT,unit=13),
            Pin(num='A16',name='NANDF_ALE',func=pin_types.BIDIR,unit=14),
            Pin(num='A17',name='NANDF_CS2',func=pin_types.BIDIR,unit=14),
            Pin(num='A18',name='NANDF_D0',func=pin_types.BIDIR,unit=14),
            Pin(num='A19',name='NANDF_D4',func=pin_types.BIDIR,unit=14),
            Pin(num='A20',name='SD4_DAT3',func=pin_types.BIDIR,unit=14),
            Pin(num='B16',name='NANDF_RB0',func=pin_types.BIDIR,unit=14),
            Pin(num='B17',name='SD4_CMD',func=pin_types.BIDIR,unit=14),
            Pin(num='B18',name='NANDF_D5',func=pin_types.BIDIR,unit=14),
            Pin(num='B19',name='SD4_DAT1',func=pin_types.BIDIR,unit=14),
            Pin(num='B20',name='SD4_DAT6',func=pin_types.BIDIR,unit=14),
            Pin(num='C15',name='NANDF_CLE',func=pin_types.BIDIR,unit=14),
            Pin(num='C16',name='NANDF_CS1',func=pin_types.BIDIR,unit=14),
            Pin(num='C17',name='NANDF_D1',func=pin_types.BIDIR,unit=14),
            Pin(num='C18',name='NANDF_D7',func=pin_types.BIDIR,unit=14),
            Pin(num='C19',name='SD4_DAT5',func=pin_types.BIDIR,unit=14),
            Pin(num='D16',name='NANDF_CS3',func=pin_types.BIDIR,unit=14),
            Pin(num='D17',name='NANDF_D3',func=pin_types.BIDIR,unit=14),
            Pin(num='D18',name='SD4_DAT0',func=pin_types.BIDIR,unit=14),
            Pin(num='D19',name='SD4_DAT7',func=pin_types.BIDIR,unit=14),
            Pin(num='E15',name='NANDF_WP_B',func=pin_types.BIDIR,unit=14),
            Pin(num='E16',name='SD4_CLK',func=pin_types.BIDIR,unit=14),
            Pin(num='E17',name='NANDF_D6',func=pin_types.BIDIR,unit=14),
            Pin(num='E18',name='SD4_DAT4',func=pin_types.BIDIR,unit=14),
            Pin(num='F15',name='NANDF_CS0',func=pin_types.BIDIR,unit=14),
            Pin(num='F16',name='NANDF_D2',func=pin_types.BIDIR,unit=14),
            Pin(num='F17',name='SD4_DAT2',func=pin_types.BIDIR,unit=14),
            Pin(num='G15',name='NVCC_NANDF',func=pin_types.PWRIN,unit=14),
            Pin(num='A2',name='PCIE_REXT',func=pin_types.PASSIVE,unit=15),
            Pin(num='A3',name='PCIE_TXM',func=pin_types.OUTPUT,unit=15),
            Pin(num='B1',name='PCIE_RXM',func=pin_types.INPUT,unit=15),
            Pin(num='B2',name='PCIE_RXP',func=pin_types.INPUT,unit=15),
            Pin(num='B3',name='PCIE_TXP',func=pin_types.OUTPUT,unit=15),
            Pin(num='G7',name='PCIE_VPH',func=pin_types.PWRIN,unit=15),
            Pin(num='G8',name='PCIE_VPTX',func=pin_types.PWRIN,unit=15),
            Pin(num='H7',name='PCIE_VP',func=pin_types.PWRIN,unit=15),
            Pin(num='A6',name='USB_OTG_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='B6',name='USB_OTG_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='B8',name='USB_OTG_CHD_B',func=pin_types.BIDIR,unit=16),
            Pin(num='D10',name='USB_H1_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='E10',name='USB_H1_DP',func=pin_types.BIDIR,unit=16),
            Pin(num='E9',name='USB_OTG_VBUS',func=pin_types.PWRIN,unit=16),
            Pin(num='F10',name='USB_H1_DN',func=pin_types.BIDIR,unit=16),
            Pin(num='A24',name='RGMII_TD3',func=pin_types.BIDIR,unit=17),
            Pin(num='B23',name='RGMII_RD1',func=pin_types.BIDIR,unit=17),
            Pin(num='B24',name='RGMII_RD2',func=pin_types.BIDIR,unit=17),
            Pin(num='B25',name='RGMII_RXC',func=pin_types.BIDIR,unit=17),
            Pin(num='C22',name='RGMII_TD0',func=pin_types.BIDIR,unit=17),
            Pin(num='C23',name='RGMII_TX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='C24',name='RGMII_RD0',func=pin_types.BIDIR,unit=17),
            Pin(num='D21',name='RGMII_TXC',func=pin_types.BIDIR,unit=17),
            Pin(num='D22',name='RGMII_RX_CTL',func=pin_types.BIDIR,unit=17),
            Pin(num='D23',name='RGMII_RD3',func=pin_types.BIDIR,unit=17),
            Pin(num='E21',name='RGMII_TD2',func=pin_types.BIDIR,unit=17),
            Pin(num='F20',name='RGMII_TD1',func=pin_types.BIDIR,unit=17),
            Pin(num='G18',name='NVCC_RGMII',func=pin_types.PWRIN,unit=17),
            Pin(num='A21',name='SD1_DAT0',func=pin_types.BIDIR,unit=18),
            Pin(num='B21',name='SD1_CMD',func=pin_types.BIDIR,unit=18),
            Pin(num='C20',name='SD1_DAT1',func=pin_types.BIDIR,unit=18),
            Pin(num='D20',name='SD1_CLK',func=pin_types.BIDIR,unit=18),
            Pin(num='E19',name='SD1_DAT2',func=pin_types.BIDIR,unit=18),
            Pin(num='F18',name='SD1_DAT3',func=pin_types.BIDIR,unit=18),
            Pin(num='G16',name='NVCC_SD1',func=pin_types.PWRIN,unit=18),
            Pin(num='A22',name='SD2_DAT0',func=pin_types.BIDIR,unit=19),
            Pin(num='A23',name='SD2_DAT2',func=pin_types.BIDIR,unit=19),
            Pin(num='B22',name='SD2_DAT3',func=pin_types.BIDIR,unit=19),
            Pin(num='C21',name='SD2_CLK',func=pin_types.BIDIR,unit=19),
            Pin(num='E20',name='SD2_DAT1',func=pin_types.BIDIR,unit=19),
            Pin(num='F19',name='SD2_CMD',func=pin_types.BIDIR,unit=19),
            Pin(num='G17',name='NVCC_SD2',func=pin_types.PWRIN,unit=19),
            Pin(num='A15',name='SD3_DAT2',func=pin_types.BIDIR,unit=20),
            Pin(num='B13',name='SD3_CMD',func=pin_types.BIDIR,unit=20),
            Pin(num='B15',name='SD3_DAT3',func=pin_types.BIDIR,unit=20),
            Pin(num='C13',name='SD3_DAT5',func=pin_types.BIDIR,unit=20),
            Pin(num='D13',name='SD3_DAT4',func=pin_types.BIDIR,unit=20),
            Pin(num='D14',name='SD3_CLK',func=pin_types.BIDIR,unit=20),
            Pin(num='D15',name='SD3_RST',func=pin_types.BIDIR,unit=20),
            Pin(num='E13',name='SD3_DAT6',func=pin_types.BIDIR,unit=20),
            Pin(num='E14',name='SD3_DAT0',func=pin_types.BIDIR,unit=20),
            Pin(num='F13',name='SD3_DAT7',func=pin_types.BIDIR,unit=20),
            Pin(num='F14',name='SD3_DAT1',func=pin_types.BIDIR,unit=20),
            Pin(num='G14',name='NVCC_SD3',func=pin_types.PWRIN,unit=20),
            Pin(num='AA11',name='DRAM_SDCKE1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA12',name='DRAM_A14',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA14',name='DRAM_A2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA15',name='DRAM_A10',func=pin_types.OUTPUT,unit=21),
            Pin(num='AA17',name='DRAM_D32',func=pin_types.BIDIR,unit=21),
            Pin(num='AA18',name='DRAM_D33',func=pin_types.BIDIR,unit=21),
            Pin(num='AA20',name='DRAM_D45',func=pin_types.BIDIR,unit=21),
            Pin(num='AA21',name='DRAM_D57',func=pin_types.BIDIR,unit=21),
            Pin(num='AA23',name='DRAM_D61',func=pin_types.BIDIR,unit=21),
            Pin(num='AA24',name='DRAM_SDQS7_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AA25',name='DRAM_SDQS7',func=pin_types.BIDIR,unit=21),
            Pin(num='AA5',name='DRAM_D3',func=pin_types.BIDIR,unit=21),
            Pin(num='AA6',name='DRAM_D10',func=pin_types.BIDIR,unit=21),
            Pin(num='AA8',name='DRAM_D17',func=pin_types.BIDIR,unit=21),
            Pin(num='AA9',name='DRAM_D23',func=pin_types.BIDIR,unit=21),
            Pin(num='AB10',name='DRAM_SDQS3_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AB11',name='DRAM_D27',func=pin_types.BIDIR,unit=21),
            Pin(num='AB12',name='DRAM_SDBA2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB13',name='DRAM_A8',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB14',name='DRAM_A1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB15',name='DRAM_RAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB16',name='DRAM_SDWE',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB17',name='DRAM_SDODT1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB18',name='DRAM_DQM4',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB19',name='DRAM_D38',func=pin_types.BIDIR,unit=21),
            Pin(num='AB20',name='DRAM_D41',func=pin_types.BIDIR,unit=21),
            Pin(num='AB21',name='DRAM_D42',func=pin_types.BIDIR,unit=21),
            Pin(num='AB22',name='DRAM_D52',func=pin_types.BIDIR,unit=21),
            Pin(num='AB23',name='DRAM_D60',func=pin_types.BIDIR,unit=21),
            Pin(num='AB25',name='DRAM_D56',func=pin_types.BIDIR,unit=21),
            Pin(num='AB4',name='DRAM_D6',func=pin_types.BIDIR,unit=21),
            Pin(num='AB5',name='DRAM_D12',func=pin_types.BIDIR,unit=21),
            Pin(num='AB6',name='DRAM_D14',func=pin_types.BIDIR,unit=21),
            Pin(num='AB7',name='DRAM_D16',func=pin_types.BIDIR,unit=21),
            Pin(num='AB8',name='DRAM_DQM2',func=pin_types.OUTPUT,unit=21),
            Pin(num='AB9',name='DRAM_D18',func=pin_types.BIDIR,unit=21),
            Pin(num='AC1',name='DRAM_D4',func=pin_types.BIDIR,unit=21),
            Pin(num='AC10',name='DRAM_SDQS3',func=pin_types.BIDIR,unit=21),
            Pin(num='AC11',name='DRAM_D31',func=pin_types.BIDIR,unit=21),
            Pin(num='AC12',name='DRAM_A11',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC13',name='DRAM_A6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC14',name='DRAM_A0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC15',name='DRAM_SDBA0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC16',name='DRAM_SDODT0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC17',name='DRAM_A13',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC18',name='DRAM_D34',func=pin_types.BIDIR,unit=21),
            Pin(num='AC19',name='DRAM_D39',func=pin_types.BIDIR,unit=21),
            Pin(num='AC2',name='DRAM_VREF',func=pin_types.PWRIN,unit=21),
            Pin(num='AC20',name='DRAM_DQM5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC21',name='DRAM_D47',func=pin_types.BIDIR,unit=21),
            Pin(num='AC22',name='DRAM_D48',func=pin_types.BIDIR,unit=21),
            Pin(num='AC23',name='DRAM_D53',func=pin_types.BIDIR,unit=21),
            Pin(num='AC24',name='DRAM_D51',func=pin_types.BIDIR,unit=21),
            Pin(num='AC25',name='DRAM_D55',func=pin_types.BIDIR,unit=21),
            Pin(num='AC3',name='DRAM_DQM0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC4',name='DRAM_D2',func=pin_types.BIDIR,unit=21),
            Pin(num='AC5',name='DRAM_D13',func=pin_types.BIDIR,unit=21),
            Pin(num='AC6',name='DRAM_DQM1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AC7',name='DRAM_D15',func=pin_types.BIDIR,unit=21),
            Pin(num='AC8',name='DRAM_D22',func=pin_types.BIDIR,unit=21),
            Pin(num='AC9',name='DRAM_D28',func=pin_types.BIDIR,unit=21),
            Pin(num='AD1',name='DRAM_D5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD11',name='DRAM_D30',func=pin_types.BIDIR,unit=21),
            Pin(num='AD12',name='DRAM_A12',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD14',name='DRAM_SDCLK_1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD15',name='DRAM_SDCLK_0',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD17',name='DRAM_CS1',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD18',name='DRAM_SDQS4',func=pin_types.BIDIR,unit=21),
            Pin(num='AD2',name='DRAM_D0',func=pin_types.BIDIR,unit=21),
            Pin(num='AD20',name='DRAM_SDQS5',func=pin_types.BIDIR,unit=21),
            Pin(num='AD21',name='DRAM_D43',func=pin_types.BIDIR,unit=21),
            Pin(num='AD23',name='DRAM_SDQS6',func=pin_types.BIDIR,unit=21),
            Pin(num='AD24',name='DRAM_DQM6',func=pin_types.OUTPUT,unit=21),
            Pin(num='AD25',name='DRAM_D54',func=pin_types.BIDIR,unit=21),
            Pin(num='AD3',name='DRAM_SDQS0_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AD5',name='DRAM_D8',func=pin_types.BIDIR,unit=21),
            Pin(num='AD6',name='DRAM_SDQS1',func=pin_types.BIDIR,unit=21),
            Pin(num='AD8',name='DRAM_SDQS2',func=pin_types.BIDIR,unit=21),
            Pin(num='AD9',name='DRAM_D29',func=pin_types.BIDIR,unit=21),
            Pin(num='AE10',name='DRAM_DQM3',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE11',name='DRAM_D26',func=pin_types.BIDIR,unit=21),
            Pin(num='AE12',name='DRAM_A9',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE13',name='DRAM_A5',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE14',name='DRAM_SDCLK_1_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE15',name='DRAM_SDCLK_0_B',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE16',name='DRAM_CAS',func=pin_types.OUTPUT,unit=21),
            Pin(num='AE17',name='ZQPAD',func=pin_types.PASSIVE,unit=21),
            Pin(num='AE18',name='DRAM_SDQS4_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE19',name='DRAM_D35',func=pin_types.BIDIR,unit=21),
            Pin(num='AE2',name='DRAM_D1',func=pin_types.BIDIR,unit=21),
            Pin(num='AE20',name='DRAM_SDQS5_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE21',name='DRAM_D46',func=pin_types.BIDIR,unit=21),
            Pin(num='AE22',name='DRAM_D49',func=pin_types.BIDIR,unit=21),
            Pin(num='AE23',name='DRAM_SDQS6_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE24',name='DRAM_D50',func=pin_types.BIDIR,unit=21),
            Pin(num='AE3',name='DRAM_SDQS0',func=pin_types.BIDIR,unit=21),
            Pin(num='AE4',name='DRAM_D7',func=pin_types.BIDIR,unit=21),
            Pin(num='AE5',name='DRAM_D9',func=pin_types.BIDIR,unit=21),
            Pin(num='AE6',name='DRAM_SDQS1_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE7',name='DRAM_D11',func=pin_types.BIDIR,unit=21),
            Pin(num='AE8',name='DRAM_SDQS2_B',func=pin_types.BIDIR,unit=21),
            Pin(num='AE9',name='DRAM_D24',func=pin_types.BIDIR,unit=21),
            Pin(num='R18',name='NVCC_DRAM',func=pin_types.PWRIN,unit=21),
            Pin(num='T18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='U18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V10',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V11',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V12',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V13',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V14',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V15',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V16',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V17',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V18',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='V9',name='NVCC_DRAM',func=pin_types.PASSIVE,unit=21),
            Pin(num='W14',name='DRAM_A4',func=pin_types.OUTPUT,unit=21),
            Pin(num='W25',name='DRAM_D63',func=pin_types.BIDIR,unit=21),
            Pin(num='Y10',name='DRAM_D25',func=pin_types.BIDIR,unit=21),
            Pin(num='Y11',name='DRAM_SDCKE0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y12',name='DRAM_A15',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y13',name='DRAM_A7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y14',name='DRAM_A3',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y15',name='DRAM_SDBA1',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y16',name='DRAM_CS0',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y17',name='DRAM_D36',func=pin_types.BIDIR,unit=21),
            Pin(num='Y18',name='DRAM_D37',func=pin_types.BIDIR,unit=21),
            Pin(num='Y19',name='DRAM_D40',func=pin_types.BIDIR,unit=21),
            Pin(num='Y20',name='DRAM_D44',func=pin_types.BIDIR,unit=21),
            Pin(num='Y21',name='DRAM_DQM7',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y22',name='DRAM_D59',func=pin_types.BIDIR,unit=21),
            Pin(num='Y23',name='DRAM_D62',func=pin_types.BIDIR,unit=21),
            Pin(num='Y25',name='DRAM_D58',func=pin_types.BIDIR,unit=21),
            Pin(num='Y6',name='DRAM_RESET',func=pin_types.OUTPUT,unit=21),
            Pin(num='Y7',name='DRAM_D20',func=pin_types.BIDIR,unit=21),
            Pin(num='Y8',name='DRAM_D21',func=pin_types.BIDIR,unit=21),
            Pin(num='Y9',name='DRAM_D19',func=pin_types.BIDIR,unit=21),
            Pin(num='A7',name='XTALI',func=pin_types.INPUT,unit=22),
            Pin(num='B7',name='XTALO',func=pin_types.OUTPUT,unit=22),
            Pin(num='C9',name='RTC_XTALO',func=pin_types.OUTPUT,unit=23),
            Pin(num='D9',name='RTC_XTALI',func=pin_types.INPUT,unit=23),
            Pin(num='A12',name='SATA_TXP',func=pin_types.OUTPUT,unit=24),
            Pin(num='A14',name='SATA_RXM',func=pin_types.INPUT,unit=24),
            Pin(num='B12',name='SATA_TXM',func=pin_types.OUTPUT,unit=24),
            Pin(num='B14',name='SATA_RXP',func=pin_types.INPUT,unit=24),
            Pin(num='C14',name='SATA_REXT',func=pin_types.PASSIVE,unit=24),
            Pin(num='G12',name='SATA_VPH',func=pin_types.PWRIN,unit=24),
            Pin(num='G13',name='SATA_VP',func=pin_types.PWRIN,unit=24)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C10', 'N8', 'U8', 'C4', 'K12', 'N9', 'C6', 'U9', 'K13', 'D3', 'P10', 'V19', 'D6', 'K14', 'P11', 'D8', 'V8', 'K15', 'E5', 'P12', 'W10', 'K16', 'P13', 'E6', 'W11', 'K17', 'P14', 'E7', 'W12', 'K18', 'P15', 'E8', 'W13', 'K8', 'U19', 'P16', 'F5', 'K9', 'W15', 'P17', 'F6', 'L10', 'W16', 'F7', 'P18', 'L11', 'W17', 'P8', 'F8', 'L12', 'W18', 'P9', 'F9', 'L13', 'W19', 'R10', 'G10', 'L14', 'W3', 'R11', 'G11', 'L15', 'W7', 'R12', 'G19', 'L16', 'W8', 'R13', 'G3', 'L17', 'W9', 'G9', 'R14', 'L18', 'Y24', 'H10', 'R15', 'L2', 'Y5', 'H11', 'R16', 'L5', 'H12', 'R17', 'L8', 'H13', 'R8', 'L9', 'H14', 'R9', 'M10', 'H15', 'T10', 'M11', 'H16', 'T11', 'M12', 'H17', 'T12', 'M13', 'H18', 'T13', 'M14', 'A13', 'H8', 'T14', 'M15', 'A25', 'H9', 'A4', 'T15', 'M16', 'A8', 'J10', 'T16', 'M17', 'AA10', 'T17', 'AA7', 'J11', 'M18', 'AA13', 'J12', 'T19', 'AA16', 'M8', 'AA19', 'T8', 'J13', 'M9', 'AA22', 'AB24', 'T9', 'J14', 'N10', 'AB3', 'U10', 'J15', 'N11', 'AD10', 'U11', 'J16', 'AD13', 'N12', 'AD16', 'U12', 'J17', 'N13', 'AD19', 'U13', 'J18', 'AD22', 'N14', 'AD4', 'U14', 'J2', 'N15', 'AD7', 'U15', 'J8', 'AE1', 'N16', 'U16', 'AE25', 'J9', 'N17', 'B4', 'U17', 'K10', 'N18', 'C1', 'K11']},{'label': 'uB', 'num': 2, 'pin_nums': ['E12', 'A5', 'C8', 'B5']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'F12', 'C12', 'E11', 'D11', 'F11', 'C11']},{'label': 'uD', 'num': 4, 'pin_nums': ['B11', 'C7', 'A9', 'B9', 'D7', 'A10', 'D5', 'B10', 'C5', 'A11']},{'label': 'uE', 'num': 5, 'pin_nums': ['D4', 'G4', 'E1', 'H1', 'E2', 'H2', 'E3', 'H3', 'E4', 'H4', 'F1', 'K7', 'F2', 'F3', 'F4', 'D1', 'G1', 'D2', 'G2']},{'label': 'uF', 'num': 6, 'pin_nums': ['M1', 'N6', 'M2', 'N7', 'M3', 'P1', 'M4', 'P2', 'M5', 'P3', 'M6', 'P4', 'N1', 'L1', 'N2', 'L3', 'N3', 'L4', 'N4', 'L6', 'N5']},{'label': 'uG', 'num': 7, 'pin_nums': ['R24', 'U25', 'P20', 'R25', 'V24', 'P21', 'T20', 'V25', 'P22', 'T21', 'W24', 'P23', 'T22', 'P24', 'T23', 'P25', 'T24', 'N19', 'R20', 'T25', 'N20', 'R21', 'U22', 'N21', 'R22', 'U23', 'N25', 'R23', 'U24', 'P19']},{'label': 'uH', 'num': 8, 'pin_nums': ['K25', 'G25', 'M22', 'F21', 'J22', 'L19', 'H19', 'M23', 'J23', 'F22', 'L20', 'H20', 'M24', 'J24', 'F23', 'L21', 'H21', 'M25', 'F24', 'J25', 'L22', 'H22', 'N22', 'C25', 'F25', 'K19', 'L23', 'H23', 'N23', 'D24', 'G20', 'K20', 'L24', 'H24', 'N24', 'D25', 'K21', 'G21', 'L25', 'E22', 'H25', 'K22', 'G22', 'M19', 'E23', 'J19', 'K23', 'G23', 'M20', 'J20', 'E24', 'K24', 'G24', 'J21', 'M21', 'E25']},{'label': 'uI', 'num': 9, 'pin_nums': ['V23', 'W22', 'U20', 'V21', 'R19', 'W20', 'U21', 'W23', 'V22', 'W21', 'V20']},{'label': 'uJ', 'num': 10, 'pin_nums': ['R1', 'T5', 'R2', 'T6', 'R3', 'T7', 'R4', 'U5', 'R5', 'U6', 'R6', 'U7', 'R7', 'V5', 'T1', 'V6', 'P5', 'T2', 'W4', 'P6', 'T3', 'W5', 'P7', 'T4', 'W6']},{'label': 'uK', 'num': 11, 'pin_nums': ['J4', 'K6', 'K1', 'K4', 'J1', 'J5', 'K3', 'L7', 'K2', 'K5', 'J3', 'J6', 'M7']},{'label': 'uL', 'num': 12, 'pin_nums': ['G5', 'H6', 'C2', 'G6', 'J7', 'C3', 'H5']},{'label': 'uM', 'num': 13, 'pin_nums': ['V2', 'AA2', 'V3', 'AA3', 'V4', 'AA4', 'V7', 'AB1', 'W1', 'AB2', 'W2', 'U1', 'Y1', 'U2', 'Y2', 'U3', 'Y3', 'U4', 'Y4', 'V1', 'AA1']},{'label': 'uN', 'num': 14, 'pin_nums': ['E18', 'A17', 'C17', 'F15', 'A18', 'C18', 'F16', 'A19', 'C19', 'F17', 'A20', 'D16', 'G15', 'B16', 'D17', 'B17', 'D18', 'B18', 'D19', 'B19', 'E15', 'B20', 'E16', 'C15', 'E17', 'A16', 'C16']},{'label': 'uO', 'num': 15, 'pin_nums': ['B2', 'G8', 'A3', 'B3', 'H7', 'B1', 'G7', 'A2']},{'label': 'uP', 'num': 16, 'pin_nums': ['D10', 'F10', 'B6', 'E10', 'B8', 'E9', 'A6']},{'label': 'uQ', 'num': 17, 'pin_nums': ['C22', 'G18', 'D21', 'B24', 'E21', 'C23', 'B23', 'A24', 'D22', 'B25', 'F20', 'C24', 'D23']},{'label': 'uR', 'num': 18, 'pin_nums': ['E19', 'C20', 'F18', 'A21', 'D20', 'G16', 'B21']},{'label': 'uS', 'num': 19, 'pin_nums': ['F19', 'A22', 'C21', 'G17', 'A23', 'E20', 'B22']},{'label': 'uT', 'num': 20, 'pin_nums': ['D15', 'B13', 'F13', 'E14', 'D13', 'E13', 'B15', 'F14', 'D14', 'C13', 'A15', 'G14']},{'label': 'uU', 'num': 21, 'pin_nums': ['AC7', 'AB11', 'AE9', 'AC8', 'AB12', 'R18', 'AC9', 'AB13', 'T18', 'AD1', 'U18', 'AB14', 'AD11', 'AB15', 'V10', 'AD12', 'V11', 'AB16', 'AD14', 'V12', 'AB17', 'AD15', 'V13', 'AB18', 'AD17', 'V14', 'AB19', 'AD18', 'V15', 'AB20', 'AD2', 'V16', 'AB21', 'AD20', 'V17', 'AB22', 'AD21', 'V18', 'AB23', 'AD23', 'V9', 'AB25', 'AD24', 'W14', 'AB4', 'AD25', 'W25', 'AB5', 'AD3', 'Y10', 'AB6', 'AD5', 'Y11', 'AB7', 'AD6', 'Y12', 'AB8', 'AD8', 'Y13', 'AB9', 'AD9', 'AC1', 'Y14', 'AE10', 'Y15', 'AC10', 'AE11', 'Y16', 'AC11', 'AE12', 'Y17', 'AC12', 'AE13', 'Y18', 'AC13', 'AE14', 'AC14', 'Y19', 'AE15', 'AC15', 'Y20', 'AE16', 'AA11', 'AC16', 'Y21', 'AE17', 'AA12', 'AC17', 'Y22', 'AE18', 'AA14', 'AC18', 'Y23', 'AE19', 'AA15', 'AC19', 'Y25', 'AE2', 'AA17', 'AC2', 'Y6', 'AE20', 'AA18', 'AC20', 'Y7', 'AE21', 'AA20', 'AC21', 'Y8', 'AE22', 'AA21', 'AC22', 'Y9', 'AA23', 'AE23', 'AC23', 'AA24', 'AE24', 'AC24', 'AA25', 'AE3', 'AC25', 'AA5', 'AE4', 'AC3', 'AA6', 'AE5', 'AC4', 'AB10', 'AA8', 'AE6', 'AC5', 'AA9', 'AE7', 'AC6', 'AE8']},{'label': 'uV', 'num': 22, 'pin_nums': ['B7', 'A7']},{'label': 'uW', 'num': 23, 'pin_nums': ['D9', 'C9']},{'label': 'uX', 'num': 24, 'pin_nums': ['B14', 'G13', 'A14', 'A12', 'C14', 'B12', 'G12']}] })])