from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_PIC16 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'PIC16F1454-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1454-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41639A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1454-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PWM1/DT/RX/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CK/TX/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLKR/~{SS}/PWM2/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ICSPCLK/SDI/SDA/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPDAT/SCK/SCL/RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1454-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1454-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41639A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1454-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1455-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1455-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41639A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1455-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4/AN3/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PWM1/DT/RX/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CK/TX/CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLKR/~{SS}/PWM2/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ICSPCLK/SDI/SDA/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPDAT/SCK/SCL/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1455-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1455-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41639A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1455-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1459-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1459-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41639A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1459-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB4/AN10/SDA/SDI',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5/SOSCI/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM1/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4/AN3/SOSCO/T1G/OSC2/CLKOUT/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CLKR/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{SS}/PWM2/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SDO/AN9/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5/AN11/RX/DX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1459-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1459-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41639A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1459-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DX',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='ICSPCLK/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ICSPDAT/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/OSC2/CLKOUT/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{SS}/PWM2/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1503-IMG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1503-IMG'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41607A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1503-IMG\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5/T1CKI/NCO1CLK/CLCIN1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA2/AN2/DACOUT2/C1OUT/T0CKI/~{CWG1FLT}/CLC1/PWM3/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4/AN3/T1G/NCO1/SDO/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/T1G/CLC1IN0/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{SS}/PWM2/CLCIN0/C2IN3-/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/C2IN2-/C1IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/PWM4/NCO1/C2IN1-/C1IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCK/SCL/CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1503-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1503-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41607A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1503-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCK/SCL/CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/AN2/DACOUT2/C1OUT/T0CKI/~{CWG1FLT}/CLC1/PWM3/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/T1CKI/NCO1CLK/CLCIN1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/T1G/NCO1/SDO/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/CLC1IN0/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/PWM2/CLCIN0/C2IN3-/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/PWM4/NCO1/C2IN1-/C1IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1507-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1507-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41586A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1507-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB4/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PWM4/NCO1/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CLC2/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2/AN2/~{CWG1FLT}/CLC1/T0CKI/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/AN1/Vref+/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/AN0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5/NCO1CLK/T1CKI/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4/AN3/~{T1G}/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLC2IN1/CWG1B/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM2/CLC2IN0/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='NCO1/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLCIN1/AN9/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5/AN11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1507-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1507-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41586A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1507-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/~{CWG1FLT}/CLC1/T0CKI/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/NCO1CLK/T1CKI/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/~{T1G}/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC2IN1/CWG1B/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NCO1/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLCIN1/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1508-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1508-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1508-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1508-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1508-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1508-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1509-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1509-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1509-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1509-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1509-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1509-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1512-IMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1512-IMV'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1512-IMV\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1512-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1512-ISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1512-ISP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1513-IMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1513-IMV'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1513-IMV\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1513-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1513-ISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1513-ISP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1516-IMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1516-IMV'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1516-IMV\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1516-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1516-ISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1516-ISP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1517-IMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1517-IMV'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1517-IMV\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5/AN13/T1G',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB6/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB7/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN24/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RE1/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN25/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN20/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN21/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AN22/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AN23/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN26/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AN27/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0/AN12/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1517-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1517-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1517-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN20/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN21/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN22/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN23/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN24/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AN25/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='AN26/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AN27/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='RB0/AN12/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3/AN9/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5/AN13/T1G',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1517-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1517-IPT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1517-IPT\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/T1G',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN24/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AN25/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='AN20/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='AN21/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN26/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AN22/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN23/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AN27/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0/AN12/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1518-IMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1518-IMV'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1518-IMV\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1518-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1518-ISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1518-ISP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1519-IMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1519-IMV'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1519-IMV\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5/AN13/T1G',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB6/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB7/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN24/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RE1/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN25/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN20/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN21/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AN22/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AN23/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN26/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AN27/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0/AN12/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1519-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1519-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1519-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN20/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN21/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN22/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN23/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN24/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AN25/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='AN26/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AN27/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='RB0/AN12/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3/AN9/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5/AN13/T1G',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1519-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1519-IPT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1519-IPT\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/T1G',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN24/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AN25/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='AN20/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='AN21/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN26/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AN22/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN23/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AN27/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0/AN12/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1526-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1526-IPT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41458B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1526-IPT\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='AN28/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{SS1}/AN5/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN9/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN8/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AN7/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN6/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCAP/AN16/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN27/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/AN0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='RA5/AN4/T3G',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1/SOSCI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CCP3/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0/SOSCO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/TX1/CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/RX1/DT1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SCK1/SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SDI1/SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/ICSPDAT/ISCDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/OSC1/CKLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TX2/CK2/AN15/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='RB6/ICSPLCK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/AN22/T1G/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/AN21/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/AN20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/AN19',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/AN18',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/AN17/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='~{SS2}/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RX2/DT2/AN14/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SCK2/SCL2/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SDI2/SDA2/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='SDO2/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='AN26/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='AN25/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='T5CKI/AN24/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='AN23/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='CCP2/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CCP4/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='CCP6/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='CCP7/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='CCP8/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='CCP9/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='CCP10/AN29/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='Vpp/~{MCLR}/RG5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CCP5/T5G/AN12/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1527-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1527-IPT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41458B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1527-IPT\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='AN28/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{SS1}/AN5/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN9/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN8/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AN7/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN6/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCAP/AN16/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN27/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/AN0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='RA5/AN4/T3G',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1/SOSCI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CCP3/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0/SOSCO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/TX1/CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/RX1/DT1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SCK1/SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SDI1/SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/ICSPDAT/ISCDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/OSC1/CKLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TX2/CK2/AN15/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='RB6/ICSPLCK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/AN22/T1G/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/AN21/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/AN20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/AN19',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/AN18',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/AN17/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='~{SS2}/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RX2/DT2/AN14/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SCK2/SCL2/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SDI2/SDA2/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='SDO2/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='AN26/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='AN25/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='T5CKI/AN24/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='AN23/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='CCP2/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CCP4/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='CCP6/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='CCP7/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='CCP8/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='CCP9/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='CCP10/AN29/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='Vpp/~{MCLR}/RG5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CCP5/T5G/AN12/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15323-xSL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15323-xSL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-14_3.9x8.65mm_P1.27mm'], 'footprint':'Package_SO:SO-14_3.9x8.65mm_P1.27mm', 'keywords':'8-bit microcontroller low power', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/PIC16_L_F15313_23_Data_Sheet_40001897C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15323-xSL\n\n8-bit microcontroller low power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/VPP/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15356-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15356-xML'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15356-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='29',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15356-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15356-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15356-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='29',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15356-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15356-xSO'}), 'ref_prefix':'U?', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15356-xSO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15356-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15356-xSP'}), 'ref_prefix':'U?', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15356-xSP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15356-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15356-xSS'}), 'ref_prefix':'U?', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15356-xSS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15375-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15375-xML'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15375-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT),
            Pin(num='45',name='PAD',func=pin_types.PWRIN),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15375-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15375-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15375-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='41',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15375-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15375-xP'}), 'ref_prefix':'U?', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15375-xP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15375-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15375-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15375-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='12',name='NC',func=pin_types.NOCONNECT),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15386-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15386-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15386-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='49',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15386-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15386-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15386-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1619-xGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1619-xGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm'], 'footprint':'Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001770D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1619-xGZ\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='21',name='EP',func=pin_types.PASSIVE),
            Pin(num='1',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1619-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1619-xML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001770D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1619-xML\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='21',name='EP',func=pin_types.PASSIVE),
            Pin(num='1',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1619-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1619-xP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001770D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1619-xP\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1619-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1619-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001770D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1619-xSO\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1619-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1619-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001770D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1619-xSS\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1786-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1786-xML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1786-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1786-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1786-xP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1786-xP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1786-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1786-xSP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1786-xSP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829-IML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41440C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829-IML\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/MCLR/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41440C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829-IP\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/MCLR/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829LIN-ESS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829LIN-ESS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'Flash-Based 8-Bit CMOS microcontroller regulator LIN', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41673A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829LIN-ESS\n\nFlash-Based 8-Bit CMOS microcontroller regulator LIN', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREG',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='/FAULT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/MCLR',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='LINVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LBUS',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18324-xSL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18324-xSL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001800c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18324-xSL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18325-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18325-ISL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001795b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18325-ISL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL1/SCK/T5CKI/C2IN0+/ANC0/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/ANA2/Vref-/DAC1Ref-/T0CKI/CCP3/CWG1IN/CWG2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/ANA1/Vref+/C1IN0-/C2IN0-/DAC1Ref+/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/ANA0/C1IN0+/DAC1OUT/~{SS2}/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/ANA5/T1CKI/SOSCIN/SOSCI/CLCIN3/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/ANA4/T1G/SOSCO/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DT/RX/SDA2/SDI2/CCP1/T3CKI/MDCIN2/ANC5/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLCIN1/SCL2/SCK2/T3G/ANC4/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLCIN0/~{SS1}/CCP2/T5G/MDMIN/C2IN3-/C1IN3-/ANC3/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='MDCIN1/C2IN2-/C1IN2-/ANC2/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLCIN2/SDA1/SDI/CCP4/C2IN1-/C1IN1-/ANC1/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18325-xGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18325-xGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm'], 'footprint':'Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001795E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18325-xGZ\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18325-xJQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18325-xJQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-16-1EP_4x4mm_P0.65mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:UQFN-16-1EP_4x4mm_P0.65mm_EP2.6x2.6mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001795E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18325-xJQ\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/~{MCLR}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18344-GZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18344-GZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm'], 'footprint':'Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001839B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18344-GZ\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18344-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18344-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001800a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18344-P\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18344-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18344-SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001800a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18344-SO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18344-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18344-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001800a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18344-SS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18346-GZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18346-GZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm'], 'footprint':'Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001839B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18346-GZ\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18346-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18346-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001839B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18346-P\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18346-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18346-SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001839B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18346-SO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18346-SS_0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18346-SS_0'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001839B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18346-SS_0\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18854-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18854-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power CRC DSM  ADC^2 CLC PLL 32MHz', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF18855-75-Data-Sheet-40001802F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18854-xSO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power CRC DSM  ADC^2 CLC PLL 32MHz', 'pins':[
            Pin(num='19',name='VSS',func=pin_types.PASSIVE),
            Pin(num='1',name='RE3/~{MCLR}/VPP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18855-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18855-xMV'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-28-1EP_4x4mm_P0.4mm_EP2.35x2.35mm'], 'footprint':'Package_DFN_QFN:UQFN-28-1EP_4x4mm_P0.4mm_EP2.35x2.35mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power CRC DSM  ADC^2 CLC PLL 32MHz', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF18855-75-Data-Sheet-40001802F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18855-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power CRC DSM  ADC^2 CLC PLL 32MHz', 'pins':[
            Pin(num='29',name='VSS',func=pin_types.PASSIVE),
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/VPP',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19195-x5LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19195-x5LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19195-x5LX\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19195-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19195-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19195-xMR\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19195-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19195-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19195-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1934-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1934-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41364E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1934-IML\n\n', 'pins':[
            Pin(num='1',name='SEG8/DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1/AN10/C12IN3-/CPS1/VLCD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2/AN8/CPS2/VLCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB3/AN9/C12IN2-/CPS3/CCP2/P2A/VLCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4/AN11/CPS4/COM0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/CPS5/CCP3/P3A/T1G/COM1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/MCLR/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/C12IN0-/C2OUT/SRNQ/SS/VCAP/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SEG17/P2D/CPS12/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1/C12IN1-/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2/C2IN+/Vref-/DACOUT/COM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/C1IN+/Vref+/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/C1OUT/CPS6/T0CKI/SRQ/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/C2OUT/CPS7/SRNQ/SS/VCAP/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SEG21/P3A/CCP3/AN5/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SEG22/P3B/AN6/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SEG23/CCP5/AN7/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SEG18/P1B/CPS13/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7/OSC1/CLKIN/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6/OSC2/CLKOUT/VCAP/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P2B/T1CLKI/T1OSO/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P2A/CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SEG3/P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SEG6/SCLK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='COM3/CPS8/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CCP4/CPS9/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG19/P1C/CPS14/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P2B/CPS10/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SEG16/P2C/CPS11/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SEG11/T1G/SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SEG10/SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='SEG9/CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG20/P1D/CPS15/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB0/AN12/CPS0/SRI/INT/SEG0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1934-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1934-IPT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41364E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1934-IPT\n\n', 'pins':[
            Pin(num='1',name='SEG8/DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8/CPS2/VLCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/C12IN2-/CPS3/CCP2/P2A/VLCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4/AN11/CPS4/COM0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/CPS5/CCP3/P3A/T1G/COM1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/MCLR/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/C12IN0-/C2OUT/SRNQ/SS/VCAP/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SEG17/P2D/CPS12/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1/C12IN1-/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2/C2IN+/Vref-/DACOUT/COM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/C1IN+/Vref+/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/C1OUT/CPS6/T0CKI/SRQ/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/C2OUT/CPS7/SRNQ/SS/VCAP/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SEG21/P3A/CCP3/AN5/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SEG22/P3B/AN6/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SEG23/CCP5/AN7/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SEG18/P1B/CPS13/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7/OSC1/CLKIN/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6/OSC2/CLKOUT/VCAP/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P2B/T1CKI/T1OSO/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='P2A/CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SEG3/P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SEG6/SCLK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='COM3/CPS8/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CCP4/CPS9/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG19/P1C/CPS14/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P2B/CPS10/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SEG16/P2C/CPS11/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SEG11/T1G/SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SEG10/SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='SEG9/CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG20/P1D/CPS15/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB0/AN12/CPS0/SRI/INT/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10/C12IN3-/CPS1/VLCD1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F505-IMG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F505-IMG'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F505-IMG\n\nFLASH-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F505-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F505-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F505-IP\n\nFLASH-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F505-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F505-ISL'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F505-ISL\n\nFLASH-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F505-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F505-IST'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F505-IST\n\nFLASH-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F54-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F54-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41213D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F54-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F54-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F54-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41213D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F54-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F54-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F54-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41213D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F54-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F610-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F610-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41288F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F610-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA2/T0CKI/INT/C1OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/C12IN0-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4/~{T1G}/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C12IN3-/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='C12IN2-/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='C12IN1-/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='C2IN+/RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F610-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F610-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41288F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F610-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='C2IN+/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/T0CKI/INT/C1OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/C12IN0-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/~{T1G}/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='C12IN3-/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='C12IN2-/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='C12IN1-/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F616-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F616-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41288F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F616-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR),
            Pin(num='10',name='RA2/AN2/T0CKI/INT/C1OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/AN1/C12IN0-/Vref/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/AN0/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4/AN3/~{T1G}/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1A/CCP1/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1C/C12IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1D/C12IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='C12IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F616-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F616-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41288F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F616-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/AN2/T0CKI/INT/C1OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/AN1/C12IN0-/Vref/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/AN0/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/~{T1G}/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P1A/CCP1/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1C/C12IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P1D/C12IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='C12IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F627-xxIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F627-xxIP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F627-xxIP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F627-xxISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F627-xxISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F627-xxISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F627-xxISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F627-xxISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F627-xxISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F627A-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F627A-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F627A-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F627A-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F627A-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F627A-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F627A-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F627A-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40044G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F627A-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F631-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F631-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F631-IP\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F631-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F631-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F631-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F631-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F631-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F631-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F677-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F677-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F677-IP\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCL/SCK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDA/SDI/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F677-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F677-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F677-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCL/SCK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDA/SDI/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F677-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F677-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F677-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCL/SCK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDA/SDI/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F684-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F684-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41202F-print.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F684-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA2/AN2/T0CKI/INT/C1OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/AN1/C1IN-/Vref/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/AN0/C1IN+/ICSPDAT/ULPWU',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4/AN3/~{T1G}/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1A/CCP1/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1C/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1D/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='C2IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F684-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F684-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41202F-print.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F684-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/AN2/T0CKI/INT/C1OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/AN1/C1IN-/Vref/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/AN0/C1IN+/ICSPDAT/ULPWU',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/~{T1G}/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P1A/CCP1/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1C/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P1D/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='C2IN-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F685-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F685-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F685-IP\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/CCP1/P1A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F685-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F685-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F685-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/CCP1/P1A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F685-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F685-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F685-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/CCP1/P1A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F687-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F687-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F687-IP\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F687-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F687-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F687-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F687-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F687-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F687-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F690-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F690-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F690-IP\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='C1OUT/T0CKI/INT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/CCP1/P1A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F690-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F690-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F690-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='C1OUT/T0CKI/INT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/CCP1/P1A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F690-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F690-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F690-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='C1OUT/T0CKI/INT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/CCP1/P1A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F716-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F716-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41206B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F716-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{ECCPAS0}/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1B/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1C/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1D/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI/RA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/~{ECCPAS2}/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='T1OSO/T1CKI/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='T1OSI/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CCP1/P1A/RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F716-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F716-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41206B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F716-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{ECCPAS0}/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1B/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1C/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1D/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI/RA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/~{ECCPAS2}/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='T1OSO/T1CKI/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='T1OSI/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CCP1/P1A/RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F716-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F716-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41206B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F716-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CCP1/P1A/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{ECCPAS0}/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1B/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1C/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P1D/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI/RA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='INT/~{ECCPAS2}/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='T1OSO/T1CKI/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='T1OSI/RB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F73-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F73-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F73-IML\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F73-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F73-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F73-ISO\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F73-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F73-ISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F73-ISP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F73-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F73-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F73-ISS\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F74-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F74-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F74-IP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/C1OUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F818-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F818-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F818-IML\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F818-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F818-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F818-IP\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F818-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F818-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F818-ISO\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F818-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F818-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F818-ISS\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F83-XXP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F83-XXP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30430c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F83-XXP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F83-XXSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F83-XXSO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30430c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F83-XXSO\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F84A-XXP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F84A-XXP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/35007b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F84A-XXP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F84A-XXSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F84A-XXSO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/35007b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F84A-XXSO\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F84A-XXSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F84A-XXSS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/35007b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F84A-XXSS\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F870-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F870-ISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30569b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F870-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp/THV',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F870-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F870-ISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30569b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F870-ISP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp/THV',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F870-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F870-ISS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30569b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F870-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp/THV',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F871-IL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F871-IL'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30569b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F871-IL\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='10',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{MCLR}/Vpp/THV',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F871-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F871-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30569b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F871-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp/THV',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F871-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F871-IPT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30569b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F871-IPT\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{MCLR}/Vpp/THV',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F873-XXISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F873-XXISO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30292C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F873-XXISO\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/CK/TX',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/DT/RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F873-XXISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F873-XXISP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30292C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F873-XXISP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/CK/TX',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/DT/RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F874-XXIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F874-XXIP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30292C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F874-XXIP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T1OSO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F874A-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F874A-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39582b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F874A-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T1OSO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C1OUT/T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F874A-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F874A-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39582b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F874A-IPT\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='C1OUT/T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='T1OSO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F88-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F88-IML'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30487D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F88-IML\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB3/PGM/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5/~{SS}/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB6/AN5/PGC/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB7/AN6/PGD/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vref-/CVref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='C1OUT/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='C2OUT/T0CKI/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/SDO/RX/DT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F88-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F88-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30487D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F88-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref-/CVref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5/~{SS}/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/AN5/PGC/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/AN6/PGD/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='C1OUT/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C2OUT/T0CKI/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/SDO/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/PGM/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F882-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F882-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41291D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F882-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/P1A/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ULPWU/C12IN0-/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/AN12/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P1C/AN10/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P1B/AN8/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/C12IN2-/AN8/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1D/AN11/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{T1G}/AN13/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C12IN1-/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/C2IN1+/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C1IN+/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/C1OUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CLKIN/OSC1/RA7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F884-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F884-IP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41291D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F884-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCL/SCK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='C12IN0-/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C12IN1-/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/AN12/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='C12IN3-/AN10/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN8/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='C12IN2-/PGM/AN9/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AN11/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{T1G}/AN13/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='C2IN+/CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C1IN+/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C1OUT/T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='C2OUT/~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1904-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1904-IP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/OTH/ProductDocuments/DataSheets/40001569D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1904-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16C505-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16C505-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'ROM-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16C505-IP\n\nROM-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16C505-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16C505-ISL'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'ROM-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16C505-ISL\n\nROM-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16C505-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16C505-IST'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'ROM-Based 8bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41236E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16C505-IST\n\nROM-Based 8bit Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ICSPCLK/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ICSPDAT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLKIN/OSC1/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKOUT/OSC2/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1454-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1454-ISL'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1454-ISL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1454-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1454-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1454-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1454-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1454-IST'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1454-IST\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1455-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1455-ISL'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1455-ISL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1455-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1455-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1455-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1455-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1455-IST'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1455-IST\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ICSPDAT/SCK/SCL/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/PWM2/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/SDO/CLKOUT/OSC2/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/DT/RX/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CK/TX/CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/~{SS}/PWM2/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ICSPCLK/SDI/SDA/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1459-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1459-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1459-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DX',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='ICSPCLK/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ICSPDAT/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/OSC2/CLKOUT/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{SS}/PWM2/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1459-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1459-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1459-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DX',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='ICSPCLK/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ICSPDAT/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/OSC2/CLKOUT/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{SS}/PWM2/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1459-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1459-IST'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1459-IST\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DX',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C2IN2-/C1IN2-/DACOUT1/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='ICSPCLK/~{CWGFLT}/C2IN-/C1IN-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ICSPDAT/C2IN+/C1IN+/Vref+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='Vusb3v3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/D-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/D+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/OSC2/CLKOUT/CLKR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CWG1A/T0CKI/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CWG1B/C1OUT/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLKR/C1IN3-/C2IN3-/DACOUT2/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{SS}/PWM2/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1503-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1503-ISL'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41607A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1503-ISL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCK/SCL/CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/AN2/DACOUT2/C1OUT/T0CKI/~{CWG1FLT}/CLC1/PWM3/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/T1CKI/NCO1CLK/CLCIN1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/T1G/NCO1/SDO/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/CLC1IN0/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/PWM2/CLCIN0/C2IN3-/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/PWM4/NCO1/C2IN1-/C1IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1503-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1503-IST'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41607A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1503-IST\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCK/SCL/CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/AN2/DACOUT2/C1OUT/T0CKI/~{CWG1FLT}/CLC1/PWM3/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/T1CKI/NCO1CLK/CLCIN1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/AN3/T1G/NCO1/SDO/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/CLC1IN0/~{SS}/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/PWM2/CLCIN0/C2IN3-/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/C2IN2-/C1IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/PWM4/NCO1/C2IN1-/C1IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1507-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1507-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41586A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1507-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/~{CWG1FLT}/CLC1/T0CKI/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/NCO1CLK/T1CKI/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/~{T1G}/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC2IN1/CWG1B/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NCO1/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLCIN1/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1507-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1507-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41586A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1507-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/~{CWG1FLT}/CLC1/T0CKI/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/NCO1CLK/T1CKI/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/~{T1G}/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC2IN1/CWG1B/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NCO1/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLCIN1/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1508-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1508-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1508-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1508-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1508-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1508-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1509-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1509-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1509-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1509-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1509-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41609A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1509-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7/TX/CK/CLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6/SCL/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/AN11/RX/DT/CLC4IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4/AN10/SDA/SDI/CLC3IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C1IN2-/C2IN2-/AN6/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM4/NCO1/C1IN1-/C2IN1-/AN5/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLC2/C2IN+/AN4/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2/AN2/DACOUT2/C1OUT/T0CLKI/~{CWG1FLT}/CLC1/PWM3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/AN1/Vref+/C1IN0-/C2IN0-/CLC4IN1/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/DACOUT1/C1IN+/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5/SOSCI/T1CKI/NCO1CLK/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4/AN3/SOSCO/T1G/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/T1G/~{SS}/CLC1IN0/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM1/CLC1/CWG1A/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLC4/CLC2IN1/CWG1B/C2OUT/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PWM2/CLC2IN0/C1IN3-/AN7/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CLC3IN1/NCO1/~{SS}/AN8/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLC1IN1/SDO/AN9/RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1512-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1512-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1512-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1512-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1512-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1512-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1513-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1513-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1513-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1513-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1513-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41624A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1513-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1516-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1516-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1516-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1516-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1516-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1516-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/Vcap/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1518-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1518-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1518-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1518-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1518-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41452B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1518-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CCP1/AN14/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCK/SCL/AN15/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/AN16/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDO/AN17/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TX/CK/AN18/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RX/DT/AN19/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0/AN0/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0/AN12/INT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1/AN10/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN8/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3/AN9/CCP2/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4/AN11/ADOUT/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5/AN13/T1G/IOC',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ADGRDA/IOC/ICSPCLK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ADGRDB/IOC/ICSPDAT/ICDDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5/AN4/VCAP/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1526-IMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1526-IMR'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41458B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1526-IMR\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='AN28/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{SS1}/AN5/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN9/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN8/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AN7/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN6/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCAP/AN16/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN27/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/AN0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='RA5/AN4/T3G',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1/SOSCI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CCP3/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0/SOSCO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/TX1/CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/RX1/DT1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SCK1/SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SDI1/SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/ICSPDAT/ISCDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/OSC1/CKLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TX2/CK2/AN15/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='RB6/ICSPLCK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/AN22/T1G/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/AN21/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/AN20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/AN19',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/AN18',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/AN17/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='~{SS2}/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RX2/DT2/AN14/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SCK2/SCL2/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SDI2/SDA2/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='SDO2/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='AN26/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='AN25/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='T5CKI/AN24/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='AN23/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='CCP2/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CCP4/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='CCP6/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='CCP7/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='CCP8/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='CCP9/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='CCP10/AN29/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='Vpp/~{MCLR}/RG5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CCP5/T5G/AN12/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1527-IMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1527-IMR'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41458B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1527-IMR\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='AN28/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{SS1}/AN5/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AN11/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AN10/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN9/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN8/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AN7/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN6/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCAP/AN16/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN27/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RA3/AN3/Vref+',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/AN1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/AN0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='RA5/AN4/T3G',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/T0CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1/SOSCI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CCP3/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0/SOSCO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/TX1/CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/RX1/DT1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SCK1/SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SDI1/SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/ICSPDAT/ISCDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/OSC1/CKLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TX2/CK2/AN15/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='RB6/ICSPLCK/ICDCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/AN22/T1G/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/AN21/T3CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/AN20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/AN19',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/AN18',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/AN17/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='~{SS2}/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RX2/DT2/AN14/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SCK2/SCL2/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SDI2/SDA2/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='SDO2/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='AN26/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='AN25/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='T5CKI/AN24/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='AN23/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='CCP2/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CCP4/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='CCP6/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='CCP7/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='CCP8/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='CCP9/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='CCP10/AN29/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='Vpp/~{MCLR}/RG5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CCP5/T5G/AN12/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15376-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15376-xML'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15376-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT),
            Pin(num='45',name='PAD',func=pin_types.PWRIN),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15376-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15376-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15376-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='41',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15376-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15376-xP'}), 'ref_prefix':'U?', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15376-xP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15376-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15376-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15376-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='12',name='NC',func=pin_types.NOCONNECT),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15385-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15385-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15385-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='49',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F15385-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F15385-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F15385-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1786-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1786-xSO'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1786-xSO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1786-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1786-xSS'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1786-xSS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829-ISL'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41440C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829-ISL\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/MCLR/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829-ISO'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41440C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/MCLR/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829-ISS'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41440C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/MCLR/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1829-IST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1829-IST'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41440C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1829-IST\n\nFlash-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/MCLR/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18344-xSL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18344-xSL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001800c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18344-xSL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F18855-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F18855-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power CRC DSM  ADC^2 CLC PLL 32MHz', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001802G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F18855-xSO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power CRC DSM  ADC^2 CLC PLL 32MHz', 'pins':[
            Pin(num='19',name='VSS',func=pin_types.PASSIVE),
            Pin(num='1',name='RE3/~{MCLR}/VPP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19196-x5LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19196-x5LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19196-x5LX\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19196-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19196-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19196-xMR\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19196-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19196-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19196-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19197-x5LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19197-x5LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19197-x5LX\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19197-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19197-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19197-xMR\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F19197-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F19197-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F19197-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1937-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1937-IML'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41364E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1937-IML\n\n', 'pins':[
            Pin(num='1',name='SEG8/DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1/AN10/C12IN3-/CPS1/VLCD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2/AN8/CPS2/VLCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB3/AN9/C12IN2-/CPS3/CCP2/P2A/VLCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4/AN11/CPS4/COM0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/CPS5/CCP3/P3A/T1G/COM1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/MCLR/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/C12IN0-/C2OUT/SRNQ/SS/VCAP/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SEG17/P2D/CPS12/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1/C12IN1-/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2/C2IN+/Vref-/DACOUT/COM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/C1IN+/Vref+/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/C1OUT/CPS6/T0CKI/SRQ/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/C2OUT/CPS7/SRNQ/SS/VCAP/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SEG21/P3A/CCP3/AN5/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SEG22/P3B/AN6/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SEG23/CCP5/AN7/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SEG18/P1B/CPS13/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7/OSC1/CLKIN/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6/OSC2/CLKOUT/VCAP/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P2B/T1CLKI/T1OSO/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P2A/CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SEG3/P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SEG6/SCLK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='COM3/CPS8/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CCP4/CPS9/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG19/P1C/CPS14/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P2B/CPS10/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SEG16/P2C/CPS11/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SEG11/T1G/SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SEG10/SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='SEG9/CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG20/P1D/CPS15/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB0/AN12/CPS0/SRI/INT/SEG0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1937-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1937-IPT'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41364E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1937-IPT\n\n', 'pins':[
            Pin(num='1',name='SEG8/DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8/CPS2/VLCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/C12IN2-/CPS3/CCP2/P2A/VLCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4/AN11/CPS4/COM0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/CPS5/CCP3/P3A/T1G/COM1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/MCLR/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/C12IN0-/C2OUT/SRNQ/SS/VCAP/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SEG17/P2D/CPS12/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1/C12IN1-/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2/C2IN+/Vref-/DACOUT/COM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/C1IN+/Vref+/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/C1OUT/CPS6/T0CKI/SRQ/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/C2OUT/CPS7/SRNQ/SS/VCAP/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SEG21/P3A/CCP3/AN5/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SEG22/P3B/AN6/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SEG23/CCP5/AN7/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SEG18/P1B/CPS13/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7/OSC1/CLKIN/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6/OSC2/CLKOUT/VCAP/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P2B/T1CKI/T1OSO/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='P2A/CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SEG3/P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SEG6/SCLK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='COM3/CPS8/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CCP4/CPS9/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG19/P1C/CPS14/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P2B/CPS10/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SEG16/P2C/CPS11/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SEG11/T1G/SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SEG10/SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='SEG9/CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG20/P1D/CPS15/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB0/AN12/CPS0/SRI/INT/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10/C12IN3-/CPS1/VLCD1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1939-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1939-IML'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41364E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1939-IML\n\n', 'pins':[
            Pin(num='1',name='SEG8/DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1/AN10/C12IN3-/CPS1/VLCD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2/AN8/CPS2/VLCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB3/AN9/C12IN2-/CPS3/CCP2/P2A/VLCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4/AN11/CPS4/COM0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/CPS5/CCP3/P3A/T1G/COM1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/MCLR/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/C12IN0-/C2OUT/SRNQ/SS/VCAP/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SEG17/P2D/CPS12/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1/C12IN1-/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2/C2IN+/Vref-/DACOUT/COM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/C1IN+/Vref+/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/C1OUT/CPS6/T0CKI/SRQ/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/C2OUT/CPS7/SRNQ/SS/VCAP/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SEG21/P3A/CCP3/AN5/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SEG22/P3B/AN6/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SEG23/CCP5/AN7/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SEG18/P1B/CPS13/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7/OSC1/CLKIN/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6/OSC2/CLKOUT/VCAP/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P2B/T1CLKI/T1OSO/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P2A/CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SEG3/P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SEG6/SCLK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='COM3/CPS8/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CCP4/CPS9/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG19/P1C/CPS14/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P2B/CPS10/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SEG16/P2C/CPS11/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SEG11/T1G/SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SEG10/SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='SEG9/CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG20/P1D/CPS15/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB0/AN12/CPS0/SRI/INT/SEG0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F1939-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F1939-IPT'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41364E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F1939-IPT\n\n', 'pins':[
            Pin(num='1',name='SEG8/DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2/AN8/CPS2/VLCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3/AN9/C12IN2-/CPS3/CCP2/P2A/VLCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4/AN11/CPS4/COM0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5/AN13/CPS5/CCP3/P3A/T1G/COM1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK/ICDCLK/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT/ICDDAT/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE3/MCLR/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0/AN0/C12IN0-/C2OUT/SRNQ/SS/VCAP/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SEG17/P2D/CPS12/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1/AN1/C12IN1-/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2/AN2/C2IN+/Vref-/DACOUT/COM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3/AN3/C1IN+/Vref+/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4/C1OUT/CPS6/T0CKI/SRQ/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5/AN4/C2OUT/CPS7/SRNQ/SS/VCAP/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SEG21/P3A/CCP3/AN5/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SEG22/P3B/AN6/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SEG23/CCP5/AN7/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SEG18/P1B/CPS13/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7/OSC1/CLKIN/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6/OSC2/CLKOUT/VCAP/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P2B/T1CKI/T1OSO/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='P2A/CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SEG3/P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SEG6/SCLK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='COM3/CPS8/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CCP4/CPS9/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG19/P1C/CPS14/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P2B/CPS10/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SEG16/P2C/CPS11/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SEG11/T1G/SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SEG10/SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='SEG9/CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG20/P1D/CPS15/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB0/AN12/CPS0/SRI/INT/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1/AN10/C12IN3-/CPS1/VLCD1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F628-xxIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F628-xxIP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F628-xxIP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F628-xxISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F628-xxISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F628-xxISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F628-xxISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F628-xxISS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F628-xxISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F628A-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F628A-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F628A-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F628A-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F628A-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F628A-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F628A-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F628A-ISS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40044G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F628A-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F648A-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F648A-IP'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F648A-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F648A-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F648A-ISO'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40300c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F648A-ISO\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F648A-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F648A-ISS'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40044G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F648A-ISS\n\nFLASH-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='Vref/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSC0/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKIN/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMP1/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/CMP2/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}/Vpp/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/TX/CK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F689-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F689-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F689-IP\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F689-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F689-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F689-ISO\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F689-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F689-ISS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41262E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F689-ISS\n\nFlash-Based 8-Bit CMOS Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX/CK/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK/SCL/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RX/DT/AN11/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDI/SDA/AN10/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC2/AN6/C12IN2-',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC1/AN5/C12IN1-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC0/AN4/C2IN+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='T0CKI/INT/C1OUT/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='C12IN0-/ICSPCLK/Vref/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C1IN+/ICSPDAT/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='T1CKI/OSC1/CLKIN/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{T1G}/OSC2/CLKOUT/AN3/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC4/C2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC3/AN7/C12IN3-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC6/AN8/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC7/AN9/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F76-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F76-IML'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F76-IML\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F76-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F76-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F76-ISO\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F76-ISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F76-ISP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F76-ISP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F76-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F76-ISS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F76-ISS\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T10S0/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/CCP2/T1OSI',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F77-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F77-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30325b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F77-IP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CCP2/T1OSI/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/C1OUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F819-IML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F819-IML'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F819-IML\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F819-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F819-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F819-IP\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F819-ISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F819-ISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F819-ISO\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F819-ISS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F819-ISS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller nanoWatt', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39598F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F819-ISS\n\nFlash-Based 8-Bit Microcontroller nanoWatt', 'pins':[
            Pin(num='1',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB3/CCP1/PGM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB4/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB5/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB6/T1OSO/T1CKI/PGC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB7/T1OSI/PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CLKO/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CLKI/OSC1/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='T0CKL/AN4/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vpp/~{MCLR}/RA5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RB0/INT',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB1/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB2/SDO/CCP1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F84-XXP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F84-XXP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30430c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F84-XXP\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F84-XXSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F84-XXSO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30430c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F84-XXSO\n\nFlash-Based 8-Bit Microcontroller', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC2/CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OSC1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TOCKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F876-XXISO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F876-XXISO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30292C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F876-XXISO\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/CK/TX',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/DT/RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F876-XXISP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F876-XXISP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30292C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F876-XXISP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CKI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/CK/TX',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/DT/RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F877-XXIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F877-XXIP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/30292C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F877-XXIP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T1OSO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F877A-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F877A-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/39582b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F877A-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='T1OSO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C1OUT/T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F877A-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F877A-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', ''], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F877A-IPT\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='DT/RX/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PGM/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PGC/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PGD/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4/PSP4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='C1OUT/T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0/~{RD}/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1/~{WR}/AN6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2/~{CS}/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD5/PSP5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='T1OSO/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SCK/SCL/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0/PSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1/PSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6/PSP6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2/PSP2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3/PSP3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SDI/SDA/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='CK/TX/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7/PSP7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='INT/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F883-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F883-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41291D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F883-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/P1A/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ULPWU/C12IN0-/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/AN12/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P1C/AN10/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P1B/AN8/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/C12IN2-/AN8/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1D/AN11/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{T1G}/AN13/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C12IN1-/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/C2IN1+/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C1IN+/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/C1OUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CLKIN/OSC1/RA7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F886-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F886-IP'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41291D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F886-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CLKOUT/OSC2/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0/T1OSO/T1CK1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1/T1OSI/CCP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2/P1A/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6/TX/CK',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7/RX/DT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ULPWU/C12IN0-/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='INT/AN12/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P1C/AN10/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P1B/AN8/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGM/C12IN2-/AN8/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1D/AN11/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{T1G}/AN13/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C12IN1-/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CVref/C2IN1+/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C1IN+/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='T0CKI/C1OUT/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SS}/C2OUT/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CLKIN/OSC1/RA7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16F887-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16F887-IP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Flash-Based 8-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/41291D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16F887-IP\n\nFlash-Based 8-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/Vpp',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2/AN7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7/OSC1/CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6/OSC2/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='T10S0/T1CKI/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='T1OSI/CCP2/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P1A/CCP1/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCL/SCK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='C12IN0-/ULPWU/AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SDA/SDI/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SDO/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TX/CK/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RX/DT/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5/P1B',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6/P1C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C12IN1-/AN1/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7/P1D',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='INT/AN12/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='C12IN3-/AN10/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN8/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='C12IN2-/PGM/AN9/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AN11/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{T1G}/AN13/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='C2IN+/CVref/Vref-/AN2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C1IN+/Vref+/AN3/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C1OUT/T0CKI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='C2OUT/~{SS}/AN4/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1/AN6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15356-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15356-xML'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15356-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='29',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15356-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15356-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15356-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='29',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15356-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15356-xSO'}), 'ref_prefix':'U?', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15356-xSO\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15356-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15356-xSP'}), 'ref_prefix':'U?', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15356-xSP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15356-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15356-xSS'}), 'ref_prefix':'U?', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15356-xSS\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15375-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15375-xML'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15375-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT),
            Pin(num='45',name='PAD',func=pin_types.PWRIN),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15375-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15375-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15375-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='41',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15375-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15375-xP'}), 'ref_prefix':'U?', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15375-xP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15375-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15375-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15375-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='12',name='NC',func=pin_types.NOCONNECT),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15376-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15376-xML'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_8x8mm_P0.65mm_EP6.45x6.45mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15376-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT),
            Pin(num='45',name='PAD',func=pin_types.PWRIN),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15376-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15376-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15376-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='41',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15376-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15376-xP'}), 'ref_prefix':'U?', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15376-xP\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15376-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15376-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15376-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='12',name='NC',func=pin_types.NOCONNECT),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VPP/MCLR/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN0/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15385-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15385-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15385-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='49',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15385-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15385-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15385-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15386-xMV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15386-xMV'}), 'ref_prefix':'U?', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.6x4.6mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15386-xMV\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='49',name='PAD',func=pin_types.PWRIN),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF15386-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF15386-xPT'}), 'ref_prefix':'U?', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF15356-75-76-85-86-Data%20Sheet-40001866B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF15386-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='3',name='RD5',func=pin_types.BIDIR),
            Pin(num='4',name='RD6',func=pin_types.BIDIR),
            Pin(num='1',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VPP/~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1786-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1786-xML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1786-xML\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1786-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1786-xP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1786-xP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1786-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1786-xSO'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1786-xSO\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1786-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1786-xSP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1786-xSP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1786-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1786-xSS'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001637C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1786-xSS\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='RE3/~{MCLR}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ICSPCLK/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ICSPDAT/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF18325-ISL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF18325-ISL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/40001795b.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF18325-ISL\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL1/SCK/T5CKI/C2IN0+/ANC0/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA2/ANA2/Vref-/DAC1Ref-/T0CKI/CCP3/CWG1IN/CWG2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA1/ANA1/Vref+/C1IN0-/C2IN0-/DAC1Ref+/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA0/ANA0/C1IN0+/DAC1OUT/~{SS2}/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA5/ANA5/T1CKI/SOSCIN/SOSCI/CLCIN3/CLKIN/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA4/ANA4/T1G/SOSCO/CLKOUT/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DT/RX/SDA2/SDI2/CCP1/T3CKI/MDCIN2/ANC5/RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLCIN1/SCL2/SCK2/T3G/ANC4/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CLCIN0/~{SS1}/CCP2/T5G/MDMIN/C2IN3-/C1IN3-/ANC3/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='MDCIN1/C2IN2-/C1IN2-/ANC2/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLCIN2/SDA1/SDI/CCP4/C2IN1-/C1IN1-/ANC1/RC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF18325-xGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF18325-xGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm', 'Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm'], 'footprint':'Package_DFN_QFN:UQFN-20-1EP_4x4mm_P0.5mm_EP2.8x2.8mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001795E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF18325-xGZ\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA3/~{MCLR}/VPP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF18325-xJQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF18325-xJQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-16-1EP_4x4mm_P0.65mm_EP2.6x2.6mm', 'Package_DFN_QFN:UQFN-16-1EP_4x4mm_P0.65mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:UQFN-16-1EP_4x4mm_P0.65mm_EP2.6x2.6mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001795E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF18325-xJQ\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RA1/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA0/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA3/~{MCLR}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF1907-IP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF1907-IP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller XLP', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/OTH/ProductDocuments/DataSheets/40001569D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF1907-IP\n\nFLASH-Based 8-Bit CMOS Microcontroller XLP', 'pins':[
            Pin(num='1',name='~{MCLR}/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RB6/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RB7/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19195-x5LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19195-x5LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19195-x5LX\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19195-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19195-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19195-xMR\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19195-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19195-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19195-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19196-x5LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19196-x5LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19196-x5LX\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19196-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19196-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19196-xMR\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19196-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19196-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19196-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19197-x5LX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19197-x5LX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:VQFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19197-x5LX\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19197-xMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19197-xMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19197-xMR\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC16LF19197-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC16LF19197-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'FLASH-Based 8-Bit CMOS Microcontroller Low Power', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC16LF19195-6-7-Data-Sheet-40001873D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC16.kicad_sym\nPIC16LF19197-xPT\n\nFLASH-Based 8-Bit CMOS Microcontroller Low Power', 'pins':[
            Pin(num='1',name='VLCD2/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SEG25/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SEG24/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SEG23/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SEG22/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SEG21/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SEG20/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SEG19/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SEG41/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='COM7/SEG15/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VLCD1/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='COM6/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA3/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA2/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RA0/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='COM5/RH1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='COM4/RH0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA4/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SEG42/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RC6/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RC7/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC2/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC3/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC4/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RC5/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RB7/SEG39/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RA7/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SEG43/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RA6/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RB6/SEG38/ICSPCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB5/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB4/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RB3/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RB2/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RB1/SEG8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RB0/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD7/SEG7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SEG44/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD6/SEG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD5/SEG5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4/SEG4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD3/SEG3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD2/SEG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD1/SEG1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CFLY2/SEG40/RH3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CFLY1/SEG32/RH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RD0/SEG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SEG31/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SEG45/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='COM3/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='COM2/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='COM1/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='COM0/RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VLCD3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VPP/~{MCLR}/RG5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SEG26/RG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])