from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Reference_Voltage = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD586', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD586'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD586.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nAD586\n\nvoltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR1399KEZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR1399KEZ'}), 'ref_prefix':'U', 'fplist':['Package_LCC:Analog_LCC-8_5x5mm_P1.27mm'], 'footprint':'Package_LCC:Analog_LCC-8_5x5mm_P1.27mm', 'keywords':'Zener diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr1399.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR1399KEZ\n\nZener diode device voltage reference', 'pins':[
            Pin(num='1',name='-REFS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-REFF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='HEATER+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='HEATER-',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='+REFF',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='+REFS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR1399KHZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR1399KHZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:Analog_TO-46-4_ThermalShield'], 'footprint':'Package_TO_SOT_THT:Analog_TO-46-4_ThermalShield', 'keywords':'Zener diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr1399.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR1399KHZ\n\nZener diode device voltage reference', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR420ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR420ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr420_421_423_425.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR420ARMZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT),
            Pin(num='2',name='VIN',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='TP',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR440ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR440ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR440ARMZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CJ432', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CJ432'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.cj-elec.com/txUpfile/20134181474991806.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nCJ432\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISL21070DIH306Z-TK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISL21070DIH306Z-TK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'Micropower Voltage Reference 0.6V', 'description':'', 'datasheet':'http://www.intersil.com/content/dam/Intersil/documents/fn75/fn7599.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nISL21070DIH306Z-TK\n\nMicropower Voltage Reference 0.6V', 'pins':[
            Pin(num='1',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285D-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285D-1.2'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285D-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285M-ADJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285M-ADJ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm185-adj.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285M-ADJ\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285S-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285S-1.2'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/185fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285S-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285Z-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285Z-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285Z-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285Z-ADJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285Z-ADJ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm185-adj.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285Z-ADJ\n\ndiode device voltage reference', 'pins':[
            Pin(num='1',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM329xZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM329xZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/129329fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM329xZ\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM399', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM399'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:Analog_TO-46-4_ThermalShield'], 'footprint':'Package_TO_SOT_THT:Analog_TO-46-4_ThermalShield', 'keywords':'Zener diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/199399fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM399\n\nZener diode device voltage reference', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4030-4.096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4030-4.096'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4030-4.096\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-2.0'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-2.0\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-2.0'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-2.0\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-2.0'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-2.0\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4041LP-ADJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4041LP-ADJ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4041-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4041LP-ADJ\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4125AIM5-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4125AIM5-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Micropower Low Dropout Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4125.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4125AIM5-2.5\n\nPrecision Micropower Low Dropout Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4128', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4128'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Micropower Low Dropout Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4128.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4128\n\nPrecision Micropower Low Dropout Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4132xMF-1.8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4132xMF-1.8'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Low Dropout Voltage Reference 1.8V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4132.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4132xMF-1.8\n\nPrecision Low Dropout Voltage Reference 1.8V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1009xS8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1009xS8'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1009.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1009xS8\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1019xN8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1019xN8'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1019fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1019xN8\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461AxS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461AxS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461AxS8-2.5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634BCMS8-1.25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634BCMS8-1.25'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634BCMS8-1.25\n\nvoltage reference Micropower', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634CCZ-1.25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634CCZ-1.25'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634CCZ-1.25\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634xxS8-1.25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634xxS8-1.25'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634xxS8-1.25\n\nvoltage reference Micropower', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-1.25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-1.25'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-1.25\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657AHMS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657AHMS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657AHMS8-2.5\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6035xSA25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6035xSA25'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6035.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6035xSA25\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT12+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT12+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max6070-max6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT12+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT12+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT12+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max6070-max6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT12+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6100'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6100\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6350'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'precision voltage reference', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6325-MAX6350.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6350\n\nprecision voltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX874', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX874'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Low-Dropout Precision Voltage Reference', 'description':'', 'datasheet':'https://pdfserv.maximintegrated.com/en/ds/MAX872-MAX874.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX874\n\nLow-Dropout Precision Voltage Reference', 'pins':[
            Pin(num='1',name='IC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temper',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='IC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COMP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-10xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-10xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 1.024V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-10xCH\n\nprecision buffered voltage reference 1.024V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-10xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-10xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 1.024V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-10xRW\n\nprecision buffered voltage reference 1.024V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-10xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-10xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 1.024V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-10xSN\n\nprecision buffered voltage reference 1.024V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1525-TO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1525-TO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'Voltage Reference 2.5V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21653b.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1525-TO\n\nVoltage Reference 2.5V', 'pins':[
            Pin(num='1',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='Vin',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1525-TT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1525-TT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'Voltage Reference 2.5V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21653b.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1525-TT\n\nVoltage Reference 2.5V', 'pins':[
            Pin(num='1',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='Vss',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02AP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02AP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02AP\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF102AP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF102AP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref102.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF102AP\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF102AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF102AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF102AU\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF191', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF191'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF191\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF2025', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF2025'}), 'ref_prefix':'U?', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref2033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF2025\n\nvoltage reference', 'pins':[
            Pin(num='1',name='Vbias',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vref',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3012', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3012'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3012\n\nvoltage reference', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3212AMDBVREP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3212AMDBVREP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Micropower Precision Voltage Reference 1.25V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3240-ep.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3212AMDBVREP\n\nMicropower Precision Voltage Reference 1.25V', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5020AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5020AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 2.048V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5020AD\n\nLow Noise Precision Voltage Reference 2.048V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5020ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5020ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 2.048V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5020ADGK\n\nLow Noise Precision Voltage Reference 2.048V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF6025xDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF6025xDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'low Noise precision voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref6025.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF6025xDGK\n\nlow Noise precision voltage reference', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND_F',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND_S',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431D\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431DBV\n\ndiode device shunt regulator', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431DBZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431DBZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431DBZ\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431DCK\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431KTP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431KTP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TO-252-2'], 'footprint':'Package_TO_SOT_SMD:TO-252-2', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/760499.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431KTP\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431LP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431LP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device regulator shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431LP\n\ndiode device regulator shunt', 'pins':[
            Pin(num='1',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431P\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431PK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431PK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-89-3'], 'footprint':'Package_TO_SOT_SMD:SOT-89-3', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431PK\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431PS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431PS'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431PS\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL431PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL431PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL431PW\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL432DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL432DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL432DBV\n\ndiode device shunt regulator', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL432DBZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL432DBZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL432DBZ\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL432PK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL432PK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-89-3'], 'footprint':'Package_TO_SOT_SMD:SOT-89-3', 'keywords':'diode device shunt regulator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl431.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTL432PK\n\ndiode device shunt regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLE2425xD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLE2425xD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Rail splitter precision virtual ground 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tle2425.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTLE2425xD\n\nRail splitter precision virtual ground 2.5V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='COMMON',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLE2426xD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLE2426xD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Rail splitter precision virtual ground', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tle2426.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTLE2426xD\n\nRail splitter precision virtual ground', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='COMMON',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NOISE_REDUCTION',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLE2426xLP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLE2426xLP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Rail splitter precision virtual ground', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tle2426.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTLE2426xLP\n\nRail splitter precision virtual ground', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='COMMON',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLE2426xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLE2426xP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Rail splitter precision vitrual ground', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tle2426.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTLE2426xP\n\nRail splitter precision vitrual ground', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='COMMON',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NOISE_REDUCTION',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR421ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR421ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'2.5V voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr420_421_423_425.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR421ARMZ\n\n2.5V voltage reference', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT),
            Pin(num='2',name='VIN',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='TP',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR423ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR423ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'3V voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr420_421_423_425.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR423ARMZ\n\n3V voltage reference', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT),
            Pin(num='2',name='VIN',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='TP',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR425ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR425ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'5V voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr420_421_423_425.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR425ARMZ\n\n5V voltage reference', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT),
            Pin(num='2',name='VIN',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='TP',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR440xRZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR440xRZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR440xRZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR441ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR441ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR441ARMZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR441xRZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR441xRZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR441xRZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR443ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR443ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR443ARMZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR443xRZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR443xRZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR443xRZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR444ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR444ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR444ARMZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR444xRZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR444xRZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR444xRZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR445ARMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR445ARMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR445ARMZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR445xRZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR445xRZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Ultraprecision Low Noise', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/adr440_441_443_444_445.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR445xRZ\n\nvoltage reference Ultraprecision Low Noise', 'pins':[
            Pin(num='2',name='V_{IN}',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE),
            Pin(num='6',name='V_{OUT}',func=pin_types.OUTPUT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR4520', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR4520'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADR4520_4525_4530_4533_4540_4550.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR4520\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR4525', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR4525'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADR4520_4525_4530_4533_4540_4550.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR4525\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR4530', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR4530'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADR4520_4525_4530_4533_4540_4550.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR4530\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR4533', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR4533'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADR4520_4525_4530_4533_4540_4550.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR4533\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR4540', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR4540'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADR4520_4525_4530_4533_4540_4550.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR4540\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADR4550', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADR4550'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADR4520_4525_4530_4533_4540_4550.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nADR4550\n\nvref', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISL21070CIH320Z-TK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISL21070CIH320Z-TK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'Micropower Voltage Reference 2.0V', 'description':'', 'datasheet':'http://www.intersil.com/content/dam/Intersil/documents/fn75/fn7599.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nISL21070CIH320Z-TK\n\nMicropower Voltage Reference 2.0V', 'pins':[
            Pin(num='1',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISL21070CIH325Z-TK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISL21070CIH325Z-TK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'Micropower Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.intersil.com/content/dam/Intersil/documents/fn75/fn7599.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nISL21070CIH325Z-TK\n\nMicropower Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285D-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285D-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285D-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285S-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285S-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/185fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285S-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM285Z-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM285Z-1.2'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM285Z-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385BZ-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385BZ-1.2'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385BZ-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385BZ-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385BZ-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385BZ-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385D-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385D-1.2'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385D-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385D-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385D-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385D-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385M-ADJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385M-ADJ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm185-adj.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385M-ADJ\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385S-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385S-1.2'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/185fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385S-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385S-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385S-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/185fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385S-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385Z-1.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385Z-1.2'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385Z-1.2\n\ndiode device voltage reference', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385Z-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385Z-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/LM285-D.PDF', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385Z-2.5\n\ndiode device voltage reference', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM385Z-ADJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM385Z-ADJ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm185-adj.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM385Z-ADJ\n\ndiode device voltage reference', 'pins':[
            Pin(num='1',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4030-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4030-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4030-2.5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-10'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-10\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-2.5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-3\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-4.1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-4.1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-4.1\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DBZ-8.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DBZ-8.2'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DBZ-8.2\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-10'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-10\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-2.5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-3\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-4.1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-4.1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-4.1\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040DCK-8.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040DCK-8.2'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040DCK-8.2\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-10'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-10\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-2.5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-3\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-4.1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-4.1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-4.1\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-5\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4040LP-8.2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4040LP-8.2'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference shunt', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4040-n.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4040LP-8.2\n\ndiode device voltage reference shunt', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4125IM5-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4125IM5-2.0'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Micropower Low Dropout Voltage Reference 2V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4125.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4125IM5-2.0\n\nPrecision Micropower Low Dropout Voltage Reference 2V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4125IM5-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4125IM5-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Micropower Low Dropout Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4125.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4125IM5-2.5\n\nPrecision Micropower Low Dropout Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4132xMF-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4132xMF-2.0'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Low Dropout Voltage Reference 2.048V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4132.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4132xMF-2.0\n\nPrecision Low Dropout Voltage Reference 2.048V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4132xMF-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4132xMF-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Low Dropout Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4132.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4132xMF-2.5\n\nPrecision Low Dropout Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4132xMF-3.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4132xMF-3.0'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Low Dropout Voltage Reference 3.0V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4132.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4132xMF-3.0\n\nPrecision Low Dropout Voltage Reference 3.0V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4132xMF-3.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4132xMF-3.3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Low Dropout Voltage Reference 3.3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4132.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4132xMF-3.3\n\nPrecision Low Dropout Voltage Reference 3.3V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4132xMF-4.1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4132xMF-4.1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'Precision Low Dropout Voltage Reference 4.096V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4132.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLM4132xMF-4.1\n\nPrecision Low Dropout Voltage Reference 4.096V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1009CMS8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1009CMS8'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'diode device voltage reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1009.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1009CMS8\n\ndiode device voltage reference', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1009xZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1009xZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92L_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'diode device voltage reference LT1009CZ LT1009IZ', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1009.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1009xZ\n\ndiode device voltage reference LT1009CZ LT1009IZ', 'pins':[
            Pin(num='1',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461AxS8-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461AxS8-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461AxS8-3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461AxS8-3.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461AxS8-3.3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461AxS8-3.3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461AxS8-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461AxS8-4'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461AxS8-4\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461AxS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461AxS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461AxS8-5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461BxS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461BxS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461BxS8-2.5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461BxS8-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461BxS8-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461BxS8-3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461BxS8-3.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461BxS8-3.3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461BxS8-3.3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461BxS8-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461BxS8-4'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461BxS8-4\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461BxS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461BxS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461BxS8-5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461CxS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461CxS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461CxS8-2.5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461CxS8-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461CxS8-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461CxS8-3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461CxS8-3.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461CxS8-3.3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461CxS8-3.3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461CxS8-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461CxS8-4'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461CxS8-4\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461CxS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461CxS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461CxS8-5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461DxS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461DxS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461DxS8-2.5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461DxS8-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461DxS8-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461DxS8-3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461DxS8-3.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461DxS8-3.3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461DxS8-3.3\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461DxS8-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461DxS8-4'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461DxS8-4\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1461DxS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1461DxS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference precision', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/LT1461.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1461DxS8-5\n\nvoltage reference precision', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634BCMS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634BCMS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634BCMS8-2.5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634CCZ-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634CCZ-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634CCZ-2.5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634CCZ-4.096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634CCZ-4.096'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634CCZ-4.096\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634CCZ-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634CCZ-5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634CCZ-5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634xxS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634xxS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634xxS8-2.5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634xxS8-4.096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634xxS8-4.096'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634xxS8-4.096\n\nvoltage reference Micropower', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1634xxS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1634xxS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1634ff.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1634xxS8-5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Test',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-2.048', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-2.048'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-2.048\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-2.5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-2.5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-3\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-3.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-3.3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-3.3\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-4.096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-4.096'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-4.096\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1790-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1790-5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'voltage reference Micropower', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1790fc.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT1790-5\n\nvoltage reference Micropower', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vout',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657AHMS8-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657AHMS8-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657AHMS8-3\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657AHMS8-4.096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657AHMS8-4.096'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657AHMS8-4.096\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657AHMS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657AHMS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657AHMS8-5\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657BHMS8-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657BHMS8-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657BHMS8-2.5\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657BHMS8-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657BHMS8-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657BHMS8-3\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657BHMS8-4.096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657BHMS8-4.096'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657BHMS8-4.096\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT6657BHMS8-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT6657BHMS8-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'voltage reference vref', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6657fd.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nLT6657BHMS8-5\n\nvoltage reference vref', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6001'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6001-MAX6005.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6001\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6002'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6001-MAX6005.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6002\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6003'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6001-MAX6005.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6003\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6004', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6004'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6001-MAX6005.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6004\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6005'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6001-MAX6005.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6005\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6035xxUR25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6035xxUR25'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'vref', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6035.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6035xxUR25\n\nvref', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6035xxUR30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6035xxUR30'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'vref', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6035.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6035xxUR30\n\nvref', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6035xxUR50', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6035xxUR50'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'vref', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6035.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6035xxUR50\n\nvref', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT18+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT18+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max6070-max6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT18+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT18V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT18V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070AAUT18/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max6070-max6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT18V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070AAUT18/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT21+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT21+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT21+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT25+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT25+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT25+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT30+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT30+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT30+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT33+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT33+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT33+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT33V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT33V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070AAUT33/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT33V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070AAUT33/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT41+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT41+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT41+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT50+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT50+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT50+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070AAUT50V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070AAUT50V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070AAUT50/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070AAUT50V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070AAUT50/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT12+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT12+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT12+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT12V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT12V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT12/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT12V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT12/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT18+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT18+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT18+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT21+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT21+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT21+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT21V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT21V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT21/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT21V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT21/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT25+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT25+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT25+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT25V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT25V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT25/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT25V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT25/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT30+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT30+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT30+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT33+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT33+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT33+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT33V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT33V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT33/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT33V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT33/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT41+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT41+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT41+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT41V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT41V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT41/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT41V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT41/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT50+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT50+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT50+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070BAUT50V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070BAUT50V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT50/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070BAUT50V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070BAUT50/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070DAUT12V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070DAUT12V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT12/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070DAUT12V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT12/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070DAUT25V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070DAUT25V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT25/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070DAUT25V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT25/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070DAUT30V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070DAUT30V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT30/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070DAUT30V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT30/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6070DAUT41V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6070DAUT41V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT41/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6070DAUT41V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6070DAUT41/V+T', 'pins':[
            Pin(num='1',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT18+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT18+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT18+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT21+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT21+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT21+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT25+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT25+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT25+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT30+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT30+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT30+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT30V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT30V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6071AAUT30/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT30V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6071AAUT30/V+T', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT33+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT33+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT33+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT41+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT41+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT41+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071AAUT50+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071AAUT50+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071AAUT50+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT12+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT12+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT12+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT18+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT18+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT18+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT21+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT21+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT21+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT25+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT25+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT25+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT25V+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT25V+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference AEC-Q100 MAX6071BAUT25/V+T', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT25V+T\n\nLow Noise Precision Voltage Reference AEC-Q100 MAX6071BAUT25/V+T', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT30+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT30+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT30+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT33+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT33+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT33+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT41+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT41+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT41+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6071BAUT50+T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6071BAUT50+T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Low Noise Precision Voltage Reference', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/MAX6070-MAX6071.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6071BAUT50+T\n\nLow Noise Precision Voltage Reference', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTF',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6101'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6101\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6102'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6102\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6103', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6103'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6103\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6104', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6104'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6104\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6105', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6105'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6105\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6106', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6106'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6106\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6107', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6107'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference ldo', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6100-MAX6107.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6107\n\nvoltage reference ldo', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6225', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6225'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'precision voltage reference', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6225-MAX6250.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6225\n\nprecision voltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6241'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'precision voltage reference', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6225-MAX6250.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6241\n\nprecision voltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6250', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6250'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'precision voltage reference', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6225-MAX6250.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6250\n\nprecision voltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6325', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6325'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'precision voltage reference', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6325-MAX6350.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6325\n\nprecision voltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6341', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6341'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'precision voltage reference', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX6325-MAX6350.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX6341\n\nprecision voltage reference', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX872', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX872'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Low-Dropout Precision Voltage Reference', 'description':'', 'datasheet':'https://pdfserv.maximintegrated.com/en/ds/MAX872-MAX874.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMAX872\n\nLow-Dropout Precision Voltage Reference', 'pins':[
            Pin(num='1',name='IC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temper',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='IC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COMP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-12xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-12xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 1.25V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-12xCH\n\nprecision buffered voltage reference 1.25V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-12xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-12xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 1.25V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-12xRW\n\nprecision buffered voltage reference 1.25V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-12xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-12xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 1.25V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-12xSN\n\nprecision buffered voltage reference 1.25V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-18xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-18xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 1.8V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-18xCH\n\nprecision buffered voltage reference 1.8V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-18xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-18xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 1.8V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-18xRW\n\nprecision buffered voltage reference 1.8V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-18xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-18xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 1.8V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-18xSN\n\nprecision buffered voltage reference 1.8V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-20xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-20xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 2.048V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-20xCH\n\nprecision buffered voltage reference 2.048V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-20xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-20xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 2.048V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-20xRW\n\nprecision buffered voltage reference 2.048V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-20xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-20xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 2.048V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-20xSN\n\nprecision buffered voltage reference 2.048V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-25xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-25xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 2.5V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-25xCH\n\nprecision buffered voltage reference 2.5V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-25xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-25xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 2.5V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-25xRW\n\nprecision buffered voltage reference 2.5V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-25xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-25xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 2.5V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-25xSN\n\nprecision buffered voltage reference 2.5V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-30xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-30xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 3V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-30xCH\n\nprecision buffered voltage reference 3V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-30xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-30xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 3V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-30xRW\n\nprecision buffered voltage reference 3V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-30xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-30xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 3V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-30xSN\n\nprecision buffered voltage reference 3V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-33xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-33xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 3.3V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-33xCH\n\nprecision buffered voltage reference 3.3V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-33xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-33xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 3.3V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-33xRW\n\nprecision buffered voltage reference 3.3V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-33xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-33xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 3.3V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-33xSN\n\nprecision buffered voltage reference 3.3V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-40xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-40xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'precision buffered voltage reference 4.096V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-40xCH\n\nprecision buffered voltage reference 4.096V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='VDD',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-40xRW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-40xRW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2mm_P0.5mm_EP0.8x1.2mm', 'keywords':'precision buffered voltage reference 4.096V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-40xRW\n\nprecision buffered voltage reference 4.096V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1501-40xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1501-40xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'precision buffered voltage reference 4.096V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005474E.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1501-40xSN\n\nprecision buffered voltage reference 4.096V', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT),
            Pin(num='4',name='GND',func=pin_types.PASSIVE),
            Pin(num='5',name='GND',func=pin_types.PASSIVE),
            Pin(num='6',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='OUT',func=pin_types.PWROUT),
            Pin(num='8',name='FB',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1541-TO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1541-TO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'Voltage Reference 4.096V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21653b.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1541-TO\n\nVoltage Reference 4.096V', 'pins':[
            Pin(num='1',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='Vin',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1541-TT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1541-TT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'Voltage Reference 4.096V', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21653b.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nMCP1541-TT\n\nVoltage Reference 4.096V', 'pins':[
            Pin(num='1',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='Vss',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF01CP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF01CP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF01CP\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF01CS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF01CS'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF01CS\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF01EZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF01EZ'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF01EZ\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF01HP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF01HP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF01HP\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF01HZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF01HZ'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF01HZ\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02AU'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02AU\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02AZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02AZ'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02AZ\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02BP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02BP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02BP\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02BU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02BU'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02BU\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02CP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02CP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02CP\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02CS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02CS'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02CS\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02EZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02EZ'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02EZ\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02HP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02HP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02HP\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02HS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02HS'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02HS\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02HZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02HZ'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02HZ\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF02Z', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF02Z'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF02Z\n\nPrecision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF03GP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF03GP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF03GP\n\nPrecision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF03GS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF03GS'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/REF01_02_03.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF03GS\n\nPrecision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF102BP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF102BP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref102.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF102BP\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF102BU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF102BU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF102BU\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF102CP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF102CP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref102.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF102CP\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF102CU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF102CU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref02.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF102CU\n\nPrecision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TEMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NR',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF192', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF192'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF192\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF193', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF193'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF193\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF194', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF194'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF194\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF195', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF195'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF195\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF196', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF196'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF196\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF198', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF198'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Precision voltage references', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/REF19xSeries.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF198\n\nPrecision voltage references', 'pins':[
            Pin(num='1',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Sleep}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF2030', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF2030'}), 'ref_prefix':'U?', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref2033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF2030\n\nvoltage reference', 'pins':[
            Pin(num='1',name='Vbias',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vref',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF2033', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF2033'}), 'ref_prefix':'U?', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref2033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF2033\n\nvoltage reference', 'pins':[
            Pin(num='1',name='Vbias',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vref',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF2041', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF2041'}), 'ref_prefix':'U?', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref2033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF2041\n\nvoltage reference', 'pins':[
            Pin(num='1',name='Vbias',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Vref',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3020', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3020'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3020\n\nvoltage reference', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3025', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3025'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3025\n\nvoltage reference', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3030', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3030'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3030\n\nvoltage reference', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3033', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3033'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3033\n\nvoltage reference', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3040', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3040'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'voltage reference', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3033.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3040\n\nvoltage reference', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3220AMDBVREP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3220AMDBVREP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Micropower Precision Voltage Reference 2.048V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3240-ep.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3220AMDBVREP\n\nMicropower Precision Voltage Reference 2.048V', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3225AMDBVREP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3225AMDBVREP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Micropower Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3240-ep.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3225AMDBVREP\n\nMicropower Precision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3230AMDBVREP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3230AMDBVREP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Micropower Precision Voltage Reference 3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3240-ep.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3230AMDBVREP\n\nMicropower Precision Voltage Reference 3V', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3233AMDBVREP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3233AMDBVREP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Micropower Precision Voltage Reference 3.3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3240-ep.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3233AMDBVREP\n\nMicropower Precision Voltage Reference 3.3V', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF3240AMDBVREP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF3240AMDBVREP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Micropower Precision Voltage Reference 4.096V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref3240-ep.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF3240AMDBVREP\n\nMicropower Precision Voltage Reference 4.096V', 'pins':[
            Pin(num='1',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GNDS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5010AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5010AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5010AD\n\nLow Noise Precision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5010ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5010ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5010ADGK\n\nLow Noise Precision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5010ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5010ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5010ID\n\nLow Noise Precision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5010IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5010IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 10V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5010IDGK\n\nLow Noise Precision Voltage Reference 10V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5020ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5020ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 2.048V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5020ID\n\nLow Noise Precision Voltage Reference 2.048V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5020IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5020IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 2.048V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5020IDGK\n\nLow Noise Precision Voltage Reference 2.048V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5025AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5025AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5025AD\n\nLow Noise Precision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5025ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5025ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5025ADGK\n\nLow Noise Precision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5025ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5025ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5025ID\n\nLow Noise Precision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5025IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5025IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5025IDGK\n\nLow Noise Precision Voltage Reference 2.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5030AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5030AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5030AD\n\nLow Noise Precision Voltage Reference 3V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5030ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5030ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5030ADGK\n\nLow Noise Precision Voltage Reference 3V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5030ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5030ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5030ID\n\nLow Noise Precision Voltage Reference 3V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5030IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5030IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 3V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5030IDGK\n\nLow Noise Precision Voltage Reference 3V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5040AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5040AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 4.096V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5040AD\n\nLow Noise Precision Voltage Reference 4.096V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5040ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5040ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 4.096V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5040ADGK\n\nLow Noise Precision Voltage Reference 4.096V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5040ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5040ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 4.096V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5040ID\n\nLow Noise Precision Voltage Reference 4.096V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5040IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5040IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 4.096V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5040IDGK\n\nLow Noise Precision Voltage Reference 4.096V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5045AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5045AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 4.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5045AD\n\nLow Noise Precision Voltage Reference 4.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5045ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5045ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 4.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5045ADGK\n\nLow Noise Precision Voltage Reference 4.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5045ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5045ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 4.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5045ID\n\nLow Noise Precision Voltage Reference 4.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5045IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5045IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 4.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5045IDGK\n\nLow Noise Precision Voltage Reference 4.5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5050AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5050AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5050AD\n\nLow Noise Precision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5050ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5050ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5050ADGK\n\nLow Noise Precision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5050ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5050ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Low Noise Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5050ID\n\nLow Noise Precision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF5050IDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF5050IDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Low Noise Precision Voltage Reference 5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ref5030.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF5050IDGK\n\nLow Noise Precision Voltage Reference 5V', 'pins':[
            Pin(num='1',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Temp',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Trim/NR',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF6030xDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF6030xDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'low Noise precision voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref6025.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF6030xDGK\n\nlow Noise precision voltage reference', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND_F',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND_S',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF6033xDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF6033xDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'low Noise precision voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref6025.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF6033xDGK\n\nlow Noise precision voltage reference', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND_F',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND_S',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF6041xDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF6041xDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'low Noise precision voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref6025.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF6041xDGK\n\nlow Noise precision voltage reference', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND_F',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND_S',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF6045xDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF6045xDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'low Noise precision voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref6025.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF6045xDGK\n\nlow Noise precision voltage reference', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND_F',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND_S',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'REF6050xDGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'REF6050xDGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'low Noise precision voltage reference', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ref6025.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nREF6050xDGK\n\nlow Noise precision voltage reference', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_S',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND_F',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND_S',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLE2425xLP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLE2425xLP'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Rail splitter precision virtual ground 2.5V', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tle2425.pdf', 'search_text':'/usr/share/kicad/symbols/Reference_Voltage.kicad_sym\nTLE2425xLP\n\nRail splitter precision virtual ground 2.5V', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='COMMON',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])