from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

FPGA_Xilinx_Spartan6 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'XC6SLX100-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100-CSG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L14N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L14P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L12P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L12N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L11P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L11N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L13P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L13N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F8',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G8',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='D14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='T15',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J20',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='RFUSE',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U17',name='VBATT',func=pin_types.PWRIN,unit=4),
            Pin(num='U19',name='VFS',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G11', 'A7', 'K19', 'R15', 'AA22', 'D19', 'G13', 'R16', 'K20', 'B6', 'B10', 'D20', 'G14', 'K21', 'R17', 'B7', 'D21', 'G15', 'K22', 'R19', 'AA20', 'V22', 'D22', 'G16', 'L15', 'R20', 'AB20', 'A8', 'A9', 'D6', 'G17', 'L16', 'R21', 'D7', 'G19', 'L17', 'R22', 'AB21', 'AA19', 'D8', 'G20', 'L19', 'T17', 'V18', 'A14', 'B8', 'D9', 'G21', 'L20', 'T18', 'C10', 'V19', 'E10', 'G22', 'A13', 'L21', 'T19', 'B4', 'C11', 'E12', 'G9', 'L22', 'T20', 'C12', 'E13', 'H10', 'M16', 'T21', 'A11', 'A5', 'C13', 'B20', 'E17', 'H11', 'B22', 'M17', 'T22', 'B3', 'C14', 'W20', 'E19', 'H12', 'M18', 'U18', 'B21', 'W21', 'C15', 'E20', 'H13', 'W22', 'M19', 'A21', 'Y19', 'C16', 'E22', 'H14', 'A4', 'M20', 'Y20', 'C17', 'E8', 'H16', 'Y21', 'M21', 'C18', 'Y22', 'E9', 'H17', 'M22', 'C19', 'V20', 'F10', 'H18', 'N15', 'C20', 'F12', 'H19', 'N16', 'C21', 'A18', 'AA21', 'B19', 'F13', 'H20', 'N18', 'A15', 'C22', 'A6', 'F14', 'H21', 'N19', 'V17', 'C5', 'F15', 'H22', 'N20', 'C6', 'F16', 'J16', 'B18', 'N22', 'B16', 'C7', 'F17', 'J17', 'A17', 'P15', 'C8', 'A16', 'F18', 'J18', 'P16', 'C9', 'U22', 'A19', 'B11', 'F19', 'J19', 'B14', 'P17', 'A12', 'B15', 'D10', 'V21', 'F20', 'J21', 'P18', 'A10', 'B12', 'D11', 'F21', 'J22', 'P19', 'D12', 'F22', 'K16', 'P20', 'A20', 'D13', 'D17', 'F9', 'K17', 'P21', 'U20', 'D15', 'AB19', 'G10', 'K18', 'P22']},{'label': 'uB', 'num': 2, 'pin_nums': ['F4', 'K8', 'R2', 'V1', 'Y14', 'AB14', 'F5', 'R3', 'L1', 'Y15', 'V11', 'AB15', 'F6', 'L2', 'R4', 'V12', 'Y16', 'AB16', 'F7', 'L3', 'R7', 'V13', 'Y17', 'AB17', 'F8', 'L4', 'R8', 'V15', 'Y18', 'AB18', 'G1', 'L6', 'R9', 'V16', 'Y2', 'AB2', 'G2', 'L7', 'T1', 'V2', 'Y3', 'AB3', 'G3', 'T10', 'M1', 'V3', 'Y4', 'AB4', 'G4', 'M2', 'T11', 'V5', 'Y5', 'AB5', 'G6', 'M3', 'T12', 'V7', 'Y6', 'AB6', 'G7', 'M4', 'T13', 'V8', 'Y7', 'AB7', 'G8', 'M5', 'T14', 'V9', 'Y8', 'AB8', 'H1', 'M6', 'T2', 'W1', 'Y9', 'AB9', 'H2', 'M7', 'T3', 'W10', 'B1', 'H3', 'M8', 'T4', 'W11', 'B2', 'H4', 'N1', 'T5', 'W12', 'C1', 'H5', 'N3', 'T6', 'W13', 'C2', 'H6', 'N4', 'T7', 'A2', 'W14', 'C3', 'H8', 'A3', 'N5', 'T8', 'W15', 'AA10', 'C4', 'J1', 'N6', 'T9', 'W17', 'AA11', 'D1', 'J3', 'N7', 'U1', 'AA12', 'W2', 'D2', 'J4', 'AA14', 'P1', 'U10', 'W3', 'AA15', 'D3', 'J5', 'P2', 'U12', 'W4', 'AA16', 'D5', 'J6', 'P3', 'U13', 'AA18', 'W5', 'E1', 'J7', 'AA2', 'P4', 'U14', 'W6', 'AA3', 'E3', 'K1', 'P5', 'U15', 'W8', 'AA4', 'E4', 'K2', 'P6', 'U3', 'AA6', 'W9', 'E5', 'K3', 'AA7', 'P7', 'U4', 'Y1', 'AA8', 'E6', 'K4', 'P8', 'U5', 'Y10', 'AB10', 'F1', 'K5', 'R1', 'U6', 'Y11', 'AB11', 'U9', 'AB13', 'F2', 'K6', 'R11', 'U8', 'Y12', 'AB12', 'F3', 'K7', 'R13', 'Y13']},{'label': 'uC', 'num': 3, 'pin_nums': ['AA1', 'E18', 'U16', 'E14', 'D14', 'E16', 'T15', 'W18']},{'label': 'uD', 'num': 4, 'pin_nums': ['B5', 'K15', 'P14', 'K9', 'B9', 'P9', 'D16', 'L10', 'R10', 'L11', 'D18', 'R12', 'D4', 'L12', 'R14', 'E11', 'L13', 'R18', 'E15', 'L14', 'R5', 'E2', 'L18', 'R6', 'E21', 'L5', 'T16', 'K14', 'E7', 'L8', 'U11', 'F11', 'L9', 'U17', 'G12', 'M10', 'U19', 'G18', 'M11', 'U2', 'G5', 'M12', 'U21', 'H15', 'M13', 'U7', 'H7', 'M14', 'V10', 'H9', 'M15', 'V14', 'J10', 'M9', 'V4', 'J11', 'N10', 'V6', 'J12', 'N11', 'W16', 'J13', 'N12', 'W19', 'J14', 'N13', 'W7', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J20', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12', 'B17', 'P13']}] }),
        Part(**{ 'name':'XC6SLX100-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100-FGG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V19',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W8',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='N15',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='Y20',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='Y22',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P15',name='RFUSE',func=pin_types.PWRIN,unit=4),
            Pin(num='P16',name='VFS',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R17',name='VBATT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E13', 'G22', 'L20', 'U22', 'C13', 'E14', 'L21', 'A11', 'G8', 'V20', 'A12', 'C14', 'E16', 'A14', 'G9', 'L22', 'V21', 'C15', 'E17', 'A15', 'H10', 'M16', 'V22', 'A16', 'C16', 'E19', 'H11', 'M17', 'W20', 'A17', 'C17', 'E20', 'H12', 'M18', 'A18', 'W21', 'A20', 'C19', 'E22', 'H13', 'M19', 'W22', 'A21', 'C20', 'E8', 'M20', 'H14', 'A3', 'C21', 'E9', 'H16', 'M21', 'A4', 'C22', 'F10', 'H17', 'M22', 'A5', 'C5', 'F12', 'H18', 'N16', 'A6', 'A10', 'C6', 'F13', 'H19', 'N18', 'A7', 'C7', 'F14', 'H20', 'N19', 'A8', 'C8', 'F15', 'H21', 'N20', 'A9', 'C9', 'F16', 'H22', 'N22', 'B10', 'D10', 'F17', 'J16', 'P17', 'B11', 'D11', 'F18', 'J17', 'P18', 'B12', 'D12', 'F19', 'J18', 'P19', 'B14', 'D13', 'F20', 'J19', 'P20', 'B15', 'D14', 'F21', 'J20', 'P21', 'B16', 'D15', 'F22', 'J22', 'P22', 'B18', 'D17', 'F8', 'K16', 'R19', 'B19', 'D19', 'F9', 'K17', 'R20', 'L19', 'B20', 'D20', 'G10', 'K18', 'R21', 'B21', 'D21', 'G11', 'K19', 'R22', 'B22', 'D22', 'G13', 'K20', 'T19', 'B4', 'D6', 'G14', 'K21', 'T20', 'B6', 'D7', 'G16', 'K22', 'T21', 'B7', 'D8', 'G17', 'L15', 'T22', 'B8', 'D9', 'G19', 'L16', 'U18', 'C10', 'A13', 'C12', 'E10', 'G20', 'L17', 'U19', 'C11', 'E12', 'G21', 'U20']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB16', 'L2', 'V1', 'R2', 'Y12', 'AB17', 'F5', 'L3', 'V11', 'R3', 'Y13', 'AB18', 'F6', 'L4', 'R4', 'V12', 'Y14', 'AB19', 'F7', 'L6', 'R7', 'V13', 'Y15', 'AB2', 'G1', 'L7', 'R8', 'V15', 'Y17', 'AB20', 'G2', 'M1', 'R9', 'V16', 'Y18', 'AB21', 'G3', 'M2', 'T1', 'V17', 'Y19', 'U9', 'AB3', 'G4', 'M3', 'V18', 'T11', 'Y2', 'A2', 'AB4', 'G6', 'M4', 'T13', 'V19', 'Y21', 'AA10', 'AB6', 'G7', 'M5', 'T14', 'V2', 'Y3', 'AA11', 'AB7', 'H1', 'M6', 'T15', 'V3', 'Y4', 'AA12', 'AB8', 'H2', 'M7', 'T16', 'V5', 'Y7', 'AA14', 'AB9', 'H3', 'M8', 'T17', 'V7', 'Y8', 'AA15', 'B1', 'H4', 'N1', 'T18', 'V8', 'Y9', 'AA16', 'B2', 'H5', 'N3', 'T2', 'V9', 'AA18', 'B3', 'H6', 'N4', 'T3', 'W1', 'AA19', 'C1', 'H8', 'N5', 'T4', 'W10', 'AA2', 'C2', 'J1', 'N6', 'T5', 'W11', 'AA20', 'C3', 'J3', 'N7', 'T6', 'W12', 'AA21', 'C4', 'J4', 'P1', 'T7', 'W13', 'AA22', 'D1', 'J5', 'P2', 'T9', 'W14', 'AA3', 'D2', 'J6', 'P3', 'U1', 'W17', 'AA4', 'D3', 'J7', 'P4', 'U13', 'W18', 'AA6', 'D5', 'K1', 'P5', 'U14', 'W2', 'AA7', 'E1', 'K2', 'P6', 'U15', 'W3', 'AA8', 'E3', 'K3', 'P7', 'U16', 'W4', 'AB10', 'E4', 'K4', 'P8', 'U17', 'W5', 'AB11', 'E5', 'K5', 'R1', 'U3', 'W8', 'AB12', 'E6', 'K6', 'R11', 'U4', 'W9', 'AB13', 'F1', 'K7', 'R13', 'U5', 'Y1', 'AB14', 'F2', 'F4', 'K8', 'R15', 'U6', 'Y10', 'AB15', 'F3', 'L1', 'R16', 'Y11']},{'label': 'uC', 'num': 3, 'pin_nums': ['Y22', 'E18', 'N15', 'AA1', 'C18', 'A19', 'G15', 'Y20']},{'label': 'uD', 'num': 4, 'pin_nums': ['B17', 'K14', 'P13', 'B5', 'P14', 'K15', 'B9', 'K9', 'P15', 'D16', 'P16', 'L10', 'D18', 'L11', 'P9', 'D4', 'L12', 'R10', 'E11', 'L13', 'R12', 'E15', 'R14', 'L14', 'E2', 'L18', 'R17', 'E21', 'L5', 'R18', 'E7', 'L8', 'R5', 'F11', 'L9', 'R6', 'G12', 'M10', 'U11', 'G18', 'M11', 'U2', 'G5', 'M12', 'U21', 'H15', 'M13', 'U7', 'H7', 'M14', 'V10', 'H9', 'M15', 'V14', 'J10', 'M9', 'V4', 'J11', 'N10', 'V6', 'J12', 'N11', 'W16', 'J13', 'N12', 'W19', 'J14', 'N13', 'W7', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J21', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12']}] }),
        Part(**{ 'name':'XC6SLX100-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100-FGG676\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L12N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE24',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L19N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L31N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L19P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L31P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L54N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L54P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L55N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L55P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M21',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L56P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L56N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L55N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L55P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='V22',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA13',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='IO_L4P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB15',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L4N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC11',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC12',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC19',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC20',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD17',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD18',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD19',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD21',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD22',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE11',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE17',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF10',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF12',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF17',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L27P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L27N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y13',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A23',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='D22',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D26',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E23',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F22',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='F24',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='F5',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G19',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G20',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G21',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G22',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G23',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G6',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H18',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H19',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H20',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H21',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H22',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H26',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J10',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J20',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J21',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J22',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='J7',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K21',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K22',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K24',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='K5',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K9',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L20',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L21',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L8',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M24',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M26',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N26',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='TDO',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='CMPCS_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='SUSPEND',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='DONE_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='C23',name='TMS',func=pin_types.BIDIR,unit=4),
            Pin(num='E21',name='TCK',func=pin_types.BIDIR,unit=4),
            Pin(num='F20',name='TDI',func=pin_types.BIDIR,unit=4),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AA10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA16',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA20',name='RFUSE',func=pin_types.PWRIN,unit=5),
            Pin(num='AA21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB19',name='VFS',func=pin_types.PWRIN,unit=5),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='G15',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='W20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='W21',name='VBATT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['R22', 'AC25', 'E16', 'C16', 'L17', 'R23', 'W19', 'AC26', 'E17', 'C17', 'L18', 'R24', 'W22', 'AD24', 'C18', 'E18', 'L19', 'R25', 'A13', 'W23', 'AD25', 'C19', 'E19', 'A11', 'L23', 'R26', 'A12', 'W24', 'AD26', 'C20', 'E20', 'A14', 'L24', 'T18', 'W25', 'AE23', 'C21', 'E6', 'A15', 'M18', 'T19', 'W26', 'AE24', 'A16', 'C22', 'E8', 'M19', 'T20', 'Y20', 'AE25', 'A17', 'E9', 'C5', 'M20', 'T22', 'A18', 'Y21', 'AE26', 'A19', 'C6', 'F10', 'M21', 'T23', 'Y22', 'A2', 'AF24', 'C7', 'F11', 'M23', 'T24', 'Y24', 'A20', 'AF25', 'C8', 'F13', 'N17', 'T25', 'Y25', 'A21', 'B10', 'C9', 'F15', 'N18', 'T26', 'Y26', 'A22', 'B11', 'D10', 'F16', 'N19', 'U17', 'A3', 'B12', 'D11', 'F17', 'N20', 'U18', 'A4', 'B14', 'D12', 'F18', 'N21', 'U19', 'B15', 'A5', 'D13', 'F7', 'N22', 'U20', 'A6', 'B16', 'D14', 'F9', 'N23', 'U21', 'A7', 'B18', 'D15', 'G10', 'N24', 'U22', 'A8', 'B19', 'D16', 'G14', 'P17', 'U23', 'A9', 'B20', 'D17', 'G16', 'P18', 'U24', 'AA22', 'B22', 'D18', 'G17', 'P20', 'U25', 'AA23', 'B3', 'D19', 'G18', 'P21', 'U26', 'AA24', 'B4', 'D20', 'G8', 'AC24', 'P22', 'V17', 'AA25', 'B6', 'D21', 'H14', 'P23', 'V18', 'AA26', 'B7', 'D5', 'H15', 'P24', 'V19', 'AB21', 'B8', 'D6', 'H16', 'P26', 'V20', 'AB22', 'C10', 'D7', 'H17', 'R17', 'V21', 'AB23', 'C11', 'D8', 'J14', 'R18', 'V22', 'E14', 'AB24', 'C12', 'D9', 'J15', 'R19', 'V23', 'AB26', 'C13', 'E10', 'J17', 'R20', 'V24', 'W18', 'C14', 'AC23', 'E13', 'K18', 'R21', 'V26', 'A10', 'C15', 'K19']},{'label': 'uB', 'num': 2, 'pin_nums': ['T10', 'AB13', 'AE21', 'AD1', 'M4', 'T2', 'W1', 'AB14', 'AE3', 'AD10', 'M6', 'T3', 'W10', 'AB15', 'AD11', 'AE4', 'M7', 'T4', 'W11', 'AB17', 'AD12', 'AE5', 'M8', 'T6', 'W12', 'AB18', 'AD13', 'AE7', 'AB11', 'M9', 'T7', 'W13', 'AB3', 'AD14', 'AE8', 'N3', 'T8', 'W14', 'AB4', 'AD15', 'AE9', 'N4', 'T9', 'W16', 'AB5', 'AF10', 'AD16', 'N5', 'U1', 'W17', 'AB6', 'AD17', 'AF11', 'N6', 'U12', 'W2', 'AB7', 'AD18', 'AF12', 'N7', 'U13', 'W3', 'AB8', 'AD19', 'AF13', 'N8', 'U15', 'W4', 'AB9', 'AD2', 'AF14', 'N9', 'U2', 'AE20', 'W5', 'AC1', 'AD20', 'AF15', 'P1', 'U3', 'W6', 'AA1', 'AC10', 'AD21', 'AF16', 'P10', 'U4', 'W7', 'AA11', 'AC11', 'AD22', 'AF17', 'P3', 'U5', 'W8', 'AC12', 'AA12', 'AD3', 'AF18', 'P4', 'U7', 'W9', 'AA13', 'AC13', 'AD4', 'AF19', 'P5', 'U8', 'Y1', 'AA14', 'AC14', 'AD5', 'AF2', 'P6', 'U9', 'Y10', 'AA15', 'AC15', 'AD6', 'AF20', 'P7', 'V1', 'Y12', 'AA17', 'AC16', 'AD7', 'AF21', 'P8', 'V10', 'Y13', 'AA18', 'AC17', 'AD8', 'AF22', 'P9', 'V11', 'Y14', 'AA19', 'AC18', 'AD9', 'AF4', 'R1', 'V12', 'Y15', 'AA2', 'AC19', 'AE1', 'AF5', 'R10', 'V13', 'Y16', 'AA3', 'AC2', 'AE11', 'AF6', 'R2', 'V14', 'Y17', 'AA4', 'AC20', 'AE12', 'AF7', 'R3', 'V15', 'Y18', 'AA5', 'AC21', 'AE13', 'AF8', 'R4', 'V16', 'Y2', 'AA7', 'AC3', 'AE15', 'AF9', 'R5', 'V3', 'Y3', 'AA8', 'AC4', 'AE16', 'L3', 'R6', 'V4', 'Y5', 'AA9', 'AC5', 'AE17', 'L4', 'R7', 'V5', 'Y6', 'AB1', 'AC6', 'AE19', 'L6', 'R9', 'V6', 'V8', 'Y8', 'AB10', 'AC7', 'AE2', 'L7', 'T1', 'V7', 'Y9', 'AC9', 'M10']},{'label': 'uC', 'num': 3, 'pin_nums': ['H3', 'A23', 'K7', 'B1', 'F23', 'H5', 'A25', 'K8', 'B2', 'F24', 'H6', 'K9', 'B23', 'F26', 'H7', 'L1', 'B24', 'F3', 'H8', 'L2', 'B25', 'F4', 'J1', 'L20', 'B26', 'F5', 'J10', 'L21', 'C1', 'G1', 'J2', 'L25', 'C2', 'G19', 'J20', 'L26', 'C24', 'G2', 'J21', 'L8', 'C25', 'G20', 'J22', 'L9', 'C26', 'G21', 'J23', 'M1', 'C3', 'G22', 'J24', 'M2', 'C4', 'G23', 'J25', 'M24', 'D1', 'G24', 'J26', 'M25', 'D2', 'G25', 'J3', 'M26', 'D22', 'G26', 'J4', 'M3', 'D23', 'G3', 'J5', 'N1', 'D24', 'G4', 'J6', 'N2', 'D25', 'G5', 'J7', 'N25', 'D26', 'G6', 'K1', 'N26', 'D3', 'G7', 'K10', 'E1', 'H1', 'K20', 'E2', 'H18', 'K21', 'E23', 'H19', 'K22', 'E24', 'H2', 'K23', 'E25', 'H20', 'K24', 'E26', 'H21', 'K26', 'E3', 'H22', 'K3', 'E4', 'H24', 'K4', 'E5', 'F22', 'H25', 'K5', 'F1', 'H26', 'K6']},{'label': 'uD', 'num': 4, 'pin_nums': ['AF3', 'AD23', 'E21', 'A24', 'AF23', 'AC22', 'C23', 'F20']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA10', 'M17', 'T17', 'AA16', 'F6', 'M22', 'T21', 'AA20', 'G12', 'M5', 'T5', 'AA21', 'G15', 'N10', 'U10', 'AA6', 'H11', 'N11', 'U11', 'AB12', 'H23', 'N12', 'U14', 'AB16', 'H4', 'N13', 'U16', 'AB19', 'J18', 'N14', 'U6', 'AB2', 'J19', 'N15', 'V2', 'AB20', 'J8', 'N16', 'V25', 'AB25', 'J9', 'P11', 'V9', 'AC8', 'K11', 'P12', 'W15', 'AE10', 'K13', 'P13', 'W20', 'AE14', 'K16', 'P14', 'W21', 'AE18', 'K17', 'P15', 'Y11', 'AE22', 'K2', 'P16', 'Y19', 'AE6', 'K25', 'P19', 'Y23', 'AF1', 'L10', 'P2', 'Y4', 'AF26', 'L11', 'P25', 'Y7', 'B13', 'L12', 'R11', 'B17', 'L13', 'R12', 'B21', 'L14', 'R13', 'B5', 'L15', 'R14', 'B9', 'L16', 'R15', 'D4', 'L22', 'R16', 'E11', 'L5', 'R8', 'E15', 'M11', 'T11', 'E22', 'M12', 'T12', 'E7', 'M13', 'T13', 'F19', 'M14', 'T14', 'A1', 'F2', 'F25', 'M15', 'T15', 'A26', 'F21', 'M16', 'T16']}] }),
        Part(**{ 'name':'XC6SLX100T-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100T-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100T-CSG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L69N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L69P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L71N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L71P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L72N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L72P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L70N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L70P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F14',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='C19',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='F17',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='H16',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F18',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VBATT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='RFUSE',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U19',name='VFS',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G8', 'R22', 'A18', 'E17', 'G9', 'A20', 'L22', 'T12', 'E19', 'H10', 'M16', 'T13', 'A21', 'E20', 'H11', 'M17', 'T15', 'A4', 'E22', 'H12', 'A5', 'M18', 'T17', 'AA19', 'E5', 'H13', 'M19', 'T18', 'AA20', 'E6', 'H14', 'AA21', 'M20', 'T19', 'AA22', 'E8', 'H17', 'M21', 'T20', 'AB19', 'F10', 'H18', 'M22', 'T21', 'AB20', 'F11', 'H19', 'N14', 'T22', 'AB21', 'F12', 'H20', 'N15', 'U18', 'B18', 'F16', 'H21', 'N16', 'U20', 'B19', 'F19', 'H22', 'N18', 'U22', 'B20', 'F20', 'H8', 'N19', 'V17', 'B21', 'F21', 'J16', 'N20', 'V18', 'B22', 'F22', 'J17', 'N22', 'V19', 'B3', 'F6', 'J18', 'P15', 'V20', 'B4', 'F7', 'J19', 'P16', 'V21', 'C17', 'F8', 'J20', 'P17', 'V22', 'C18', 'F9', 'J22', 'P18', 'W20', 'C20', 'G10', 'K16', 'P19', 'W21', 'C21', 'G11', 'K17', 'P20', 'W22', 'C22', 'G12', 'K18', 'P21', 'Y19', 'C5', 'G13', 'K19', 'P22', 'Y20', 'D17', 'G15', 'K20', 'R12', 'Y21', 'D18', 'G16', 'K21', 'R13', 'Y22', 'D19', 'G17', 'K22', 'R15', 'D20', 'G19', 'L15', 'R16', 'A19', 'D21', 'A17', 'G20', 'L16', 'R17', 'D22', 'G21', 'L17', 'R19', 'D5', 'G22', 'L19', 'L21', 'R20', 'E10', 'G7', 'L20', 'R21', 'E16']},{'label': 'uB', 'num': 2, 'pin_nums': ['P7', 'Y13', 'AA15', 'D1', 'K4', 'P8', 'V1', 'Y14', 'D2', 'AA16', 'K5', 'R1', 'V11', 'Y15', 'AA18', 'D3', 'K6', 'R2', 'V12', 'Y16', 'AA2', 'D4', 'K7', 'R3', 'V13', 'Y17', 'AA3', 'E1', 'K8', 'R4', 'V15', 'Y18', 'AA4', 'E3', 'L1', 'R6', 'V2', 'Y2', 'AA6', 'E4', 'L2', 'R7', 'V3', 'Y3', 'AA7', 'F1', 'L3', 'R8', 'V5', 'Y4', 'AA8', 'F2', 'L4', 'R9', 'V7', 'Y5', 'AB10', 'F3', 'L6', 'T1', 'V8', 'Y6', 'AB11', 'F4', 'L7', 'T10', 'V9', 'Y7', 'AB12', 'F5', 'M1', 'T11', 'W1', 'Y8', 'AB13', 'G1', 'M2', 'T14', 'W10', 'Y9', 'AB14', 'G2', 'M3', 'T2', 'W11', 'AB15', 'G3', 'M4', 'T3', 'W12', 'AB16', 'G4', 'M5', 'T4', 'W13', 'AB17', 'G6', 'M6', 'T5', 'W14', 'AB18', 'H1', 'M7', 'T6', 'W15', 'AB2', 'H2', 'M8', 'T7', 'W16', 'AB3', 'H3', 'N1', 'T8', 'W17', 'AB4', 'H4', 'N3', 'T9', 'W2', 'AB5', 'H5', 'N4', 'U1', 'W3', 'AB6', 'H6', 'N5', 'U10', 'W4', 'AB7', 'J1', 'N6', 'U13', 'W5', 'AB8', 'J3', 'N7', 'U14', 'W6', 'AB9', 'J4', 'P1', 'U15', 'W8', 'A2', 'B1', 'J5', 'P2', 'U3', 'W9', 'A3', 'J6', 'B2', 'P3', 'U4', 'C4', 'Y1', 'AA10', 'C1', 'J7', 'P4', 'U5', 'Y10', 'AA11', 'C2', 'K1', 'P5', 'U6', 'U9', 'Y11', 'AA12', 'C3', 'K2', 'P6', 'U8', 'Y12', 'AA14', 'K3']},{'label': 'uC', 'num': 3, 'pin_nums': ['A14', 'B6', 'D13', 'A16', 'B8', 'D15', 'A6', 'C11', 'D7', 'A8', 'C13', 'D9', 'B10', 'C15', 'E14', 'A12', 'B12', 'C7', 'B16', 'F14', 'A10', 'B14', 'C9', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['A7', 'B9', 'D12', 'D8', 'E13', 'E9', 'A15', 'B13', 'C10', 'D14', 'E11', 'E15']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA1', 'C19', 'F17', 'U12', 'H16', 'U16', 'W18', 'E18']},{'label': 'uF', 'num': 6, 'pin_nums': ['M15', 'AA13', 'J10', 'M9', 'V6', 'AA17', 'J11', 'N10', 'W19', 'AA5', 'J12', 'N11', 'W7', 'AA9', 'J13', 'N12', 'AB1', 'J14', 'N13', 'AB22', 'J15', 'N17', 'B11', 'J2', 'N2', 'B15', 'J21', 'N21', 'B17', 'J8', 'N8', 'B5', 'J9', 'N9', 'B7', 'K10', 'P10', 'C12', 'K11', 'P11', 'A9', 'C14', 'K12', 'P12', 'C16', 'K13', 'P13', 'C6', 'K14', 'P14', 'C8', 'K15', 'P9', 'D10', 'K9', 'R10', 'D16', 'L10', 'R11', 'D6', 'L11', 'R14', 'E12', 'L12', 'R18', 'E2', 'L13', 'R5', 'E21', 'L14', 'T16', 'E7', 'L18', 'U11', 'F13', 'L5', 'U17', 'F15', 'L8', 'U19', 'F18', 'L9', 'U2', 'G14', 'M10', 'U21', 'A1', 'G18', 'M11', 'U7', 'A11', 'G5', 'M12', 'V10', 'A13', 'H15', 'M13', 'V14', 'V4', 'A22', 'H7', 'M14', 'V16', 'H9']}] }),
        Part(**{ 'name':'XC6SLX100T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100T-FGG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E12',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F12',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='A21',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='AA22',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='AB2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB21',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='D20',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='G17',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='V18',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P15',name='RFUSE',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='VBATT',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VFS',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C18', 'F22', 'J19', 'P18', 'C19', 'J20', 'F6', 'P19', 'C20', 'F7', 'J22', 'P20', 'C21', 'K16', 'F8', 'P21', 'C22', 'F9', 'K17', 'P22', 'C3', 'G10', 'K18', 'R15', 'C4', 'G11', 'K19', 'R16', 'C5', 'K20', 'G13', 'R17', 'D17', 'G14', 'K21', 'R19', 'D18', 'G15', 'K22', 'R20', 'D19', 'G16', 'L15', 'R21', 'D21', 'G19', 'L16', 'R22', 'A19', 'D22', 'G20', 'L17', 'T17', 'D3', 'G21', 'L19', 'T18', 'D4', 'G22', 'L20', 'T19', 'D5', 'G8', 'L21', 'T20', 'A18', 'E16', 'G9', 'L22', 'T21', 'E17', 'H10', 'M16', 'A2', 'T22', 'E19', 'H11', 'M17', 'U18', 'E20', 'H12', 'M18', 'U19', 'E22', 'H13', 'M19', 'U20', 'A20', 'E5', 'H14', 'M20', 'U22', 'A3', 'E6', 'H16', 'M21', 'V19', 'J18', 'A4', 'F10', 'H17', 'M22', 'A5', 'V20', 'F14', 'B18', 'H18', 'N15', 'V21', 'B19', 'F15', 'H19', 'N16', 'B2', 'A17', 'V22', 'F16', 'B20', 'H20', 'N18', 'W20', 'B21', 'F17', 'H21', 'N19', 'W21', 'B22', 'F18', 'H22', 'N20', 'W22', 'B3', 'F19', 'J16', 'N22', 'Y21', 'B4', 'F20', 'J17', 'P16', 'Y22', 'C17', 'F21', 'P17']},{'label': 'uB', 'num': 2, 'pin_nums': ['AA1', 'J5', 'U10', 'P2', 'W17', 'AA10', 'AB8', 'J6', 'U12', 'P3', 'W18', 'AA11', 'AB9', 'J7', 'P4', 'U13', 'W2', 'AA12', 'B1', 'K1', 'P5', 'U14', 'W3', 'AA14', 'C1', 'K2', 'P6', 'U15', 'W4', 'AA15', 'C2', 'K3', 'P7', 'U16', 'W5', 'AA16', 'D1', 'K4', 'P8', 'U3', 'W6', 'U1', 'AA18', 'D2', 'K5', 'U4', 'R1', 'W8', 'AA19', 'E1', 'K6', 'R11', 'U5', 'W9', 'AA2', 'E3', 'K7', 'R13', 'U6', 'Y1', 'AA20', 'E4', 'K8', 'R2', 'U8', 'Y10', 'AA21', 'F1', 'L1', 'R3', 'U9', 'Y11', 'AA3', 'F2', 'L2', 'R4', 'V1', 'Y12', 'AA4', 'F3', 'L3', 'R7', 'V11', 'Y13', 'AA6', 'F4', 'L4', 'R8', 'V12', 'Y14', 'AA7', 'F5', 'L6', 'R9', 'V13', 'Y15', 'AA8', 'G1', 'L7', 'T1', 'V15', 'Y16', 'AB10', 'G2', 'M1', 'T10', 'V16', 'Y17', 'AB11', 'G3', 'M2', 'T11', 'V17', 'Y18', 'AB12', 'G4', 'M3', 'T12', 'V2', 'Y19', 'AB13', 'G6', 'M4', 'T13', 'V3', 'Y2', 'AB14', 'G7', 'M5', 'T14', 'V5', 'Y20', 'AB15', 'H1', 'M6', 'T15', 'V7', 'Y3', 'AB16', 'H2', 'M7', 'T2', 'V8', 'Y4', 'AB17', 'H3', 'M8', 'T3', 'V9', 'Y5', 'AB18', 'H4', 'N1', 'T4', 'W1', 'Y6', 'AB19', 'H5', 'N3', 'T5', 'W10', 'Y7', 'AB20', 'H6', 'N4', 'T6', 'W11', 'Y8', 'AB3', 'H8', 'N5', 'T7', 'W12', 'Y9', 'AB4', 'J1', 'N6', 'T8', 'W13', 'AB5', 'AB7', 'J3', 'N7', 'T9', 'W14', 'AB6', 'J4', 'P1', 'W15']},{'label': 'uC', 'num': 3, 'pin_nums': ['A14', 'B6', 'D13', 'A16', 'B8', 'D15', 'A6', 'C11', 'D7', 'A8', 'C13', 'D9', 'B10', 'C15', 'E12', 'B12', 'C7', 'F12', 'A10', 'B14', 'C9', 'A12', 'B16', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['D14', 'E10', 'A15', 'B13', 'C10', 'E8', 'A7', 'B9', 'D12', 'D8', 'E13', 'E9']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA22', 'E18', 'V18', 'AB21', 'A21', 'AB2', 'D20', 'G17']},{'label': 'uF', 'num': 6, 'pin_nums': ['D10', 'K15', 'P14', 'D16', 'P15', 'K9', 'D6', 'L10', 'P9', 'E11', 'R10', 'L11', 'E14', 'L12', 'R12', 'E15', 'L13', 'R14', 'E2', 'L14', 'R18', 'E21', 'R5', 'L18', 'E7', 'L5', 'R6', 'F11', 'L8', 'T16', 'F13', 'L9', 'U11', 'A1', 'G12', 'M10', 'U17', 'A11', 'G18', 'M11', 'U2', 'A13', 'G5', 'M12', 'U21', 'A22', 'H15', 'M13', 'U7', 'A9', 'H7', 'M14', 'V10', 'AA13', 'H9', 'M15', 'V14', 'AA17', 'J10', 'M9', 'V4', 'AA5', 'J11', 'N10', 'V6', 'AA9', 'J12', 'N11', 'W16', 'AB1', 'J13', 'N12', 'W19', 'AB22', 'J14', 'N13', 'W7', 'B11', 'J15', 'N14', 'B15', 'J2', 'N17', 'B17', 'J21', 'N2', 'B5', 'J8', 'N21', 'B7', 'J9', 'N8', 'C12', 'K10', 'N9', 'C14', 'K11', 'P10', 'C16', 'K12', 'P11', 'C6', 'K13', 'P12', 'C8', 'K14', 'P13']}] }),
        Part(**{ 'name':'XC6SLX100T-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100T-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100T-FGG676\n\nFPGA', 'pins':[
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA15',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA21',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB22',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB7',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC22',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD22',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD23',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE15',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE24',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE5',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF5',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W14',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W19',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W20',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y20',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y9',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A25',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='D23',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D26',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E23',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F22',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F23',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F24',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='G1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G20',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G22',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='G23',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H20',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H21',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H22',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H26',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J20',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J21',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J22',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='J7',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J9',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K18',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K19',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K21',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K22',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K24',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='K5',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K9',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L10',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L19',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L20',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L21',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L7',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L8',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M18',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M19',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M20',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M21',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M23',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M24',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M26',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M8',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N26',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A16',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A18',name='MGTTXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A20',name='MGTTXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B16',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B18',name='MGTTXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B20',name='MGTTXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C15',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C17',name='MGTRXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C19',name='MGTRXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D15',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D17',name='MGTRXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D19',name='MGTRXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='MGTRXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AC12',name='MGTREFCLK1P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AC16',name='MGTREFCLK0P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC18',name='MGTRXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC20',name='MGTRXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='MGTRXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='MGTRXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD12',name='MGTREFCLK1N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD16',name='MGTREFCLK0N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD18',name='MGTRXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='MGTRXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='MGTRXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE11',name='MGTREFCLK0P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='MGTREFCLK1P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='MGTTXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='MGTTXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='MGTTXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE9',name='MGTTXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF11',name='MGTREFCLK0N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF17',name='MGTREFCLK1N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF19',name='MGTTXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='MGTTXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='MGTTXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF9',name='MGTTXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='A19',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='AB10',name='MGTRREF_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AB12',name='MGTAVTTRCAL_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AC19',name='MGTAVTTRX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AC9',name='MGTAVTTRX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD11',name='MGTAVCC_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD13',name='MGTAVCCPLL1_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD15',name='MGTAVCCPLL0_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AD17',name='MGTAVCC_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AE12',name='MGTAVCCPLL0_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AE16',name='MGTAVCCPLL1_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AF20',name='MGTAVTTTX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='MGTAVTTTX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='MGTAVCC_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D18',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=6),
            Pin(num='A24',name='TCK',func=pin_types.BIDIR,unit=7),
            Pin(num='AF2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='DONE_2',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='TDI',func=pin_types.BIDIR,unit=7),
            Pin(num='F21',name='TMS',func=pin_types.BIDIR,unit=7),
            Pin(num='G21',name='TDO',func=pin_types.BIDIR,unit=7),
            Pin(num='Y19',name='CMPCS_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='Y22',name='SUSPEND',func=pin_types.BIDIR,unit=7),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AD19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D20',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V19',name='RFUSE',func=pin_types.PWRIN,unit=8),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V22',name='VBATT',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='VFS',func=pin_types.PWRIN,unit=8),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B23', 'J17', 'A12', 'T24', 'B3', 'F7', 'K12', 'T25', 'B4', 'F8', 'L23', 'T26', 'B5', 'F9', 'L24', 'U19', 'A2', 'C13', 'G10', 'N17', 'U20', 'C21', 'G11', 'N18', 'U21', 'C22', 'G13', 'N19', 'U22', 'A13', 'C3', 'A14', 'G15', 'N20', 'U23', 'A22', 'C4', 'G16', 'N21', 'U24', 'A23', 'C5', 'G17', 'N22', 'U25', 'A3', 'D13', 'G18', 'N23', 'A4', 'U26', 'D21', 'A5', 'G19', 'N24', 'V20', 'AA23', 'D22', 'G6', 'P17', 'AA24', 'V21', 'D5', 'AA25', 'G7', 'P18', 'V23', 'AA26', 'E10', 'G8', 'P19', 'V24', 'AB23', 'E13', 'G9', 'P21', 'V26', 'AB24', 'E16', 'H10', 'P22', 'W21', 'AB26', 'E18', 'H11', 'P23', 'W23', 'AC23', 'E20', 'H12', 'P24', 'W24', 'AC24', 'E21', 'H15', 'P26', 'W25', 'AC25', 'E5', 'H16', 'R18', 'W26', 'AC26', 'E6', 'H17', 'R19', 'Y24', 'AD24', 'E8', 'H18', 'R20', 'Y25', 'AD25', 'F10', 'H19', 'R21', 'Y26', 'AD26', 'F13', 'H7', 'R23', 'AE25', 'F15', 'H8', 'R24', 'AE26', 'F16', 'H9', 'R25', 'B12', 'F17', 'J11', 'R26', 'B13', 'F18', 'J12', 'T19', 'B14', 'F19', 'J14', 'T20', 'B21', 'F20', 'F6', 'J15', 'T22', 'B22', 'F5', 'J16', 'T23']},{'label': 'uB', 'num': 2, 'pin_nums': ['M9', 'W4', 'AA19', 'N4', 'AC6', 'U1', 'W5', 'AA2', 'AD1', 'N5', 'U15', 'W6', 'AA20', 'AD14', 'N6', 'U2', 'W7', 'AA21', 'AD2', 'N7', 'U3', 'W8', 'AA22', 'AD22', 'N8', 'U4', 'W9', 'AA3', 'AD23', 'N9', 'U5', 'Y1', 'AA4', 'AD3', 'P1', 'U7', 'Y11', 'AA6', 'AD4', 'P10', 'U8', 'Y12', 'AA7', 'AD5', 'P3', 'AC5', 'U9', 'Y13', 'AA8', 'AD6', 'P4', 'V1', 'Y16', 'AA9', 'AE1', 'P5', 'V10', 'Y17', 'AB1', 'AE13', 'P6', 'V11', 'Y18', 'AB11', 'AE14', 'P8', 'V16', 'Y2', 'AB14', 'AE15', 'P9', 'V18', 'Y20', 'AB15', 'AE2', 'R1', 'V3', 'Y21', 'AB17', 'AE23', 'R10', 'V4', 'Y3', 'AB19', 'AE24', 'R2', 'V5', 'Y5', 'AB21', 'AE3', 'R3', 'V6', 'Y6', 'AB22', 'AE4', 'R4', 'V7', 'Y8', 'AB3', 'AE5', 'R5', 'W1', 'Y9', 'AB4', 'AF13', 'R6', 'W10', 'AB5', 'AF14', 'R7', 'W11', 'AB6', 'AF15', 'R8', 'W14', 'AB7', 'AF22', 'R9', 'W15', 'AA1', 'AB9', 'AF23', 'T1', 'W16', 'AA10', 'AC1', 'AF24', 'T2', 'W17', 'AA11', 'AC14', 'AF3', 'T3', 'W18', 'AA12', 'AC2', 'AF4', 'T4', 'W19', 'AA14', 'AC22', 'AF5', 'T6', 'W2', 'AA15', 'AC3', 'AF6', 'T7', 'T9', 'W20', 'AA17', 'AC4', 'M10', 'T8', 'W3', 'AA18']},{'label': 'uC', 'num': 3, 'pin_nums': ['M23', 'H1', 'D1', 'M24', 'K22', 'H2', 'D2', 'K23', 'M25', 'D23', 'H20', 'K24', 'M26', 'H21', 'D24', 'K26', 'M3', 'D25', 'H22', 'K3', 'M4', 'D26', 'H24', 'K4', 'M6', 'D3', 'H25', 'K5', 'M7', 'E1', 'H26', 'K6', 'M8', 'E2', 'H3', 'K7', 'N1', 'E23', 'H5', 'K8', 'N2', 'E24', 'H6', 'K9', 'N25', 'E25', 'J1', 'L1', 'N26', 'E26', 'J2', 'L10', 'N3', 'E3', 'J20', 'L19', 'E4', 'J21', 'L2', 'F1', 'J22', 'L20', 'F22', 'J23', 'L21', 'F23', 'J24', 'L25', 'F24', 'J25', 'L26', 'F26', 'J26', 'L3', 'F3', 'J3', 'L4', 'A25', 'F4', 'J4', 'L6', 'G4', 'B1', 'G1', 'J5', 'L7', 'B2', 'G2', 'J6', 'L8', 'B24', 'G20', 'J7', 'L9', 'B25', 'G22', 'J9', 'M1', 'B26', 'G23', 'K1', 'M18', 'C1', 'G24', 'K10', 'M19', 'C2', 'G25', 'K18', 'M2', 'C24', 'K19', 'G26', 'M20', 'C25', 'G3', 'K20', 'M21', 'C26', 'K21']},{'label': 'uD', 'num': 4, 'pin_nums': ['A18', 'B6', 'D11', 'A20', 'B8', 'D15', 'A6', 'C11', 'D17', 'A8', 'C15', 'D19', 'B10', 'C17', 'D7', 'B16', 'C19', 'D9', 'A10', 'B18', 'C7', 'A16', 'B20', 'C9']},{'label': 'uE', 'num': 5, 'pin_nums': ['AD20', 'AF11', 'AC16', 'AC18', 'AD8', 'AF17', 'AC20', 'AE11', 'AF19', 'AC8', 'AE17', 'AF21', 'AD10', 'AE19', 'AF7', 'AE9', 'AF9', 'AD12', 'AE21', 'AC10', 'AD16', 'AE7', 'AD18', 'AC12']},{'label': 'uF', 'num': 6, 'pin_nums': ['C12', 'A7', 'AD17', 'AB10', 'AE12', 'C14', 'AB12', 'AE16', 'C16', 'AC19', 'AF20', 'D18', 'AC9', 'AF8', 'D8', 'AD11', 'B11', 'E11', 'AD13', 'B15', 'E9', 'A19', 'AD15', 'C10']},{'label': 'uG', 'num': 7, 'pin_nums': ['G21', 'C23', 'AF2', 'AF25', 'Y19', 'Y22', 'F21', 'A24']},{'label': 'uH', 'num': 8, 'pin_nums': ['AF12', 'N14', 'U10', 'A11', 'AF16', 'J8', 'N15', 'U11', 'A15', 'AF18', 'K11', 'N16', 'U12', 'A17', 'AF26', 'K13', 'P11', 'U14', 'A21', 'B17', 'K15', 'P12', 'U16', 'A26', 'B19', 'K16', 'P13', 'U17', 'A9', 'B7', 'K17', 'P14', 'U18', 'AA5', 'B9', 'K2', 'P15', 'U6', 'AB16', 'C18', 'K25', 'P16', 'V17', 'AB18', 'C20', 'L11', 'P2', 'V19', 'AB2', 'C6', 'L12', 'P20', 'V2', 'AB20', 'C8', 'L13', 'P25', 'V22', 'AB25', 'D10', 'L14', 'P7', 'V25', 'AB8', 'D12', 'L15', 'R11', 'V8', 'AC11', 'D14', 'L16', 'R12', 'V9', 'AC13', 'D16', 'L17', 'R13', 'W13', 'AC15', 'D20', 'L18', 'R14', 'W22', 'AC17', 'D4', 'L22', 'R15', 'Y10', 'AC21', 'D6', 'L5', 'R16', 'Y14', 'AC7', 'E15', 'M11', 'R17', 'Y23', 'AD19', 'E17', 'M12', 'R22', 'Y4', 'AD21', 'E19', 'M13', 'T10', 'Y7', 'AD7', 'E22', 'M14', 'T11', 'AD9', 'E7', 'M15', 'T12', 'AE10', 'F2', 'M16', 'T13', 'AE18', 'F25', 'M17', 'T14', 'AE20', 'G14', 'M22', 'T15', 'AE22', 'G5', 'M5', 'T16', 'AE6', 'H23', 'N10', 'T17', 'AE8', 'H4', 'N11', 'T18', 'AF1', 'J10', 'J19', 'N12', 'T21', 'AF10', 'J18', 'N13', 'T5', 'A1']}] }),
        Part(**{ 'name':'XC6SLX100T-FGG900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX100T-FGG900'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX100T-FGG900\n\nFPGA', 'pins':[
            Pin(num='A15',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA24',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA27',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA28',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA29',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA30',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB28',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB30',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AC27',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC28',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC29',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC30',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD27',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD28',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD30',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE27',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE28',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE29',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE30',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF28',name='IO_L55P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF30',name='IO_L55N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG26',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG27',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG28',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG29',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG30',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH26',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH27',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AH30',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ27',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AJ28',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ29',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ30',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK27',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK28',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK29',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C24',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C25',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D24',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L60N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E24',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L54N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L60P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L20N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L54P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L61N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='IO_L20P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L19N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L53N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H21',name='IO_L61P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='IO_L9N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L19P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L53P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L55N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO_L9P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L25N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L55P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L25P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='M23',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M24',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N27',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P22',name='IO_L56P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L56N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P24',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L54P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L54N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R24',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R27',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R29',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T28',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T30',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U24',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U27',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U28',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U29',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U30',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V27',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V28',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V30',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W27',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W28',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W29',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W30',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y27',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y28',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y30',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA14',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA17',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA21',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB23',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC11',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC13',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC16',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC19',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC20',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC22',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC23',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC24',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD14',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD19',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD20',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD21',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD22',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD23',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD24',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD6',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE11',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE13',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE14',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE17',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE21',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE22',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE24',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L6P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE6',name='IO_L4P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE9',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF1',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF17',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF25',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF3',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L4N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF9',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG1',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG16',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AG24',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG25',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG5',name='IO_L6N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG7',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH1',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH16',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH2',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH24',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH25',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AH3',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH7',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ1',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ15',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ17',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ2',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ25',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ26',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ4',name='IO_L14P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AK15',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK16',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK17',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK2',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK25',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK26',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK3',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK4',name='IO_L14N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK6',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N1',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L56N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L56P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L27N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L27P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='V1',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L5P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W20',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y11',name='IO_L5N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y6',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A2',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A26',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A27',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A28',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A29',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B27',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B28',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='B29',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B30',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='B5',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='C26',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C27',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C29',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C30',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D27',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D28',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D3',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D30',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E27',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E28',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E30',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F25',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F27',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F28',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='G25',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='G27',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G28',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G29',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H26',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H27',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H28',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H3',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H6',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J27',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J28',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K24',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K26',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K27',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K28',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K30',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='L1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='L24',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='L27',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L28',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L7',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M26',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M27',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M28',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M3',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M30',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M5',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='N24',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A11',name='MGTTXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A19',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A21',name='MGTTXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A23',name='MGTTXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='MGTTXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTTXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B13',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B19',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B21',name='MGTTXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B23',name='MGTTXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='MGTTXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C10',name='MGTRXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C12',name='MGTRXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C14',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C18',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C20',name='MGTRXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C22',name='MGTRXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='MGTRXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D12',name='MGTRXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D14',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D18',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D20',name='MGTRXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D22',name='MGTRXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='MGTRXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='MGTRXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AG14',name='MGTREFCLK1P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AG18',name='MGTREFCLK0P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AG20',name='MGTRXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AG22',name='MGTRXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AH10',name='MGTRXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AH12',name='MGTRXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AH14',name='MGTREFCLK1N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AH18',name='MGTREFCLK0N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AH20',name='MGTRXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AH22',name='MGTRXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ11',name='MGTTXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ13',name='MGTREFCLK0P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ19',name='MGTREFCLK1P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ21',name='MGTTXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ23',name='MGTTXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ9',name='MGTTXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AK11',name='MGTTXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='MGTREFCLK0N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AK19',name='MGTREFCLK1N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AK21',name='MGTTXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AK23',name='MGTTXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AK9',name='MGTTXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='A10',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='AF12',name='MGTRREF_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AF14',name='MGTAVTTRCAL_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AG11',name='MGTAVTTRX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AG21',name='MGTAVTTRX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AH13',name='MGTAVCC_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AH15',name='MGTAVCCPLL1_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AH17',name='MGTAVCCPLL0_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AH19',name='MGTAVCC_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ14',name='MGTAVCCPLL0_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ18',name='MGTAVCCPLL1_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AK10',name='MGTAVTTTX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AK22',name='MGTAVTTTX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=6),
            Pin(num='B18',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C13',name='MGTAVCC_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C17',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C19',name='MGTAVCC_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D11',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='D21',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='E12',name='MGTRREF_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=6),
            Pin(num='AB25',name='SUSPEND',func=pin_types.BIDIR,unit=7),
            Pin(num='AB8',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AC25',name='CMPCS_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AD25',name='DONE_2',func=pin_types.BIDIR,unit=7),
            Pin(num='H23',name='TCK',func=pin_types.BIDIR,unit=7),
            Pin(num='H25',name='TDO',func=pin_types.BIDIR,unit=7),
            Pin(num='J24',name='TDI',func=pin_types.BIDIR,unit=7),
            Pin(num='K25',name='TMS',func=pin_types.BIDIR,unit=7),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB24',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB26',name='VBATT',func=pin_types.PWRIN,unit=8),
            Pin(num='AB27',name='RFUSE',func=pin_types.PWRIN,unit=8),
            Pin(num='AB29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF27',name='VFS',func=pin_types.PWRIN,unit=8),
            Pin(num='AF29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG23',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AG9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AH11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C28',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='D9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='H24',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J23',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M14',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M25',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T18',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V20',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y18',name='VCCAUX',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C7', 'G21', 'K11', 'N29', 'U28', 'AE28', 'D16', 'K12', 'G23', 'U29', 'N30', 'A17', 'AE29', 'D24', 'G7', 'K13', 'P21', 'U30', 'AE30', 'D25', 'G8', 'K14', 'P22', 'V23', 'AF28', 'D6', 'G9', 'K15', 'P23', 'V24', 'AF30', 'D7', 'H10', 'K17', 'P24', 'V26', 'A16', 'AG26', 'E15', 'H11', 'K19', 'P25', 'V27', 'AG27', 'E16', 'K20', 'H12', 'V28', 'P26', 'A25', 'AG28', 'E19', 'H13', 'K21', 'P27', 'V30', 'AG29', 'E23', 'H14', 'L10', 'P28', 'W21', 'AG30', 'E24', 'H15', 'L11', 'P30', 'W22', 'AH26', 'E25', 'A6', 'H16', 'L12', 'R21', 'W23', 'AH27', 'E6', 'A7', 'H17', 'L13', 'R22', 'W24', 'AA23', 'AH29', 'E7', 'H18', 'L14', 'R23', 'W25', 'AA24', 'AH30', 'E8', 'H19', 'L15', 'AA25', 'R24', 'W26', 'AA27', 'AJ27', 'F15', 'H20', 'L17', 'R25', 'W27', 'AA28', 'AJ28', 'F16', 'H21', 'L18', 'AA29', 'R26', 'W28', 'AJ29', 'F18', 'AA30', 'H22', 'L19', 'R27', 'W29', 'AB28', 'AJ30', 'F19', 'H7', 'L21', 'R28', 'W30', 'AB30', 'AK27', 'F20', 'H8', 'L9', 'R29', 'Y22', 'AC26', 'AK28', 'F23', 'H9', 'M10', 'R30', 'Y23', 'AC27', 'AK29', 'F24', 'J10', 'M13', 'T24', 'Y24', 'AC28', 'B15', 'F6', 'J12', 'M15', 'T25', 'Y25', 'AC29', 'B16', 'F8', 'J13', 'M17', 'T26', 'Y26', 'AC30', 'B17', 'G11', 'J14', 'M18', 'T27', 'Y27', 'AD26', 'B25', 'G13', 'J17', 'M19', 'T28', 'Y28', 'AD27', 'B6', 'G15', 'J18', 'M21', 'T29', 'Y29', 'K10', 'A15', 'AD28', 'B7', 'G16', 'J19', 'M23', 'T30', 'Y30', 'AD29', 'C16', 'G17', 'J20', 'M24', 'U23', 'AD30', 'C24', 'G18', 'J22', 'N23', 'U24', 'AE25', 'AE27', 'C25', 'G19', 'J8', 'N27', 'U25', 'AE26', 'C6', 'G20', 'N28', 'U27']},{'label': 'uB', 'num': 2, 'pin_nums': ['Y3', 'AC13', 'AF19', 'AD5', 'AJ1', 'N9', 'V1', 'Y4', 'AA15', 'AC15', 'AF2', 'AD6', 'P1', 'AJ15', 'V10', 'Y5', 'AA16', 'AC16', 'AD7', 'AF21', 'AJ16', 'P2', 'V2', 'Y6', 'AA17', 'AC18', 'AD8', 'AF23', 'AJ17', 'P3', 'V3', 'Y7', 'AA18', 'AC19', 'AD9', 'AF24', 'AJ2', 'P4', 'V4', 'Y8', 'AA19', 'AC2', 'AE1', 'AF25', 'AJ25', 'P6', 'V7', 'Y9', 'AA20', 'AC20', 'AE11', 'AF3', 'AJ26', 'P7', 'V8', 'AA21', 'AC21', 'AF4', 'AE12', 'P9', 'AJ3', 'V9', 'AA22', 'AC22', 'AE13', 'AF6', 'AJ4', 'R1', 'W1', 'AA3', 'AC23', 'AE14', 'AF7', 'AJ6', 'R2', 'W10', 'AA4', 'AC24', 'AE15', 'AF8', 'AJ7', 'R3', 'AF17', 'W11', 'AA5', 'AC3', 'AE16', 'AF9', 'AK15', 'R4', 'W14', 'AA6', 'AC4', 'AE17', 'AG1', 'AK16', 'R5', 'W2', 'AA7', 'AC5', 'AE19', 'AG16', 'AK17', 'R6', 'W20', 'AA8', 'AC6', 'AE20', 'AG2', 'AK2', 'R7', 'W3', 'AA9', 'AC9', 'AE21', 'AG24', 'AK25', 'R8', 'W4', 'N8', 'AB1', 'AD1', 'AE22', 'AG25', 'AK26', 'T1', 'W5', 'AB13', 'AD11', 'AE23', 'AG3', 'AK3', 'T2', 'W6', 'AB16', 'AD12', 'AE24', 'AG4', 'AK4', 'T3', 'W7', 'AB18', 'AD13', 'AE3', 'AG5', 'AK5', 'T4', 'W9', 'AB19', 'AD14', 'AE4', 'AG6', 'AK6', 'T5', 'Y1', 'AB2', 'AD15', 'AE5', 'AG7', 'AK7', 'T6', 'Y10', 'AB20', 'AD16', 'AE6', 'AH1', 'M6', 'T7', 'Y11', 'AB21', 'AD19', 'AE7', 'AH16', 'M7', 'T8', 'Y13', 'AB23', 'AD2', 'AE8', 'AH2', 'M8', 'T9', 'Y14', 'AB3', 'AD20', 'AE9', 'AH24', 'N1', 'U1', 'Y15', 'AB4', 'AD21', 'AF1', 'AH25', 'N10', 'U3', 'Y16', 'AB6', 'AD22', 'AF11', 'AH3', 'N3', 'U4', 'Y17', 'AB7', 'AD23', 'AF13', 'AH4', 'N4', 'U5', 'AA1', 'Y2', 'AC1', 'AD24', 'AF15', 'AH5', 'N5', 'U6', 'AA10', 'Y20', 'AA14', 'AC10', 'AD3', 'AF16', 'AH6', 'N7', 'U7', 'AA12', 'Y21', 'AC11', 'AD4', 'AH7', 'U8']},{'label': 'uC', 'num': 3, 'pin_nums': ['D1', 'G27', 'K27', 'G28', 'D2', 'K28', 'D26', 'G29', 'K3', 'G3', 'D27', 'K30', 'D28', 'G30', 'K4', 'D29', 'G4', 'K6', 'D3', 'G5', 'L1', 'A2', 'D30', 'H1', 'L2', 'A26', 'D4', 'H2', 'L24', 'A27', 'D5', 'H26', 'L25', 'A28', 'E1', 'H27', 'L26', 'A29', 'E26', 'H28', 'L27', 'A3', 'E27', 'H29', 'L28', 'A4', 'E28', 'H3', 'L29', 'A5', 'E29', 'H30', 'L3', 'B1', 'E3', 'H4', 'L30', 'B2', 'E30', 'H5', 'L4', 'B27', 'E4', 'H6', 'L5', 'B28', 'E5', 'J1', 'L6', 'B29', 'F1', 'J25', 'L7', 'B3', 'F2', 'J27', 'M1', 'B30', 'F25', 'J28', 'M2', 'B4', 'F26', 'J29', 'M26', 'B5', 'F27', 'J3', 'M27', 'C1', 'F28', 'J30', 'M28', 'G26', 'C2', 'F3', 'J4', 'M29', 'C26', 'F30', 'J5', 'M3', 'C27', 'F4', 'J6', 'M30', 'C29', 'G1', 'K1', 'M4', 'C30', 'G2', 'K2', 'M5', 'C4', 'G25', 'K24', 'N24', 'C5', 'K26', 'N25']},{'label': 'uD', 'num': 4, 'pin_nums': ['B13', 'D22', 'C18', 'B19', 'A11', 'C20', 'A13', 'B21', 'C22', 'A19', 'B23', 'D10', 'A21', 'B9', 'D12', 'A23', 'C10', 'D14', 'A9', 'C12', 'D18', 'B11', 'C14', 'D20']},{'label': 'uE', 'num': 5, 'pin_nums': ['AH12', 'AJ21', 'AK9', 'AG10', 'AJ23', 'AH14', 'AJ19', 'AG12', 'AH18', 'AJ9', 'AG14', 'AK11', 'AH20', 'AG18', 'AH22', 'AK13', 'AG20', 'AJ11', 'AK19', 'AG22', 'AJ13', 'AK21', 'AH10', 'AK23']},{'label': 'uF', 'num': 6, 'pin_nums': ['AH13', 'E12', 'B14', 'AH15', 'B18', 'E14', 'A10', 'AH17', 'C13', 'A22', 'AH19', 'C15', 'AF12', 'AJ14', 'C17', 'AF14', 'AJ18', 'C19', 'AG11', 'AK10', 'D11', 'AG21', 'AK22', 'D21']},{'label': 'uG', 'num': 7, 'pin_nums': ['AB25', 'AC25', 'H23', 'J24', 'AB8', 'H25', 'K25', 'AD25']},{'label': 'uH', 'num': 8, 'pin_nums': ['M12', 'U13', 'W17', 'AB26', 'AJ5', 'E20', 'M14', 'P5', 'U14', 'W18', 'AJ8', 'AB27', 'E22', 'M16', 'P8', 'U15', 'W8', 'AB29', 'AK1', 'F29', 'M22', 'R10', 'U16', 'Y18', 'AB5', 'AK12', 'F5', 'M25', 'R11', 'U17', 'AC17', 'AK14', 'F7', 'M9', 'R12', 'U18', 'AC7', 'AK18', 'G24', 'N11', 'R13', 'U19', 'AC8', 'AK20', 'G6', 'N12', 'R14', 'U2', 'AE2', 'AK24', 'H24', 'N13', 'AJ24', 'R15', 'U20', 'AF10', 'AK30', 'J11', 'N14', 'R16', 'U21', 'AF18', 'AK8', 'J15', 'N15', 'R17', 'U22', 'AF20', 'B10', 'J16', 'N16', 'R18', 'U26', 'AF22', 'B12', 'J2', 'N17', 'R19', 'U9', 'AF26', 'B20', 'J21', 'N18', 'R20', 'V11', 'AF27', 'B22', 'J23', 'N19', 'R9', 'V12', 'AF29', 'B24', 'J26', 'N2', 'T10', 'V13', 'B26', 'AF5', 'J7', 'N20', 'T11', 'V14', 'AG13', 'B8', 'J9', 'N21', 'T12', 'V15', 'AG15', 'C11', 'K16', 'N22', 'T13', 'V16', 'A1', 'AG17', 'C21', 'K18', 'N26', 'T14', 'V17', 'A12', 'AG19', 'C23', 'K22', 'N6', 'T15', 'V18', 'A14', 'AG23', 'C28', 'K23', 'P10', 'T16', 'V19', 'A18', 'AG9', 'C3', 'K29', 'P11', 'T17', 'V20', 'A20', 'AH11', 'C9', 'K5', 'P12', 'T18', 'V21', 'A24', 'D13', 'AH21', 'K7', 'P13', 'T19', 'V22', 'A30', 'AH23', 'D15', 'K8', 'P14', 'T20', 'V25', 'A8', 'AH28', 'D17', 'K9', 'P15', 'T21', 'V29', 'AA13', 'AH9', 'D19', 'L16', 'P16', 'T22', 'V5', 'AA2', 'AJ10', 'D23', 'L22', 'P17', 'T23', 'V6', 'AA26', 'AJ12', 'D9', 'L23', 'P18', 'U10', 'W13', 'AB15', 'AJ20', 'E10', 'L8', 'P19', 'P29', 'U11', 'W15', 'AB22', 'AJ22', 'E18', 'M11', 'P20', 'U12', 'W16', 'AB24', 'E2']}] }),
        Part(**{ 'name':'XC6SLX150-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150-CSG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L14N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L14P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L12P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L12N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L11P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L11N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L13P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L13N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F8',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G8',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='D14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='T15',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J20',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='RFUSE',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U17',name='VBATT',func=pin_types.PWRIN,unit=4),
            Pin(num='U19',name='VFS',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E19', 'A5', 'H12', 'M18', 'U18', 'M17', 'A6', 'C15', 'E20', 'M19', 'H13', 'U20', 'A7', 'C16', 'E22', 'H14', 'M20', 'U22', 'A8', 'C17', 'E8', 'H16', 'M21', 'V17', 'A10', 'A9', 'C18', 'E9', 'H17', 'M22', 'V18', 'AA19', 'C19', 'F10', 'H18', 'N15', 'V19', 'AA20', 'C20', 'F12', 'H19', 'N16', 'V20', 'AA21', 'C21', 'F13', 'H20', 'N18', 'V21', 'AA22', 'C22', 'F14', 'H21', 'N19', 'V22', 'AB19', 'C5', 'F15', 'H22', 'N20', 'W20', 'AB20', 'C6', 'F16', 'J16', 'N22', 'W21', 'AB21', 'C7', 'F17', 'J17', 'P15', 'W22', 'B10', 'C8', 'F18', 'J18', 'P16', 'Y19', 'B11', 'C9', 'F19', 'J19', 'P17', 'Y20', 'B12', 'D10', 'F20', 'J21', 'P18', 'Y21', 'B14', 'D11', 'F21', 'J22', 'P19', 'Y22', 'B15', 'D12', 'F22', 'K16', 'P20', 'B16', 'D13', 'F9', 'K17', 'P21', 'B18', 'D15', 'G10', 'K18', 'P22', 'B19', 'D17', 'G11', 'K19', 'R15', 'B20', 'A11', 'D19', 'G13', 'K20', 'R16', 'B21', 'D20', 'G14', 'K21', 'R17', 'B22', 'D21', 'G15', 'K22', 'R19', 'A4', 'B3', 'D22', 'G16', 'L15', 'R20', 'B4', 'A13', 'D6', 'G17', 'L16', 'R21', 'A12', 'B6', 'D7', 'G19', 'A14', 'L17', 'R22', 'B7', 'D8', 'G20', 'A15', 'L19', 'T17', 'B8', 'A16', 'D9', 'G21', 'L20', 'T18', 'A17', 'C10', 'E10', 'G22', 'L21', 'T19', 'A18', 'C11', 'A19', 'E12', 'G9', 'L22', 'T20', 'A20', 'C12', 'C14', 'E13', 'H10', 'M16', 'T21', 'A21', 'C13', 'E17', 'H11', 'T22']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB10', 'K5', 'R1', 'U6', 'Y11', 'AB11', 'F2', 'K6', 'U8', 'R11', 'Y12', 'AB12', 'F3', 'K7', 'R13', 'U9', 'Y13', 'AB13', 'F4', 'K8', 'R2', 'V1', 'Y14', 'AB14', 'F5', 'L1', 'R3', 'V11', 'Y15', 'AB15', 'F6', 'L2', 'R4', 'V12', 'Y16', 'AB16', 'F7', 'L3', 'R7', 'V13', 'Y17', 'AB17', 'F8', 'L4', 'V15', 'R8', 'Y18', 'AB18', 'G1', 'L6', 'R9', 'V16', 'Y2', 'AB2', 'G2', 'L7', 'T1', 'V2', 'Y3', 'AB3', 'G3', 'M1', 'T10', 'V3', 'Y4', 'AB4', 'G4', 'M2', 'T11', 'V5', 'Y5', 'AB5', 'G6', 'M3', 'T12', 'V7', 'Y6', 'AB6', 'G7', 'M4', 'T13', 'V8', 'Y7', 'AB7', 'G8', 'M5', 'T14', 'V9', 'Y8', 'U5', 'AB8', 'H1', 'M6', 'T2', 'W1', 'Y9', 'AB9', 'H2', 'M7', 'T3', 'W10', 'A2', 'B1', 'H3', 'M8', 'T4', 'W11', 'A3', 'B2', 'H4', 'N1', 'T5', 'W12', 'AA10', 'C1', 'H5', 'N3', 'T6', 'W13', 'AA11', 'C2', 'H6', 'N4', 'T7', 'W14', 'AA12', 'C3', 'H8', 'N5', 'T8', 'W15', 'AA14', 'C4', 'J1', 'N6', 'T9', 'W17', 'AA15', 'D1', 'J3', 'N7', 'U1', 'W2', 'AA16', 'D2', 'J4', 'P1', 'U10', 'W3', 'AA18', 'D3', 'J5', 'P2', 'U12', 'W4', 'AA2', 'D5', 'J6', 'P3', 'U13', 'W5', 'AA3', 'E1', 'J7', 'P4', 'U14', 'W6', 'AA4', 'E3', 'K1', 'P5', 'U15', 'W8', 'AA6', 'E4', 'K2', 'P6', 'U3', 'W9', 'AA7', 'E5', 'F1', 'K3', 'P7', 'U4', 'Y1', 'AA8', 'E6', 'K4', 'P8', 'Y10']},{'label': 'uC', 'num': 3, 'pin_nums': ['W18', 'D14', 'E16', 'T15', 'E14', 'AA1', 'E18', 'U16']},{'label': 'uD', 'num': 4, 'pin_nums': ['AB22', 'K12', 'P11', 'B13', 'P12', 'K13', 'B17', 'K14', 'P13', 'B5', 'P14', 'K15', 'B9', 'K9', 'P9', 'D16', 'L10', 'R10', 'D18', 'L11', 'R12', 'D4', 'R14', 'L12', 'E11', 'L13', 'R18', 'E15', 'L14', 'R5', 'E2', 'L18', 'R6', 'E21', 'L5', 'T16', 'E7', 'L8', 'U11', 'F11', 'L9', 'U17', 'G12', 'M10', 'U19', 'G18', 'M11', 'U2', 'G5', 'M12', 'U21', 'H15', 'M13', 'U7', 'H7', 'M14', 'V10', 'H9', 'M15', 'V14', 'J10', 'M9', 'V4', 'J11', 'N10', 'V6', 'J12', 'N11', 'W16', 'J13', 'N12', 'W19', 'J14', 'N13', 'W7', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J20', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10']}] }),
        Part(**{ 'name':'XC6SLX150-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150-FGG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L54N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V19',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L54P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='N15',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='Y20',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='Y22',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P15',name='RFUSE',func=pin_types.PWRIN,unit=4),
            Pin(num='P16',name='VFS',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R17',name='VBATT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T21', 'B7', 'G17', 'D8', 'L15', 'T22', 'B8', 'G19', 'D9', 'L16', 'U18', 'C10', 'E10', 'G20', 'L17', 'U19', 'C11', 'G21', 'E12', 'L19', 'U20', 'C12', 'E13', 'G22', 'L20', 'U22', 'A13', 'C13', 'E14', 'G8', 'A11', 'L21', 'V20', 'A12', 'C14', 'E16', 'G9', 'A14', 'L22', 'V21', 'C15', 'H10', 'E17', 'A15', 'M16', 'V22', 'C16', 'A16', 'E19', 'H11', 'K22', 'M17', 'W20', 'A17', 'C17', 'E20', 'H12', 'M18', 'W21', 'A18', 'C19', 'A20', 'E22', 'H13', 'M19', 'W22', 'A21', 'C20', 'E8', 'H14', 'M20', 'A3', 'C21', 'E9', 'H16', 'M21', 'A4', 'C22', 'F10', 'H17', 'M22', 'A5', 'C5', 'F12', 'H18', 'N16', 'C6', 'A6', 'F13', 'H19', 'N18', 'A7', 'C7', 'F14', 'H20', 'N19', 'A8', 'C8', 'F15', 'H21', 'N20', 'A9', 'C9', 'F16', 'H22', 'N22', 'B10', 'D10', 'F17', 'J16', 'P17', 'B11', 'D11', 'F18', 'J17', 'P18', 'B12', 'D12', 'F19', 'J18', 'P19', 'B14', 'D13', 'F20', 'J19', 'P20', 'B15', 'D14', 'F21', 'J20', 'P21', 'B16', 'D15', 'F22', 'J22', 'P22', 'D7', 'B18', 'D17', 'F8', 'K16', 'R19', 'B19', 'D19', 'A10', 'F9', 'K17', 'R20', 'B20', 'D20', 'G10', 'K18', 'R21', 'B21', 'D21', 'G11', 'K19', 'R22', 'B22', 'D22', 'G13', 'K20', 'T19', 'D6', 'B4', 'G14', 'K21', 'T20', 'B6', 'G16']},{'label': 'uB', 'num': 2, 'pin_nums': ['W14', 'E5', 'AB12', 'R1', 'K5', 'U13', 'W15', 'E6', 'AB13', 'R11', 'K6', 'U14', 'W17', 'AB14', 'F1', 'K7', 'R13', 'U15', 'W18', 'AB15', 'F2', 'K8', 'R15', 'U16', 'W2', 'AB16', 'F3', 'L1', 'R16', 'U17', 'W3', 'AB17', 'F4', 'L2', 'R2', 'U3', 'W4', 'AB18', 'F5', 'L3', 'R3', 'U4', 'W5', 'AB19', 'F6', 'R4', 'L4', 'U5', 'W6', 'AB2', 'F7', 'L6', 'R7', 'U6', 'W8', 'AB20', 'G1', 'L7', 'R8', 'U8', 'W9', 'AB21', 'G2', 'M1', 'R9', 'U9', 'Y1', 'AB3', 'G3', 'M2', 'T1', 'V1', 'Y10', 'A2', 'AB4', 'G4', 'M3', 'T10', 'V11', 'Y11', 'AA10', 'AB5', 'G6', 'M4', 'T11', 'V12', 'Y12', 'AA11', 'AB6', 'G7', 'M5', 'T12', 'V13', 'Y13', 'AA12', 'AB7', 'H1', 'M6', 'T13', 'V15', 'Y14', 'AA14', 'AB8', 'H2', 'M7', 'T14', 'E4', 'V16', 'Y15', 'AA15', 'AB9', 'H3', 'M8', 'T15', 'V17', 'Y16', 'AA16', 'B1', 'H4', 'N1', 'T16', 'V18', 'Y17', 'AA18', 'B2', 'H5', 'N3', 'T17', 'V19', 'Y18', 'AA19', 'B3', 'H6', 'N4', 'T18', 'V2', 'Y19', 'AA2', 'C1', 'H8', 'N5', 'T2', 'V3', 'Y2', 'AA20', 'C2', 'J1', 'N6', 'T3', 'V5', 'Y21', 'AA21', 'C3', 'J3', 'N7', 'T4', 'V7', 'Y3', 'P8', 'AA22', 'C4', 'J4', 'P1', 'T5', 'V8', 'Y4', 'AA3', 'D1', 'J5', 'P2', 'T6', 'V9', 'Y5', 'AA4', 'D2', 'J6', 'P3', 'T7', 'W1', 'Y6', 'AA6', 'D3', 'J7', 'P4', 'T8', 'W10', 'Y7', 'AA7', 'D5', 'K1', 'P5', 'T9', 'W11', 'Y8', 'AA8', 'E1', 'K2', 'P6', 'U1', 'W12', 'Y9', 'AB10', 'E3', 'K3', 'P7', 'U10', 'W13', 'AB11', 'K4', 'U12']},{'label': 'uC', 'num': 3, 'pin_nums': ['AA1', 'Y22', 'N15', 'E18', 'C18', 'Y20', 'A19', 'G15']},{'label': 'uD', 'num': 4, 'pin_nums': ['U7', 'H7', 'V10', 'M14', 'H9', 'M15', 'V14', 'H15', 'J10', 'M9', 'V4', 'J11', 'N10', 'V6', 'J12', 'N11', 'W16', 'J13', 'N12', 'W19', 'J14', 'N13', 'W7', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J21', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12', 'B17', 'K14', 'P13', 'B5', 'K15', 'P14', 'B9', 'K9', 'P15', 'D16', 'L10', 'P16', 'D18', 'L11', 'P9', 'D4', 'L12', 'R10', 'E11', 'L13', 'R12', 'L14', 'E15', 'R14', 'E2', 'L18', 'R17', 'E21', 'L5', 'R18', 'E7', 'L8', 'R5', 'F11', 'L9', 'R6', 'G12', 'M10', 'U11', 'G18', 'M11', 'U2', 'G5', 'M12', 'U21', 'M13']}] }),
        Part(**{ 'name':'XC6SLX150-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150-FGG676\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L12N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE24',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L19N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L31N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L19P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L31P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L54N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L30N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L54P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L30P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L25N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L55N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L25P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L55P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L9N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L53N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L9P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L53P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M21',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L56P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L56N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L55N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L55P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='V22',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA13',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='IO_L4P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB15',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L4N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC11',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC12',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC19',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC20',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD17',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD18',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD19',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD21',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD22',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE11',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE17',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF10',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF12',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF17',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L27P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L27N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y13',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A23',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='D22',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D26',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E23',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F22',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='F24',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='F5',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G19',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G20',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G21',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G22',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G23',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G6',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H18',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H19',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H20',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H21',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H22',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H26',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J10',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J20',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J21',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J22',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='J7',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K21',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K22',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K24',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='K5',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K9',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L20',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L21',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L8',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M24',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M26',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N26',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='TDO',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='CMPCS_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='SUSPEND',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='DONE_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='C23',name='TMS',func=pin_types.BIDIR,unit=4),
            Pin(num='E21',name='TCK',func=pin_types.BIDIR,unit=4),
            Pin(num='F20',name='TDI',func=pin_types.BIDIR,unit=4),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AA10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA16',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA20',name='RFUSE',func=pin_types.PWRIN,unit=5),
            Pin(num='AA21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB19',name='VFS',func=pin_types.PWRIN,unit=5),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='G15',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='W20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='W21',name='VBATT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['F16', 'R20', 'V24', 'A6', 'B16', 'D14', 'F17', 'K18', 'R21', 'V26', 'B18', 'A7', 'D15', 'F18', 'K19', 'R22', 'W18', 'A8', 'B19', 'D16', 'F7', 'L17', 'R23', 'W19', 'A9', 'B20', 'D17', 'F8', 'L18', 'R24', 'W22', 'AA22', 'B22', 'D18', 'F9', 'L19', 'R25', 'W23', 'AA23', 'B3', 'D19', 'G10', 'L23', 'R26', 'W24', 'AA24', 'B4', 'D20', 'G11', 'L24', 'T18', 'W25', 'B6', 'AA25', 'D21', 'G13', 'M18', 'T19', 'W26', 'AA26', 'B7', 'D5', 'G14', 'M19', 'T20', 'Y20', 'AB21', 'B8', 'A12', 'D6', 'G16', 'M20', 'T22', 'Y21', 'AB22', 'C10', 'D7', 'G17', 'M21', 'T23', 'Y22', 'AB23', 'C11', 'D8', 'G18', 'B15', 'M23', 'T24', 'Y24', 'AB24', 'C12', 'D9', 'G8', 'N17', 'T25', 'Y25', 'AB26', 'C13', 'E10', 'G9', 'N18', 'T26', 'Y26', 'AC23', 'C14', 'E12', 'H10', 'N19', 'U17', 'AC24', 'C15', 'A11', 'E13', 'H12', 'N20', 'U18', 'AC25', 'C16', 'E14', 'H13', 'N21', 'U19', 'A13', 'AC26', 'C17', 'E16', 'H14', 'N22', 'U20', 'AD24', 'C18', 'E17', 'H15', 'N23', 'U21', 'AD25', 'C19', 'E18', 'H16', 'N24', 'U22', 'AD26', 'C20', 'A14', 'E19', 'H17', 'P17', 'U23', 'AE23', 'C21', 'A15', 'E20', 'H9', 'P18', 'U24', 'A16', 'AE24', 'C22', 'E6', 'J11', 'P20', 'U25', 'A17', 'AE25', 'C5', 'E8', 'J12', 'A18', 'P21', 'U26', 'A19', 'AE26', 'C6', 'E9', 'J13', 'P22', 'V17', 'A2', 'AF24', 'C7', 'F10', 'J14', 'P23', 'V18', 'A20', 'AF25', 'C8', 'F11', 'J15', 'P24', 'V19', 'A21', 'C9', 'B10', 'F12', 'J16', 'P26', 'V20', 'A22', 'B11', 'D10', 'F13', 'J17', 'R17', 'V21', 'A3', 'B12', 'D11', 'F14', 'K12', 'K15', 'R18', 'V22', 'A4', 'B14', 'D12', 'F15', 'K14', 'A10', 'R19', 'V23', 'A5', 'D13']},{'label': 'uB', 'num': 2, 'pin_nums': ['AE19', 'R9', 'Y8', 'V6', 'AB10', 'AC7', 'AE2', 'L7', 'T1', 'Y9', 'V7', 'AB11', 'AC9', 'AE20', 'M10', 'T10', 'V8', 'AB13', 'AD1', 'AE21', 'M4', 'T2', 'W1', 'AB14', 'AD10', 'AE3', 'M6', 'T3', 'W10', 'AB15', 'AD11', 'AE4', 'M7', 'T4', 'W11', 'AB17', 'AD12', 'AE5', 'M8', 'T6', 'W12', 'AB18', 'AD13', 'AE7', 'M9', 'T7', 'W13', 'AB3', 'AD14', 'AE8', 'N3', 'T8', 'W14', 'AB4', 'AD15', 'AE9', 'N4', 'T9', 'W16', 'AB5', 'AD16', 'AF10', 'N5', 'U1', 'W17', 'AB6', 'AD17', 'AF11', 'N6', 'U12', 'W2', 'AB7', 'AD18', 'AF12', 'N7', 'U13', 'W3', 'AB8', 'AD19', 'AF13', 'N8', 'U15', 'W4', 'AB9', 'AD2', 'AF14', 'N9', 'U2', 'W5', 'AC1', 'AD20', 'AF15', 'P1', 'U3', 'W6', 'AA1', 'AC10', 'AD21', 'AF16', 'P10', 'U4', 'W7', 'AA11', 'AC11', 'AD22', 'AF17', 'P3', 'U5', 'W8', 'AA12', 'AC12', 'AD3', 'AF18', 'P4', 'U7', 'W9', 'AA13', 'AC13', 'AD4', 'AF19', 'P5', 'U8', 'Y1', 'AA14', 'AC14', 'AD5', 'AF2', 'P6', 'U9', 'Y10', 'AA15', 'AC15', 'AD6', 'AF20', 'P7', 'V1', 'Y12', 'AA17', 'AC16', 'AD7', 'AF21', 'P8', 'V10', 'Y13', 'AA18', 'AC17', 'AD8', 'AF22', 'P9', 'V11', 'Y14', 'AA19', 'AC18', 'AD9', 'AF4', 'R1', 'V12', 'Y15', 'AA2', 'AC19', 'AE1', 'AF5', 'R10', 'V13', 'Y16', 'AA3', 'AC2', 'AE11', 'AF6', 'R2', 'V14', 'Y17', 'AA4', 'AC20', 'AE12', 'AF7', 'AC6', 'R3', 'V15', 'Y18', 'AA5', 'AC21', 'AE13', 'AF8', 'R4', 'V16', 'Y2', 'AA7', 'AC3', 'AE15', 'AF9', 'R5', 'V3', 'Y3', 'AA8', 'AC4', 'AE16', 'L3', 'L6', 'R6', 'V4', 'Y5', 'AA9', 'AC5', 'AE17', 'L4', 'R7', 'V5', 'Y6', 'AB1']},{'label': 'uC', 'num': 3, 'pin_nums': ['H22', 'H24', 'E4', 'K4', 'E5', 'H25', 'K5', 'A23', 'F1', 'H26', 'K6', 'A25', 'F22', 'H3', 'K7', 'B1', 'F23', 'H5', 'K8', 'B2', 'F24', 'H6', 'K9', 'B23', 'F26', 'H7', 'L1', 'B24', 'F3', 'H8', 'L2', 'B25', 'F4', 'J1', 'L20', 'B26', 'F5', 'J10', 'L21', 'C1', 'G1', 'J2', 'L25', 'C2', 'G19', 'J20', 'L26', 'C24', 'G2', 'J21', 'L8', 'C25', 'G20', 'J22', 'L9', 'C26', 'G21', 'J23', 'M1', 'C3', 'G22', 'J24', 'M2', 'C4', 'G23', 'J25', 'M24', 'D1', 'G24', 'J26', 'M25', 'D2', 'G25', 'J3', 'M26', 'D22', 'G26', 'J4', 'M3', 'D23', 'G3', 'J5', 'N1', 'D24', 'G4', 'J6', 'N2', 'D25', 'G5', 'J7', 'N25', 'D26', 'G6', 'K1', 'N26', 'D3', 'G7', 'K10', 'E1', 'H1', 'K20', 'E2', 'H18', 'K21', 'E23', 'H19', 'K22', 'E24', 'H2', 'K23', 'E25', 'H20', 'K24', 'K3', 'E26', 'H21', 'K26', 'E3']},{'label': 'uD', 'num': 4, 'pin_nums': ['AF3', 'AF23', 'C23', 'F20', 'AC22', 'E21', 'A24', 'AD23']},{'label': 'uE', 'num': 5, 'pin_nums': ['M13', 'M14', 'F19', 'T14', 'A1', 'F2', 'M15', 'T15', 'A26', 'F21', 'M16', 'T16', 'AA10', 'F25', 'M17', 'T17', 'AA16', 'F6', 'M22', 'T21', 'AA20', 'G12', 'M5', 'T5', 'AA21', 'G15', 'N10', 'U10', 'AA6', 'H11', 'N11', 'U11', 'AB12', 'H23', 'N12', 'U14', 'AB16', 'H4', 'N13', 'U16', 'AB19', 'J18', 'N14', 'U6', 'AB2', 'J19', 'N15', 'V2', 'AB20', 'J8', 'N16', 'V25', 'AB25', 'J9', 'P11', 'V9', 'AC8', 'K11', 'P12', 'W15', 'AE10', 'K13', 'P13', 'W20', 'AE14', 'K16', 'P14', 'W21', 'AE18', 'K17', 'P15', 'Y11', 'AE22', 'K2', 'P16', 'Y19', 'AE6', 'K25', 'P19', 'Y23', 'AF1', 'L10', 'P2', 'Y4', 'AF26', 'L11', 'P25', 'Y7', 'B13', 'L12', 'R11', 'B17', 'L13', 'R12', 'B21', 'L14', 'R13', 'B5', 'L15', 'R14', 'B9', 'L16', 'R15', 'D4', 'L22', 'R16', 'E11', 'L5', 'R8', 'E15', 'M11', 'T11', 'T13', 'E22', 'M12', 'T12', 'E7']}] }),
        Part(**{ 'name':'XC6SLX150-FGG900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150-FGG900'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150-FGG900\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L30N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L31N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L53N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L9N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA24',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA27',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA28',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA29',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA30',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB28',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB30',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AC27',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC28',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC29',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC30',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD27',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD28',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD30',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE27',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE28',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE29',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE30',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF28',name='IO_L55P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF30',name='IO_L55N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG26',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG27',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG28',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG29',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG30',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH26',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH27',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AH30',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ27',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AJ28',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ29',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ30',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK27',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK28',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK29',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO_L30P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B21',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B25',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L9P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L19N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L31P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L41N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L54N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='IO_L53P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C24',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C25',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L12N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L19P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L29N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L41P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L54P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L55N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D24',name='IO_L61N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L29P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L55P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E24',name='IO_L61P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L20N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L28N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L42N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L60N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L20P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L28P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L42P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L60P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L25N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H19',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L25P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L27N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J17',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L27P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M24',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N27',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P22',name='IO_L56P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L56N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P24',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L54P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L54N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R24',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R27',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R29',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T28',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T30',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U24',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U27',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U28',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U29',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U30',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='V23',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V27',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V28',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V30',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W24',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W27',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W28',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W29',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W30',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y27',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y28',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y30',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L5N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L5P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA15',name='IO_L37P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA19',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L37N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L25P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC12',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC16',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='IO_L25N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC20',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC22',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L56P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L36P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD17',name='IO_L27P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD18',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD19',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD20',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD21',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD22',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD23',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD24',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD6',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE10',name='IO_L56N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE13',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE14',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L36N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE17',name='IO_L27N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE18',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE22',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE24',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L6P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE6',name='IO_L4P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE9',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF1',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF13',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF17',name='IO_L26P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF21',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF25',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF3',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L4N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF9',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG1',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG10',name='IO_L55P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG11',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG12',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG13',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG14',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG15',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG16',name='IO_L35P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG17',name='IO_L26N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG18',name='IO_L24P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG19',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AG20',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG21',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG22',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG23',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG24',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG25',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG5',name='IO_L6N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG7',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG8',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG9',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH1',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH10',name='IO_L55N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH11',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH12',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH14',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH15',name='IO_L38P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH16',name='IO_L35N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH17',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH18',name='IO_L24N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH19',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH2',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH20',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH21',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH22',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH23',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH24',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH25',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH3',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH6',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH8',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH9',name='IO_L54P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ1',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ10',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ12',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ14',name='IO_L39P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ16',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ18',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ2',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ20',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ22',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ23',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ24',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ26',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ4',name='IO_L14P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK10',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK11',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK12',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK14',name='IO_L39N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK15',name='IO_L38N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK16',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK17',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK18',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK19',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK2',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK20',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK21',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK22',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK23',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK24',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK25',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK26',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK3',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK4',name='IO_L14N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK6',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK7',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK8',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK9',name='IO_L54N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N1',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L56N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L56P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L27N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L27P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='V1',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y6',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A2',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A26',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A27',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A28',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A29',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B27',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B28',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='B29',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B30',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='B5',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='C26',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C27',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C29',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C30',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D27',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D28',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D3',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D30',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E27',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E28',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E30',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F25',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F27',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F28',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='G25',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='G27',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G28',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G29',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H26',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H27',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H28',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H3',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H6',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J27',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J28',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K24',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K26',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K27',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K28',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K30',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='L1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='L24',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='L27',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L28',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L7',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M26',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M27',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M28',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M3',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M30',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M5',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='N24',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='AB25',name='SUSPEND',func=pin_types.BIDIR,unit=4),
            Pin(num='AB8',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AC25',name='CMPCS_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AD25',name='DONE_2',func=pin_types.BIDIR,unit=4),
            Pin(num='F24',name='TCK',func=pin_types.BIDIR,unit=4),
            Pin(num='G24',name='TDO',func=pin_types.BIDIR,unit=4),
            Pin(num='H25',name='TDI',func=pin_types.BIDIR,unit=4),
            Pin(num='K25',name='TMS',func=pin_types.BIDIR,unit=4),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AA16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='AA21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AB13',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AB17',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AB26',name='VBATT',func=pin_types.PWRIN,unit=5),
            Pin(num='AB27',name='RFUSE',func=pin_types.PWRIN,unit=5),
            Pin(num='AB9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AC24',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AC7',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AE11',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AE21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AF27',name='VFS',func=pin_types.PWRIN,unit=5),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C28',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F20',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F29',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H24',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J23',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='J24',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K17',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K29',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M25',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N18',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='N22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P18',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U18',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='V14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='V17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='V18',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='V25',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='W11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='W12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='W15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='W16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='W19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='W20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y19',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y20',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA20',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB23',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB24',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB29',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AC10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AC23',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF29',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AF5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ25',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V20',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V29',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W23',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='Y13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='Y17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='Y18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='Y21',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B11', 'E22', 'K14', 'G20', 'T29', 'Y29', 'AC29', 'B12', 'C8', 'E23', 'M23', 'G21', 'Y30', 'T30', 'AC30', 'B13', 'C9', 'E24', 'G22', 'M24', 'U23', 'A13', 'AD26', 'B15', 'D10', 'E6', 'G23', 'N23', 'U24', 'AD27', 'B16', 'D11', 'E7', 'G6', 'N27', 'U25', 'AD28', 'B17', 'D12', 'E8', 'G7', 'N28', 'A11', 'U27', 'A12', 'AD29', 'B19', 'D13', 'F11', 'A14', 'G8', 'N29', 'U28', 'AD30', 'B20', 'D14', 'F12', 'G9', 'N30', 'A15', 'U29', 'AE25', 'B21', 'A16', 'D15', 'F13', 'H10', 'P21', 'U30', 'A17', 'AE26', 'B23', 'D16', 'F14', 'H11', 'P22', 'A18', 'V21', 'AE27', 'B24', 'A19', 'D17', 'F15', 'H13', 'P23', 'V23', 'A20', 'AE28', 'B25', 'D18', 'F16', 'H14', 'P24', 'A21', 'V24', 'AE29', 'B7', 'D19', 'F17', 'A10', 'H15', 'P25', 'A22', 'V26', 'K12', 'AE30', 'B8', 'D20', 'F18', 'H17', 'P26', 'A23', 'V27', 'AF28', 'B9', 'D21', 'F19', 'H18', 'P27', 'A24', 'V28', 'AF30', 'C10', 'D22', 'F21', 'H19', 'P28', 'A25', 'V30', 'AG26', 'C11', 'D23', 'F22', 'H21', 'P30', 'A6', 'W21', 'AG27', 'C12', 'D24', 'F23', 'H22', 'R21', 'A7', 'W22', 'AG28', 'C13', 'D25', 'F6', 'H7', 'R22', 'A8', 'W24', 'AG29', 'C14', 'D6', 'F7', 'J10', 'R23', 'A9', 'W25', 'AG30', 'C15', 'D7', 'F8', 'J11', 'R24', 'AA23', 'W26', 'AH26', 'C16', 'D8', 'F9', 'J12', 'R25', 'AA24', 'W27', 'AH27', 'C17', 'D9', 'G10', 'J13', 'R26', 'AA25', 'W28', 'AH29', 'C18', 'E10', 'G11', 'J14', 'R27', 'AA27', 'W29', 'AH30', 'C19', 'E11', 'G12', 'J15', 'R28', 'AA28', 'W30', 'AJ27', 'C20', 'E12', 'G13', 'J16', 'R29', 'AA29', 'Y22', 'AJ28', 'C21', 'E14', 'G14', 'J17', 'R30', 'AA30', 'Y23', 'AJ29', 'C22', 'E15', 'G15', 'J19', 'T24', 'AB28', 'Y24', 'AJ30', 'C23', 'E16', 'G16', 'J20', 'T25', 'AB30', 'Y25', 'AK27', 'C24', 'E18', 'G17', 'J21', 'T26', 'AC26', 'Y26', 'AK28', 'C25', 'C7', 'E19', 'G18', 'K11', 'T27', 'AC27', 'Y27', 'AK29', 'C6', 'AC28', 'E20', 'G19', 'T28', 'Y28']},{'label': 'uB', 'num': 2, 'pin_nums': ['V4', 'AD23', 'AG22', 'AF12', 'AH6', 'AK18', 'P4', 'V7', 'AC11', 'AD24', 'AG23', 'AF13', 'AK19', 'AH7', 'P6', 'V8', 'AK17', 'AC12', 'AD3', 'AF15', 'AG24', 'AH8', 'AK2', 'AA1', 'P7', 'V9', 'AC14', 'AD4', 'AF16', 'AG25', 'AH9', 'AK20', 'AA10', 'P8', 'W1', 'AC15', 'AD5', 'AF17', 'AG3', 'AJ1', 'AK21', 'AA11', 'R1', 'W10', 'AC16', 'AD6', 'AF19', 'AG4', 'AJ10', 'AK22', 'AA12', 'R2', 'W2', 'AC18', 'AD7', 'AF2', 'AG5', 'AJ11', 'AK23', 'AA14', 'R3', 'W3', 'AC19', 'AD8', 'AG6', 'AF20', 'AJ12', 'AK24', 'AA15', 'R4', 'W4', 'AC2', 'AD9', 'AF21', 'AG7', 'AJ14', 'AK25', 'AA18', 'R5', 'W5', 'AC20', 'AE1', 'AF23', 'AG8', 'AJ15', 'AK26', 'AA19', 'R6', 'W6', 'AC21', 'AE10', 'AF24', 'AG9', 'AJ16', 'AK3', 'AA3', 'R7', 'W7', 'AC22', 'AE12', 'AF25', 'AH1', 'AJ18', 'AK4', 'AA4', 'T1', 'W9', 'AC3', 'AE13', 'AF3', 'AH10', 'AJ19', 'AK5', 'AA5', 'T2', 'Y1', 'AC4', 'AE14', 'AF4', 'AH11', 'AJ2', 'AK6', 'AA6', 'T3', 'Y10', 'AC5', 'AE15', 'AF6', 'AH12', 'AJ20', 'AK7', 'AA7', 'T4', 'Y2', 'AC6', 'AE16', 'AF7', 'AH13', 'AJ22', 'AK8', 'AA8', 'T5', 'Y3', 'AC9', 'AE17', 'AF8', 'AH14', 'AJ23', 'AK9', 'AA9', 'T6', 'Y4', 'AD1', 'AE18', 'AF9', 'AH15', 'AJ24', 'L8', 'AB1', 'T7', 'Y5', 'AD10', 'AE19', 'AG1', 'AH16', 'AJ26', 'M6', 'AB11', 'T8', 'Y6', 'AD11', 'AE20', 'AG10', 'AH17', 'AJ3', 'M7', 'AB12', 'T9', 'Y7', 'AD12', 'AE22', 'AG11', 'AH18', 'AJ4', 'M9', 'AB14', 'U1', 'Y8', 'AD13', 'AE23', 'AG12', 'AH19', 'AJ6', 'N1', 'AB15', 'U3', 'Y9', 'AD14', 'AE24', 'AG13', 'AH2', 'AJ7', 'N10', 'AB16', 'U4', 'AD15', 'AE3', 'AG14', 'AH20', 'AJ8', 'N3', 'AB18', 'U5', 'AD16', 'AE4', 'AG15', 'AH21', 'AK10', 'N4', 'AB19', 'U6', 'AD17', 'AE5', 'AG16', 'AH22', 'AK11', 'N5', 'AB2', 'U7', 'AD18', 'AE6', 'AG17', 'AH23', 'AK12', 'N7', 'AG21', 'AB20', 'U8', 'AD19', 'AE7', 'AG18', 'AH24', 'AK13', 'N8', 'AB3', 'V1', 'AD2', 'AE8', 'AG19', 'AH25', 'AK14', 'N9', 'AB4', 'V10', 'AD20', 'AE9', 'AG2', 'AH3', 'AK15', 'P1', 'AB6', 'V2', 'AC1', 'AD21', 'AF1', 'AG20', 'AH4', 'AK16', 'P2', 'AB7', 'V3', 'AD22', 'AF11', 'AH5', 'P3']},{'label': 'uC', 'num': 3, 'pin_nums': ['B2', 'E30', 'L4', 'H5', 'E4', 'B27', 'L5', 'H6', 'B28', 'E5', 'J1', 'L6', 'F1', 'B29', 'L7', 'J25', 'F2', 'B3', 'J27', 'M1', 'B30', 'F25', 'J28', 'M2', 'B4', 'F26', 'J29', 'M26', 'B5', 'F27', 'M27', 'J3', 'C1', 'F28', 'J30', 'M28', 'C2', 'F3', 'J4', 'M29', 'C26', 'F30', 'J5', 'M3', 'C27', 'F4', 'J6', 'M30', 'C29', 'G1', 'K1', 'M4', 'E3', 'C30', 'G2', 'K2', 'M5', 'C4', 'G25', 'K24', 'N24', 'C5', 'G26', 'K26', 'N25', 'D1', 'G27', 'K27', 'D2', 'G28', 'K28', 'D26', 'G29', 'K3', 'G3', 'D27', 'K30', 'D28', 'G30', 'K4', 'D29', 'G4', 'K6', 'D3', 'G5', 'L1', 'A2', 'D30', 'H1', 'L2', 'A26', 'D4', 'H2', 'L24', 'A27', 'D5', 'H26', 'L25', 'A28', 'E1', 'H27', 'L26', 'A29', 'E26', 'H28', 'L27', 'A3', 'E27', 'H29', 'L28', 'A4', 'E28', 'H3', 'L29', 'A5', 'E29', 'H30', 'L3', 'B1', 'H4', 'L30']},{'label': 'uD', 'num': 4, 'pin_nums': ['G24', 'AD25', 'AB8', 'K25', 'AC25', 'AB25', 'F24', 'H25']},{'label': 'uE', 'num': 5, 'pin_nums': ['V13', 'J18', 'AB27', 'N2', 'L17', 'R9', 'V14', 'J2', 'AB9', 'N20', 'L18', 'T10', 'V17', 'AC24', 'J22', 'L19', 'N21', 'T11', 'V18', 'AC7', 'J23', 'L20', 'N22', 'T12', 'V25', 'AE11', 'J24', 'L21', 'N26', 'T13', 'V5', 'AE21', 'J26', 'L22', 'N6', 'T14', 'V6', 'AF27', 'J7', 'L23', 'P10', 'T15', 'W11', 'B10', 'J8', 'P11', 'L9', 'T16', 'W12', 'B14', 'J9', 'M10', 'P12', 'T17', 'W15', 'B18', 'K10', 'M11', 'P13', 'T18', 'W16', 'B22', 'K13', 'M12', 'P14', 'T19', 'W19', 'B26', 'K15', 'M13', 'P15', 'T20', 'W20', 'B6', 'K16', 'M14', 'P16', 'T21', 'Y12', 'C28', 'K17', 'M15', 'P17', 'T22', 'Y15', 'C3', 'K18', 'M16', 'P18', 'T23', 'Y16', 'E13', 'K19', 'M17', 'P19', 'U10', 'Y19', 'E17', 'K20', 'M18', 'P20', 'U11', 'Y20', 'E2', 'K21', 'M19', 'P29', 'U12', 'E21', 'K22', 'M20', 'P5', 'U13', 'E25', 'K23', 'M21', 'P9', 'U14', 'E9', 'K29', 'M22', 'R10', 'U15', 'F10', 'K5', 'M25', 'R11', 'U16', 'F20', 'K7', 'M8', 'R12', 'H9', 'U17', 'K8', 'F29', 'N11', 'R13', 'U18', 'F5', 'K9', 'N12', 'R14', 'U19', 'A1', 'H12', 'L10', 'N13', 'R15', 'U2', 'A30', 'H16', 'L11', 'N14', 'R16', 'U20', 'AA16', 'H20', 'L12', 'N15', 'R17', 'U21', 'AA21', 'H23', 'L13', 'N16', 'R18', 'U22', 'AB13', 'H24', 'L14', 'N17', 'R19', 'U26', 'N19', 'AB17', 'L15', 'H8', 'N18', 'R20', 'U9', 'AB26', 'L16', 'R8']},{'label': 'uF', 'num': 6, 'pin_nums': ['W17', 'AB10', 'AC13', 'AF22', 'AJ25', 'V16', 'W18', 'Y21', 'AB21', 'AA26', 'W23', 'AC17', 'AF26', 'AJ5', 'V19', 'AA13', 'AB22', 'AC23', 'AF29', 'AJ9', 'V20', 'W8', 'AA17', 'AB23', 'AC8', 'AF5', 'AK1', 'V22', 'Y11', 'AA2', 'AB24', 'AE2', 'AH28', 'AK30', 'V29', 'Y13', 'AJ21', 'AA20', 'AB29', 'AF10', 'AJ13', 'V11', 'W13', 'Y14', 'V15', 'AA22', 'AB5', 'AF14', 'AJ17', 'V12', 'W14', 'Y17', 'AF18', 'AC10', 'Y18']}] }),
        Part(**{ 'name':'XC6SLX150T-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150T-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150T-CSG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L69N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L69P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L71N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L71P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L72N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L72P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L70N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L70P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F14',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='C19',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='F17',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='H16',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F18',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VBATT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='RFUSE',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U19',name='VFS',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['M22', 'F11', 'AB20', 'N14', 'H19', 'T22', 'F12', 'AB21', 'H20', 'N15', 'U18', 'B18', 'F16', 'H21', 'N16', 'U20', 'F19', 'B19', 'H22', 'N18', 'U22', 'B20', 'F20', 'H8', 'N19', 'V17', 'B21', 'F21', 'J16', 'N20', 'V18', 'B22', 'F22', 'J17', 'N22', 'V19', 'F6', 'B3', 'J18', 'P15', 'V20', 'B4', 'F7', 'J19', 'P16', 'V21', 'C17', 'F8', 'J20', 'P17', 'V22', 'C18', 'F9', 'J22', 'P18', 'W20', 'C20', 'G10', 'K16', 'P19', 'F10', 'W21', 'C21', 'G11', 'H18', 'K17', 'P20', 'W22', 'C22', 'G12', 'K18', 'P21', 'Y19', 'C5', 'G13', 'K19', 'P22', 'Y20', 'D17', 'G15', 'K20', 'R12', 'A17', 'Y21', 'D18', 'G16', 'K21', 'R13', 'Y22', 'D19', 'G17', 'K22', 'R15', 'D20', 'G19', 'L15', 'R16', 'A18', 'G20', 'D21', 'L16', 'R17', 'A20', 'D22', 'G21', 'L17', 'R19', 'D5', 'G22', 'L19', 'R20', 'A19', 'E10', 'G7', 'L20', 'R21', 'E16', 'G8', 'L21', 'R22', 'E17', 'G9', 'L22', 'T12', 'E19', 'H10', 'M16', 'T13', 'A21', 'E20', 'H11', 'M17', 'T15', 'A4', 'H12', 'E22', 'M18', 'T17', 'A5', 'E5', 'H13', 'AA19', 'M19', 'T18', 'H14', 'AA20', 'E6', 'M20', 'T19', 'AA21', 'T21', 'E8', 'H17', 'AA22', 'M21', 'T20', 'AB19']},{'label': 'uB', 'num': 2, 'pin_nums': ['V5', 'AA8', 'L4', 'F2', 'R9', 'V7', 'Y5', 'AB10', 'L6', 'F3', 'T1', 'V8', 'Y6', 'AB11', 'F4', 'L7', 'T10', 'V9', 'Y7', 'AB12', 'F5', 'M1', 'T11', 'W1', 'Y8', 'AB13', 'G1', 'M2', 'T14', 'W10', 'Y9', 'AB14', 'G2', 'M3', 'T2', 'W11', 'AB15', 'G3', 'M4', 'T3', 'W12', 'AB16', 'M5', 'G4', 'T4', 'W13', 'AB17', 'G6', 'M6', 'T5', 'W14', 'AB18', 'H1', 'M7', 'T6', 'W15', 'AB2', 'H2', 'M8', 'T7', 'W16', 'AB3', 'H3', 'N1', 'T8', 'W17', 'AB4', 'H4', 'N3', 'T9', 'W2', 'AB5', 'H5', 'N4', 'U1', 'W3', 'AB6', 'H6', 'N5', 'U10', 'W4', 'AB7', 'J1', 'N6', 'U13', 'W5', 'AB8', 'J3', 'N7', 'U14', 'W6', 'AB9', 'J4', 'P1', 'U15', 'W8', 'A2', 'B1', 'J5', 'P2', 'U3', 'W9', 'A3', 'B2', 'J6', 'P3', 'U4', 'Y1', 'AA10', 'C1', 'J7', 'P4', 'U5', 'Y10', 'AA11', 'C2', 'K1', 'P5', 'U6', 'Y11', 'AA12', 'C3', 'K2', 'P6', 'AA7', 'U8', 'Y12', 'C4', 'AA14', 'K3', 'P7', 'U9', 'Y13', 'AA15', 'D1', 'K4', 'P8', 'V1', 'Y14', 'AA16', 'D2', 'K5', 'R1', 'V11', 'Y15', 'L3', 'AA18', 'D3', 'K6', 'R2', 'V12', 'Y16', 'AA2', 'D4', 'K7', 'R3', 'V13', 'Y17', 'AA3', 'E1', 'K8', 'R4', 'V15', 'Y18', 'AA4', 'E3', 'L1', 'R6', 'V2', 'Y2', 'Y4', 'AA6', 'E4', 'L2', 'R7', 'V3', 'Y3', 'F1', 'R8']},{'label': 'uC', 'num': 3, 'pin_nums': ['A14', 'D13', 'B6', 'A16', 'D15', 'B8', 'A6', 'C11', 'D7', 'A8', 'C13', 'D9', 'B16', 'B10', 'C15', 'D11', 'E14', 'B12', 'C7', 'F14', 'A10', 'B14', 'C9', 'A12']},{'label': 'uD', 'num': 4, 'pin_nums': ['A7', 'B9', 'D12', 'D8', 'E9', 'B13', 'C10', 'A15', 'D14', 'E11', 'E15', 'E13']},{'label': 'uE', 'num': 5, 'pin_nums': ['F17', 'U12', 'W18', 'C19', 'E18', 'AA1', 'H16', 'U16']},{'label': 'uF', 'num': 6, 'pin_nums': ['J8', 'B17', 'N8', 'J9', 'B5', 'N9', 'B7', 'K10', 'P10', 'K11', 'C12', 'P11', 'C14', 'K12', 'P12', 'K13', 'C16', 'P13', 'C6', 'K14', 'P14', 'C8', 'K15', 'P9', 'D10', 'K9', 'R10', 'D16', 'L10', 'R11', 'J21', 'D6', 'L11', 'R14', 'E12', 'L12', 'R18', 'E2', 'L13', 'R5', 'E21', 'L14', 'T16', 'E7', 'L18', 'U11', 'F13', 'L5', 'U17', 'F15', 'L8', 'U19', 'F18', 'L9', 'U2', 'G14', 'M10', 'U21', 'A1', 'G18', 'M11', 'U7', 'A11', 'G5', 'M12', 'V10', 'A13', 'H15', 'M13', 'V14', 'A22', 'H7', 'M14', 'V16', 'A9', 'H9', 'M15', 'V4', 'AA13', 'J10', 'M9', 'V6', 'AA17', 'J11', 'N10', 'W19', 'AA5', 'J12', 'N11', 'W7', 'AA9', 'J13', 'N12', 'AB1', 'J14', 'N13', 'AB22', 'J15', 'N17', 'B11', 'J2', 'N2', 'B15', 'N21']}] }),
        Part(**{ 'name':'XC6SLX150T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150T-FGG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E12',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F12',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='A21',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='AA22',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='AB2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB21',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='D20',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='G17',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='V18',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P15',name='RFUSE',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='VBATT',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VFS',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G14', 'K21', 'R19', 'D18', 'G15', 'R20', 'K22', 'D19', 'G16', 'L15', 'R21', 'D21', 'G19', 'R22', 'L16', 'A19', 'D22', 'G20', 'L17', 'T17', 'D3', 'G21', 'L19', 'T18', 'D4', 'G22', 'L20', 'T19', 'D5', 'G8', 'T20', 'L21', 'A18', 'E16', 'G9', 'L22', 'T21', 'E17', 'H10', 'A2', 'M16', 'T22', 'E19', 'H11', 'M17', 'U18', 'E20', 'H12', 'M18', 'U19', 'E22', 'H13', 'M19', 'U20', 'A20', 'E5', 'H14', 'M20', 'U22', 'A3', 'E6', 'H16', 'M21', 'V19', 'A4', 'F10', 'H17', 'M22', 'V20', 'A5', 'B18', 'F14', 'H18', 'N15', 'V21', 'B19', 'F15', 'H19', 'B2', 'A17', 'N16', 'V22', 'B20', 'F16', 'H20', 'N18', 'W20', 'B21', 'F17', 'H21', 'N19', 'W21', 'B22', 'F18', 'H22', 'N20', 'W22', 'B3', 'F19', 'J16', 'N22', 'Y21', 'B4', 'F20', 'J17', 'P16', 'Y22', 'C17', 'F21', 'J18', 'P17', 'C18', 'F22', 'J19', 'P18', 'C19', 'F6', 'J20', 'P19', 'C20', 'F7', 'J22', 'P20', 'C21', 'F8', 'K16', 'P21', 'C22', 'F9', 'K17', 'P22', 'C3', 'G10', 'K18', 'R15', 'C4', 'D17', 'G11', 'K19', 'R16', 'C5', 'G13', 'K20', 'R17']},{'label': 'uB', 'num': 2, 'pin_nums': ['E1', 'R11', 'W9', 'U5', 'AA2', 'E3', 'K7', 'R13', 'Y1', 'U6', 'AA20', 'E4', 'K8', 'R2', 'U8', 'Y10', 'AA21', 'F1', 'L1', 'R3', 'U9', 'Y11', 'AA3', 'F2', 'L2', 'R4', 'V1', 'Y12', 'AA4', 'F3', 'L3', 'R7', 'V11', 'Y13', 'AA6', 'F4', 'L4', 'R8', 'V12', 'Y14', 'AA7', 'F5', 'L6', 'R9', 'Y15', 'V13', 'AA8', 'G1', 'L7', 'T1', 'V15', 'Y16', 'AB10', 'G2', 'M1', 'T10', 'V16', 'Y17', 'AB11', 'G3', 'M2', 'T11', 'V17', 'Y18', 'AB12', 'G4', 'M3', 'T12', 'V2', 'Y19', 'AB13', 'G6', 'M4', 'T13', 'V3', 'Y2', 'AB14', 'G7', 'M5', 'T14', 'V5', 'Y20', 'AB15', 'H1', 'M6', 'T15', 'V7', 'Y3', 'AB16', 'H2', 'M7', 'T2', 'V8', 'Y4', 'AB17', 'H3', 'M8', 'T3', 'V9', 'Y5', 'AB18', 'H4', 'N1', 'T4', 'W1', 'Y6', 'AB19', 'H5', 'N3', 'T5', 'W10', 'Y7', 'AB20', 'H6', 'N4', 'T6', 'W11', 'Y8', 'AB3', 'H8', 'N5', 'T7', 'W12', 'Y9', 'AB4', 'J1', 'N6', 'T8', 'W13', 'AB5', 'J3', 'N7', 'T9', 'W14', 'AB6', 'J4', 'P1', 'U1', 'W15', 'AA1', 'AB7', 'J5', 'P2', 'U10', 'W17', 'AA10', 'AB8', 'J6', 'P3', 'U12', 'W18', 'AA11', 'AB9', 'J7', 'P4', 'U13', 'W2', 'AA12', 'B1', 'K1', 'P5', 'U14', 'W3', 'AA14', 'C1', 'K2', 'P6', 'U15', 'W4', 'AA15', 'C2', 'K3', 'P7', 'U16', 'W5', 'AA16', 'D1', 'K4', 'K6', 'P8', 'U3', 'W6', 'AA18', 'D2', 'K5', 'R1', 'U4', 'W8', 'AA19']},{'label': 'uC', 'num': 3, 'pin_nums': ['D13', 'A16', 'D15', 'B8', 'A6', 'C11', 'D7', 'A8', 'A14', 'C13', 'D9', 'B10', 'C15', 'E12', 'B12', 'C7', 'F12', 'A10', 'B14', 'C9', 'A12', 'B16', 'D11', 'B6']},{'label': 'uD', 'num': 4, 'pin_nums': ['A15', 'C10', 'D14', 'B13', 'E10', 'E8', 'A7', 'B9', 'D12', 'D8', 'E13', 'E9']},{'label': 'uE', 'num': 5, 'pin_nums': ['AB21', 'E18', 'AB2', 'D20', 'A21', 'G17', 'V18', 'AA22']},{'label': 'uF', 'num': 6, 'pin_nums': ['L5', 'R6', 'F11', 'L8', 'T16', 'F13', 'L9', 'U11', 'A1', 'G12', 'M10', 'U17', 'A11', 'G18', 'M11', 'U2', 'A13', 'G5', 'M12', 'U21', 'A22', 'H15', 'M13', 'U7', 'A9', 'H7', 'M14', 'V10', 'AA13', 'H9', 'M15', 'V14', 'AA17', 'J10', 'M9', 'V4', 'AA5', 'J11', 'N10', 'V6', 'AA9', 'J12', 'N11', 'W16', 'AB1', 'J13', 'N12', 'W19', 'AB22', 'J14', 'N13', 'W7', 'B11', 'J15', 'N14', 'B15', 'J2', 'N17', 'B17', 'J21', 'N2', 'B5', 'J8', 'N21', 'B7', 'J9', 'N8', 'C12', 'K10', 'N9', 'C14', 'K11', 'P10', 'C16', 'K12', 'P11', 'C6', 'K13', 'P12', 'C8', 'K14', 'P13', 'D10', 'K15', 'P14', 'D16', 'K9', 'P15', 'D6', 'L10', 'P9', 'E11', 'L11', 'R10', 'E14', 'L12', 'R12', 'E15', 'L13', 'R14', 'E2', 'E7', 'L14', 'R18', 'E21', 'L18', 'R5']}] }),
        Part(**{ 'name':'XC6SLX150T-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150T-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150T-FGG676\n\nFPGA', 'pins':[
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L31N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L30N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L31P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L30P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L41N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L41P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA13',name='IO_L36N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA15',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA16',name='IO_L24N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA21',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L36P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB22',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB7',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC22',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD22',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD23',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE15',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE24',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE5',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF5',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L27P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L35P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L27N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L26P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L26N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W12',name='IO_L35N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W19',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W20',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L24P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y20',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y9',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A25',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='D23',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D26',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E23',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F22',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F23',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F24',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='G1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G20',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G22',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='G23',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H20',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H21',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H22',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H26',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J20',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J21',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J22',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='J7',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J9',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K18',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K19',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K21',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K22',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K24',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='K5',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K9',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L10',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L19',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L20',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L21',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L7',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L8',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M18',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M19',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M20',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M21',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M23',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M24',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M26',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M8',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N26',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A16',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A18',name='MGTTXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A20',name='MGTTXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B16',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B18',name='MGTTXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B20',name='MGTTXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C15',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C17',name='MGTRXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C19',name='MGTRXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D15',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D17',name='MGTRXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D19',name='MGTRXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='MGTRXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AC12',name='MGTREFCLK1P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AC16',name='MGTREFCLK0P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC18',name='MGTRXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC20',name='MGTRXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='MGTRXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='MGTRXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD12',name='MGTREFCLK1N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD16',name='MGTREFCLK0N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD18',name='MGTRXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='MGTRXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='MGTRXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE11',name='MGTREFCLK0P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='MGTREFCLK1P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='MGTTXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='MGTTXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='MGTTXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE9',name='MGTTXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF11',name='MGTREFCLK0N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF17',name='MGTREFCLK1N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF19',name='MGTTXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='MGTTXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='MGTTXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF9',name='MGTTXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='A19',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='AB10',name='MGTRREF_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AB12',name='MGTAVTTRCAL_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AC19',name='MGTAVTTRX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AC9',name='MGTAVTTRX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD11',name='MGTAVCC_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD13',name='MGTAVCCPLL1_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD15',name='MGTAVCCPLL0_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AD17',name='MGTAVCC_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AE12',name='MGTAVCCPLL0_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AE16',name='MGTAVCCPLL1_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AF20',name='MGTAVTTTX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='MGTAVTTTX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='MGTAVCC_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D18',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=6),
            Pin(num='A24',name='TCK',func=pin_types.BIDIR,unit=7),
            Pin(num='AF2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='DONE_2',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='TDI',func=pin_types.BIDIR,unit=7),
            Pin(num='F21',name='TMS',func=pin_types.BIDIR,unit=7),
            Pin(num='G21',name='TDO',func=pin_types.BIDIR,unit=7),
            Pin(num='Y19',name='CMPCS_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='Y22',name='SUSPEND',func=pin_types.BIDIR,unit=7),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AD19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D20',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V19',name='RFUSE',func=pin_types.PWRIN,unit=8),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V22',name='VBATT',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='VFS',func=pin_types.PWRIN,unit=8),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T22', 'A23', 'G10', 'C5', 'A12', 'J17', 'T23', 'A3', 'G11', 'D13', 'A4', 'K12', 'T24', 'A5', 'D21', 'G12', 'K14', 'T25', 'AA23', 'D22', 'G13', 'AA24', 'L23', 'T26', 'AA25', 'D5', 'G15', 'L24', 'U19', 'AA26', 'E10', 'G16', 'N17', 'U20', 'AB23', 'E12', 'G17', 'N18', 'U21', 'AB24', 'G18', 'E13', 'N19', 'U22', 'AB26', 'E14', 'G19', 'N20', 'U23', 'AC23', 'E16', 'G6', 'N21', 'U24', 'AC24', 'E18', 'G7', 'N22', 'U25', 'AC25', 'E20', 'G8', 'N23', 'U26', 'AC26', 'E21', 'G9', 'N24', 'V20', 'AD24', 'E5', 'H10', 'P17', 'V21', 'AD25', 'E6', 'H11', 'P18', 'V23', 'AD26', 'E8', 'H12', 'P19', 'V24', 'AE25', 'F10', 'H13', 'P21', 'V26', 'AE26', 'F11', 'H14', 'P22', 'W21', 'B12', 'F12', 'H15', 'P23', 'W23', 'B13', 'F13', 'H16', 'P24', 'W24', 'B14', 'F14', 'H17', 'P26', 'W25', 'B21', 'F15', 'H18', 'R18', 'W26', 'A14', 'B22', 'F16', 'H19', 'R19', 'Y24', 'B23', 'F17', 'H7', 'R20', 'Y25', 'B3', 'F18', 'H8', 'A22', 'R21', 'Y26', 'B4', 'F19', 'H9', 'R23', 'A13', 'B5', 'F20', 'J11', 'R24', 'C13', 'F5', 'J12', 'A2', 'R25', 'F9', 'C21', 'F6', 'J13', 'R26', 'C22', 'F7', 'J14', 'T19', 'C3', 'F8', 'J15', 'T20', 'C4', 'J16']},{'label': 'uB', 'num': 2, 'pin_nums': ['Y9', 'AC2', 'AA15', 'T4', 'AF4', 'W12', 'AC22', 'AA16', 'T6', 'AF5', 'W14', 'AA17', 'AC3', 'AF6', 'T7', 'W15', 'AC4', 'AA18', 'M10', 'T8', 'W16', 'AA19', 'AC5', 'M9', 'T9', 'W17', 'AA2', 'AC6', 'N4', 'U1', 'W18', 'AA20', 'AD1', 'N5', 'U13', 'AC14', 'W19', 'AA21', 'AD14', 'N6', 'U15', 'W2', 'AA22', 'AD2', 'N7', 'U2', 'W20', 'AA3', 'AD22', 'N8', 'U3', 'W3', 'AA4', 'AD23', 'N9', 'U4', 'W4', 'AA6', 'AD3', 'P1', 'U5', 'W5', 'AA7', 'AD4', 'P10', 'U7', 'W6', 'AA8', 'AD5', 'P3', 'U8', 'W7', 'T3', 'AA9', 'AD6', 'P4', 'U9', 'W8', 'AB1', 'AE1', 'P5', 'V1', 'W9', 'AB11', 'AE13', 'P6', 'V10', 'Y1', 'AB13', 'AE14', 'P8', 'V11', 'Y11', 'AB14', 'AE15', 'P9', 'V12', 'Y12', 'AB15', 'AE2', 'R1', 'V13', 'Y13', 'AB17', 'AE23', 'R10', 'V14', 'Y15', 'AB19', 'AE24', 'R2', 'V15', 'Y16', 'AB21', 'AE3', 'R3', 'V16', 'Y17', 'AE4', 'AB22', 'R4', 'V18', 'Y18', 'AB3', 'AE5', 'R5', 'V3', 'Y2', 'AB4', 'AF13', 'R6', 'V4', 'Y20', 'AA1', 'AB5', 'AF14', 'R7', 'V5', 'Y21', 'AA10', 'AB6', 'AF15', 'R8', 'V6', 'Y3', 'AA11', 'AB7', 'AF22', 'R9', 'V7', 'Y5', 'AA12', 'AB9', 'AF23', 'T1', 'W1', 'Y6', 'AA13', 'AF24', 'AC1', 'T2', 'W10', 'Y8', 'AA14', 'AF3', 'W11']},{'label': 'uC', 'num': 3, 'pin_nums': ['F3', 'J3', 'L4', 'A25', 'J4', 'F4', 'L6', 'B1', 'G1', 'J5', 'L7', 'B2', 'J6', 'G2', 'L8', 'B24', 'G20', 'J7', 'L9', 'B25', 'G22', 'J9', 'M1', 'B26', 'G23', 'K1', 'M18', 'C1', 'G24', 'K10', 'M19', 'C2', 'G25', 'K18', 'M2', 'C24', 'G26', 'K19', 'M20', 'C25', 'G3', 'K20', 'M21', 'C26', 'G4', 'K21', 'M23', 'D1', 'H1', 'K22', 'M24', 'D2', 'H2', 'K23', 'M25', 'D23', 'H20', 'K24', 'M26', 'D24', 'H21', 'K26', 'M3', 'D25', 'H22', 'K3', 'M4', 'D26', 'H24', 'K4', 'M6', 'D3', 'H25', 'K5', 'M7', 'E1', 'H26', 'K6', 'M8', 'E2', 'H3', 'K7', 'N1', 'E23', 'H5', 'K8', 'N2', 'E24', 'H6', 'K9', 'N25', 'J26', 'E25', 'J1', 'L1', 'N26', 'E26', 'J2', 'L10', 'N3', 'E3', 'J20', 'L19', 'E4', 'J21', 'L2', 'F1', 'J22', 'L20', 'F22', 'J23', 'L21', 'F23', 'J24', 'L25', 'F24', 'J25', 'L26', 'F26', 'L3']},{'label': 'uD', 'num': 4, 'pin_nums': ['B10', 'C17', 'D7', 'C19', 'B16', 'D9', 'A10', 'B18', 'C7', 'A16', 'B20', 'C9', 'A18', 'B6', 'D11', 'A20', 'B8', 'D15', 'A6', 'C11', 'D17', 'A8', 'C15', 'D19']},{'label': 'uE', 'num': 5, 'pin_nums': ['AD10', 'AE19', 'AF7', 'AD12', 'AF9', 'AE21', 'AC10', 'AD16', 'AE7', 'AC12', 'AD18', 'AE9', 'AC16', 'AD20', 'AF11', 'AC18', 'AD8', 'AF17', 'AC20', 'AE11', 'AF19', 'AC8', 'AE17', 'AF21']},{'label': 'uF', 'num': 6, 'pin_nums': ['AC9', 'AF8', 'D8', 'AD11', 'B11', 'E11', 'AD13', 'B15', 'E9', 'A19', 'AD15', 'C10', 'A7', 'AD17', 'C12', 'AB10', 'AE12', 'C14', 'AB12', 'AE16', 'C16', 'AC19', 'AF20', 'D18']},{'label': 'uG', 'num': 7, 'pin_nums': ['C23', 'AF2', 'G21', 'Y22', 'A24', 'F21', 'Y19', 'AF25']},{'label': 'uH', 'num': 8, 'pin_nums': ['R22', 'E19', 'AD21', 'T10', 'M13', 'Y7', 'E22', 'AD7', 'M14', 'T11', 'AD9', 'E7', 'M15', 'T12', 'F2', 'AE10', 'M16', 'T13', 'AE18', 'F25', 'M17', 'T14', 'AE20', 'G14', 'M22', 'T15', 'AE22', 'G5', 'M5', 'T16', 'AE6', 'H23', 'N10', 'T17', 'E17', 'AE8', 'H4', 'N11', 'T18', 'AF1', 'J10', 'N12', 'T21', 'AF10', 'J18', 'N13', 'T5', 'A1', 'AF12', 'J19', 'N14', 'U10', 'A11', 'AF16', 'J8', 'N15', 'U11', 'A15', 'AF18', 'K11', 'N16', 'U12', 'A17', 'AF26', 'K13', 'P11', 'U14', 'A21', 'K15', 'B17', 'P12', 'U16', 'A26', 'B19', 'K16', 'P13', 'U17', 'A9', 'B7', 'K17', 'P14', 'U18', 'AA5', 'B9', 'K2', 'P15', 'U6', 'AB16', 'C18', 'K25', 'P16', 'V17', 'AB18', 'C20', 'L11', 'P2', 'V19', 'AB2', 'C6', 'L12', 'P20', 'V2', 'AB20', 'C8', 'L13', 'P25', 'V22', 'AB25', 'L14', 'D10', 'P7', 'V25', 'AB8', 'D12', 'L15', 'R11', 'V8', 'AC11', 'D14', 'L16', 'R12', 'V9', 'AC13', 'D16', 'L17', 'R13', 'W13', 'AC15', 'D20', 'L18', 'R14', 'W22', 'AC17', 'D4', 'L22', 'R15', 'Y10', 'AC21', 'D6', 'L5', 'R16', 'Y14', 'Y4', 'AC7', 'E15', 'M11', 'R17', 'Y23', 'AD19', 'M12']}] }),
        Part(**{ 'name':'XC6SLX150T-FGG900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX150T-FGG900'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX150T-FGG900\n\nFPGA', 'pins':[
            Pin(num='A15',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA24',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA27',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA28',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA29',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA30',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB28',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB30',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AC27',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC28',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC29',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC30',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD27',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD28',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD30',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE27',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE28',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE29',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE30',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF28',name='IO_L55P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF30',name='IO_L55N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG26',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG27',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG28',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG29',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AG30',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH26',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH27',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AH29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AH30',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ27',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AJ28',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ29',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ30',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK27',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK28',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AK29',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B17',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C24',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C25',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='IO_L12N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D24',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO_L60N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E24',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F17',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L54N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO_L60P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L20N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L54P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='IO_L61N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G22',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='IO_L20P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L19N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L53N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H21',name='IO_L61P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='IO_L9N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L19P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L53P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L55N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO_L9P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L25N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L55P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L25P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='M23',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M24',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N27',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N28',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N29',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N30',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P22',name='IO_L56P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='IO_L56N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P24',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P27',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P28',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P30',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L54P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L54N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R24',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R27',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R28',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R29',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R30',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T27',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T28',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T30',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U24',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U27',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U28',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U29',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U30',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V27',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V28',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V30',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W27',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W28',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W29',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W30',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y27',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y28',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y29',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y30',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA14',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA17',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA21',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA9',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L54P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB23',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC11',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC12',name='IO_L54N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC13',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC16',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC19',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC20',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC22',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC23',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC24',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD14',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD17',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD18',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD19',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD20',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD21',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD22',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD23',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AD24',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD6',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE10',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE11',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE13',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE14',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE17',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE18',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE21',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE22',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE24',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L6P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE6',name='IO_L4P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE9',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF1',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF17',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF25',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF3',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L4N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF9',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG1',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG16',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AG24',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG25',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG5',name='IO_L6N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AG6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG7',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AG8',name='IO_L55P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH1',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH16',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH2',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH24',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH25',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AH3',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AH6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH7',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AH8',name='IO_L55N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ1',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ15',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ17',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ2',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ25',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ26',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AJ4',name='IO_L14P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AJ7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AK15',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK16',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK17',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK2',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK25',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK26',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK3',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK4',name='IO_L14N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AK6',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AK7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N1',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L56N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L56P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L27N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L27P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='V1',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L5P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L56P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W19',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W20',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y11',name='IO_L5N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L56N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y6',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A2',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A26',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A27',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A28',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A29',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B27',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B28',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='B29',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B30',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='B5',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='C26',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C27',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C29',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C30',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D26',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D27',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D28',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D3',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D30',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E27',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E28',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E29',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E30',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F25',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F27',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F28',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F30',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='G25',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='G27',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G28',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G29',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H26',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H27',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H28',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H3',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H6',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J27',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J28',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K24',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K26',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K27',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K28',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K30',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='L1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='L24',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='L27',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L28',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L7',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M26',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M27',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M28',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M29',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M3',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M30',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M5',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='N24',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A11',name='MGTTXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A13',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A19',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A21',name='MGTTXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A23',name='MGTTXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A9',name='MGTTXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTTXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B13',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B19',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B21',name='MGTTXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B23',name='MGTTXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B9',name='MGTTXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C10',name='MGTRXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C12',name='MGTRXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C14',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C18',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C20',name='MGTRXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C22',name='MGTRXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D10',name='MGTRXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D12',name='MGTRXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D14',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D18',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D20',name='MGTRXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D22',name='MGTRXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='MGTRXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AG12',name='MGTRXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AG14',name='MGTREFCLK1P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AG18',name='MGTREFCLK0P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AG20',name='MGTRXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AG22',name='MGTRXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AH10',name='MGTRXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AH12',name='MGTRXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AH14',name='MGTREFCLK1N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AH18',name='MGTREFCLK0N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AH20',name='MGTRXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AH22',name='MGTRXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ11',name='MGTTXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ13',name='MGTREFCLK0P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ19',name='MGTREFCLK1P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ21',name='MGTTXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ23',name='MGTTXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AJ9',name='MGTTXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AK11',name='MGTTXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AK13',name='MGTREFCLK0N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AK19',name='MGTREFCLK1N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AK21',name='MGTTXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AK23',name='MGTTXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AK9',name='MGTTXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='A10',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='AF12',name='MGTRREF_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AF14',name='MGTAVTTRCAL_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AG11',name='MGTAVTTRX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AG21',name='MGTAVTTRX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AH13',name='MGTAVCC_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AH15',name='MGTAVCCPLL1_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AH17',name='MGTAVCCPLL0_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AH19',name='MGTAVCC_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ14',name='MGTAVCCPLL0_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AJ18',name='MGTAVCCPLL1_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AK10',name='MGTAVTTTX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AK22',name='MGTAVTTTX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=6),
            Pin(num='B18',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C13',name='MGTAVCC_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C17',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C19',name='MGTAVCC_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D11',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='D21',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='E12',name='MGTRREF_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=6),
            Pin(num='AB25',name='SUSPEND',func=pin_types.BIDIR,unit=7),
            Pin(num='AB8',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AC25',name='CMPCS_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AD25',name='DONE_2',func=pin_types.BIDIR,unit=7),
            Pin(num='H23',name='TCK',func=pin_types.BIDIR,unit=7),
            Pin(num='H25',name='TDO',func=pin_types.BIDIR,unit=7),
            Pin(num='J24',name='TDI',func=pin_types.BIDIR,unit=7),
            Pin(num='K25',name='TMS',func=pin_types.BIDIR,unit=7),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB24',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB26',name='VBATT',func=pin_types.PWRIN,unit=8),
            Pin(num='AB27',name='RFUSE',func=pin_types.PWRIN,unit=8),
            Pin(num='AB29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF27',name='VFS',func=pin_types.PWRIN,unit=8),
            Pin(num='AF29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AG23',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AG9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AH11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH28',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AH9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AJ8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK30',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AK8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C28',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D23',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='D9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='H24',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J23',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M14',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M25',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N20',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R18',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T18',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U20',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V19',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V20',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V29',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y18',name='VCCAUX',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E8', 'K11', 'N27', 'U25', 'AC27', 'AK29', 'E9', 'G23', 'K12', 'U27', 'N28', 'AC28', 'B15', 'F10', 'G7', 'K13', 'N29', 'U28', 'AC29', 'B16', 'F11', 'G8', 'K14', 'N30', 'U29', 'AC30', 'B17', 'F12', 'G9', 'K15', 'P21', 'U30', 'AD26', 'B25', 'F13', 'H10', 'K17', 'P22', 'V23', 'AD27', 'B6', 'F14', 'H11', 'K19', 'P23', 'V24', 'AD28', 'B7', 'F15', 'H12', 'K20', 'V26', 'P24', 'AD29', 'C16', 'F16', 'H13', 'K21', 'P25', 'V27', 'AD30', 'C24', 'F17', 'H14', 'L10', 'P26', 'V28', 'AE25', 'C25', 'F18', 'H15', 'L11', 'P27', 'V30', 'AE26', 'C6', 'F19', 'H16', 'L12', 'P28', 'W21', 'AE27', 'C7', 'F20', 'H17', 'L13', 'P30', 'W22', 'AE28', 'C8', 'F21', 'H18', 'L14', 'R21', 'W23', 'AE29', 'A17', 'D16', 'F22', 'H19', 'L15', 'R22', 'W24', 'AE30', 'D24', 'F23', 'H20', 'L17', 'R23', 'W25', 'AF28', 'D25', 'F24', 'H21', 'L18', 'R24', 'W26', 'AF30', 'D6', 'F6', 'H22', 'L19', 'R25', 'W27', 'AG26', 'A16', 'D7', 'F8', 'H7', 'L20', 'R26', 'W28', 'AG27', 'D8', 'F9', 'AK28', 'H8', 'L21', 'R27', 'W29', 'A25', 'AG28', 'E11', 'G10', 'H9', 'L9', 'R28', 'W30', 'AG29', 'E13', 'G11', 'J10', 'M10', 'R29', 'Y22', 'AG30', 'E15', 'G12', 'J12', 'M13', 'R30', 'Y23', 'AH26', 'E16', 'G13', 'A6', 'J13', 'M15', 'T24', 'Y24', 'AH27', 'E17', 'G14', 'A7', 'J14', 'M17', 'T25', 'Y25', 'AH29', 'AA23', 'E19', 'G15', 'J17', 'M18', 'T26', 'Y26', 'AA24', 'AH30', 'E21', 'G16', 'J18', 'M19', 'AA25', 'T27', 'Y27', 'AJ27', 'AA27', 'E23', 'G17', 'J19', 'M20', 'T28', 'Y28', 'AA28', 'A15', 'AJ28', 'E24', 'G18', 'J20', 'M21', 'AA29', 'T29', 'Y29', 'AJ29', 'E25', 'G19', 'AA30', 'J22', 'M23', 'T30', 'Y30', 'AJ30', 'AB28', 'E6', 'G20', 'G22', 'J8', 'M24', 'U23', 'AB30', 'AK27', 'E7', 'G21', 'K10', 'N23', 'U24', 'AC26']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB23', 'AE22', 'AG25', 'AK2', 'R7', 'W2', 'AA11', 'AB3', 'AA10', 'AD15', 'AE23', 'AK25', 'AG3', 'W20', 'R8', 'AA12', 'AB4', 'AD16', 'AE24', 'AG4', 'AK26', 'T1', 'W3', 'AA14', 'AB6', 'AD17', 'AE3', 'AG5', 'AK3', 'T2', 'W4', 'AA15', 'AB7', 'AD18', 'AE4', 'AG6', 'AK4', 'T3', 'W5', 'AA16', 'AB9', 'AD19', 'AE5', 'AG7', 'AK5', 'T4', 'W6', 'AA17', 'AC1', 'AD2', 'AE6', 'AG8', 'AK6', 'T5', 'W7', 'AA18', 'AC10', 'AD20', 'AE7', 'AK7', 'AH1', 'W9', 'T6', 'AA19', 'AC11', 'AD21', 'AE8', 'AH16', 'M6', 'T7', 'Y1', 'AA20', 'AC12', 'AD22', 'AE9', 'AH2', 'M7', 'T8', 'Y10', 'AA21', 'AC13', 'AD23', 'AF1', 'AH24', 'M8', 'T9', 'Y11', 'AA22', 'AC14', 'AD24', 'AF11', 'AH25', 'N1', 'U1', 'Y12', 'AA3', 'AC15', 'AD3', 'AF13', 'AH3', 'N10', 'U3', 'Y13', 'AA4', 'AC16', 'AD4', 'AF15', 'AH4', 'N3', 'U4', 'Y14', 'AA5', 'AC18', 'AD5', 'AF16', 'AH5', 'N4', 'U5', 'Y15', 'AK17', 'AA6', 'AC19', 'AD6', 'AF17', 'AH6', 'N5', 'U6', 'Y16', 'AA7', 'AC2', 'AD7', 'AF19', 'AH7', 'N7', 'U7', 'Y17', 'AA8', 'AC20', 'AD8', 'AF2', 'AH8', 'N8', 'U8', 'Y19', 'AA9', 'AC21', 'AD9', 'AF21', 'AJ1', 'N9', 'V1', 'Y2', 'AB1', 'AC22', 'AE1', 'AF23', 'AJ15', 'P1', 'V10', 'Y20', 'AB10', 'AC23', 'AE10', 'AF24', 'AJ16', 'P2', 'V2', 'Y21', 'AB11', 'AC24', 'AE11', 'AF25', 'AJ17', 'P3', 'V3', 'Y3', 'AB12', 'AC3', 'AE12', 'AF3', 'AJ2', 'P4', 'V4', 'Y4', 'AB13', 'AC4', 'AE13', 'AF4', 'AJ25', 'P6', 'V7', 'Y5', 'AB14', 'AC5', 'AE14', 'AF6', 'AJ26', 'P7', 'V8', 'Y6', 'AB16', 'AC6', 'AE15', 'AF7', 'AJ3', 'P9', 'V9', 'Y7', 'AB17', 'AC9', 'AE16', 'AF8', 'AJ4', 'R1', 'W1', 'Y8', 'AB18', 'AD1', 'AE17', 'AF9', 'AJ6', 'R2', 'W10', 'Y9', 'AB19', 'AD10', 'AE18', 'AG1', 'AJ7', 'R3', 'W11', 'AB2', 'AD11', 'AE19', 'AG16', 'AK15', 'R4', 'W12', 'AB20', 'AD12', 'AD14', 'AE20', 'AG2', 'AK16', 'R5', 'AA1', 'W14', 'AB21', 'AD13', 'AE21', 'AG24', 'R6', 'W19']},{'label': 'uC', 'num': 3, 'pin_nums': ['E1', 'H27', 'L26', 'E26', 'A29', 'L27', 'H28', 'A3', 'E27', 'H29', 'L28', 'A4', 'E28', 'L29', 'H3', 'A5', 'E29', 'H30', 'L3', 'B1', 'E3', 'H4', 'L30', 'B2', 'E30', 'H5', 'L4', 'B27', 'E4', 'L5', 'H6', 'B28', 'E5', 'J1', 'L6', 'B29', 'F1', 'J25', 'L7', 'B3', 'F2', 'J27', 'M1', 'B30', 'F25', 'J28', 'M2', 'B4', 'F26', 'J29', 'M26', 'B5', 'F27', 'J3', 'M27', 'C1', 'F28', 'J30', 'M28', 'C2', 'F3', 'J4', 'M29', 'C26', 'F30', 'J5', 'M3', 'C27', 'F4', 'J6', 'M30', 'C29', 'G1', 'K1', 'M4', 'C30', 'G2', 'K2', 'M5', 'C4', 'G25', 'K24', 'N24', 'C5', 'G26', 'K26', 'N25', 'D1', 'G27', 'K27', 'D2', 'G28', 'K28', 'D26', 'G29', 'K3', 'D27', 'G3', 'K30', 'D28', 'G30', 'K4', 'D29', 'G4', 'K6', 'D3', 'G5', 'L1', 'A2', 'D30', 'H1', 'L2', 'A26', 'A28', 'D4', 'H2', 'L24', 'A27', 'D5', 'H26', 'L25']},{'label': 'uD', 'num': 4, 'pin_nums': ['C22', 'A19', 'D10', 'B23', 'B21', 'A21', 'B9', 'D12', 'A23', 'C10', 'D14', 'A9', 'C12', 'D18', 'B11', 'C14', 'D20', 'B13', 'C18', 'D22', 'A11', 'B19', 'C20', 'A13']},{'label': 'uE', 'num': 5, 'pin_nums': ['AJ9', 'AG12', 'AH18', 'AH20', 'AG14', 'AK11', 'AG18', 'AH22', 'AK13', 'AG20', 'AJ11', 'AK19', 'AG22', 'AJ13', 'AK21', 'AH10', 'AJ19', 'AK23', 'AH12', 'AJ21', 'AK9', 'AG10', 'AH14', 'AJ23']},{'label': 'uF', 'num': 6, 'pin_nums': ['AH19', 'A22', 'C15', 'AF12', 'AJ14', 'C17', 'AF14', 'AJ18', 'C19', 'AG11', 'AK10', 'D11', 'AG21', 'AK22', 'D21', 'AH13', 'B14', 'E12', 'A10', 'AH15', 'B18', 'C13', 'E14', 'AH17']},{'label': 'uG', 'num': 7, 'pin_nums': ['K25', 'H23', 'AB25', 'AC25', 'J24', 'H25', 'AB8', 'AD25']},{'label': 'uH', 'num': 8, 'pin_nums': ['R17', 'AF20', 'J16', 'B10', 'N16', 'R18', 'U26', 'AF22', 'J2', 'B12', 'N17', 'R19', 'U9', 'AF26', 'B20', 'J21', 'N18', 'R20', 'V11', 'AF27', 'B22', 'J23', 'N19', 'R9', 'V12', 'AF29', 'B24', 'J26', 'N2', 'T10', 'V13', 'AF5', 'B26', 'J7', 'N20', 'T11', 'V14', 'AG13', 'B8', 'J9', 'N21', 'T12', 'V15', 'AG15', 'K16', 'C11', 'N22', 'T13', 'V16', 'A1', 'AG17', 'C21', 'K18', 'AF18', 'N26', 'T14', 'V17', 'A12', 'AG19', 'C23', 'K22', 'N6', 'T15', 'V18', 'A14', 'AG23', 'C28', 'K23', 'P10', 'T16', 'V19', 'A18', 'AG9', 'C3', 'K29', 'P11', 'T17', 'V20', 'A20', 'AH11', 'C9', 'K5', 'P12', 'T18', 'V21', 'A24', 'AH21', 'D13', 'K7', 'P13', 'T19', 'V22', 'A30', 'AH23', 'D15', 'K8', 'P14', 'T20', 'V25', 'AH28', 'A8', 'D17', 'K9', 'P15', 'T21', 'J15', 'V29', 'AA13', 'AH9', 'D19', 'L16', 'P16', 'T22', 'V5', 'AA2', 'AJ10', 'D23', 'L22', 'P17', 'T23', 'V6', 'AA26', 'AJ12', 'D9', 'L23', 'P18', 'U10', 'W13', 'AB15', 'AJ20', 'E10', 'L8', 'P19', 'U11', 'W15', 'AB22', 'AJ22', 'E18', 'M11', 'P20', 'U12', 'W16', 'AB24', 'AJ24', 'E2', 'M12', 'P29', 'U13', 'W17', 'AB26', 'AJ5', 'E20', 'M14', 'P5', 'U14', 'W18', 'AB27', 'AJ8', 'E22', 'M16', 'P8', 'U15', 'W8', 'AB29', 'AK1', 'F29', 'M22', 'R10', 'U16', 'Y18', 'AB5', 'AK12', 'F5', 'M25', 'R11', 'U17', 'AC17', 'AK14', 'F7', 'M9', 'R12', 'U18', 'AC7', 'AK18', 'G24', 'N11', 'R13', 'U19', 'AC8', 'AK20', 'G6', 'N12', 'R14', 'U2', 'AE2', 'AK24', 'H24', 'N13', 'R15', 'U20', 'U22', 'AF10', 'AK30', 'J11', 'N14', 'R16', 'U21', 'AK8', 'N15']}] }),
        Part(**{ 'name':'XC6SLX16-CPG196', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX16-CPG196'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX16-CPG196\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L1P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L1N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='IO_L32P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L32N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='IO_L33P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L33N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L34P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L34N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L41P_GCLK9_IRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L41N_GCLK8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L40P_GCLK11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L40N_GCLK10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L43P_GCLK5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L43N_GCLK4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L42P_GCLK7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L42N_GCLK6_TRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L46P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L46N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L45P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L45N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='IO_L47P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L47N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L51N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L51P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L50P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F1',name='IO_L44N_GCLK20_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L44P_GCLK21_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L49N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L49P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L42N_GCLK24_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L42P_GCLK25_TRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H1',name='IO_L43N_GCLK22_IRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L43P_GCLK23_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L41P_GCLK27_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L37N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L37P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L36N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L36P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N10',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A13',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='B13',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='L12',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='M12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N14',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D12', 'H12', 'K12', 'F12', 'A4', 'B4', 'A5', 'C12', 'D13', 'F13', 'H13', 'K13', 'A6', 'B5', 'A11', 'C13', 'D14', 'F14', 'H14', 'K14', 'A7', 'B6', 'B3', 'A8', 'C11', 'C4', 'D8', 'G11', 'J11', 'L13', 'A2', 'A9', 'B7', 'C5', 'E12', 'G12', 'J12', 'L14', 'B10', 'B8', 'C8', 'E13', 'G13', 'J13', 'B11', 'M13', 'B9', 'A12', 'B12', 'C9', 'E14', 'G14', 'J14', 'M14', 'B2', 'C10', 'D11', 'F11', 'H11', 'K11', 'A3', 'A10']},{'label': 'uB', 'num': 2, 'pin_nums': ['M1', 'E4', 'C1', 'H1', 'N10', 'K2', 'M10', 'N11', 'N7', 'P2', 'P3', 'D1', 'F1', 'H2', 'M2', 'N12', 'N8', 'P4', 'K3', 'D2', 'F2', 'H3', 'K4', 'M4', 'N13', 'N9', 'P5', 'D3', 'F3', 'J1', 'L1', 'M5', 'N2', 'P10', 'P6', 'D4', 'F4', 'J2', 'L2', 'M6', 'N3', 'P11', 'P7', 'E1', 'G1', 'J3', 'L4', 'M8', 'N4', 'P12', 'P8', 'E2', 'G2', 'J4', 'L8', 'M9', 'N5', 'P13', 'P9', 'B1', 'E3', 'G3', 'K1', 'N6']},{'label': 'uC', 'num': 3, 'pin_nums': ['A13', 'B14', 'L12', 'N1', 'B13', 'C14', 'M12', 'N14']},{'label': 'uD', 'num': 4, 'pin_nums': ['A1', 'D6', 'H4', 'G10', 'J6', 'K8', 'L9', 'A14', 'D7', 'E9', 'G4', 'H5', 'J7', 'K9', 'M11', 'C2', 'D9', 'F10', 'G5', 'H6', 'J8', 'L10', 'M3', 'C3', 'E10', 'F5', 'G6', 'H7', 'J9', 'L11', 'M7', 'C6', 'E11', 'F6', 'G7', 'H8', 'K10', 'L3', 'P1', 'C7', 'E5', 'F7', 'G8', 'H9', 'K5', 'L5', 'P14', 'D10', 'E6', 'E8', 'F8', 'G9', 'J10', 'K6', 'L6', 'D5', 'E7', 'F9', 'H10', 'J5', 'K7', 'L7']}] }),
        Part(**{ 'name':'XC6SLX16-CSG225', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX16-CSG225'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX16-CSG225\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G5',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L9',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M3',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P13',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P9',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='D12',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='E13',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='L10',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='L13',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='R14',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L4',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A10', 'D7', 'K11', 'A9', 'D8', 'K12', 'B11', 'D9', 'K13', 'B12', 'E14', 'K15', 'B13', 'E15', 'L12', 'B14', 'E6', 'L14', 'B15', 'E7', 'L15', 'B2', 'E8', 'M13', 'B3', 'E9', 'M14', 'B4', 'F10', 'M15', 'B5', 'F11', 'N14', 'B7', 'F12', 'N15', 'B8', 'F13', 'P14', 'B9', 'F15', 'P15', 'C10', 'F8', 'C11', 'G11', 'C12', 'G12', 'C14', 'G13', 'C15', 'G14', 'C4', 'G15', 'C5', 'H10', 'C6', 'H11', 'C7', 'H12', 'A13', 'C8', 'H13', 'C9', 'H14', 'D10', 'H15', 'D11', 'J11', 'A11', 'A12', 'D13', 'J12', 'A2', 'D14', 'J13', 'A3', 'A4', 'D15', 'J14', 'A8', 'A5', 'D5', 'J15', 'A6', 'A7', 'D6', 'K10']},{'label': 'uB', 'num': 2, 'pin_nums': ['R3', 'G4', 'R4', 'M5', 'G5', 'M6', 'R5', 'H1', 'M7', 'R6', 'H2', 'M8', 'R7', 'H3', 'M9', 'R8', 'H4', 'N1', 'R9', 'H5', 'N10', 'H6', 'N11', 'J1', 'N12', 'J2', 'N2', 'J3', 'N4', 'J4', 'N5', 'J5', 'N6', 'K1', 'N7', 'C1', 'K3', 'N8', 'C2', 'K4', 'N9', 'D1', 'K5', 'P1', 'D2', 'K8', 'P11', 'D3', 'L1', 'P12', 'D4', 'L2', 'P13', 'G3', 'E1', 'L3', 'P2', 'E2', 'L5', 'P3', 'E3', 'L6', 'P4', 'E4', 'L7', 'P5', 'E5', 'L8', 'P7', 'F1', 'L9', 'P8', 'F3', 'M1', 'P9', 'M10', 'F4', 'R10', 'F5', 'M11', 'R11', 'G1', 'M2', 'R12', 'G2', 'M3', 'R13', 'M4']},{'label': 'uC', 'num': 3, 'pin_nums': ['D12', 'E13', 'L13', 'R2', 'E10', 'L10', 'R14', 'A14']},{'label': 'uD', 'num': 4, 'pin_nums': ['A15', 'F14', 'L4', 'G8', 'J8', 'B1', 'F2', 'E12', 'M12', 'J9', 'G9', 'G7', 'B10', 'F6', 'H7', 'K14', 'N13', 'B6', 'F7', 'H8', 'K2', 'N3', 'C13', 'F9', 'H9', 'K6', 'P10', 'J7', 'C3', 'G10', 'J10', 'K7', 'P6', 'R15', 'E11', 'G6', 'J6', 'K9', 'R1', 'A1', 'L11']}] }),
        Part(**{ 'name':'XC6SLX16-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX16-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX16-CSG324\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L41N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L41P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='IO_L42N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L9P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L9N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L42P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E3',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G6',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M5',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R10',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R13',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R16',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='V17',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['U18', 'A11', 'F11', 'C14', 'K13', 'F12', 'C15', 'A13', 'K14', 'C17', 'F13', 'K15', 'F14', 'C18', 'K16', 'F10', 'C4', 'F15', 'A12', 'K17', 'C5', 'F16', 'A14', 'K18', 'C6', 'F17', 'A15', 'L12', 'C7', 'F18', 'A16', 'L13', 'A2', 'C8', 'F7', 'L14', 'A3', 'A4', 'C9', 'F8', 'L15', 'A5', 'D11', 'F9', 'L16', 'A6', 'D12', 'G11', 'L17', 'A7', 'D13', 'G13', 'L18', 'A8', 'D14', 'G14', 'M13', 'A9', 'D17', 'G15', 'M14', 'B10', 'D18', 'G16', 'M15', 'B11', 'D4', 'G18', 'M16', 'B12', 'D6', 'G8', 'M18', 'B14', 'D7', 'G9', 'A10', 'N14', 'B15', 'D8', 'H12', 'N15', 'B16', 'D9', 'H13', 'N16', 'B2', 'E10', 'H14', 'N17', 'B3', 'E11', 'H15', 'N18', 'B4', 'E12', 'H16', 'P15', 'B5', 'E13', 'H17', 'P16', 'B6', 'E16', 'H18', 'P17', 'B8', 'E17', 'J13', 'P18', 'B9', 'E18', 'J14', 'R17', 'C10', 'E6', 'J16', 'T17', 'C11', 'E7', 'J17', 'T18', 'C12', 'E8', 'J18', 'U17', 'C13', 'K12']},{'label': 'uB', 'num': 2, 'pin_nums': ['J7', 'N9', 'V9', 'T5', 'C1', 'P1', 'K1', 'T6', 'C2', 'K2', 'P11', 'T7', 'D1', 'P12', 'K3', 'T8', 'D2', 'P2', 'K4', 'T9', 'D3', 'K5', 'P3', 'U1', 'E1', 'K6', 'P4', 'U10', 'E2', 'L1', 'P6', 'U11', 'E3', 'L2', 'P7', 'U13', 'E4', 'L3', 'P8', 'U14', 'F1', 'L4', 'P9', 'U15', 'N8', 'F2', 'L5', 'R10', 'U16', 'F3', 'L6', 'R11', 'U2', 'F4', 'L7', 'R12', 'U3', 'F5', 'M1', 'R13', 'U4', 'F6', 'M10', 'R15', 'U5', 'G1', 'M11', 'R2', 'U7', 'G3', 'M3', 'R3', 'U8', 'G4', 'M4', 'R5', 'U9', 'G6', 'M5', 'R6', 'V10', 'H1', 'M8', 'R7', 'V11', 'H2', 'N1', 'R8', 'V12', 'H3', 'N10', 'T1', 'V13', 'H4', 'N11', 'T10', 'V14', 'H5', 'N12', 'T11', 'V15', 'H6', 'N2', 'T12', 'V16', 'H7', 'N3', 'T13', 'V3', 'J1', 'N4', 'T14', 'V4', 'J2', 'N5', 'T15', 'V5', 'J3', 'N6', 'T2', 'V6', 'J5', 'N7', 'T3', 'V7', 'J6', 'T4', 'V8']},{'label': 'uC', 'num': 3, 'pin_nums': ['A17', 'D15', 'P13', 'V17', 'B18', 'D16', 'R16', 'V2']},{'label': 'uD', 'num': 4, 'pin_nums': ['C16', 'G10', 'H8', 'J9', 'L8', 'N13', 'R9', 'C3', 'G12', 'K10', 'L9', 'P10', 'T16', 'H9', 'A1', 'D10', 'G17', 'J10', 'K11', 'M12', 'P14', 'U12', 'A18', 'D5', 'G2', 'J11', 'K7', 'M17', 'P5', 'U6', 'J8', 'B1', 'E14', 'G5', 'J12', 'K8', 'M2', 'M9', 'R1', 'R4', 'V1', 'B13', 'E15', 'G7', 'J15', 'K9', 'M6', 'R14', 'V18', 'B17', 'E5', 'H10', 'J4', 'L10', 'M7', 'R18', 'B7', 'E9', 'H11', 'L11']}] }),
        Part(**{ 'name':'XC6SLX16-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX16-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX16-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D16',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L10',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M12',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N11',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N3',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N8',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R9',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='L11',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P14',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E6', 'K16', 'B6', 'E7', 'L12', 'B8', 'E8', 'L13', 'B9', 'F10', 'L14', 'C10', 'F12', 'L16', 'C11', 'F13', 'M13', 'C13', 'F14', 'M14', 'C15', 'F15', 'M15', 'C16', 'F16', 'M16', 'C4', 'F7', 'N14', 'C5', 'F9', 'N15', 'C6', 'G11', 'N16', 'C7', 'G12', 'P15', 'C8', 'G13', 'P16', 'C9', 'G14', 'R12', 'D10', 'G16', 'A13', 'R13', 'D11', 'H11', 'R14', 'D12', 'H13', 'R15', 'D14', 'H14', 'A11', 'R16', 'A12', 'D15', 'H15', 'A14', 'T12', 'D16', 'H16', 'A4', 'T13', 'A5', 'D5', 'J11', 'T14', 'A6', 'D6', 'J12', 'T15', 'A7', 'A8', 'D7', 'J13', 'A9', 'D8', 'J14', 'B10', 'D9', 'J15', 'B12', 'E10', 'J16', 'B13', 'E11', 'K11', 'B14', 'E12', 'K12', 'B15', 'E13', 'K13', 'A10', 'B16', 'B5', 'E15', 'K14', 'B4', 'E16', 'K15']},{'label': 'uB', 'num': 2, 'pin_nums': ['P1', 'D2', 'K6', 'P10', 'K5', 'D3', 'L1', 'P11', 'E1', 'L10', 'P12', 'E2', 'L3', 'P2', 'E3', 'L4', 'P4', 'E4', 'L5', 'P5', 'F1', 'L7', 'P6', 'F2', 'L8', 'P7', 'F3', 'M1', 'P8', 'F4', 'M10', 'P9', 'F5', 'M11', 'R1', 'F6', 'M12', 'R11', 'G1', 'M2', 'R2', 'G3', 'M3', 'R3', 'G4', 'M4', 'R4', 'G5', 'M5', 'R5', 'G6', 'M6', 'R7', 'H1', 'M7', 'R8', 'H2', 'M9', 'R9', 'H3', 'N1', 'T10', 'H4', 'N10', 'T11', 'H5', 'N11', 'T3', 'J1', 'N12', 'T4', 'J2', 'A2', 'N2', 'T5', 'A3', 'J3', 'N3', 'T6', 'B1', 'J4', 'N4', 'T7', 'B2', 'J6', 'N5', 'T8', 'B3', 'K1', 'N6', 'T9', 'C1', 'K2', 'N7', 'C2', 'K3', 'N8', 'C3', 'K4', 'N9', 'D1']},{'label': 'uC', 'num': 3, 'pin_nums': ['C12', 'P13', 'T2', 'E14', 'P14', 'C14', 'A15', 'L11']},{'label': 'uD', 'num': 4, 'pin_nums': ['K10', 'G15', 'M8', 'B7', 'H7', 'K7', 'N13', 'D13', 'G2', 'H8', 'D4', 'G7', 'H9', 'K8', 'P3', 'B11', 'G10', 'E5', 'G8', 'J10', 'K9', 'J9', 'R10', 'L9', 'E9', 'G9', 'J5', 'L15', 'R6', 'A1', 'F11', 'H10', 'J7', 'L2', 'T1', 'H12', 'A16', 'F8', 'J8', 'L6', 'T16', 'H6']}] }),
        Part(**{ 'name':'XC6SLX25-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX25-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX25-CSG324\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L41N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L41P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='IO_L42N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L42P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E3',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G6',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M5',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R10',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R13',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R16',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='V17',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A4', 'C9', 'G15', 'M15', 'D11', 'A5', 'M16', 'G16', 'A6', 'D12', 'G18', 'M18', 'D13', 'A7', 'N14', 'G9', 'D14', 'A8', 'H12', 'N15', 'A9', 'D17', 'H13', 'N16', 'B10', 'D18', 'H14', 'N17', 'B11', 'D4', 'N18', 'H15', 'B12', 'D6', 'H16', 'P15', 'B14', 'D7', 'H17', 'P16', 'B15', 'D8', 'H18', 'P17', 'A10', 'B16', 'D9', 'J13', 'P18', 'B2', 'E10', 'J14', 'R17', 'B3', 'E11', 'J16', 'T17', 'E12', 'B4', 'J17', 'T18', 'C8', 'B5', 'E13', 'J18', 'U17', 'B6', 'E16', 'K12', 'U18', 'B8', 'E17', 'K13', 'B9', 'E18', 'K14', 'C10', 'F10', 'K15', 'C11', 'F11', 'K16', 'A13', 'C12', 'F12', 'K17', 'F13', 'C13', 'K18', 'F14', 'C14', 'L12', 'C15', 'F15', 'L13', 'C17', 'F16', 'L14', 'C18', 'F17', 'L15', 'C4', 'F18', 'A11', 'L16', 'A12', 'C5', 'F9', 'A14', 'L17', 'C6', 'G11', 'A15', 'L18', 'G13', 'A16', 'C7', 'M13', 'A3', 'A2', 'G14', 'M14']},{'label': 'uB', 'num': 2, 'pin_nums': ['M10', 'R15', 'U5', 'M11', 'G1', 'U7', 'R2', 'G3', 'M3', 'R3', 'U8', 'G4', 'M4', 'U9', 'R5', 'G6', 'M5', 'R6', 'V10', 'H1', 'M8', 'R7', 'V11', 'H2', 'N1', 'R8', 'V12', 'H3', 'N10', 'V13', 'T1', 'H4', 'N11', 'T10', 'V14', 'H5', 'N12', 'T11', 'V15', 'H6', 'N2', 'T12', 'V16', 'H7', 'N3', 'T13', 'V3', 'J1', 'N4', 'T14', 'V4', 'J2', 'N5', 'T15', 'V5', 'J3', 'N6', 'T2', 'V6', 'J5', 'N7', 'T3', 'V7', 'J6', 'N8', 'T4', 'V8', 'J7', 'N9', 'T5', 'V9', 'C1', 'K1', 'P1', 'T6', 'C2', 'K2', 'P11', 'T7', 'D1', 'K3', 'P12', 'T8', 'D2', 'K4', 'P2', 'T9', 'D3', 'K5', 'P3', 'U1', 'E1', 'K6', 'P4', 'U10', 'E2', 'L1', 'P6', 'U11', 'E3', 'L2', 'P7', 'U13', 'E4', 'L3', 'P8', 'U14', 'F1', 'L4', 'P9', 'U15', 'F2', 'L5', 'R10', 'U16', 'F3', 'L6', 'R11', 'U2', 'F4', 'F6', 'L7', 'R12', 'U3', 'F5', 'M1', 'R13', 'U4']},{'label': 'uC', 'num': 3, 'pin_nums': ['B18', 'R16', 'V2', 'D16', 'A17', 'D15', 'P13', 'V17']},{'label': 'uD', 'num': 4, 'pin_nums': ['M9', 'H11', 'L11', 'E9', 'J8', 'R4', 'C16', 'G10', 'H8', 'J9', 'L8', 'N13', 'R9', 'C3', 'G12', 'H9', 'K10', 'L9', 'P10', 'T16', 'A1', 'D10', 'G17', 'J10', 'K11', 'M12', 'P14', 'U12', 'A18', 'D5', 'G2', 'J11', 'K7', 'M17', 'P5', 'U6', 'B1', 'E14', 'G5', 'J12', 'K8', 'M2', 'R1', 'V1', 'B13', 'B7', 'E15', 'G7', 'J15', 'K9', 'M6', 'R14', 'V18', 'B17', 'E5', 'H10', 'J4', 'L10', 'M7', 'R18']}] }),
        Part(**{ 'name':'XC6SLX25-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX25-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX25-FGG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='IO_L44N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L44P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L54N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L54P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='N15',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='Y20',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='Y22',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C10', 'A12', 'A11', 'H22', 'E12', 'R22', 'C11', 'J17', 'E13', 'T19', 'C12', 'E14', 'J18', 'T20', 'C13', 'J19', 'E16', 'T21', 'A13', 'C14', 'E17', 'J20', 'A14', 'T22', 'C15', 'E19', 'J22', 'A15', 'U18', 'C16', 'A16', 'E20', 'K17', 'U20', 'A17', 'C17', 'K18', 'E22', 'U22', 'A18', 'C19', 'A20', 'E9', 'K19', 'V21', 'A21', 'C20', 'F12', 'K20', 'V22', 'A3', 'C21', 'F13', 'K21', 'W20', 'A4', 'C22', 'F14', 'K22', 'W21', 'A5', 'C5', 'F15', 'L16', 'W22', 'H21', 'A6', 'C6', 'F18', 'L17', 'A7', 'C7', 'F19', 'L19', 'A8', 'C8', 'F20', 'L20', 'A9', 'C9', 'F21', 'L21', 'B10', 'D10', 'F22', 'L22', 'B11', 'D11', 'G10', 'M19', 'B12', 'D12', 'G13', 'M20', 'B14', 'D13', 'G14', 'M21', 'B15', 'D14', 'G19', 'M22', 'B16', 'D15', 'G20', 'N18', 'B18', 'D17', 'G21', 'N19', 'B19', 'D19', 'G22', 'N20', 'B20', 'D20', 'H12', 'N22', 'B21', 'D21', 'H13', 'P19', 'B22', 'D22', 'H14', 'P20', 'B4', 'D6', 'H18', 'P21', 'B6', 'D7', 'H19', 'P22', 'A10', 'B7', 'D8', 'H20', 'R20', 'B8', 'D9', 'R21']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB10', 'L7', 'Y1', 'U3', 'AB11', 'F4', 'M1', 'Y10', 'U4', 'AB12', 'F5', 'M2', 'U5', 'Y11', 'AB13', 'F6', 'M3', 'Y12', 'U6', 'AB14', 'G1', 'M4', 'U9', 'Y13', 'AB15', 'G2', 'M5', 'V1', 'Y14', 'AB16', 'G3', 'N1', 'V11', 'Y15', 'AB17', 'G4', 'N3', 'Y16', 'V12', 'AB18', 'G6', 'N5', 'V13', 'Y17', 'AB19', 'H1', 'P1', 'V15', 'Y18', 'AB2', 'H2', 'P2', 'V16', 'Y19', 'AB20', 'H3', 'R1', 'V2', 'Y2', 'AB21', 'H4', 'R11', 'V3', 'Y21', 'AB3', 'H5', 'R2', 'V5', 'Y3', 'A2', 'AB4', 'H6', 'R3', 'V7', 'Y4', 'AA10', 'AB5', 'H8', 'R7', 'V8', 'Y5', 'AA11', 'AB6', 'J1', 'R8', 'V9', 'Y6', 'AA12', 'AB7', 'J3', 'R9', 'W1', 'Y7', 'AA14', 'AB8', 'J4', 'T1', 'W10', 'Y8', 'AA15', 'AB9', 'J5', 'T11', 'W11', 'Y9', 'AA16', 'B1', 'J6', 'T13', 'W12', 'AA18', 'B2', 'J7', 'T2', 'W13', 'AA19', 'B3', 'K1', 'T3', 'W14', 'AA2', 'C1', 'K2', 'T4', 'W15', 'AA20', 'C2', 'K3', 'T5', 'W18', 'AA21', 'C3', 'K4', 'T6', 'W2', 'AA22', 'D1', 'K5', 'T7', 'W3', 'AA3', 'D2', 'K6', 'T9', 'W4', 'AA4', 'E1', 'L1', 'U1', 'W5', 'AA6', 'E3', 'L2', 'U13', 'W6', 'AA7', 'F1', 'F3', 'L3', 'U14', 'W8', 'AA8', 'F2', 'L4', 'U15', 'W9']},{'label': 'uC', 'num': 3, 'pin_nums': ['E18', 'N15', 'Y22', 'AA1', 'A19', 'C18', 'G15', 'Y20']},{'label': 'uD', 'num': 4, 'pin_nums': ['J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12', 'B17', 'K14', 'P13', 'B5', 'K15', 'P14', 'B9', 'K9', 'P9', 'D16', 'L10', 'R10', 'D18', 'L11', 'R12', 'D4', 'L12', 'R14', 'E11', 'L13', 'R18', 'E15', 'L14', 'R5', 'E2', 'L18', 'R6', 'E21', 'L5', 'U11', 'E7', 'L8', 'U2', 'F11', 'L9', 'U21', 'G12', 'M10', 'U7', 'G18', 'M11', 'V10', 'G5', 'M12', 'V14', 'H15', 'M13', 'V4', 'H7', 'M14', 'V6', 'H9', 'M15', 'W16', 'J10', 'M9', 'W19', 'J11', 'N10', 'W7', 'J12', 'N11', 'J13', 'N12', 'J14', 'N13', 'A1', 'J15', 'N14', 'A22', 'AA17', 'J2', 'N17', 'AA13', 'J21', 'N2']}] }),
        Part(**{ 'name':'XC6SLX25-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX25-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX25-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D16',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L10',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M12',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N11',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N3',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N8',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R9',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='L11',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P14',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C7', 'G12', 'P15', 'G13', 'C8', 'P16', 'A11', 'C9', 'G14', 'R12', 'A13', 'G16', 'D10', 'R13', 'D11', 'H11', 'R14', 'D12', 'H13', 'R15', 'D14', 'H14', 'A12', 'R16', 'D15', 'H15', 'T12', 'A14', 'D16', 'H16', 'A4', 'T13', 'A5', 'D5', 'J11', 'T14', 'A6', 'D6', 'J12', 'T15', 'A7', 'A8', 'D7', 'J13', 'A9', 'D8', 'J14', 'B10', 'D9', 'J15', 'B12', 'E10', 'J16', 'G11', 'B13', 'E11', 'K11', 'B14', 'E12', 'K12', 'B15', 'E13', 'K13', 'B16', 'E15', 'K14', 'B4', 'E16', 'K15', 'B5', 'E6', 'K16', 'B6', 'E7', 'L12', 'B8', 'E8', 'L13', 'B9', 'F10', 'L14', 'C10', 'F12', 'L16', 'C11', 'F13', 'M13', 'C13', 'F14', 'M14', 'C15', 'F15', 'M15', 'A10', 'C16', 'F16', 'M16', 'C4', 'F7', 'N14', 'C5', 'F9', 'N15', 'C6', 'N16']},{'label': 'uB', 'num': 2, 'pin_nums': ['F6', 'R11', 'G1', 'R2', 'M2', 'G3', 'M3', 'R3', 'G4', 'M4', 'R4', 'G5', 'M5', 'R5', 'G6', 'M6', 'R7', 'H1', 'M7', 'R8', 'H2', 'M9', 'R9', 'H3', 'N1', 'T10', 'H4', 'N10', 'T11', 'H5', 'N11', 'T3', 'J1', 'N12', 'T4', 'A2', 'J2', 'N2', 'T5', 'A3', 'J3', 'N3', 'T6', 'B1', 'J4', 'N4', 'T7', 'B2', 'J6', 'N5', 'T8', 'B3', 'K1', 'N6', 'T9', 'C1', 'K2', 'N7', 'C2', 'K3', 'N8', 'C3', 'K4', 'N9', 'D1', 'K5', 'P1', 'D2', 'K6', 'P10', 'D3', 'L1', 'P11', 'E1', 'L10', 'P12', 'E2', 'L3', 'P2', 'E3', 'L4', 'P4', 'E4', 'L5', 'P5', 'F1', 'L7', 'P6', 'F2', 'L8', 'P7', 'F3', 'M1', 'P8', 'F4', 'M10', 'M12', 'P9', 'F5', 'M11', 'R1']},{'label': 'uC', 'num': 3, 'pin_nums': ['A15', 'L11', 'C12', 'E14', 'P13', 'P14', 'T2', 'C14']},{'label': 'uD', 'num': 4, 'pin_nums': ['R10', 'G8', 'K9', 'J10', 'E9', 'G9', 'J5', 'L15', 'R6', 'A1', 'F11', 'H10', 'J7', 'L2', 'T1', 'A16', 'F8', 'H12', 'J8', 'L6', 'T16', 'B11', 'G10', 'H6', 'J9', 'L9', 'B7', 'G15', 'H7', 'K10', 'M8', 'D13', 'G2', 'H8', 'K7', 'N13', 'D4', 'G7', 'H9', 'K8', 'P3', 'E5']}] }),
        Part(**{ 'name':'XC6SLX25T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX25T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX25T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A15',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E3',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G6',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M5',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R10',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R13',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C8',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D6',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='A17',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='B18',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='P13',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='R16',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='V17',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='V2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D14',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D4',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P5',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['K13', 'E8', 'K14', 'K15', 'F12', 'F14', 'K16', 'F15', 'K17', 'F16', 'K18', 'F17', 'L12', 'F18', 'L13', 'F7', 'L14', 'F8', 'L15', 'G11', 'L16', 'G12', 'L17', 'G13', 'L18', 'G14', 'M13', 'G15', 'M14', 'A15', 'G16', 'M15', 'A16', 'A2', 'G18', 'M16', 'A3', 'G8', 'M18', 'B15', 'G9', 'N14', 'B16', 'B2', 'H12', 'N15', 'B3', 'H13', 'N16', 'C15', 'C17', 'H14', 'N17', 'C18', 'H15', 'N18', 'C3', 'H16', 'P15', 'D15', 'H17', 'P16', 'D17', 'H18', 'P17', 'D18', 'J13', 'P18', 'E12', 'J14', 'R17', 'E14', 'J16', 'T17', 'E16', 'J17', 'T18', 'E17', 'E6', 'J18', 'U17', 'E18', 'K12', 'U18']},{'label': 'uB', 'num': 2, 'pin_nums': ['T5', 'K1', 'C1', 'T6', 'P1', 'K2', 'C2', 'P11', 'T7', 'D1', 'K3', 'P12', 'T8', 'K4', 'D2', 'P2', 'T9', 'D3', 'K5', 'P3', 'U1', 'E1', 'K6', 'P4', 'U10', 'E2', 'L1', 'P6', 'U11', 'E3', 'L2', 'P7', 'U13', 'J7', 'E4', 'L3', 'P8', 'U14', 'F1', 'L4', 'P9', 'U15', 'F2', 'L5', 'R10', 'U16', 'F3', 'L6', 'R11', 'U2', 'F4', 'L7', 'R12', 'U3', 'F5', 'M1', 'R13', 'U4', 'F6', 'M10', 'R15', 'U5', 'M11', 'G1', 'R2', 'U7', 'G3', 'M3', 'R3', 'U8', 'G4', 'M4', 'R5', 'U9', 'G6', 'M5', 'R6', 'V10', 'H1', 'M8', 'R7', 'V11', 'H2', 'N1', 'R8', 'V12', 'H3', 'N10', 'T1', 'V13', 'H4', 'N11', 'T10', 'V14', 'N12', 'H5', 'T11', 'V15', 'H6', 'N2', 'T12', 'V16', 'H7', 'N3', 'T13', 'V3', 'J1', 'N4', 'T14', 'V4', 'J2', 'N5', 'T15', 'V5', 'J3', 'N6', 'T2', 'V6', 'J5', 'N7', 'T3', 'V7', 'V9', 'J6', 'N8', 'T4', 'V8', 'N9']},{'label': 'uC', 'num': 3, 'pin_nums': ['C5', 'C9', 'D7', 'B4', 'A6', 'B8', 'C7', 'D5', 'D9', 'B6', 'A4', 'A8']},{'label': 'uD', 'num': 4, 'pin_nums': ['A5', 'D6', 'E7', 'C8', 'B7', 'D10', 'E5']},{'label': 'uE', 'num': 5, 'pin_nums': ['A17', 'F13', 'R16', 'B18', 'D16', 'V17', 'V2', 'P13']},{'label': 'uF', 'num': 6, 'pin_nums': ['K8', 'R1', 'V1', 'M2', 'A7', 'C12', 'E13', 'G7', 'J15', 'K9', 'M6', 'R14', 'V18', 'A9', 'E15', 'H10', 'C14', 'J4', 'L10', 'M7', 'R18', 'A18', 'D8', 'B1', 'C16', 'F11', 'G5', 'H11', 'J12', 'J8', 'L11', 'M9', 'R4', 'B13', 'C4', 'F9', 'H8', 'J9', 'L8', 'N13', 'R9', 'B17', 'C6', 'G10', 'H9', 'K10', 'L9', 'P10', 'T16', 'A1', 'B5', 'D14', 'G17', 'J10', 'K11', 'M12', 'P14', 'U12', 'A11', 'B9', 'D4', 'G2', 'J11', 'K7', 'M17', 'P5', 'U6', 'C10']}] }),
        Part(**{ 'name':'XC6SLX25T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX25T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX25T-FGG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='A21',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='AA22',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='AB2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB21',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='D20',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='G17',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='V18',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C22', 'G11', 'U20', 'K22', 'G13', 'C3', 'U22', 'L16', 'C4', 'G14', 'L17', 'V19', 'G15', 'C5', 'V20', 'L19', 'G16', 'D17', 'L20', 'V21', 'D18', 'G19', 'L21', 'V22', 'D19', 'G20', 'L22', 'W20', 'D3', 'G21', 'W21', 'M17', 'D4', 'G22', 'A18', 'M18', 'W22', 'D5', 'G8', 'M19', 'Y21', 'E16', 'G9', 'M20', 'Y22', 'E17', 'H10', 'M21', 'E19', 'H11', 'M22', 'E20', 'H12', 'N16', 'E22', 'H13', 'N18', 'E5', 'H14', 'N19', 'H18', 'E6', 'N20', 'F10', 'H19', 'A19', 'N22', 'A17', 'H20', 'F14', 'A2', 'P16', 'A20', 'F15', 'H21', 'P19', 'A3', 'F16', 'H22', 'P20', 'A4', 'F17', 'J16', 'A5', 'P21', 'B18', 'F18', 'J17', 'P22', 'B19', 'F19', 'J18', 'B2', 'R19', 'B20', 'F20', 'J19', 'R20', 'B3', 'F21', 'J20', 'R21', 'B4', 'F22', 'J22', 'R22', 'G10', 'C17', 'F6', 'K17', 'T20', 'C18', 'F7', 'K18', 'T21', 'C19', 'F8', 'K19', 'T22', 'C20', 'F9', 'K20', 'U18', 'C21', 'K21', 'U19']},{'label': 'uB', 'num': 2, 'pin_nums': ['H3', 'P2', 'V11', 'Y16', 'AB14', 'H5', 'V12', 'P3', 'Y17', 'AB15', 'J1', 'P4', 'V13', 'Y18', 'AB16', 'J3', 'V16', 'P5', 'Y19', 'AB17', 'J4', 'P8', 'V17', 'Y2', 'AB18', 'J5', 'R1', 'V2', 'Y20', 'AB19', 'J6', 'R13', 'V7', 'Y3', 'AB20', 'K1', 'V8', 'R2', 'Y4', 'AB3', 'K2', 'R3', 'V9', 'Y5', 'AB4', 'K3', 'R7', 'W1', 'Y6', 'AB5', 'K4', 'R8', 'W10', 'Y7', 'V1', 'AB6', 'K5', 'R9', 'W11', 'Y8', 'AA1', 'AB7', 'K6', 'T1', 'W12', 'Y9', 'AA10', 'AB8', 'L1', 'T10', 'W13', 'AA11', 'AB9', 'L2', 'T12', 'W14', 'AA12', 'B1', 'L3', 'T13', 'W15', 'AA14', 'C1', 'L4', 'T14', 'W17', 'AA15', 'C2', 'L6', 'T2', 'W18', 'AA16', 'D1', 'L7', 'T7', 'W2', 'AA18', 'D2', 'M1', 'T8', 'W3', 'AA19', 'E1', 'M2', 'T9', 'W4', 'AA2', 'E3', 'M3', 'U1', 'W5', 'AA20', 'E4', 'M4', 'U10', 'W6', 'AA21', 'F1', 'M5', 'U12', 'W8', 'AA3', 'F2', 'M6', 'U13', 'W9', 'AA4', 'F3', 'M7', 'U14', 'Y1', 'AA6', 'F4', 'M8', 'U3', 'Y10', 'AA7', 'G1', 'N1', 'U5', 'Y11', 'AA8', 'G2', 'N3', 'U6', 'Y12', 'AB10', 'G3', 'N4', 'U8', 'Y13', 'AB11', 'AB13', 'H1', 'N5', 'U9', 'Y14', 'AB12', 'H2', 'P1', 'Y15']},{'label': 'uC', 'num': 3, 'pin_nums': ['C11', 'A10', 'C9', 'A8', 'B6', 'D7', 'A6', 'B10', 'B8', 'C7', 'D11', 'D9']},{'label': 'uD', 'num': 4, 'pin_nums': ['D12', 'C10', 'D8', 'E9', 'A7', 'E8', 'B9']},{'label': 'uE', 'num': 5, 'pin_nums': ['AB2', 'G17', 'D20', 'A21', 'AB21', 'AA22', 'E18', 'V18']},{'label': 'uF', 'num': 6, 'pin_nums': ['D16', 'K9', 'P9', 'L10', 'D6', 'R10', 'E11', 'L11', 'R12', 'L12', 'E14', 'R14', 'E15', 'L13', 'R18', 'E2', 'L14', 'R5', 'E21', 'L18', 'R6', 'E7', 'L5', 'U11', 'F11', 'L8', 'U2', 'F13', 'L9', 'U21', 'A1', 'G12', 'M10', 'U7', 'A11', 'G18', 'M11', 'V10', 'A13', 'G5', 'M12', 'V14', 'A22', 'H15', 'M13', 'V4', 'A9', 'H7', 'M14', 'V6', 'AA13', 'H9', 'M15', 'W16', 'AA17', 'J10', 'M9', 'W19', 'AA5', 'J11', 'N10', 'W7', 'AA9', 'J12', 'N11', 'AB1', 'J13', 'N12', 'AB22', 'J14', 'N13', 'K15', 'B11', 'J15', 'N14', 'B15', 'J2', 'N17', 'B17', 'J21', 'N2', 'B5', 'J8', 'N21', 'B7', 'J9', 'N8', 'C12', 'K10', 'N9', 'C14', 'K11', 'P10', 'C16', 'K12', 'P11', 'C6', 'K13', 'P12', 'C8', 'K14', 'P13', 'D10', 'P14']}] }),
        Part(**{ 'name':'XC6SLX4-CPG196', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX4-CPG196'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX4-CPG196\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L1P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L1N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='IO_L32P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L32N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='IO_L33P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L33N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L34P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L34N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L41P_GCLK9_IRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L41N_GCLK8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L40P_GCLK11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L40N_GCLK10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L43P_GCLK5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L43N_GCLK4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L42P_GCLK7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L42N_GCLK6_TRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L46P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L46N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L45P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L45N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='IO_L47P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L47N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L51N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L51P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L50P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F1',name='IO_L44N_GCLK20_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L44P_GCLK21_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L49N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L49P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L42N_GCLK24_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L42P_GCLK25_TRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H1',name='IO_L43N_GCLK22_IRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L43P_GCLK23_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L41P_GCLK27_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L37N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L37P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L36N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L36P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N10',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A13',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='B13',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='L12',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='M12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N14',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G11', 'L13', 'J11', 'A9', 'A10', 'B7', 'C5', 'B10', 'E12', 'G12', 'J12', 'L14', 'A2', 'B8', 'C8', 'B11', 'E13', 'G13', 'J13', 'M13', 'B6', 'B12', 'B9', 'C9', 'A12', 'D8', 'E14', 'G14', 'J14', 'M14', 'A3', 'B2', 'C10', 'D11', 'F11', 'H11', 'K11', 'A4', 'B3', 'C11', 'D12', 'F12', 'H12', 'K12', 'A5', 'B4', 'C12', 'D13', 'F13', 'H13', 'K13', 'A6', 'A11', 'B5', 'C13', 'D14', 'A7', 'F14', 'H14', 'K14', 'A8', 'C4']},{'label': 'uB', 'num': 2, 'pin_nums': ['L1', 'J1', 'D3', 'F3', 'M5', 'N2', 'P10', 'P6', 'D4', 'F4', 'J2', 'L2', 'N3', 'P11', 'P7', 'M6', 'E1', 'G1', 'J3', 'L4', 'M8', 'N4', 'N9', 'P12', 'P5', 'P8', 'E2', 'G2', 'J4', 'L8', 'M9', 'N5', 'P13', 'P9', 'B1', 'E3', 'G3', 'K1', 'M1', 'N10', 'N6', 'P2', 'C1', 'E4', 'H1', 'K2', 'M10', 'N11', 'N7', 'P3', 'D1', 'F1', 'H2', 'K3', 'M2', 'N12', 'N8', 'P4', 'D2', 'F2', 'H3', 'K4', 'N13', 'M4']},{'label': 'uC', 'num': 3, 'pin_nums': ['N14', 'B13', 'C14', 'M12', 'L12', 'A13', 'B14', 'N1']},{'label': 'uD', 'num': 4, 'pin_nums': ['C3', 'F5', 'E10', 'H7', 'J9', 'L11', 'M7', 'C6', 'E11', 'F6', 'G7', 'H8', 'K10', 'L3', 'P1', 'C7', 'E5', 'F7', 'G8', 'H9', 'K5', 'L5', 'P14', 'D10', 'E6', 'F8', 'G9', 'J10', 'K6', 'L6', 'D5', 'E7', 'F9', 'H10', 'J5', 'K7', 'L7', 'A1', 'D6', 'E8', 'G10', 'H4', 'J6', 'K8', 'L9', 'A14', 'D7', 'E9', 'G4', 'G6', 'H5', 'J7', 'K9', 'M11', 'C2', 'D9', 'F10', 'G5', 'H6', 'J8', 'L10', 'M3']}] }),
        Part(**{ 'name':'XC6SLX4-CSG225', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX4-CSG225'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX4-CSG225\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L1P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L1N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L33P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L33N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L35P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='IO_L35N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L37P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L37N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L39P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L39N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L41P_GCLK9_IRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L41N_GCLK8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L42P_GCLK7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L42N_GCLK6_TRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L36P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L36N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_GCLK5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L43N_GCLK4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO_L38P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L38N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L40P_GCLK11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L44P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L44N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40N_GCLK10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L45P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L45N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L46P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='IO_L46N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L47P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L47N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L54N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L54P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L53P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L52P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L53N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L46P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L44P_GCLK21_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H3',name='IO_L42P_GCLK25_TRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L41P_GCLK27_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L43N_GCLK22_IRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L45N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L40P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43P_GCLK23_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L45P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L39P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L9',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L38N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M3',name='IO_L38P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L37P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P13',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P9',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='D12',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='E13',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='L10',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='L13',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='R14',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L4',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A10', 'B12', 'C4', 'D14', 'E9', 'H15', 'A2', 'K12', 'M15', 'B13', 'B8', 'C5', 'D15', 'F10', 'A3', 'J11', 'K13', 'N14', 'B14', 'A4', 'B9', 'C6', 'D5', 'F13', 'J12', 'K15', 'N15', 'A5', 'B15', 'C10', 'C8', 'D8', 'F15', 'J13', 'L12', 'P14', 'A6', 'B2', 'A13', 'A7', 'C11', 'C9', 'D9', 'G14', 'J14', 'L14', 'P15', 'A8', 'B3', 'C12', 'D10', 'E14', 'G15', 'J15', 'L15', 'A9', 'B4', 'B7', 'C14', 'D11', 'E15', 'H13', 'K10', 'M13', 'B11', 'B5', 'C15', 'D13', 'E7', 'H14', 'A11', 'K11', 'M14', 'A12']},{'label': 'uB', 'num': 2, 'pin_nums': ['D2', 'P9', 'M11', 'L2', 'G1', 'J3', 'N10', 'N8', 'P5', 'R3', 'D3', 'N11', 'P1', 'P7', 'G2', 'J4', 'R4', 'L3', 'M2', 'D4', 'G4', 'K1', 'L5', 'M3', 'N12', 'P11', 'P8', 'R5', 'J2', 'E1', 'R6', 'H1', 'K3', 'L6', 'M10', 'M4', 'N1', 'N2', 'P12', 'N7', 'E2', 'P4', 'H2', 'K4', 'L8', 'M5', 'N4', 'P13', 'R10', 'R13', 'R7', 'C1', 'E3', 'D1', 'H3', 'K5', 'L9', 'M7', 'N5', 'P2', 'R11', 'R8', 'C2', 'F1', 'J1', 'K8', 'M1', 'M8', 'N6', 'P3', 'R12', 'R9', 'F3', 'L1']},{'label': 'uC', 'num': 3, 'pin_nums': ['R2', 'L10', 'A14', 'E10', 'R14', 'L13', 'D12', 'E13']},{'label': 'uD', 'num': 4, 'pin_nums': ['A1', 'G7', 'J7', 'E12', 'L11', 'R15', 'A15', 'G8', 'J8', 'L4', 'F14', 'M12', 'B1', 'F2', 'G9', 'J9', 'B10', 'F6', 'H7', 'K14', 'N13', 'B6', 'F7', 'H8', 'K2', 'N3', 'C13', 'F9', 'H9', 'K6', 'P10', 'E11', 'C3', 'G10', 'J10', 'K7', 'J6', 'P6', 'K9', 'R1', 'G6']}] }),
        Part(**{ 'name':'XC6SLX4-TQG144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX4-TQG144'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX4-TQG144\n\nFPGA', 'pins':[
            Pin(num='100',name='IO_L33P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO_L32N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO_L32P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='IO_L1N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='IO_L1P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='IO_L47N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IO_L47P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IO_L46N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='IO_L46P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO_L45N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO_L45P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO_L43N_GCLK4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO_L43P_GCLK5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='IO_L42N_GCLK6_TRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO_L42P_GCLK7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='IO_L41N_GCLK8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='IO_L41P_GCLK9_IRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='IO_L40N_GCLK10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO_L40P_GCLK11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO_L34N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO_L34P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO_L33N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='10',name='IO_L50P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='11',name='IO_L49N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='12',name='IO_L49P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='14',name='IO_L44N_GCLK20_3',func=pin_types.BIDIR,unit=2),
            Pin(num='15',name='IO_L44P_GCLK21_3',func=pin_types.BIDIR,unit=2),
            Pin(num='16',name='IO_L43N_GCLK22_IRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='17',name='IO_L43P_GCLK23_3',func=pin_types.BIDIR,unit=2),
            Pin(num='18',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='21',name='IO_L42N_GCLK24_3',func=pin_types.BIDIR,unit=2),
            Pin(num='22',name='IO_L42P_GCLK25_TRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='23',name='IO_L41N_GCLK26_3',func=pin_types.BIDIR,unit=2),
            Pin(num='24',name='IO_L41P_GCLK27_3',func=pin_types.BIDIR,unit=2),
            Pin(num='26',name='IO_L37N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='27',name='IO_L37P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='29',name='IO_L36N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='30',name='IO_L36P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='31',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='32',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='33',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='34',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='35',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='38',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='39',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='40',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='41',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='42',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='43',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='44',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='45',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='46',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='47',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='48',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='5',name='IO_L52N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='50',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='51',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='55',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='56',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='57',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='58',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='59',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='6',name='IO_L52P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='60',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='61',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='62',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='63',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='64',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='65',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='66',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='67',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='69',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='7',name='IO_L51N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='70',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='8',name='IO_L51P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='9',name='IO_L50N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='106',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='107',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='109',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='110',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='37',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='71',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='72',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='73',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='108',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='113',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='128',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='129',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='130',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='136',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='19',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='20',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='28',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='36',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='49',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='52',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='53',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='54',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='68',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='77',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='89',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='90',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='91',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='96',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['100', '121', '141', '132', '79', '111', '87', '99', '101', '133', '142', '80', '88', '122', '112', '114', '103', '123', '134', '143', '115', '81', '92', '124', '116', '135', '144', '82', '93', '120', '117', '125', '137', '140', '74', '78', '83', '94', '86', '98', '118', '126', '138', '75', '102', '84', '95', '119', '127', '139', '76', '104', '85', '97', '131', '105']},{'label': 'uB', 'num': 2, 'pin_nums': ['62', '35', '55', '70', '44', '17', '27', '38', '45', '56', '63', '8', '18', '1', '29', '39', '46', '57', '64', '9', '10', '2', '30', '4', '47', '58', '65', '11', '21', '31', '40', '48', '59', '66', '12', '22', '32', '41', '5', '6', '67', '23', '14', '33', '42', '50', '60', '69', '24', '15', '16', '34', '43', '51', '61', '7', '26']},{'label': 'uC', 'num': 3, 'pin_nums': ['107', '110', '71', '73', '106', '37', '72', '109']},{'label': 'uD', 'num': 4, 'pin_nums': ['130', '49', '91', '136', '96', '52', '36', '19', '53', '108', '20', '54', '113', '25', '68', '128', '28', '77', '129', '3', '89', '13', '90']}] }),
        Part(**{ 'name':'XC6SLX45-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45-CSG324\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L41N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L41P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E3',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G6',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M5',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R10',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R13',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R16',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='V17',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A9', 'J16', 'D4', 'T17', 'B10', 'J17', 'D6', 'T18', 'B11', 'D7', 'J18', 'U17', 'B12', 'K12', 'D8', 'U18', 'B14', 'D9', 'K13', 'B15', 'E10', 'K14', 'B16', 'E13', 'K15', 'A8', 'B2', 'K16', 'E16', 'B3', 'E17', 'K17', 'B4', 'E18', 'K18', 'B5', 'F13', 'L12', 'B6', 'F14', 'L13', 'J14', 'B8', 'F15', 'L14', 'B9', 'F16', 'L15', 'C10', 'F17', 'L16', 'C11', 'F18', 'L17', 'C13', 'F9', 'L18', 'C14', 'G13', 'M13', 'C15', 'G14', 'M14', 'C17', 'A13', 'G15', 'M15', 'C18', 'G16', 'M16', 'C4', 'G18', 'M18', 'A10', 'C5', 'G9', 'N14', 'A11', 'A12', 'C6', 'H12', 'N15', 'A14', 'C7', 'H13', 'N16', 'A15', 'C8', 'A16', 'H14', 'N17', 'A2', 'C9', 'H15', 'N18', 'A3', 'D11', 'A4', 'H16', 'P15', 'A5', 'D13', 'H17', 'P16', 'A6', 'D14', 'H18', 'P17', 'A7', 'D17', 'J13', 'P18', 'D18', 'R17']},{'label': 'uB', 'num': 2, 'pin_nums': ['J2', 'N5', 'T15', 'V5', 'J3', 'T2', 'N6', 'V6', 'J5', 'N7', 'T3', 'V7', 'J6', 'T4', 'N8', 'V8', 'J7', 'N9', 'T5', 'V9', 'C1', 'K1', 'P1', 'T6', 'C2', 'K2', 'P11', 'T7', 'D1', 'K3', 'T8', 'P12', 'D2', 'K4', 'P2', 'T9', 'D3', 'K5', 'P3', 'U1', 'E1', 'K6', 'P4', 'U10', 'E2', 'L1', 'P6', 'U11', 'E3', 'L2', 'P7', 'U13', 'E4', 'L3', 'P8', 'U14', 'F1', 'L4', 'P9', 'U15', 'F2', 'L5', 'R10', 'U16', 'F3', 'L6', 'R11', 'U2', 'F4', 'L7', 'R12', 'U3', 'F5', 'M1', 'R13', 'U4', 'F6', 'M10', 'R15', 'U5', 'G1', 'M11', 'R2', 'U7', 'G3', 'M3', 'R3', 'U8', 'G4', 'M4', 'R5', 'U9', 'T14', 'G6', 'M5', 'R6', 'V10', 'H1', 'M8', 'R7', 'V11', 'H2', 'N1', 'R8', 'V12', 'H3', 'N10', 'T1', 'V13', 'H4', 'N11', 'T10', 'V14', 'H5', 'N12', 'T11', 'V15', 'H6', 'N2', 'T12', 'V16', 'H7', 'N3', 'T13', 'V3', 'J1', 'N4', 'V4']},{'label': 'uC', 'num': 3, 'pin_nums': ['V17', 'A17', 'D15', 'P13', 'B18', 'D16', 'R16', 'V2']},{'label': 'uD', 'num': 4, 'pin_nums': ['G5', 'J12', 'B1', 'E14', 'K8', 'M2', 'R1', 'V1', 'B13', 'E15', 'G7', 'J15', 'V18', 'K9', 'M6', 'R14', 'B17', 'E5', 'H10', 'J4', 'L10', 'M7', 'R18', 'B7', 'E9', 'H11', 'J8', 'L11', 'M9', 'R4', 'C16', 'G10', 'H8', 'J9', 'L8', 'N13', 'R9', 'C3', 'G12', 'H9', 'K10', 'L9', 'P10', 'T16', 'A1', 'D10', 'G17', 'J10', 'K11', 'M12', 'P14', 'U12', 'A18', 'D5', 'G2', 'J11', 'U6', 'K7', 'M17', 'P5']}] }),
        Part(**{ 'name':'XC6SLX45-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45-CSG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L14N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L14P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L12P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L12N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L11P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L11N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L13P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L13N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F8',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G8',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='D14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='T15',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J20',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A6', 'F10', 'P15', 'J17', 'W22', 'A7', 'C16', 'F13', 'P16', 'J18', 'Y19', 'A8', 'C17', 'F14', 'J19', 'P17', 'Y20', 'A9', 'C18', 'F15', 'J21', 'P18', 'Y21', 'AA19', 'C19', 'F16', 'J22', 'P19', 'Y22', 'AA20', 'C20', 'F17', 'K16', 'P20', 'AA21', 'C21', 'F18', 'K17', 'P21', 'AA22', 'C22', 'F19', 'P22', 'K18', 'AB19', 'C5', 'F20', 'K19', 'R15', 'AB20', 'C6', 'F21', 'K20', 'R16', 'AB21', 'C7', 'F22', 'K21', 'R17', 'N22', 'B10', 'C8', 'G10', 'K22', 'R19', 'B11', 'C9', 'G13', 'L15', 'R20', 'B12', 'D10', 'G14', 'L16', 'R21', 'B14', 'D11', 'G15', 'L17', 'R22', 'B15', 'D15', 'G16', 'A10', 'L19', 'T17', 'B16', 'D17', 'G17', 'L20', 'T18', 'A12', 'B18', 'D19', 'G19', 'L21', 'T19', 'B19', 'D20', 'G20', 'L22', 'T20', 'B20', 'D21', 'G21', 'M16', 'T21', 'B21', 'D22', 'G22', 'M17', 'T22', 'B22', 'D6', 'H12', 'A11', 'M18', 'U18', 'B3', 'D7', 'H13', 'M19', 'U20', 'A13', 'B4', 'D8', 'H14', 'A14', 'M20', 'U22', 'B6', 'D9', 'H16', 'A15', 'M21', 'V17', 'B7', 'A16', 'E10', 'H17', 'M22', 'V18', 'A17', 'B8', 'E13', 'H18', 'N15', 'V19', 'A18', 'C10', 'A19', 'E17', 'H19', 'N16', 'V20', 'A20', 'C11', 'E19', 'H20', 'N18', 'V21', 'A21', 'C12', 'E20', 'H21', 'N19', 'V22', 'A4', 'C13', 'C15', 'E22', 'H22', 'N20', 'W20', 'A5', 'C14', 'E9', 'J16', 'W21']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB4', 'M2', 'W13', 'T2', 'AB5', 'G6', 'M3', 'W14', 'T3', 'AB6', 'G7', 'M4', 'T4', 'W15', 'AB7', 'G8', 'M5', 'W17', 'T7', 'AB8', 'H1', 'M6', 'T8', 'W2', 'AB9', 'H2', 'M7', 'T9', 'W3', 'A2', 'B1', 'H3', 'M8', 'U1', 'W4', 'A3', 'B2', 'H4', 'N1', 'W5', 'U10', 'AA10', 'C1', 'H5', 'N3', 'U14', 'W6', 'AA11', 'C2', 'H6', 'N4', 'U15', 'W8', 'AA12', 'C3', 'H8', 'N5', 'U3', 'W9', 'AA14', 'C4', 'J1', 'N6', 'U4', 'Y1', 'AA15', 'D1', 'J3', 'N7', 'U5', 'Y10', 'AA16', 'D2', 'J4', 'P1', 'U6', 'Y11', 'AA18', 'D3', 'J5', 'P2', 'U8', 'Y12', 'AA2', 'D5', 'J6', 'P3', 'U9', 'Y13', 'AA3', 'E1', 'J7', 'P4', 'V1', 'Y14', 'AA4', 'E3', 'K1', 'P5', 'V11', 'Y15', 'AA6', 'E4', 'K2', 'P6', 'V12', 'Y16', 'AA7', 'E5', 'K3', 'P7', 'V13', 'Y17', 'AA8', 'E6', 'K4', 'P8', 'V15', 'Y18', 'AB10', 'F1', 'K5', 'R1', 'V16', 'Y2', 'AB11', 'F2', 'K6', 'R11', 'V2', 'Y3', 'AB12', 'F3', 'K7', 'R2', 'V3', 'Y4', 'AB13', 'F4', 'K8', 'R3', 'V5', 'Y5', 'AB14', 'F5', 'L1', 'R4', 'V7', 'Y6', 'AB15', 'F6', 'L2', 'R7', 'V8', 'Y7', 'AB16', 'F7', 'L3', 'T1', 'V9', 'Y8', 'AB17', 'F8', 'L4', 'T10', 'W1', 'Y9', 'AB18', 'G1', 'L6', 'T11', 'W10', 'AB2', 'G2', 'G4', 'L7', 'T13', 'W11', 'AB3', 'G3', 'M1', 'T14', 'W12']},{'label': 'uC', 'num': 3, 'pin_nums': ['AA1', 'E14', 'E18', 'U16', 'D14', 'E16', 'T15', 'W18']},{'label': 'uD', 'num': 4, 'pin_nums': ['H9', 'M15', 'W16', 'J10', 'W19', 'M9', 'J11', 'N10', 'W7', 'J12', 'N11', 'J13', 'N12', 'J14', 'N13', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J20', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12', 'B17', 'K14', 'P13', 'B5', 'K15', 'P14', 'B9', 'K9', 'P9', 'D16', 'L10', 'R10', 'D18', 'L11', 'R12', 'D4', 'L12', 'R14', 'E11', 'L13', 'R18', 'E15', 'L14', 'R5', 'E2', 'L18', 'R6', 'E21', 'L5', 'U11', 'E7', 'L8', 'U2', 'L9', 'F11', 'U21', 'G12', 'M10', 'U7', 'G18', 'M11', 'V10', 'G5', 'M12', 'V14', 'H15', 'M13', 'V4', 'H7', 'M14', 'V6']}] }),
        Part(**{ 'name':'XC6SLX45-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45-FGG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F16',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L54N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V19',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L54P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='N15',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='Y20',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='Y22',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D15', 'H16', 'M21', 'D17', 'B15', 'M22', 'H17', 'B16', 'D19', 'H18', 'N16', 'B18', 'D20', 'N18', 'H19', 'B19', 'D21', 'H20', 'N19', 'B20', 'D22', 'H21', 'N20', 'B21', 'D6', 'H22', 'N22', 'B22', 'D7', 'P17', 'J16', 'B4', 'D8', 'J17', 'P18', 'B6', 'D9', 'J18', 'P19', 'B7', 'E13', 'J19', 'P20', 'B8', 'E16', 'J20', 'P21', 'A11', 'A12', 'C10', 'E17', 'J22', 'P22', 'C11', 'E19', 'K16', 'R19', 'C12', 'E20', 'K17', 'R20', 'A10', 'C13', 'E22', 'A13', 'K18', 'R21', 'C14', 'E9', 'A14', 'K19', 'R22', 'C15', 'F16', 'A15', 'K20', 'T19', 'A16', 'C16', 'F17', 'K21', 'T20', 'A17', 'C17', 'F18', 'K22', 'T21', 'A18', 'A20', 'C19', 'F19', 'L15', 'T22', 'A21', 'C20', 'F20', 'L16', 'U18', 'A3', 'C21', 'F21', 'L17', 'U19', 'A4', 'C22', 'F22', 'L19', 'U20', 'A5', 'C5', 'G10', 'L20', 'U22', 'A6', 'C6', 'G14', 'L21', 'V20', 'A7', 'C7', 'G16', 'L22', 'V21', 'A8', 'C8', 'G17', 'M16', 'V22', 'A9', 'C9', 'G19', 'M17', 'W20', 'B10', 'D10', 'G20', 'M18', 'W21', 'B11', 'B14', 'D11', 'G21', 'M19', 'W22', 'B12', 'D14', 'G22', 'M20']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB4', 'M3', 'T10', 'V11', 'Y11', 'AA10', 'AB5', 'G6', 'M4', 'V12', 'T11', 'Y12', 'AA11', 'AB6', 'G7', 'M5', 'T12', 'V13', 'Y13', 'AA12', 'AB7', 'H1', 'M6', 'T13', 'V15', 'Y14', 'AA14', 'AB8', 'H2', 'M7', 'T14', 'V16', 'Y15', 'AA15', 'AB9', 'H3', 'M8', 'T15', 'V17', 'Y16', 'AA16', 'B1', 'H4', 'N1', 'T16', 'V18', 'Y17', 'AA18', 'B2', 'H5', 'N3', 'T17', 'V19', 'Y18', 'AA19', 'B3', 'H6', 'N4', 'T18', 'V2', 'Y19', 'AA2', 'C1', 'H8', 'N5', 'T2', 'V3', 'Y2', 'AA20', 'C2', 'J1', 'N6', 'T3', 'V5', 'Y21', 'AA21', 'C3', 'J3', 'N7', 'T4', 'V7', 'Y3', 'AA22', 'C4', 'J4', 'P1', 'T5', 'V8', 'Y4', 'AA3', 'D1', 'J5', 'P2', 'T6', 'V9', 'Y5', 'AA4', 'D2', 'J6', 'P3', 'T7', 'W1', 'Y6', 'AA6', 'D3', 'J7', 'P4', 'T8', 'W10', 'Y7', 'AA7', 'D5', 'K1', 'P5', 'T9', 'W11', 'Y8', 'AA8', 'E1', 'K2', 'P6', 'U1', 'W12', 'Y9', 'AB10', 'E3', 'K3', 'P7', 'U10', 'W13', 'AB11', 'E4', 'K4', 'P8', 'U12', 'W14', 'AB12', 'E5', 'K5', 'R1', 'U13', 'W15', 'AB13', 'E6', 'K6', 'R11', 'U14', 'W17', 'AB14', 'F1', 'K7', 'R13', 'U15', 'W18', 'AB15', 'F2', 'K8', 'R15', 'U16', 'W2', 'AB16', 'F3', 'L1', 'R16', 'U17', 'W3', 'AB17', 'F4', 'L2', 'R2', 'U3', 'W4', 'AB18', 'F5', 'L3', 'R3', 'U4', 'W5', 'AB19', 'F6', 'L4', 'R4', 'U5', 'W6', 'AB2', 'F7', 'L6', 'R7', 'U6', 'W8', 'AB20', 'G1', 'L7', 'R8', 'U8', 'W9', 'AB21', 'G2', 'G4', 'M1', 'R9', 'U9', 'Y1', 'V1', 'AB3', 'G3', 'M2', 'T1', 'Y10', 'A2']},{'label': 'uC', 'num': 3, 'pin_nums': ['E18', 'AA1', 'N15', 'Y22', 'G15', 'A19', 'C18', 'Y20']},{'label': 'uD', 'num': 4, 'pin_nums': ['AA9', 'K10', 'N9', 'AB1', 'P10', 'K11', 'AB22', 'K12', 'P11', 'B13', 'P12', 'K13', 'B17', 'K14', 'P13', 'B5', 'K15', 'P14', 'B9', 'K9', 'P9', 'D16', 'R10', 'L10', 'D18', 'L11', 'R12', 'D4', 'L12', 'R14', 'E11', 'L13', 'R18', 'E15', 'L14', 'R5', 'E2', 'L18', 'R6', 'E21', 'L5', 'U11', 'E7', 'L8', 'U2', 'F11', 'L9', 'U21', 'G12', 'M10', 'U7', 'G18', 'M11', 'V10', 'G5', 'M12', 'V14', 'H15', 'M13', 'V4', 'H7', 'M14', 'V6', 'H9', 'M15', 'W16', 'J10', 'M9', 'W19', 'J11', 'N10', 'W7', 'J12', 'N11', 'J13', 'N12', 'J14', 'N13', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J21', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8']}] }),
        Part(**{ 'name':'XC6SLX45-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45-FGG676\n\nFPGA', 'pins':[
            Pin(num='A11',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L12N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE24',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='IO_L12P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B26',name='IO_L12N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C25',name='IO_L11P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C26',name='IO_L11N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D24',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D26',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E25',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='F24',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F26',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G25',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H24',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='H26',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J25',name='IO_L22P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO_L22N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K24',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='IO_L24P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L26',name='IO_L24N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M21',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M24',name='IO_L23P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M26',name='IO_L23N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO_L25P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO_L25N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='V22',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA13',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L11P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L51N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB15',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L11N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC11',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC12',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC19',name='IO_L7P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC20',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC9',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD11',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD17',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD18',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD19',name='IO_L7N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD21',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD22',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD9',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE11',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE17',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF10',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF12',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF17',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L79N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L79P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L68N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L68P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L67N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L67P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L77N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L77P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L66N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L66P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G1',name='IO_L65N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L65P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L64N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H3',name='IO_L64P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L63N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L63P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K1',name='IO_L62N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L62P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L61N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L61P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L52P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L8P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L52N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L8N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L51P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y14',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y18',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A24',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='AC22',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AD23',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='AF23',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='AF3',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E21',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='F20',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='AA16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='AA21',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='AA6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F21',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W20',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['U23', 'AC25', 'H14', 'C15', 'N22', 'U24', 'AC26', 'A12', 'H24', 'C17', 'N23', 'U25', 'A13', 'AD24', 'C18', 'H25', 'N24', 'U26', 'AD25', 'C19', 'H26', 'N25', 'V17', 'AD26', 'C20', 'J21', 'A14', 'N26', 'V18', 'AE23', 'C21', 'J25', 'A15', 'P20', 'V19', 'AE24', 'C22', 'J26', 'A16', 'P21', 'V20', 'AE25', 'K18', 'A17', 'C25', 'P22', 'V21', 'A18', 'AE26', 'C26', 'K19', 'P23', 'V22', 'A19', 'AF24', 'A2', 'C5', 'K23', 'P24', 'V23', 'A20', 'AF25', 'C6', 'K24', 'P26', 'V24', 'A11', 'A21', 'B11', 'C7', 'K26', 'R19', 'V26', 'A22', 'B12', 'C9', 'L17', 'AC24', 'R20', 'W18', 'A23', 'B14', 'D14', 'L18', 'R23', 'W19', 'A25', 'B15', 'D17', 'L19', 'R24', 'W22', 'B16', 'A3', 'D18', 'L23', 'R25', 'W23', 'A4', 'B18', 'D21', 'L24', 'R26', 'W24', 'A5', 'B19', 'D24', 'L25', 'T18', 'W25', 'A6', 'B20', 'D25', 'L26', 'T19', 'W26', 'A7', 'B22', 'D26', 'M18', 'T20', 'Y20', 'A8', 'B23', 'D6', 'M19', 'N21', 'T22', 'Y21', 'A9', 'B24', 'D9', 'M20', 'T23', 'Y22', 'AA22', 'B25', 'E13', 'M21', 'T24', 'Y24', 'AA23', 'B26', 'E25', 'M23', 'T25', 'Y25', 'AA24', 'B3', 'E26', 'M24', 'T26', 'Y26', 'AA25', 'B4', 'F23', 'M25', 'U17', 'AA26', 'B6', 'F24', 'M26', 'U18', 'AB23', 'B7', 'F26', 'N17', 'U19', 'AB24', 'B8', 'G10', 'N18', 'U20', 'AB26', 'C11', 'G18', 'N19', 'U21', 'AC23', 'C13', 'G25', 'N20', 'U22', 'C14', 'G26']},{'label': 'uB', 'num': 2, 'pin_nums': ['P9', 'AA17', 'AC2', 'AF6', 'AE11', 'L2', 'R1', 'V3', 'AC20', 'AA18', 'AF7', 'AE12', 'L3', 'R2', 'AF5', 'V4', 'AA19', 'AC21', 'AE13', 'AF8', 'L4', 'R3', 'V5', 'AA2', 'AC3', 'AE15', 'AF9', 'L6', 'R4', 'W1', 'AA3', 'AC4', 'AE16', 'B1', 'L7', 'R5', 'W11', 'AA4', 'AC5', 'AE17', 'B2', 'M1', 'R6', 'W12', 'AA5', 'AC6', 'AE19', 'C1', 'M10', 'R7', 'W14', 'AA7', 'AC7', 'AE2', 'C2', 'M2', 'R9', 'W16', 'AB1', 'AC9', 'AE20', 'C3', 'M3', 'T1', 'W17', 'AB10', 'AD1', 'AE21', 'C4', 'M4', 'T2', 'W2', 'AB11', 'AD10', 'AE3', 'D1', 'M6', 'T3', 'W3', 'AB13', 'AD11', 'AE4', 'D2', 'M7', 'T4', 'W4', 'AB14', 'AD12', 'AE5', 'D3', 'M8', 'T6', 'W5', 'AB15', 'AD13', 'AE7', 'E1', 'M9', 'T7', 'W6', 'AB17', 'AD14', 'AE8', 'E2', 'N1', 'T8', 'W7', 'AB18', 'AD15', 'AE9', 'E3', 'N2', 'U1', 'W8', 'AB3', 'AD16', 'AF10', 'E4', 'N3', 'U12', 'Y1', 'AB4', 'AD17', 'AF11', 'F1', 'N4', 'U13', 'Y10', 'AB5', 'AD18', 'AF12', 'F3', 'N5', 'U15', 'Y12', 'AB6', 'AD19', 'AF13', 'F4', 'N6', 'U2', 'Y14', 'AB7', 'AD2', 'AF14', 'G1', 'N7', 'U3', 'Y15', 'AC1', 'AD20', 'AF15', 'G2', 'N8', 'U4', 'Y16', 'AC10', 'AD21', 'AF16', 'H1', 'N9', 'U5', 'Y17', 'AC11', 'AD22', 'AF17', 'H2', 'P1', 'U7', 'Y18', 'AC12', 'AD3', 'AF18', 'H3', 'P10', 'U8', 'Y2', 'AC13', 'AD4', 'AF19', 'J1', 'P3', 'V1', 'AA1', 'Y3', 'AC14', 'AD5', 'AF2', 'J2', 'P4', 'V11', 'AA11', 'Y5', 'AC15', 'AD6', 'AF20', 'J6', 'P5', 'V12', 'AA12', 'Y6', 'AC16', 'AD7', 'AF21', 'K1', 'AC19', 'P6', 'V13', 'AA13', 'AC17', 'AD8', 'AF22', 'K3', 'P7', 'V14', 'AA14', 'V16', 'AC18', 'AD9', 'AF4', 'K4', 'P8', 'V15', 'AA15', 'AE1', 'L1']},{'label': 'uC', 'num': 3, 'pin_nums': ['A24', 'AF3', 'E21', 'AF23', 'AC22', 'C23', 'F20', 'AD23']},{'label': 'uD', 'num': 4, 'pin_nums': ['M11', 'M12', 'E22', 'T12', 'E7', 'M13', 'T13', 'F19', 'M14', 'T14', 'F2', 'M15', 'T15', 'F21', 'M16', 'T16', 'A1', 'F25', 'M17', 'T17', 'A26', 'F6', 'M22', 'T21', 'AA10', 'G12', 'M5', 'T5', 'AA16', 'G15', 'N10', 'U10', 'AA21', 'H11', 'N11', 'U11', 'AA6', 'H23', 'N12', 'U14', 'AB12', 'H4', 'N13', 'U16', 'AB16', 'J18', 'N14', 'U6', 'AB2', 'J19', 'N15', 'V2', 'AB20', 'J8', 'N16', 'V25', 'AB25', 'J9', 'P11', 'V9', 'AC8', 'K11', 'P12', 'W15', 'AE10', 'K13', 'P13', 'W20', 'AE14', 'K16', 'P14', 'Y11', 'AE18', 'K17', 'P15', 'Y19', 'AE22', 'K2', 'P16', 'Y23', 'AE6', 'K25', 'P19', 'Y4', 'AF1', 'L10', 'P2', 'Y7', 'AF26', 'L11', 'P25', 'B13', 'L12', 'R11', 'B17', 'L13', 'R12', 'B21', 'L14', 'R13', 'B5', 'L15', 'R14', 'B9', 'L16', 'R15', 'D4', 'L22', 'R16', 'T11', 'E11', 'L5', 'R8', 'E15']}] }),
        Part(**{ 'name':'XC6SLX45T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A15',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E3',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G6',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M5',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R10',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R13',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F10',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A13',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A5',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B11',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C8',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D6',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A17',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='B18',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='D16',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='P13',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='R16',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='V17',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='V2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D14',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D4',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P5',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A16', 'L18', 'G14', 'A3', 'M13', 'G15', 'M14', 'G16', 'M15', 'G18', 'M16', 'A2', 'G8', 'M18', 'B15', 'G9', 'N14', 'B16', 'B2', 'H12', 'N15', 'B3', 'H13', 'N16', 'C15', 'C17', 'H14', 'N17', 'C18', 'H15', 'N18', 'C3', 'H16', 'P15', 'D15', 'H17', 'P16', 'D17', 'H18', 'P17', 'D18', 'J13', 'P18', 'E12', 'J14', 'R17', 'E14', 'J16', 'T17', 'E16', 'J17', 'T18', 'E17', 'J18', 'U17', 'E18', 'K12', 'U18', 'E6', 'K13', 'E8', 'K14', 'F12', 'K15', 'F14', 'K16', 'F15', 'K17', 'F16', 'K18', 'F17', 'L12', 'F18', 'L13', 'F7', 'L14', 'F8', 'A15', 'L15', 'G11', 'G13', 'L16', 'G12', 'L17']},{'label': 'uB', 'num': 2, 'pin_nums': ['U2', 'L7', 'F4', 'U3', 'R12', 'M1', 'F5', 'R13', 'U4', 'L6', 'F6', 'M10', 'R15', 'U5', 'M11', 'G1', 'R2', 'U7', 'G3', 'M3', 'R3', 'U8', 'G4', 'M4', 'R5', 'U9', 'G6', 'M5', 'R6', 'V10', 'H1', 'M8', 'R7', 'V11', 'H2', 'N1', 'R8', 'V12', 'H3', 'N10', 'T1', 'V13', 'H4', 'N11', 'T10', 'V14', 'H5', 'N12', 'T11', 'V15', 'H6', 'N2', 'T12', 'V16', 'H7', 'N3', 'T13', 'V3', 'J1', 'N4', 'T14', 'V4', 'J2', 'N5', 'T15', 'V5', 'J3', 'N6', 'T2', 'V6', 'J5', 'N7', 'T3', 'V7', 'J6', 'N8', 'T4', 'V8', 'J7', 'N9', 'T5', 'V9', 'C1', 'K1', 'P1', 'T6', 'C2', 'K2', 'P11', 'T7', 'D1', 'K3', 'P12', 'T8', 'D2', 'K4', 'P2', 'T9', 'D3', 'K5', 'P3', 'U1', 'E1', 'K6', 'P4', 'U10', 'E2', 'L1', 'P6', 'U11', 'E3', 'L2', 'P7', 'U13', 'E4', 'L3', 'P8', 'U14', 'F1', 'L4', 'P9', 'U15', 'F2', 'L5', 'R10', 'U16', 'F3', 'R11']},{'label': 'uC', 'num': 3, 'pin_nums': ['A4', 'B8', 'D5', 'A6', 'D7', 'C11', 'A8', 'C13', 'D9', 'B10', 'E10', 'C5', 'B12', 'C7', 'F10', 'A10', 'B14', 'C9', 'A12', 'B4', 'D11', 'A14', 'B6', 'D13']},{'label': 'uD', 'num': 4, 'pin_nums': ['A5', 'B7', 'D10', 'D6', 'E5', 'E9', 'A13', 'B11', 'C8', 'D12', 'E11', 'E7']},{'label': 'uE', 'num': 5, 'pin_nums': ['P13', 'V17', 'D16', 'A17', 'F13', 'B18', 'R16', 'V2']},{'label': 'uF', 'num': 6, 'pin_nums': ['F9', 'C4', 'B13', 'H8', 'J9', 'L8', 'N13', 'R9', 'C6', 'B17', 'G10', 'T16', 'K10', 'H9', 'P10', 'L9', 'B5', 'D14', 'A1', 'G17', 'J10', 'K11', 'M12', 'P14', 'U12', 'J8', 'A11', 'B9', 'D4', 'G2', 'J11', 'K7', 'M17', 'M9', 'P5', 'R4', 'U6', 'D8', 'A18', 'C10', 'G5', 'J12', 'K8', 'M2', 'R1', 'V1', 'B1', 'C12', 'A7', 'E13', 'F11', 'G7', 'H11', 'J15', 'K9', 'M6', 'R14', 'V18', 'A9', 'C14', 'E15', 'H10', 'J4', 'L10', 'M7', 'R18', 'C16', 'L11']}] }),
        Part(**{ 'name':'XC6SLX45T-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45T-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45T-CSG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L69N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L69P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L71N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L71P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L72N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L72P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L70N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L70P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F14',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='C19',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='F17',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='H16',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F18',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['F16', 'N16', 'U20', 'A17', 'B19', 'F19', 'H22', 'N18', 'U22', 'B20', 'F20', 'H8', 'N19', 'V17', 'B21', 'F21', 'J16', 'N20', 'V18', 'B22', 'F22', 'J17', 'N22', 'V19', 'B3', 'F6', 'J18', 'P15', 'V20', 'B4', 'F7', 'J19', 'P16', 'V21', 'C17', 'F8', 'J20', 'P17', 'V22', 'C18', 'F9', 'J22', 'P18', 'W20', 'C20', 'G10', 'K16', 'P19', 'W21', 'C21', 'G11', 'K17', 'P20', 'W22', 'C22', 'G12', 'K18', 'P21', 'Y19', 'C5', 'G13', 'K19', 'P22', 'Y20', 'D17', 'G15', 'K20', 'R12', 'Y21', 'D18', 'G16', 'K21', 'R13', 'A19', 'Y22', 'D19', 'G17', 'K22', 'R15', 'D20', 'G19', 'L15', 'R16', 'D21', 'G20', 'L16', 'R17', 'D22', 'G21', 'L17', 'R19', 'A18', 'D5', 'G22', 'L19', 'R20', 'E10', 'G7', 'A20', 'L20', 'R21', 'E16', 'G8', 'L21', 'R22', 'E17', 'G9', 'L22', 'T12', 'E19', 'H10', 'M16', 'T13', 'A21', 'E20', 'H11', 'M17', 'T15', 'A4', 'E22', 'H12', 'M18', 'T17', 'A5', 'E5', 'H13', 'AA19', 'M19', 'T18', 'AA20', 'E6', 'H14', 'M20', 'T19', 'AA21', 'E8', 'H17', 'AA22', 'M21', 'T20', 'AB19', 'F10', 'H18', 'M22', 'T21', 'AB20', 'F11', 'H19', 'H21', 'N14', 'T22', 'AB21', 'F12', 'H20', 'N15', 'U18', 'B18']},{'label': 'uB', 'num': 2, 'pin_nums': ['L7', 'V9', 'Y7', 'AB12', 'F5', 'M1', 'T11', 'W1', 'Y8', 'AB13', 'G1', 'M2', 'T14', 'W10', 'Y9', 'AB14', 'G2', 'M3', 'F4', 'T2', 'W11', 'AB15', 'G3', 'M4', 'T3', 'W12', 'AB16', 'G4', 'M5', 'T4', 'W13', 'AB17', 'G6', 'M6', 'T5', 'W14', 'AB18', 'H1', 'M7', 'T6', 'W15', 'AB2', 'H2', 'M8', 'T7', 'W16', 'AB3', 'H3', 'N1', 'T8', 'W17', 'AB4', 'H4', 'N3', 'T9', 'W2', 'AB5', 'H5', 'N4', 'U1', 'W3', 'AB6', 'H6', 'N5', 'U10', 'W4', 'AB7', 'J1', 'N6', 'U13', 'W5', 'AB8', 'J3', 'N7', 'U14', 'W6', 'AB9', 'J4', 'P1', 'U15', 'W8', 'A2', 'B1', 'J5', 'P2', 'U3', 'W9', 'A3', 'B2', 'J6', 'P3', 'U4', 'Y1', 'AA10', 'C1', 'J7', 'P4', 'U5', 'Y10', 'AA11', 'C2', 'K1', 'P5', 'U6', 'Y11', 'AA12', 'C3', 'K2', 'P6', 'U8', 'Y12', 'AA14', 'C4', 'K3', 'P7', 'U9', 'Y13', 'AA15', 'D1', 'K4', 'P8', 'V1', 'Y14', 'AA16', 'D2', 'K5', 'R1', 'V11', 'Y15', 'AA18', 'D3', 'K6', 'R2', 'V12', 'Y16', 'AA2', 'D4', 'K7', 'R3', 'V13', 'Y17', 'AA3', 'E1', 'K8', 'R4', 'V15', 'Y18', 'AA4', 'E3', 'L1', 'R6', 'V2', 'Y2', 'AA6', 'E4', 'L2', 'R7', 'V3', 'Y3', 'AA7', 'F1', 'L3', 'R8', 'V5', 'Y4', 'AA8', 'F2', 'L4', 'R9', 'T10', 'V7', 'Y5', 'AB10', 'F3', 'L6', 'T1', 'V8', 'Y6', 'AB11']},{'label': 'uC', 'num': 3, 'pin_nums': ['C13', 'A8', 'D9', 'C11', 'C15', 'D7', 'B10', 'E14', 'C7', 'B12', 'F14', 'A10', 'C9', 'B14', 'A12', 'B16', 'D11', 'B6', 'A14', 'D13', 'A16', 'B8', 'D15', 'A6']},{'label': 'uD', 'num': 4, 'pin_nums': ['E11', 'A15', 'B13', 'C10', 'D14', 'E15', 'B9', 'A7', 'D12', 'D8', 'E13', 'E9']},{'label': 'uE', 'num': 5, 'pin_nums': ['AA1', 'E18', 'H16', 'U16', 'C19', 'U12', 'W18', 'F17']},{'label': 'uF', 'num': 6, 'pin_nums': ['K10', 'K11', 'C12', 'P11', 'C14', 'K12', 'P12', 'C16', 'K13', 'P13', 'C6', 'K14', 'P14', 'C8', 'K15', 'P9', 'D10', 'K9', 'R10', 'D16', 'L10', 'R11', 'D6', 'L11', 'R18', 'E12', 'L12', 'R5', 'E2', 'L13', 'U11', 'E21', 'L14', 'U17', 'E7', 'L18', 'U2', 'F13', 'L5', 'U21', 'F15', 'L8', 'U7', 'F18', 'L9', 'V10', 'G14', 'M10', 'V14', 'A1', 'G18', 'M11', 'V16', 'A11', 'G5', 'M12', 'V4', 'A13', 'H15', 'M13', 'V6', 'A22', 'H7', 'M14', 'W19', 'A9', 'H9', 'M15', 'W7', 'AA13', 'J10', 'M9', 'AA17', 'J11', 'N10', 'AA5', 'J12', 'N11', 'AA9', 'J13', 'N12', 'AB1', 'J14', 'N13', 'AB22', 'J15', 'N17', 'B11', 'J2', 'N2', 'B15', 'J21', 'N21', 'B17', 'J8', 'N8', 'P10', 'B5', 'J9', 'N9', 'B7']}] }),
        Part(**{ 'name':'XC6SLX45T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX45T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX45T-FGG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L22N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E12',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F12',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='A21',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='AA22',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='AB2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB21',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='D20',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='G17',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='V18',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A19', 'D4', 'G22', 'L20', 'T19', 'G21', 'G8', 'D5', 'T20', 'L21', 'A18', 'E16', 'G9', 'L22', 'T21', 'H10', 'E17', 'T22', 'M16', 'E19', 'H11', 'M17', 'U18', 'E20', 'H12', 'A2', 'M18', 'U19', 'E22', 'H13', 'M19', 'U20', 'A20', 'E5', 'H14', 'U22', 'M20', 'A3', 'E6', 'H16', 'M21', 'V19', 'A4', 'F10', 'H17', 'A5', 'M22', 'V20', 'B18', 'F14', 'H18', 'N15', 'V21', 'B19', 'F15', 'H19', 'B2', 'N16', 'V22', 'B20', 'F16', 'H20', 'N18', 'W20', 'B21', 'F17', 'H21', 'N19', 'W21', 'B22', 'F18', 'H22', 'A17', 'N20', 'W22', 'B3', 'F19', 'J16', 'N22', 'Y21', 'B4', 'F20', 'J17', 'P16', 'Y22', 'C17', 'F21', 'J18', 'P17', 'C18', 'F22', 'J19', 'P18', 'C19', 'F6', 'J20', 'P19', 'C20', 'F7', 'J22', 'P20', 'C21', 'F8', 'K16', 'P21', 'C22', 'F9', 'K17', 'P22', 'C3', 'G10', 'K18', 'R15', 'C4', 'G11', 'K19', 'R16', 'C5', 'G13', 'K20', 'R17', 'D17', 'G14', 'K21', 'R19', 'D18', 'G15', 'K22', 'R20', 'D19', 'G16', 'L15', 'R21', 'D21', 'G19', 'L16', 'R22', 'D22', 'G20', 'L17', 'T17', 'D3', 'L19', 'T18']},{'label': 'uB', 'num': 2, 'pin_nums': ['F4', 'L4', 'R8', 'V12', 'Y14', 'AA7', 'F5', 'R9', 'L6', 'Y15', 'V13', 'AA8', 'G1', 'L7', 'T1', 'V15', 'Y16', 'AB10', 'G2', 'M1', 'T10', 'V16', 'Y17', 'AB11', 'G3', 'M2', 'T11', 'V17', 'Y18', 'AB12', 'G4', 'M3', 'T12', 'V2', 'Y19', 'AB13', 'G6', 'M4', 'T13', 'V3', 'Y2', 'AB14', 'G7', 'T14', 'M5', 'Y20', 'V5', 'AB15', 'H1', 'M6', 'T15', 'V7', 'Y3', 'AB16', 'H2', 'M7', 'T2', 'V8', 'Y4', 'AB17', 'H3', 'M8', 'T3', 'V9', 'Y5', 'AB18', 'H4', 'N1', 'T4', 'W1', 'Y6', 'AB19', 'H5', 'N3', 'T5', 'W10', 'Y7', 'AB20', 'H6', 'N4', 'T6', 'W11', 'Y8', 'AB3', 'H8', 'N5', 'T7', 'W12', 'Y9', 'AB4', 'J1', 'N6', 'T8', 'W13', 'AB5', 'J3', 'N7', 'T9', 'W14', 'R7', 'AB6', 'J4', 'P1', 'U1', 'W15', 'AA1', 'AB7', 'J5', 'P2', 'U10', 'W17', 'AA10', 'AB8', 'J6', 'P3', 'U12', 'W18', 'AA11', 'AB9', 'J7', 'P4', 'U13', 'W2', 'AA12', 'B1', 'K1', 'P5', 'U14', 'W3', 'AA14', 'C1', 'K2', 'P6', 'U15', 'W4', 'AA15', 'C2', 'K3', 'P7', 'U16', 'W5', 'AA16', 'D1', 'K4', 'P8', 'U3', 'W6', 'AA18', 'D2', 'K5', 'R1', 'U4', 'W8', 'AA19', 'E1', 'K6', 'R11', 'U5', 'W9', 'AA2', 'E3', 'K7', 'R13', 'U6', 'Y1', 'AA20', 'E4', 'K8', 'R2', 'U8', 'Y10', 'AA21', 'F1', 'L1', 'R3', 'U9', 'Y11', 'AA3', 'AA6', 'F2', 'L2', 'R4', 'V1', 'Y12', 'AA4', 'F3', 'L3', 'V11', 'Y13']},{'label': 'uC', 'num': 3, 'pin_nums': ['A10', 'B14', 'B16', 'A12', 'D11', 'A14', 'B6', 'D13', 'A16', 'B8', 'D15', 'A6', 'C11', 'D7', 'A8', 'C13', 'D9', 'B10', 'C15', 'C9', 'E12', 'B12', 'C7', 'F12']},{'label': 'uD', 'num': 4, 'pin_nums': ['A7', 'D12', 'D8', 'E13', 'E9', 'A15', 'B13', 'C10', 'D14', 'E10', 'E8', 'B9']},{'label': 'uE', 'num': 5, 'pin_nums': ['AB21', 'E18', 'AA22', 'V18', 'A21', 'AB2', 'D20', 'G17']},{'label': 'uF', 'num': 6, 'pin_nums': ['A22', 'H15', 'M13', 'V4', 'A9', 'M14', 'H7', 'V6', 'AA13', 'H9', 'M15', 'W16', 'AA17', 'M9', 'J10', 'W19', 'AA5', 'J11', 'N10', 'W7', 'AA9', 'J12', 'N11', 'AB1', 'J13', 'N12', 'AB22', 'N13', 'J14', 'B11', 'J15', 'N14', 'B15', 'J2', 'N17', 'B17', 'J21', 'N2', 'B5', 'J8', 'N21', 'B7', 'J9', 'N8', 'C12', 'K10', 'N9', 'C14', 'K11', 'P10', 'C16', 'K12', 'P11', 'C6', 'K13', 'P12', 'C8', 'K14', 'P13', 'D10', 'K15', 'P14', 'D16', 'K9', 'P9', 'D6', 'L10', 'R10', 'E11', 'L11', 'R12', 'E14', 'L12', 'R14', 'E15', 'L13', 'R18', 'E2', 'L14', 'R5', 'E21', 'L18', 'R6', 'E7', 'L5', 'U11', 'F11', 'L8', 'U2', 'F13', 'L9', 'U21', 'M12', 'A1', 'G12', 'M10', 'U7', 'A11', 'G18', 'M11', 'V10', 'A13', 'G5', 'V14']}] }),
        Part(**{ 'name':'XC6SLX75-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX75-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX75-CSG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L14N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L14P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L12P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L12N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L11P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L11N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L13P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L13N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J21',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F8',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G8',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='D14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='T15',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J20',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='RFUSE',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U17',name='VBATT',func=pin_types.PWRIN,unit=4),
            Pin(num='U19',name='VFS',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E22', 'M20', 'U22', 'A8', 'C17', 'E8', 'H16', 'M21', 'V17', 'A9', 'C18', 'E9', 'H17', 'M22', 'V18', 'AA19', 'C19', 'F10', 'H18', 'N15', 'V19', 'AA20', 'C20', 'F12', 'H19', 'N16', 'V20', 'AA21', 'C21', 'F13', 'H20', 'N18', 'V21', 'AA22', 'C22', 'F14', 'H21', 'N19', 'V22', 'AB19', 'C5', 'F15', 'C16', 'H22', 'N20', 'W20', 'AB20', 'C6', 'F16', 'J16', 'N22', 'W21', 'AB21', 'C7', 'F17', 'J17', 'P15', 'W22', 'B10', 'C8', 'F18', 'J18', 'P16', 'Y19', 'B11', 'C9', 'F19', 'J19', 'P17', 'Y20', 'B12', 'D10', 'F20', 'J21', 'P18', 'Y21', 'B14', 'D11', 'F21', 'J22', 'P19', 'Y22', 'B15', 'D12', 'F22', 'K16', 'P20', 'B16', 'D13', 'F9', 'K17', 'P21', 'A12', 'B18', 'D15', 'G10', 'K18', 'P22', 'B19', 'D17', 'G11', 'K19', 'R15', 'A11', 'B20', 'D19', 'G13', 'K20', 'R16', 'B21', 'D20', 'G14', 'K21', 'R17', 'B22', 'D21', 'G15', 'K22', 'R19', 'B3', 'D22', 'G16', 'A13', 'L15', 'R20', 'B4', 'D6', 'G17', 'L16', 'R21', 'A14', 'B6', 'D7', 'G19', 'L17', 'R22', 'A15', 'B7', 'D8', 'G20', 'L19', 'T17', 'A16', 'B8', 'D9', 'G21', 'A17', 'L20', 'T18', 'C10', 'A18', 'E10', 'G22', 'L21', 'T19', 'A19', 'C11', 'E12', 'G9', 'A10', 'A20', 'L22', 'T20', 'C12', 'A21', 'E13', 'H10', 'M16', 'T21', 'A4', 'C13', 'E17', 'H11', 'M17', 'T22', 'A5', 'C14', 'E19', 'H12', 'H14', 'M18', 'U18', 'A6', 'C15', 'E20', 'H13', 'M19', 'U20', 'A7']},{'label': 'uB', 'num': 2, 'pin_nums': ['K7', 'V16', 'Y6', 'AB13', 'F4', 'K8', 'R3', 'V2', 'Y7', 'AB14', 'F5', 'L1', 'R4', 'V3', 'Y8', 'AB15', 'F6', 'L2', 'R7', 'V5', 'Y9', 'AB16', 'F7', 'L3', 'R8', 'V8', 'AB17', 'F8', 'L4', 'R9', 'W1', 'AB18', 'G1', 'L6', 'T1', 'W11', 'AB2', 'G2', 'L7', 'T12', 'W12', 'AB3', 'G3', 'M1', 'T13', 'W13', 'AB4', 'G4', 'M2', 'T14', 'W14', 'AB5', 'G6', 'M3', 'T2', 'W15', 'AB6', 'G7', 'M4', 'T3', 'W17', 'AB7', 'G8', 'M5', 'T4', 'W2', 'AB8', 'H1', 'M6', 'T5', 'W3', 'AB9', 'H2', 'M7', 'T6', 'W4', 'A2', 'B1', 'H3', 'M8', 'T7', 'W5', 'A3', 'B2', 'H4', 'N1', 'T8', 'W6', 'AA10', 'C1', 'H5', 'N3', 'T9', 'W9', 'AA11', 'C2', 'H6', 'N4', 'U1', 'Y1', 'AA12', 'C3', 'H8', 'N5', 'U12', 'Y10', 'AA14', 'C4', 'J1', 'N6', 'U13', 'Y11', 'AA15', 'D1', 'J3', 'N7', 'U14', 'Y12', 'AA16', 'D2', 'J4', 'P1', 'U15', 'Y13', 'AA18', 'D3', 'J5', 'P2', 'F3', 'U3', 'Y14', 'AA2', 'D5', 'J6', 'P3', 'U4', 'Y15', 'AA3', 'E1', 'J7', 'P4', 'U5', 'Y16', 'AA4', 'E3', 'K1', 'P5', 'U6', 'Y17', 'AA6', 'E4', 'K2', 'P6', 'U8', 'Y18', 'AA7', 'E5', 'K3', 'P7', 'V1', 'Y2', 'AA8', 'E6', 'K4', 'P8', 'V12', 'Y3', 'AB10', 'F1', 'K5', 'R1', 'R2', 'V13', 'Y4', 'AB11', 'F2', 'K6', 'R13', 'V15', 'Y5', 'AB12']},{'label': 'uC', 'num': 3, 'pin_nums': ['D14', 'E16', 'T15', 'W18', 'AA1', 'E18', 'E14', 'U16']},{'label': 'uD', 'num': 4, 'pin_nums': ['E7', 'U11', 'F11', 'U17', 'L9', 'G12', 'M10', 'U19', 'G18', 'M11', 'U2', 'G5', 'M12', 'U21', 'H15', 'M13', 'U7', 'H7', 'M14', 'V10', 'H9', 'M15', 'V14', 'J10', 'M9', 'V4', 'J11', 'N10', 'V6', 'J12', 'N11', 'W16', 'J13', 'N12', 'W19', 'J14', 'N13', 'W7', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J20', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12', 'B17', 'K14', 'P13', 'B5', 'K15', 'P14', 'B9', 'K9', 'P9', 'D16', 'L10', 'R10', 'D18', 'L11', 'R12', 'D4', 'L12', 'R14', 'E11', 'L13', 'R18', 'E15', 'L14', 'R5', 'E2', 'L18', 'L8', 'R6', 'E21', 'L5', 'T16']}] }),
        Part(**{ 'name':'XC6SLX75-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX75-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX75-FGG484\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L45N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L47P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='IO_L45P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L47N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L46N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L46P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T17',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='N15',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='Y20',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='Y22',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P15',name='RFUSE',func=pin_types.PWRIN,unit=4),
            Pin(num='P16',name='VFS',func=pin_types.PWRIN,unit=4),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='R17',name='VBATT',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C21', 'F14', 'J22', 'P22', 'A4', 'C22', 'K16', 'F15', 'R19', 'A5', 'C5', 'F16', 'K17', 'R20', 'A6', 'C6', 'K18', 'F17', 'R21', 'A7', 'C7', 'F18', 'K19', 'R22', 'A8', 'C8', 'F19', 'K20', 'T19', 'A9', 'C9', 'F20', 'K21', 'T20', 'B10', 'D10', 'K22', 'F21', 'T21', 'B11', 'D11', 'F22', 'L15', 'T22', 'B12', 'D12', 'G10', 'L16', 'U18', 'B14', 'D13', 'G13', 'L17', 'U19', 'A10', 'B15', 'D14', 'G14', 'L19', 'U20', 'B16', 'D15', 'G16', 'L20', 'U22', 'B18', 'D17', 'G17', 'L21', 'V20', 'B19', 'D19', 'G19', 'L22', 'V21', 'B20', 'D20', 'G20', 'M16', 'V22', 'B21', 'D21', 'G21', 'M17', 'W20', 'B22', 'D22', 'G22', 'M18', 'W21', 'B4', 'D6', 'H13', 'M19', 'W22', 'B6', 'D7', 'A12', 'H14', 'M20', 'B7', 'D8', 'H16', 'M21', 'J20', 'B8', 'D9', 'H17', 'M22', 'C10', 'E12', 'H18', 'N16', 'C11', 'E13', 'H19', 'N18', 'C12', 'E14', 'A11', 'H20', 'N19', 'C13', 'E16', 'H21', 'N20', 'A13', 'C14', 'E17', 'A14', 'H22', 'N22', 'C15', 'E19', 'A15', 'J16', 'P17', 'A16', 'C16', 'E20', 'J17', 'P18', 'A17', 'C17', 'E22', 'J18', 'P19', 'A18', 'A20', 'C19', 'E9', 'J19', 'P20', 'A3', 'A21', 'C20', 'F13', 'P21']},{'label': 'uB', 'num': 2, 'pin_nums': ['AA22', 'J5', 'V16', 'P2', 'AA3', 'D2', 'J6', 'V2', 'P3', 'AA4', 'D3', 'J7', 'P4', 'V3', 'AA6', 'D5', 'K1', 'V8', 'P5', 'AA7', 'E1', 'K2', 'P6', 'W1', 'AA8', 'E3', 'K3', 'P7', 'W11', 'AB10', 'E4', 'K4', 'P8', 'W12', 'AB11', 'E5', 'K5', 'W2', 'R1', 'AB12', 'E6', 'K6', 'R2', 'W3', 'AB13', 'F1', 'K7', 'R3', 'W4', 'AB14', 'F2', 'K8', 'R4', 'W5', 'AB15', 'F3', 'L1', 'T1', 'Y1', 'AB16', 'F4', 'L2', 'T13', 'Y11', 'AB17', 'F5', 'L3', 'T17', 'Y12', 'AB18', 'F6', 'L4', 'T18', 'Y13', 'AB19', 'F7', 'L6', 'T2', 'Y15', 'AB2', 'G1', 'L7', 'T3', 'Y17', 'AB20', 'G2', 'M1', 'T4', 'Y19', 'AB21', 'G3', 'M2', 'T5', 'Y2', 'AB3', 'G4', 'M3', 'T6', 'Y21', 'A2', 'AB4', 'G6', 'M4', 'T9', 'Y3', 'AA10', 'AB6', 'G7', 'M5', 'U1', 'Y4', 'AA11', 'AB7', 'H1', 'M6', 'U13', 'Y7', 'AA12', 'AB8', 'H2', 'M7', 'U14', 'Y9', 'AA14', 'AB9', 'H3', 'M8', 'U15', 'AA15', 'B1', 'H4', 'N1', 'U3', 'AA16', 'B2', 'H5', 'N3', 'U4', 'AA18', 'B3', 'H6', 'N4', 'U5', 'AA19', 'C1', 'H8', 'N5', 'V1', 'AA2', 'C2', 'J1', 'N6', 'V11', 'AA20', 'C3', 'D1', 'J3', 'N7', 'V12', 'AA21', 'C4', 'J4', 'P1', 'V15']},{'label': 'uC', 'num': 3, 'pin_nums': ['AA1', 'E18', 'N15', 'Y22', 'A19', 'C18', 'G15', 'Y20']},{'label': 'uD', 'num': 4, 'pin_nums': ['J14', 'N13', 'W7', 'A1', 'J15', 'N14', 'A22', 'J2', 'N17', 'AA13', 'J21', 'N2', 'AA17', 'J8', 'N21', 'AA5', 'J9', 'N8', 'AA9', 'K10', 'N9', 'AB1', 'K11', 'P10', 'AB22', 'K12', 'P11', 'B13', 'K13', 'P12', 'B17', 'K14', 'P13', 'B5', 'K15', 'P14', 'B9', 'K9', 'P15', 'D16', 'L10', 'P16', 'D18', 'L11', 'P9', 'D4', 'L12', 'R10', 'E11', 'L13', 'R12', 'E15', 'L14', 'R14', 'E2', 'L18', 'R17', 'E21', 'L5', 'R18', 'E7', 'L8', 'R5', 'F11', 'L9', 'R6', 'G12', 'M10', 'U11', 'G18', 'M11', 'U2', 'G5', 'M12', 'U21', 'H15', 'M13', 'U7', 'H7', 'M14', 'V10', 'H9', 'M15', 'V14', 'J10', 'M9', 'V4', 'J11', 'N10', 'V6', 'J12', 'N11', 'W16', 'J13', 'N12', 'W19']}] }),
        Part(**{ 'name':'XC6SLX75-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX75-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX75-FGG676\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L12N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE24',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L52N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L52P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M21',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L56P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L56N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L57N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L57P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L55N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L55P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='V22',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA13',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='IO_L16P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='IO_L4P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB15',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L16N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L4N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC12',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC15',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC21',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AC3',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L3P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AC7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD10',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD12',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD15',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD16',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD18',name='IO_L9P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD22',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L3N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD7',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD8',name='IO_L53P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE11',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE17',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE19',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE7',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF10',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF11',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF12',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF16',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF17',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF18',name='IO_L9N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF19',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF2',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AF20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF21',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF8',name='IO_L53N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L27P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L30P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L30N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L29N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L29P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L27N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L28N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L28P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L19N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L15N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L15P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L19P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y15',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A23',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B23',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='D22',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D23',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D26',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E23',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F22',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='F24',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='F5',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G19',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G20',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G21',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G22',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G23',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G6',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G7',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H18',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H19',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H20',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H21',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H22',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H26',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J10',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J20',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J21',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J22',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='J7',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K21',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K22',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K24',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='K5',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K9',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L20',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L21',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L8',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M24',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M26',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N26',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='TDO',func=pin_types.BIDIR,unit=4),
            Pin(num='AC22',name='CMPCS_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AD23',name='SUSPEND',func=pin_types.BIDIR,unit=4),
            Pin(num='AF23',name='DONE_2',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=4),
            Pin(num='C23',name='TMS',func=pin_types.BIDIR,unit=4),
            Pin(num='E21',name='TCK',func=pin_types.BIDIR,unit=4),
            Pin(num='F20',name='TDI',func=pin_types.BIDIR,unit=4),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AA10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA16',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA20',name='RFUSE',func=pin_types.PWRIN,unit=5),
            Pin(num='AA21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AA6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB19',name='VFS',func=pin_types.PWRIN,unit=5),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AC8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F21',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='G15',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='W15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='W20',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='W21',name='VBATT',func=pin_types.PWRIN,unit=5),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y19',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AA24', 'B4', 'R17', 'G8', 'V21', 'B6', 'AA25', 'R18', 'H14', 'V22', 'AA26', 'B7', 'H15', 'R19', 'V23', 'B8', 'AB21', 'R20', 'J15', 'V24', 'AB22', 'C11', 'K18', 'R21', 'V26', 'AB23', 'C13', 'K19', 'R22', 'W18', 'AB24', 'C14', 'L17', 'R23', 'W19', 'AB26', 'C15', 'R24', 'L18', 'A12', 'W22', 'AC23', 'C17', 'L19', 'R25', 'W23', 'AC24', 'C18', 'L23', 'R26', 'W24', 'AC25', 'C19', 'L24', 'T18', 'W25', 'AC26', 'C20', 'M18', 'T19', 'W26', 'AD24', 'C21', 'A11', 'M19', 'T20', 'Y20', 'AD25', 'C22', 'M20', 'T22', 'A13', 'Y21', 'AD26', 'C5', 'A14', 'M21', 'T23', 'Y22', 'AE23', 'C6', 'A15', 'M23', 'T24', 'Y24', 'A16', 'AE24', 'C7', 'N17', 'T25', 'B3', 'Y25', 'A17', 'AE25', 'C9', 'N18', 'T26', 'A10', 'A18', 'Y26', 'A19', 'AE26', 'D14', 'N19', 'U17', 'A2', 'AF24', 'D17', 'N20', 'U18', 'A20', 'AF25', 'D18', 'N21', 'U19', 'A21', 'B10', 'D21', 'N22', 'U20', 'A22', 'B11', 'D6', 'N23', 'U21', 'A3', 'B12', 'D9', 'N24', 'U22', 'P26', 'A4', 'B14', 'E13', 'P17', 'U23', 'A5', 'B15', 'E16', 'P18', 'U24', 'A6', 'B16', 'E17', 'P20', 'U25', 'A7', 'B18', 'F16', 'P21', 'U26', 'A8', 'B19', 'F17', 'P22', 'V17', 'A9', 'B20', 'F7', 'P23', 'V18', 'AA22', 'B22', 'G10', 'P24', 'V19', 'AA23', 'G18', 'V20']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB14', 'AD18', 'AF15', 'P1', 'U7', 'AF14', 'Y9', 'AB15', 'AF16', 'AD2', 'U8', 'P10', 'AB17', 'AD20', 'AF17', 'P3', 'U9', 'AB3', 'AD22', 'AF18', 'P4', 'V1', 'AB4', 'AD3', 'AF19', 'P5', 'V10', 'AB5', 'AD4', 'AF2', 'P6', 'V12', 'AB6', 'AD5', 'AF20', 'P7', 'V3', 'AB7', 'AD6', 'AF21', 'V4', 'P8', 'U5', 'AB8', 'AD7', 'AF22', 'P9', 'V5', 'AB9', 'AD8', 'AF4', 'R1', 'V6', 'AC1', 'AE1', 'AF5', 'R10', 'V7', 'AC10', 'AE11', 'AF6', 'R2', 'V8', 'AC12', 'AE12', 'AF7', 'R3', 'W1', 'AC13', 'AE13', 'AF8', 'R4', 'W10', 'AC14', 'AE15', 'AF9', 'R5', 'W12', 'AC15', 'AE16', 'L3', 'R6', 'W2', 'AC17', 'AE17', 'L4', 'R7', 'W3', 'AC18', 'AE19', 'L6', 'R9', 'W4', 'AC2', 'AE2', 'L7', 'T1', 'W5', 'AA1', 'AC21', 'AE20', 'M10', 'T10', 'W6', 'AA12', 'AC3', 'AE21', 'M4', 'T2', 'W7', 'AA13', 'AC4', 'AE3', 'M6', 'T3', 'W8', 'AA15', 'AC5', 'AE4', 'M7', 'T4', 'W9', 'AA2', 'AC6', 'AE5', 'M8', 'T6', 'Y1', 'AA3', 'AC7', 'AE7', 'M9', 'T7', 'Y12', 'AA4', 'AD1', 'AE8', 'N3', 'T8', 'Y15', 'AA5', 'AD10', 'AE9', 'N4', 'T9', 'Y17', 'AA7', 'AD12', 'AF10', 'N5', 'U1', 'Y2', 'AA8', 'AD13', 'AF11', 'N6', 'U2', 'Y3', 'AA9', 'AD14', 'AF12', 'N7', 'U3', 'Y5', 'AB1', 'AD15', 'AF13', 'N8', 'U4', 'Y6', 'AB13', 'AD16', 'N9', 'Y8']},{'label': 'uC', 'num': 3, 'pin_nums': ['E4', 'H24', 'K4', 'E5', 'K5', 'H25', 'A23', 'F1', 'H26', 'K6', 'A25', 'F22', 'K7', 'H3', 'B1', 'F23', 'H5', 'K8', 'B2', 'F24', 'H6', 'K9', 'B23', 'F26', 'H7', 'L1', 'B24', 'F3', 'L2', 'H8', 'B25', 'F4', 'J1', 'L20', 'B26', 'F5', 'J10', 'L21', 'C1', 'G1', 'J2', 'L25', 'C2', 'G19', 'J20', 'L26', 'C24', 'G2', 'J21', 'L8', 'C25', 'G20', 'J22', 'L9', 'C26', 'G21', 'J23', 'M1', 'C3', 'G22', 'J24', 'M2', 'C4', 'G23', 'J25', 'M24', 'D1', 'G24', 'J26', 'M25', 'D2', 'G25', 'J3', 'M26', 'D22', 'G26', 'J4', 'M3', 'D23', 'G3', 'J5', 'N1', 'D24', 'G4', 'J6', 'N2', 'D25', 'G5', 'J7', 'N25', 'D26', 'G6', 'K1', 'N26', 'D3', 'G7', 'K10', 'E1', 'H1', 'K20', 'E2', 'H18', 'K21', 'E23', 'H19', 'K22', 'E24', 'H2', 'K23', 'E25', 'H20', 'K24', 'E26', 'H21', 'K26', 'E3', 'H22', 'K3']},{'label': 'uD', 'num': 4, 'pin_nums': ['AC22', 'AF23', 'C23', 'F20', 'A24', 'AD23', 'AF3', 'E21']},{'label': 'uE', 'num': 5, 'pin_nums': ['F19', 'M14', 'T14', 'A1', 'F2', 'T15', 'M15', 'A26', 'F21', 'M16', 'T16', 'AA10', 'F25', 'T17', 'M17', 'AA16', 'F6', 'M22', 'T21', 'AA20', 'G12', 'M5', 'T5', 'AA21', 'G15', 'N10', 'U10', 'AA6', 'H11', 'U11', 'N11', 'AB12', 'H23', 'N12', 'U14', 'AB16', 'H4', 'N13', 'U16', 'AB19', 'J18', 'N14', 'U6', 'AB2', 'J19', 'N15', 'V2', 'AB20', 'J8', 'N16', 'V25', 'AB25', 'J9', 'P11', 'V9', 'AC8', 'K11', 'P12', 'W15', 'AE10', 'K13', 'P13', 'W20', 'AE14', 'K16', 'P14', 'W21', 'AE18', 'K17', 'P15', 'Y11', 'AE22', 'K2', 'P16', 'Y19', 'K25', 'AE6', 'P19', 'Y23', 'AF1', 'L10', 'P2', 'Y4', 'AF26', 'L11', 'P25', 'Y7', 'B13', 'L12', 'R11', 'B17', 'L13', 'R12', 'B21', 'L14', 'R13', 'B5', 'L15', 'R14', 'B9', 'L16', 'R15', 'D4', 'L22', 'R16', 'E11', 'L5', 'R8', 'E15', 'M11', 'T11', 'E22', 'M12', 'T12', 'E7', 'M13', 'T13']}] }),
        Part(**{ 'name':'XC6SLX75T-CSG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX75T-CSG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX75T-CSG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L16P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='IO_L16N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AA20',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB19',name='IO_L65P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L65N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L18P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L18N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L17P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L17N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L15P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L15N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L62P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L62N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L64P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L64N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L63P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L63N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L69N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L69P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AA4',name='IO_L12P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L12N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L75N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L75P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L71N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L71P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L73N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L73P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L74N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L74P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L72N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L72P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L70N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L70P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L21P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L21N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L22N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R8',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L20N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L20P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L11N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U15',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L13P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L11P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L13N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W1',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W17',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F14',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='AA1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='C19',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='F17',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='H16',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='U16',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='W18',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F18',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VBATT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='RFUSE',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U19',name='VFS',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D22', 'G21', 'L17', 'R19', 'A18', 'D5', 'L19', 'G22', 'R20', 'A19', 'E10', 'G7', 'L20', 'R21', 'E16', 'L21', 'G8', 'R22', 'E17', 'G9', 'L22', 'A20', 'T12', 'L16', 'E19', 'H10', 'M16', 'T13', 'A21', 'E20', 'H11', 'M17', 'T15', 'A4', 'E22', 'H12', 'M18', 'T17', 'A5', 'E5', 'AA19', 'H13', 'M19', 'T18', 'AA20', 'E6', 'H14', 'M20', 'AA21', 'T19', 'E8', 'AA22', 'H17', 'M21', 'T20', 'AB19', 'F10', 'H18', 'M22', 'T21', 'AB20', 'F11', 'H19', 'N14', 'T22', 'AB21', 'F12', 'H20', 'N15', 'U18', 'B18', 'F16', 'H21', 'N16', 'U20', 'B19', 'F19', 'H22', 'N18', 'U22', 'B20', 'F20', 'H8', 'N19', 'V17', 'B21', 'F21', 'J16', 'N20', 'V18', 'B22', 'F22', 'J17', 'N22', 'V19', 'B3', 'F6', 'J18', 'P15', 'V20', 'B4', 'F7', 'J19', 'P16', 'V21', 'C17', 'F8', 'J20', 'P17', 'V22', 'C18', 'F9', 'J22', 'P18', 'W20', 'C20', 'G10', 'K16', 'P19', 'W21', 'C21', 'G11', 'K17', 'P20', 'W22', 'C22', 'G12', 'K18', 'P21', 'Y19', 'C5', 'G13', 'K19', 'P22', 'Y20', 'D17', 'G15', 'K20', 'R12', 'Y21', 'D18', 'G16', 'K21', 'R13', 'Y22', 'D19', 'G17', 'K22', 'R15', 'D20', 'G19', 'L15', 'R16', 'D21', 'G20', 'R17', 'A17']},{'label': 'uB', 'num': 2, 'pin_nums': ['AA10', 'J7', 'U5', 'P4', 'Y14', 'AA11', 'C2', 'K1', 'U6', 'P5', 'Y15', 'AA12', 'C3', 'K2', 'P6', 'U8', 'Y16', 'AA14', 'C4', 'K3', 'P7', 'U9', 'Y17', 'AA15', 'D1', 'K4', 'P8', 'V1', 'Y18', 'AA16', 'D2', 'K5', 'R1', 'V11', 'Y2', 'AA18', 'D3', 'K6', 'R2', 'V12', 'Y3', 'AA2', 'D4', 'K7', 'V13', 'R3', 'Y4', 'AA3', 'E1', 'K8', 'R4', 'V15', 'Y5', 'AA4', 'E3', 'L1', 'R6', 'V2', 'Y6', 'AA6', 'E4', 'L2', 'R7', 'V3', 'Y7', 'AA7', 'F1', 'L3', 'R8', 'V5', 'Y8', 'AA8', 'F2', 'L4', 'R9', 'V8', 'Y9', 'AB10', 'F3', 'L6', 'T1', 'W1', 'AB11', 'F4', 'L7', 'T10', 'W11', 'AB12', 'F5', 'M1', 'T11', 'W12', 'AB13', 'G1', 'M2', 'T14', 'W13', 'AB14', 'G2', 'M3', 'T2', 'W14', 'AB15', 'G3', 'M4', 'T3', 'W15', 'AB16', 'G4', 'M5', 'T4', 'W16', 'AB17', 'G6', 'M6', 'T5', 'W17', 'U4', 'AB18', 'H1', 'M7', 'T6', 'W2', 'AB2', 'H2', 'M8', 'T7', 'W3', 'AB3', 'H3', 'N1', 'T8', 'W4', 'AB4', 'H4', 'N3', 'T9', 'W5', 'AB5', 'H5', 'N4', 'U1', 'W6', 'AB6', 'H6', 'N5', 'U10', 'W9', 'AB7', 'J1', 'N6', 'U13', 'Y1', 'AB8', 'J3', 'N7', 'U14', 'Y10', 'AB9', 'J4', 'P1', 'U15', 'Y11', 'A2', 'B1', 'C1', 'J5', 'P2', 'U3', 'Y12', 'A3', 'B2', 'J6', 'P3', 'Y13']},{'label': 'uC', 'num': 3, 'pin_nums': ['A14', 'B6', 'D13', 'A16', 'B8', 'D15', 'A6', 'C11', 'D7', 'A8', 'C13', 'D9', 'B10', 'C15', 'E14', 'B12', 'C7', 'F14', 'A10', 'B14', 'C9', 'A12', 'B16', 'D11']},{'label': 'uD', 'num': 4, 'pin_nums': ['D14', 'E11', 'A15', 'B13', 'C10', 'E15', 'A7', 'B9', 'D12', 'D8', 'E13', 'E9']},{'label': 'uE', 'num': 5, 'pin_nums': ['C19', 'F17', 'H16', 'AA1', 'E18', 'U16', 'W18', 'U12']},{'label': 'uF', 'num': 6, 'pin_nums': ['J10', 'M9', 'V6', 'AA17', 'J11', 'W19', 'N10', 'AA5', 'J12', 'N11', 'W7', 'AA9', 'J13', 'N12', 'AB1', 'J14', 'N13', 'AB22', 'J15', 'N17', 'B11', 'J2', 'N2', 'B15', 'J21', 'N21', 'B17', 'J8', 'N8', 'B5', 'J9', 'N9', 'B7', 'K10', 'P10', 'C12', 'K11', 'P11', 'C14', 'K12', 'P12', 'C16', 'K13', 'P13', 'C6', 'K14', 'P14', 'C8', 'K15', 'P9', 'D10', 'K9', 'R10', 'D16', 'L10', 'R11', 'D6', 'L11', 'R14', 'E12', 'L12', 'R18', 'E2', 'L13', 'R5', 'E21', 'L14', 'T16', 'E7', 'L18', 'U11', 'F13', 'L5', 'U17', 'F15', 'L8', 'U19', 'F18', 'L9', 'U2', 'G14', 'M10', 'U21', 'A1', 'G18', 'M11', 'U7', 'A11', 'G5', 'M12', 'V10', 'A13', 'H15', 'M13', 'V14', 'A22', 'AA13', 'H7', 'M14', 'V16', 'A9', 'H9', 'M15', 'V4']}] }),
        Part(**{ 'name':'XC6SLX75T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX75T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX75T-FGG484\n\nFPGA', 'pins':[
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L9P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L9N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L21N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L21P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L58P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L58N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L71P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L71N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L70P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L70N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L72P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L72N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L73N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L73P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F5',name='IO_L82P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L58N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L82N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G7',name='IO_L80N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L58P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L80P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H8',name='IO_L81N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L81P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N6',name='IO_L23P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L23N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L25P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L25N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L26N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L26P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L24N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L24P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V15',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A12',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A14',name='MGTTXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A16',name='MGTTXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B12',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='MGTTXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B16',name='MGTTXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C13',name='MGTRXN0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C15',name='MGTRXN1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D13',name='MGTRXP0_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='MGTRXP1_123',func=pin_types.BIDIR,unit=3),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=3),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=3),
            Pin(num='E12',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=3),
            Pin(num='F12',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=3),
            Pin(num='A15',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=4),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=4),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=4),
            Pin(num='D14',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=4),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='MGTAVCC_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E13',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=4),
            Pin(num='A21',name='TCK',func=pin_types.BIDIR,unit=5),
            Pin(num='AA22',name='SUSPEND',func=pin_types.BIDIR,unit=5),
            Pin(num='AB2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='AB21',name='DONE_2',func=pin_types.BIDIR,unit=5),
            Pin(num='D20',name='TMS',func=pin_types.BIDIR,unit=5),
            Pin(num='E18',name='TDI',func=pin_types.BIDIR,unit=5),
            Pin(num='G17',name='TDO',func=pin_types.BIDIR,unit=5),
            Pin(num='V18',name='CMPCS_B_2',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P15',name='RFUSE',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='VBATT',func=pin_types.PWRIN,unit=6),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='U17',name='VFS',func=pin_types.PWRIN,unit=6),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['P18', 'F6', 'C19', 'J20', 'P19', 'F7', 'C20', 'J22', 'P20', 'C21', 'F8', 'K16', 'P21', 'F9', 'C22', 'K17', 'P22', 'C3', 'G10', 'K18', 'R15', 'C4', 'G11', 'K19', 'R16', 'C5', 'G13', 'K20', 'R17', 'G14', 'D17', 'K21', 'R19', 'D18', 'G15', 'K22', 'R20', 'D19', 'G16', 'L15', 'R21', 'D21', 'G19', 'L16', 'R22', 'A19', 'D22', 'G20', 'L17', 'T17', 'F22', 'D3', 'G21', 'L19', 'T18', 'D4', 'G22', 'L20', 'T19', 'D5', 'G8', 'L21', 'T20', 'A18', 'E16', 'G9', 'L22', 'T21', 'E17', 'H10', 'A2', 'M16', 'T22', 'E19', 'H11', 'M17', 'U18', 'E20', 'H12', 'M18', 'U19', 'E22', 'H13', 'M19', 'U20', 'A20', 'E5', 'H14', 'M20', 'U22', 'A3', 'E6', 'H16', 'M21', 'V19', 'A4', 'F10', 'H17', 'A5', 'M22', 'V20', 'F14', 'H18', 'B18', 'N15', 'V21', 'B19', 'F15', 'H19', 'A17', 'B2', 'N16', 'V22', 'B20', 'F16', 'H20', 'N18', 'W20', 'B21', 'F17', 'H21', 'N19', 'W21', 'B22', 'F18', 'H22', 'N20', 'W22', 'B3', 'F19', 'J16', 'N22', 'Y21', 'B4', 'F20', 'J17', 'P16', 'Y22', 'C17', 'F21', 'J18', 'P17', 'C18', 'J19']},{'label': 'uB', 'num': 2, 'pin_nums': ['Y9', 'AB8', 'AA10', 'P3', 'J6', 'V1', 'AB9', 'AA11', 'P4', 'J7', 'V12', 'AA12', 'B1', 'K1', 'P5', 'V15', 'C1', 'AA14', 'K2', 'P6', 'V16', 'AA15', 'C2', 'K3', 'P7', 'V17', 'AA16', 'D1', 'K4', 'P8', 'V2', 'AA18', 'D2', 'K5', 'R1', 'V3', 'AA19', 'E1', 'R13', 'K6', 'V5', 'AA2', 'E3', 'K7', 'R2', 'V8', 'AA20', 'E4', 'K8', 'R3', 'W1', 'AA21', 'F1', 'L1', 'R4', 'W12', 'AA3', 'F2', 'L2', 'R7', 'W18', 'AA4', 'F3', 'L3', 'T1', 'W2', 'AA6', 'F4', 'L4', 'T12', 'W3', 'AA7', 'F5', 'L6', 'T13', 'W4', 'AA8', 'G1', 'L7', 'T14', 'W5', 'AB10', 'G2', 'M1', 'T2', 'W9', 'AB11', 'G3', 'M2', 'T3', 'Y1', 'AB12', 'G4', 'M3', 'T4', 'Y11', 'AB13', 'G6', 'M4', 'T5', 'Y12', 'AB14', 'G7', 'M5', 'T6', 'AB7', 'Y13', 'AB15', 'H1', 'M6', 'T7', 'Y15', 'AB16', 'H2', 'M7', 'T9', 'Y17', 'AB17', 'H3', 'M8', 'U1', 'Y19', 'AB18', 'H4', 'N1', 'U12', 'Y2', 'AB19', 'H5', 'N3', 'U13', 'Y20', 'P2', 'AB20', 'H6', 'N4', 'U14', 'Y3', 'AB3', 'H8', 'N5', 'U16', 'Y4', 'AB4', 'J1', 'N6', 'U3', 'Y5', 'AB5', 'J3', 'N7', 'U4', 'Y7', 'AB6', 'J4', 'P1', 'U5', 'Y8', 'AA1', 'J5', 'U6']},{'label': 'uC', 'num': 3, 'pin_nums': ['C7', 'B12', 'F12', 'B14', 'A10', 'C9', 'A12', 'B16', 'D11', 'A14', 'B6', 'D13', 'A16', 'B8', 'D15', 'A6', 'C11', 'D7', 'A8', 'C13', 'D9', 'B10', 'C15', 'E12']},{'label': 'uD', 'num': 4, 'pin_nums': ['A7', 'B9', 'D12', 'D8', 'E13', 'E9', 'D14', 'E8', 'A15', 'B13', 'C10', 'E10']},{'label': 'uE', 'num': 5, 'pin_nums': ['G17', 'A21', 'AB2', 'D20', 'AB21', 'AA22', 'E18', 'V18']},{'label': 'uF', 'num': 6, 'pin_nums': ['C16', 'P11', 'K12', 'C6', 'P12', 'K13', 'C8', 'K14', 'P13', 'C14', 'D10', 'P14', 'K15', 'D16', 'K9', 'P15', 'D6', 'P9', 'L10', 'E11', 'L11', 'R10', 'E14', 'R12', 'L12', 'E15', 'L13', 'R14', 'E2', 'L14', 'R18', 'E21', 'L18', 'R5', 'E7', 'L5', 'R6', 'F11', 'L8', 'T16', 'F13', 'L9', 'U11', 'A1', 'G12', 'M10', 'U17', 'A11', 'G18', 'U2', 'M11', 'A13', 'G5', 'M12', 'U21', 'A22', 'H15', 'M13', 'U7', 'A9', 'H7', 'M14', 'V10', 'AA13', 'H9', 'M15', 'V14', 'AA17', 'J10', 'M9', 'V4', 'AA5', 'J11', 'N10', 'V6', 'AA9', 'J12', 'N11', 'W16', 'AB1', 'J13', 'N12', 'W19', 'AB22', 'J14', 'N13', 'W7', 'B11', 'J15', 'N14', 'B15', 'J2', 'N17', 'B17', 'J21', 'N2', 'B5', 'J8', 'N21', 'B7', 'J9', 'N8', 'C12', 'K10', 'N9', 'K11', 'P10']}] }),
        Part(**{ 'name':'XC6SLX75T-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX75T-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX75T-FGG676\n\nFPGA', 'pins':[
            Pin(num='A12',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L24N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L67P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L67N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='AD26',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO_L59N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IO_L59P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO_L57N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E21',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F17',name='IO_L56N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L57P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L56P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L58N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L43N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='H17',name='IO_L58P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='IO_L43P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L48P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L48N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L28N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N24',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='P24',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P26',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R24',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L66P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L66N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T26',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L68P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L68N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L69P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L69N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W23',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='Y26',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA15',name='IO_L28P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA21',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L28N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB22',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L8P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB9',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC14',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC22',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AC3',name='IO_L8N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC4',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AC5',name='IO_L61P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD14',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='AD22',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD23',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AD4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD5',name='IO_L61N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AD6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE13',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE15',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AE23',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AE24',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AE4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AF13',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF14',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF15',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF22',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF23',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF24',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AF6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L57P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L57N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='T8',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L18N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L18P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L17P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W14',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W17',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W19',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W20',name='IO_L4P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W5',name='IO_L17N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='Y2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='Y20',name='IO_L4N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L7N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L7P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='A25',name='IO_L2N_M5A14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L75N_M4BA1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L75P_M4BA0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L2P_M5A13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L11P_M5CLK_5',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L11N_M5CLKN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L79N_M4A9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L79P_M4A8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L4N_M5A12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='IO_L10P_M5A0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='C26',name='IO_L10N_M5A1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L68N_M4DQ5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='D23',name='IO_L4P_M5CKE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L17P_M5DQ6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='D26',name='IO_L17N_M5DQ7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L68P_M4DQ4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L67N_M4DQ7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L67P_M4DQ6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E23',name='IO_L8P_M5A7_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E24',name='IO_L8N_M5A2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E25',name='IO_L16P_M5DQ4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E26',name='IO_L16N_M5DQ5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L81N_M4A11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='IO_L81P_M4RESET_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L66N_M4LDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F22',name='IO_L6P_M5A10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F23',name='IO_L14P_M5RASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F24',name='IO_L18P_M5LDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F26',name='IO_L18N_M5LDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='F3',name='IO_L66P_M4LDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='G1',name='IO_L65N_M4DQ3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L65P_M4DQ2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G20',name='IO_L1N_A24_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G22',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='G23',name='IO_L6N_M5A4_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G24',name='IO_L14N_M5CASN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L20P_M5DQ0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L20N_M5DQ1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L77N_M4BA2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L77P_M4WE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L64N_M4DQ1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='H20',name='IO_L1P_A25_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H21',name='IO_L5P_M5A8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H22',name='IO_L5N_M5A9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L19P_M5DQ2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='H26',name='IO_L19N_M5DQ3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L64P_M4DQ0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L83N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L83P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='IO_L63N_M4DQ9_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L63P_M4DQ8_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J20',name='IO_L7P_M5WE_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J21',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='J22',name='IO_L7N_M5BA2_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L15P_M5UDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L15N_M5LDM_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L22P_M5DQ10_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L22N_M5DQ11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L69N_M4LDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L69P_M4UDM_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L73N_M4CLKN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='J7',name='IO_L78N_M4A4_4',func=pin_types.BIDIR,unit=3),
            Pin(num='J9',name='IO_L78P_M4A10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L62N_M4DQ11_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='IO_L76N_M4A2_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K18',name='IO_L3P_M5RESET_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K19',name='IO_L3N_M5A11_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K20',name='IO_L9N_M5BA1_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K21',name='IO_L12P_M5A3_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K22',name='IO_L12N_M5ODT_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='K24',name='IO_L21P_M5DQ8_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L21N_M5DQ9_5',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L62P_M4DQ10_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='K5',name='IO_L73P_M4CLK_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L82N_M4A14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='IO_L82P_M4A13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='IO_L80N_M4A12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='K9',name='IO_L80P_M4CKE_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L61N_M4UDQSN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L10',name='IO_L76P_M4A7_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L19',name='IO_L9P_M5BA0_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L2',name='IO_L61P_M4UDQS_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L20',name='IO_L27P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L21',name='IO_L27N_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L24P_M5DQ12_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L26',name='IO_L24N_M5DQ13_5',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L71N_M4A6_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L71P_M4A5_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_L74N_M4A1_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L7',name='IO_L74P_M4A0_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L8',name='IO_L70N_M4CASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='IO_L70P_M4RASN_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L60N_M4DQ13_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M18',name='IO_L13P_M5A5_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M19',name='IO_L13N_M5A6_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M20',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M21',name='IO_L26P_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M23',name='IO_L26N_VREF_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M24',name='IO_L23P_M5UDQS_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='VCCO_5',func=pin_types.PWRIN,unit=3),
            Pin(num='M26',name='IO_L23N_M5UDQSN_5',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L60P_M4DQ12_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='IO_L58P_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L72N_M4ODT_4',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='VCCO_4',func=pin_types.PWRIN,unit=3),
            Pin(num='M8',name='IO_L72P_M4A3_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='IO_L59N_M4DQ15_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N2',name='IO_L59P_M4DQ14_4',func=pin_types.BIDIR,unit=3),
            Pin(num='N25',name='IO_L25P_M5DQ14_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N26',name='IO_L25N_M5DQ15_5',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L58N_VREF_4',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTREFCLK0N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A16',name='MGTREFCLK1N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A18',name='MGTTXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A20',name='MGTTXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTREFCLK0P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B16',name='MGTREFCLK1P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B18',name='MGTTXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B20',name='MGTTXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTREFCLK1N_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C15',name='MGTREFCLK0N_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C17',name='MGTRXN0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C19',name='MGTRXN1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTREFCLK1P_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D15',name='MGTREFCLK0P_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D17',name='MGTRXP0_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D19',name='MGTRXP1_123',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.BIDIR,unit=4),
            Pin(num='AC10',name='MGTRXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AC12',name='MGTREFCLK1P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AC16',name='MGTREFCLK0P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC18',name='MGTRXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC20',name='MGTRXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='MGTRXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='MGTRXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD12',name='MGTREFCLK1N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AD16',name='MGTREFCLK0N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD18',name='MGTRXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD20',name='MGTRXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='MGTRXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE11',name='MGTREFCLK0P_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE17',name='MGTREFCLK1P_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE19',name='MGTTXP0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE21',name='MGTTXP1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='MGTTXP0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AE9',name='MGTTXP1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF11',name='MGTREFCLK0N_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF17',name='MGTREFCLK1N_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF19',name='MGTTXN0_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF21',name='MGTTXN1_267',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='MGTTXN0_245',func=pin_types.BIDIR,unit=5),
            Pin(num='AF9',name='MGTTXN1_245',func=pin_types.BIDIR,unit=5),
            Pin(num='A19',name='MGTAVTTTX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='AB10',name='MGTRREF_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AB12',name='MGTAVTTRCAL_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AC19',name='MGTAVTTRX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AC9',name='MGTAVTTRX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD11',name='MGTAVCC_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD13',name='MGTAVCCPLL1_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AD15',name='MGTAVCCPLL0_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AD17',name='MGTAVCC_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AE12',name='MGTAVCCPLL0_245',func=pin_types.PWRIN,unit=6),
            Pin(num='AE16',name='MGTAVCCPLL1_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AF20',name='MGTAVTTTX_267',func=pin_types.PWRIN,unit=6),
            Pin(num='AF8',name='MGTAVTTTX_245',func=pin_types.PWRIN,unit=6),
            Pin(num='B11',name='MGTAVCCPLL0_101',func=pin_types.PWRIN,unit=6),
            Pin(num='B15',name='MGTAVCCPLL1_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='MGTAVCCPLL1_101',func=pin_types.PWRIN,unit=6),
            Pin(num='C14',name='MGTAVCCPLL0_123',func=pin_types.PWRIN,unit=6),
            Pin(num='C16',name='MGTAVCC_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D18',name='MGTAVTTRX_123',func=pin_types.PWRIN,unit=6),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='MGTAVTTRCAL_101',func=pin_types.PWRIN,unit=6),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.PWRIN,unit=6),
            Pin(num='A24',name='TCK',func=pin_types.BIDIR,unit=7),
            Pin(num='AF2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='AF25',name='DONE_2',func=pin_types.BIDIR,unit=7),
            Pin(num='C23',name='TDI',func=pin_types.BIDIR,unit=7),
            Pin(num='F21',name='TMS',func=pin_types.BIDIR,unit=7),
            Pin(num='G21',name='TDO',func=pin_types.BIDIR,unit=7),
            Pin(num='Y19',name='CMPCS_B_2',func=pin_types.BIDIR,unit=7),
            Pin(num='Y22',name='SUSPEND',func=pin_types.BIDIR,unit=7),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AB2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC21',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='AD19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D20',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='E19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='L5',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='N16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='R22',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T15',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T17',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U14',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U16',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='U6',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V17',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V19',name='RFUSE',func=pin_types.PWRIN,unit=8),
            Pin(num='V2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V22',name='VBATT',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='VFS',func=pin_types.PWRIN,unit=8),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y7',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B14', 'N24', 'V20', 'B21', 'G19', 'P17', 'V21', 'B22', 'G6', 'P18', 'V23', 'A14', 'B23', 'G7', 'P19', 'V24', 'B3', 'G8', 'P21', 'V26', 'B4', 'G9', 'P22', 'W21', 'A13', 'B5', 'H11', 'P23', 'W23', 'C13', 'H12', 'P24', 'W24', 'A2', 'C21', 'H15', 'P26', 'W25', 'C22', 'H16', 'R18', 'W26', 'C3', 'H17', 'R19', 'Y24', 'A22', 'C4', 'H18', 'R20', 'Y25', 'A23', 'D13', 'H19', 'R21', 'A12', 'Y26', 'A3', 'D21', 'H7', 'R23', 'A4', 'D22', 'A5', 'H8', 'R24', 'AA23', 'E13', 'H9', 'R25', 'AA24', 'E20', 'AA25', 'J11', 'R26', 'AA26', 'E21', 'J12', 'T19', 'AB23', 'E5', 'J14', 'T20', 'AB24', 'E6', 'J15', 'T22', 'AB26', 'F13', 'J16', 'T23', 'AC23', 'F17', 'J17', 'T24', 'AC24', 'F19', 'K12', 'T25', 'AC25', 'F20', 'L23', 'T26', 'AC26', 'F5', 'L24', 'U19', 'AD24', 'F6', 'N17', 'U20', 'AD25', 'F7', 'N18', 'U21', 'AD26', 'F8', 'N19', 'U22', 'AE25', 'G11', 'N20', 'U23', 'AE26', 'G13', 'N21', 'U24', 'B12', 'G16', 'G18', 'N22', 'U25', 'B13', 'G17', 'N23', 'U26']},{'label': 'uB', 'num': 2, 'pin_nums': ['R5', 'AB15', 'R6', 'AE4', 'W11', 'AB21', 'AF13', 'R7', 'W14', 'AB22', 'AF14', 'R8', 'W15', 'AB3', 'AF15', 'R9', 'W17', 'AB4', 'AF22', 'T1', 'W18', 'AB5', 'AF23', 'T2', 'W19', 'AB6', 'AF24', 'T3', 'W2', 'AB9', 'AF3', 'T4', 'W20', 'AC1', 'AF4', 'T6', 'W3', 'AC14', 'AF6', 'T7', 'W4', 'AC2', 'M10', 'T8', 'W5', 'AC22', 'M9', 'T9', 'W6', 'AC3', 'N4', 'U1', 'W7', 'AA1', 'AC4', 'N5', 'U15', 'W8', 'AA10', 'AC5', 'N6', 'U2', 'Y1', 'AD1', 'AA11', 'N7', 'U3', 'Y11', 'AA12', 'AD14', 'N8', 'U4', 'Y12', 'AA14', 'AD2', 'N9', 'U5', 'Y13', 'AA15', 'AD22', 'P1', 'U7', 'Y17', 'AA17', 'AD23', 'P10', 'U8', 'Y18', 'AA2', 'AD3', 'P3', 'U9', 'Y2', 'AA20', 'AD4', 'P4', 'V1', 'Y20', 'AA21', 'AD5', 'P5', 'V10', 'Y21', 'AD6', 'AA22', 'P6', 'V11', 'Y3', 'AA3', 'AE1', 'P8', 'V16', 'AE3', 'Y5', 'AA4', 'AE13', 'P9', 'V18', 'Y6', 'AA6', 'AE14', 'R1', 'V3', 'Y8', 'AA7', 'AE15', 'R10', 'V4', 'AA9', 'AE2', 'R2', 'V5', 'AB1', 'AE23', 'R3', 'V6', 'W1', 'AB11', 'AE24', 'R4', 'V7', 'AB14']},{'label': 'uC', 'num': 3, 'pin_nums': ['B25', 'J9', 'G22', 'B24', 'M1', 'B26', 'K1', 'G23', 'M18', 'C1', 'G24', 'K10', 'M19', 'C2', 'K18', 'G25', 'M2', 'C24', 'G26', 'K19', 'M20', 'C25', 'G3', 'K20', 'M21', 'C26', 'G4', 'K21', 'M23', 'D1', 'H1', 'K22', 'M24', 'J7', 'D2', 'H2', 'K23', 'M25', 'D23', 'H20', 'K24', 'M26', 'D24', 'H21', 'K26', 'M3', 'D25', 'H22', 'K3', 'M4', 'D26', 'H24', 'K4', 'M6', 'D3', 'H25', 'K5', 'M7', 'E1', 'H26', 'K6', 'M8', 'E2', 'K7', 'H3', 'N1', 'E23', 'H5', 'K8', 'N2', 'E24', 'H6', 'K9', 'N25', 'E25', 'J1', 'L1', 'N26', 'E26', 'J2', 'L10', 'N3', 'E3', 'J20', 'L19', 'E4', 'J21', 'L2', 'F1', 'J22', 'L20', 'F22', 'J23', 'L21', 'F23', 'J24', 'L25', 'F24', 'J25', 'L26', 'F26', 'J26', 'L3', 'F3', 'J3', 'L4', 'A25', 'F4', 'J4', 'L6', 'B1', 'G1', 'J5', 'L7', 'B2', 'G2', 'J6', 'L8', 'G20', 'L9']},{'label': 'uD', 'num': 4, 'pin_nums': ['B8', 'A20', 'D15', 'A6', 'C11', 'D17', 'A8', 'C15', 'D19', 'B10', 'C17', 'D7', 'B16', 'C19', 'D9', 'A10', 'B18', 'C7', 'A16', 'B20', 'C9', 'A18', 'B6', 'D11']},{'label': 'uE', 'num': 5, 'pin_nums': ['AC18', 'AD8', 'AF17', 'AC20', 'AE11', 'AF19', 'AC8', 'AE17', 'AF21', 'AD10', 'AE19', 'AF7', 'AD12', 'AE21', 'AF9', 'AC10', 'AD16', 'AE7', 'AD20', 'AF11', 'AC12', 'AD18', 'AE9', 'AC16']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE12', 'AB10', 'C14', 'AB12', 'AE16', 'C16', 'AC19', 'AF20', 'D18', 'AC9', 'AF8', 'D8', 'AD11', 'B11', 'E11', 'AD13', 'B15', 'E9', 'A19', 'AD15', 'C10', 'A7', 'AD17', 'C12']},{'label': 'uG', 'num': 7, 'pin_nums': ['AF2', 'C23', 'Y22', 'F21', 'AF25', 'A24', 'Y19', 'G21']},{'label': 'uH', 'num': 8, 'pin_nums': ['F25', 'T14', 'G14', 'AE20', 'M22', 'T15', 'AE22', 'G5', 'M5', 'T16', 'AE6', 'H23', 'N10', 'T17', 'AE8', 'H4', 'N11', 'T18', 'AF1', 'J10', 'N12', 'T21', 'AF10', 'J18', 'N13', 'T5', 'A1', 'AF12', 'J19', 'N14', 'U10', 'A11', 'AF16', 'J8', 'N15', 'U11', 'A15', 'AF18', 'K11', 'N16', 'U12', 'A17', 'AF26', 'K13', 'P11', 'U14', 'A21', 'B17', 'K15', 'P12', 'U16', 'A26', 'B19', 'K16', 'P13', 'U17', 'A9', 'B7', 'K17', 'P14', 'U18', 'AA5', 'B9', 'K2', 'P15', 'U6', 'AB16', 'C18', 'K25', 'P16', 'V17', 'AB18', 'C20', 'L11', 'P2', 'V19', 'AB2', 'C6', 'L12', 'P20', 'V2', 'AB20', 'C8', 'L13', 'P25', 'V22', 'AB25', 'D10', 'L14', 'P7', 'V25', 'AB8', 'D12', 'L15', 'R11', 'V8', 'AC11', 'D14', 'L16', 'R12', 'V9', 'AC13', 'D16', 'L17', 'R13', 'W13', 'AC15', 'D20', 'L18', 'R14', 'W22', 'AC17', 'D4', 'L22', 'R15', 'Y10', 'AC21', 'D6', 'L5', 'R16', 'Y14', 'AC7', 'E15', 'M11', 'R17', 'Y23', 'AD19', 'E17', 'M12', 'R22', 'Y4', 'AD21', 'E19', 'M13', 'T10', 'Y7', 'AD7', 'E22', 'M14', 'T11', 'AD9', 'E7', 'M15', 'M17', 'T12', 'AE10', 'F2', 'M16', 'T13', 'AE18']}] }),
        Part(**{ 'name':'XC6SLX9-CPG196', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX9-CPG196'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX9-CPG196\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L1P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L1N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='IO_L32P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L32N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='IO_L33P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L33N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L34P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L34N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L41P_GCLK9_IRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L41N_GCLK8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='IO_L40P_GCLK11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L40N_GCLK10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L43P_GCLK5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L43N_GCLK4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L42P_GCLK7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L42N_GCLK6_TRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L46P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L46N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L45P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L45N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='IO_L47P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L47N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L51N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L51P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L50P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='F1',name='IO_L44N_GCLK20_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L44P_GCLK21_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L49N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L49P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L42N_GCLK24_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L42P_GCLK25_TRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H1',name='IO_L43N_GCLK22_IRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L43P_GCLK23_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L41P_GCLK27_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L37N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L37P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L36N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L36P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M2',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N10',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A13',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='B13',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B14',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='L12',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='M12',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='N14',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='E7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K5',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B8', 'C8', 'G13', 'E13', 'M13', 'B11', 'B9', 'C9', 'E14', 'G14', 'A12', 'B12', 'J14', 'M14', 'B2', 'C10', 'D11', 'F11', 'H11', 'K11', 'A3', 'B3', 'C11', 'D12', 'F12', 'H12', 'K12', 'A4', 'B4', 'C12', 'D13', 'F13', 'A5', 'H13', 'K13', 'A6', 'B5', 'C13', 'D14', 'A11', 'F14', 'H14', 'K14', 'A7', 'B6', 'C4', 'D8', 'G11', 'A10', 'A8', 'J11', 'J13', 'L13', 'A2', 'A9', 'B7', 'C5', 'E12', 'G12', 'J12', 'L14', 'B10']},{'label': 'uB', 'num': 2, 'pin_nums': ['E1', 'G1', 'M8', 'J3', 'L4', 'N4', 'P12', 'P8', 'G2', 'J4', 'L8', 'M9', 'P9', 'E2', 'N5', 'P13', 'B1', 'E3', 'G3', 'K1', 'M1', 'N10', 'N6', 'P2', 'E4', 'H1', 'C1', 'K2', 'M10', 'N11', 'N7', 'P3', 'D1', 'F1', 'H2', 'K3', 'M2', 'N12', 'N8', 'P4', 'P11', 'D2', 'F2', 'H3', 'K4', 'M4', 'N13', 'N9', 'P5', 'D4', 'D3', 'F3', 'F4', 'J1', 'J2', 'L1', 'M5', 'N2', 'L2', 'P10', 'P6', 'M6', 'N3', 'P7']},{'label': 'uC', 'num': 3, 'pin_nums': ['C14', 'M12', 'N14', 'B13', 'L12', 'A13', 'B14', 'N1']},{'label': 'uD', 'num': 4, 'pin_nums': ['L3', 'E5', 'G8', 'C7', 'F7', 'H9', 'K5', 'L5', 'P14', 'D10', 'E6', 'F8', 'G9', 'L6', 'J10', 'K6', 'D5', 'E7', 'F9', 'H10', 'J5', 'K7', 'L7', 'A1', 'D6', 'E8', 'G10', 'H4', 'J6', 'K8', 'L9', 'A14', 'D7', 'E9', 'G4', 'H5', 'J7', 'K9', 'M11', 'C2', 'D9', 'F10', 'G5', 'H6', 'J8', 'L10', 'M3', 'C3', 'E10', 'F5', 'G6', 'H7', 'J9', 'L11', 'M7', 'C6', 'E11', 'F6', 'G7', 'P1', 'H8', 'K10']}] }),
        Part(**{ 'name':'XC6SLX9-CSG225', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX9-CSG225'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX9-CSG225\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D15',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E14',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='H15',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E5',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G5',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='H3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L9',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M3',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P13',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='P9',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='D12',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='E13',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='L10',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='L13',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='R14',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L4',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R15',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A4', 'J14', 'D15', 'A5', 'J15', 'D5', 'A6', 'A7', 'D6', 'K10', 'A10', 'A8', 'K11', 'D7', 'A9', 'D8', 'K12', 'B11', 'D9', 'K13', 'B12', 'E14', 'K15', 'B13', 'L12', 'E15', 'B14', 'E6', 'L14', 'B15', 'E7', 'L15', 'B2', 'E8', 'M13', 'B3', 'E9', 'M14', 'B4', 'F10', 'M15', 'B5', 'F11', 'N14', 'B7', 'F12', 'N15', 'B8', 'F13', 'P14', 'B9', 'F15', 'P15', 'C10', 'F8', 'C11', 'G11', 'C12', 'G12', 'C14', 'G13', 'C15', 'G14', 'C4', 'G15', 'C5', 'H10', 'C6', 'H11', 'C7', 'H12', 'C8', 'A13', 'H13', 'C9', 'H14', 'D10', 'H15', 'D11', 'J11', 'A11', 'A12', 'D13', 'J12', 'A2', 'D14', 'J13', 'A3']},{'label': 'uB', 'num': 2, 'pin_nums': ['M11', 'G1', 'M2', 'R12', 'G2', 'M3', 'R13', 'G3', 'M4', 'R3', 'G4', 'M5', 'R4', 'G5', 'M6', 'R5', 'H1', 'M7', 'R6', 'H2', 'M8', 'R7', 'H3', 'M9', 'R8', 'H4', 'N1', 'R9', 'H5', 'N10', 'H6', 'N11', 'J1', 'N12', 'J2', 'N2', 'J3', 'N4', 'J4', 'N5', 'J5', 'N6', 'K1', 'N7', 'C1', 'K3', 'N8', 'C2', 'K4', 'N9', 'D1', 'K5', 'P1', 'D2', 'K8', 'P11', 'D3', 'L1', 'P12', 'D4', 'L2', 'P13', 'E1', 'L3', 'P2', 'E2', 'L5', 'P3', 'E3', 'L6', 'P4', 'E4', 'L7', 'P5', 'E5', 'L8', 'P7', 'F1', 'L9', 'P8', 'F3', 'M1', 'P9', 'R11', 'F4', 'M10', 'R10', 'F5']},{'label': 'uC', 'num': 3, 'pin_nums': ['L10', 'R14', 'E10', 'A14', 'E13', 'L13', 'R2', 'D12']},{'label': 'uD', 'num': 4, 'pin_nums': ['G10', 'K7', 'C3', 'J10', 'P6', 'J6', 'K9', 'R1', 'G6', 'E11', 'A1', 'E12', 'G7', 'J7', 'L11', 'R15', 'G8', 'A15', 'F14', 'J8', 'L4', 'B1', 'F2', 'G9', 'J9', 'M12', 'F6', 'B10', 'H7', 'K14', 'N13', 'F9', 'H9', 'K6', 'B6', 'F7', 'H8', 'K2', 'N3', 'P10', 'C13']}] }),
        Part(**{ 'name':'XC6SLX9-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX9-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX9-CSG324\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L41N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L41P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='M16',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='E3',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G6',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H7',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M5',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R10',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R13',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R7',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U16',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='D15',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='R16',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='V17',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B1',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B17',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J12',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P14',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='P5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='R1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C14', 'M13', 'G13', 'C15', 'M14', 'G14', 'C17', 'G15', 'M15', 'C18', 'M16', 'G16', 'C4', 'G18', 'M18', 'C5', 'N14', 'G9', 'A11', 'C6', 'H12', 'N15', 'A14', 'C7', 'N16', 'H13', 'A12', 'C8', 'H14', 'N17', 'C11', 'A15', 'C9', 'H15', 'N18', 'A16', 'D11', 'A2', 'H16', 'P15', 'A3', 'D13', 'H17', 'P16', 'A4', 'D14', 'A5', 'H18', 'P17', 'A6', 'D17', 'J13', 'P18', 'A7', 'D18', 'J14', 'R17', 'A8', 'D4', 'J16', 'T17', 'A9', 'D6', 'J17', 'T18', 'B10', 'D7', 'J18', 'U17', 'B11', 'D8', 'K12', 'U18', 'B12', 'D9', 'K13', 'B14', 'E10', 'K14', 'A10', 'B15', 'E13', 'K15', 'B16', 'E16', 'K16', 'B2', 'E17', 'K17', 'B3', 'E18', 'K18', 'B4', 'F13', 'L12', 'B5', 'F14', 'L13', 'B6', 'F15', 'L14', 'B8', 'F16', 'L15', 'B9', 'F17', 'L16', 'C10', 'F18', 'L17', 'F9', 'L18']},{'label': 'uB', 'num': 2, 'pin_nums': ['L7', 'T13', 'V6', 'F5', 'M1', 'V7', 'T14', 'F6', 'M3', 'T15', 'V8', 'G1', 'M4', 'V9', 'T2', 'G3', 'M5', 'T3', 'G4', 'N1', 'T4', 'G6', 'N12', 'T5', 'H1', 'N2', 'T6', 'H2', 'N3', 'T7', 'H3', 'N4', 'T8', 'H4', 'N5', 'T9', 'H5', 'P1', 'U1', 'H6', 'P12', 'U10', 'H7', 'P2', 'U11', 'J1', 'P3', 'U13', 'J2', 'P4', 'U14', 'J3', 'P6', 'U16', 'J5', 'P9', 'U2', 'J6', 'R10', 'U3', 'J7', 'R11', 'U4', 'C1', 'K1', 'R12', 'U5', 'C2', 'K2', 'R13', 'U7', 'D1', 'K3', 'R15', 'U8', 'D2', 'K4', 'R2', 'U9', 'D3', 'K5', 'R3', 'V10', 'E1', 'K6', 'R5', 'V11', 'E2', 'L1', 'R6', 'V13', 'E3', 'L2', 'R7', 'V14', 'E4', 'L3', 'R8', 'V16', 'F1', 'L4', 'T1', 'V3', 'F2', 'F4', 'L5', 'T10', 'V4', 'F3', 'L6', 'T11', 'V5']},{'label': 'uC', 'num': 3, 'pin_nums': ['B18', 'D16', 'R16', 'V2', 'A17', 'P13', 'D15', 'V17']},{'label': 'uD', 'num': 4, 'pin_nums': ['B13', 'E15', 'J15', 'M6', 'K9', 'R14', 'V18', 'B17', 'E5', 'H10', 'J4', 'L10', 'M7', 'R18', 'B7', 'E9', 'H11', 'J8', 'L11', 'M9', 'R4', 'C16', 'G10', 'H8', 'J9', 'L8', 'N13', 'R9', 'C3', 'G12', 'H9', 'K10', 'L9', 'P10', 'T16', 'A1', 'D10', 'G17', 'J10', 'K11', 'M12', 'P14', 'U12', 'A18', 'D5', 'G2', 'G7', 'J11', 'K7', 'M17', 'P5', 'U6', 'B1', 'E14', 'G5', 'J12', 'K8', 'M2', 'R1', 'V1']}] }),
        Part(**{ 'name':'XC6SLX9-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX9-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX9-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L39N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L39P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='D16',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L40N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L40P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO_L36P_A9_M1BA0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L43N_GCLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R14',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D3',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G5',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G6',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L44N_GCLK20_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L43N_GCLK22_IRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L10',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M10',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M12',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N11',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='N3',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='N8',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R5',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='R9',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='C12',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='C14',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='E14',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='L11',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P13',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='P14',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L6',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L9',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E13', 'K13', 'A10', 'B16', 'E15', 'K14', 'B4', 'E16', 'K15', 'B5', 'E6', 'K16', 'B6', 'E7', 'L12', 'B8', 'E8', 'L13', 'B9', 'F10', 'L14', 'C10', 'F12', 'L16', 'C11', 'F13', 'M13', 'C13', 'F14', 'M14', 'C15', 'F15', 'M15', 'C16', 'F16', 'M16', 'C4', 'F7', 'N14', 'C5', 'F9', 'N15', 'C6', 'G11', 'N16', 'C7', 'G12', 'P15', 'C8', 'G13', 'P16', 'C9', 'G14', 'R12', 'A13', 'D10', 'G16', 'R13', 'D11', 'H11', 'R14', 'D12', 'H13', 'R15', 'D14', 'H14', 'A11', 'R16', 'A12', 'D15', 'H15', 'A14', 'T12', 'D16', 'H16', 'A4', 'T13', 'A5', 'D5', 'J11', 'T14', 'A6', 'D6', 'J12', 'T15', 'A7', 'A8', 'D7', 'J13', 'A9', 'D8', 'J14', 'B10', 'D9', 'J15', 'B12', 'E10', 'J16', 'B13', 'B15', 'E11', 'K11', 'B14', 'E12', 'K12']},{'label': 'uB', 'num': 2, 'pin_nums': ['N7', 'C2', 'K3', 'N8', 'C3', 'K4', 'N9', 'D1', 'K5', 'P1', 'D2', 'K6', 'P10', 'D3', 'L1', 'P11', 'E1', 'L10', 'P12', 'E2', 'L3', 'P2', 'E3', 'L4', 'P4', 'E4', 'L5', 'P5', 'K2', 'F1', 'L7', 'P6', 'F2', 'L8', 'P7', 'F3', 'M1', 'P8', 'F4', 'M10', 'P9', 'F5', 'M11', 'R1', 'F6', 'M12', 'R11', 'G1', 'M2', 'R2', 'G3', 'M3', 'R3', 'G4', 'M4', 'R4', 'G5', 'M5', 'R5', 'G6', 'M6', 'R7', 'H1', 'M7', 'R8', 'H2', 'M9', 'R9', 'H3', 'N1', 'T10', 'H4', 'N10', 'T11', 'H5', 'N11', 'T3', 'J1', 'N12', 'T4', 'A2', 'J2', 'N2', 'T5', 'A3', 'J3', 'N3', 'T6', 'B1', 'J4', 'N4', 'T7', 'B2', 'J6', 'N5', 'T8', 'B3', 'K1', 'N6', 'T9', 'C1']},{'label': 'uC', 'num': 3, 'pin_nums': ['A15', 'P14', 'L11', 'C14', 'E14', 'P13', 'T2', 'C12']},{'label': 'uD', 'num': 4, 'pin_nums': ['L2', 'F11', 'J7', 'A1', 'H10', 'T1', 'E9', 'J8', 'L6', 'T16', 'A16', 'F8', 'H12', 'G9', 'L15', 'R6', 'B11', 'G10', 'H6', 'J9', 'L9', 'G15', 'B7', 'H7', 'K10', 'M8', 'D13', 'G2', 'H8', 'K7', 'N13', 'D4', 'G7', 'H9', 'K8', 'P3', 'E5', 'G8', 'J10', 'K9', 'R10', 'J5']}] }),
        Part(**{ 'name':'XC6SLX9-TQG144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX9-TQG144'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Spartan6.kicad_sym\nXC6SLX9-TQG144\n\nFPGA', 'pins':[
            Pin(num='100',name='IO_L33P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO_L32N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO_L32P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='IO_L1N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='IO_L1P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='IO_L64N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='IO_L47N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IO_L47P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IO_L46N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='IO_L46P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO_L45N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO_L45P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO_L43N_GCLK4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO_L43P_GCLK5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='IO_L42N_GCLK6_TRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO_L42P_GCLK7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='IO_L41N_GCLK8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='IO_L41P_GCLK9_IRDY1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='IO_L40N_GCLK10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO_L40P_GCLK11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO_L34N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO_L34P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO_L33N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='10',name='IO_L50P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='11',name='IO_L49N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='12',name='IO_L49P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='14',name='IO_L44N_GCLK20_3',func=pin_types.BIDIR,unit=2),
            Pin(num='15',name='IO_L44P_GCLK21_3',func=pin_types.BIDIR,unit=2),
            Pin(num='16',name='IO_L43N_GCLK22_IRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='17',name='IO_L43P_GCLK23_3',func=pin_types.BIDIR,unit=2),
            Pin(num='18',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='2',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='21',name='IO_L42N_GCLK24_3',func=pin_types.BIDIR,unit=2),
            Pin(num='22',name='IO_L42P_GCLK25_TRDY2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='23',name='IO_L41N_GCLK26_3',func=pin_types.BIDIR,unit=2),
            Pin(num='24',name='IO_L41P_GCLK27_3',func=pin_types.BIDIR,unit=2),
            Pin(num='26',name='IO_L37N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='27',name='IO_L37P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='29',name='IO_L36N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='30',name='IO_L36P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='31',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='32',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='33',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='34',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='35',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='38',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='39',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='40',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='41',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='42',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='43',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='44',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='45',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='46',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='47',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='48',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='5',name='IO_L52N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='50',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='51',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='55',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='56',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='57',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='58',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='59',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='6',name='IO_L52P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='60',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='61',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='62',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='63',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='64',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='65',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='66',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='67',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='69',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='7',name='IO_L51N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='70',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='8',name='IO_L51P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='9',name='IO_L50N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='106',name='TDO',func=pin_types.BIDIR,unit=3),
            Pin(num='107',name='TMS',func=pin_types.BIDIR,unit=3),
            Pin(num='109',name='TCK',func=pin_types.BIDIR,unit=3),
            Pin(num='110',name='TDI',func=pin_types.BIDIR,unit=3),
            Pin(num='37',name='PROGRAM_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='71',name='DONE_2',func=pin_types.BIDIR,unit=3),
            Pin(num='72',name='CMPCS_B_2',func=pin_types.BIDIR,unit=3),
            Pin(num='73',name='SUSPEND',func=pin_types.BIDIR,unit=3),
            Pin(num='108',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='113',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='128',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='129',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='130',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='136',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='19',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='20',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='28',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='36',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='49',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='52',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='53',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='54',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='68',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='77',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='89',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='90',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='91',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='96',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['85', '97', '131', '120', '140', '78', '86', '98', '105', '79', '87', '99', '121', '111', '132', '141', '112', '122', '133', '142', '80', '88', '114', '123', '103', '134', '143', '115', '81', '92', '104', '116', '124', '135', '144', '82', '93', '117', '125', '137', '74', '100', '83', '94', '118', '126', '138', '75', '101', '84', '95', '102', '119', '127', '76', '139']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '43', '61', '34', '51', '7', '16', '26', '35', '44', '55', '62', '70', '17', '27', '38', '45', '56', '63', '8', '1', '18', '29', '39', '46', '57', '64', '9', '10', '2', '30', '4', '47', '58', '65', '11', '21', '31', '40', '48', '59', '66', '12', '22', '24', '32', '41', '5', '6', '67', '14', '23', '33', '42', '50', '60', '69']},{'label': 'uC', 'num': 3, 'pin_nums': ['107', '110', '73', '109', '37', '106', '72', '71']},{'label': 'uD', 'num': 4, 'pin_nums': ['89', '13', '90', '36', '130', '49', '91', '136', '52', '96', '19', '53', '108', '20', '54', '113', '25', '68', '128', '28', '129', '77', '3']}] })])