from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Sensor_Current = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'A1363xKTTN-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1363xKTTN-1'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1363-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1363xKTTN-1\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1365xKTTN-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1365xKTTN-1'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1365-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1365xKTTN-1\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1369xUA-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1369xUA-10'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-3'], 'footprint':'Sensor_Current:Allegro_SIP-3', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1369-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1369xUA-10\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS706xLC-05C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS706xLC-05C'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated obsolete', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS706ELC-05C-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS706xLC-05C\n\nhall effect current monitor sensor isolated obsolete', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS709xLFTR-6BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS709xLFTR-6BB'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS709-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS709xLFTR-6BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-6BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-6BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-6BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS711xEXLT-15AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS711xEXLT-15AB'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QFN-12-10-1EP_3x3mm_P0.5mm'], 'footprint':'Sensor_Current:Allegro_QFN-12-10-1EP_3x3mm_P0.5mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/Media/Files/Datasheets/ACS711-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS711xEXLT-15AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VIOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS711xLCTR-12AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS711xLCTR-12AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/Media/Files/Datasheets/ACS711-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS711xLCTR-12AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS712xLCTR-05B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS712xLCTR-05B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS712-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS712xLCTR-05B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS717xMATR-10B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS717xMATR-10B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS717-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS717xMATR-10B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS720xMATR-15B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS720xMATR-15B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS720-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS720xMATR-15B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~{FAULT_S}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT_F}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC_F',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VOC_S',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-05AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-05AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-05AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xMATR-10AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xMATR-10AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xMATR-10AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xMATR-12AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xMATR-12AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xMATR-12AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS726xLFTR-20B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS726xLFTR-20B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS726-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS726xLFTR-20B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VOUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VOUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VINGP',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VINGN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VOUTGN',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VOUTGP',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS730xLCTR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS730xLCTR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS730-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS730xLCTR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS732xLATR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS732xLATR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS732-ACS733-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS732xLATR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PROGRAM',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS756xCB-050B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS756xCB-050B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS756-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS756xCB-050B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-100B-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-100B-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-100B-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-150B-PSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-150B-PSS'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSS'], 'footprint':'Sensor_Current:Allegro_CB_PSS', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-150B-PSS\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS780xLRTR-050B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS780xLRTR-050B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS780xLRTR-050B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CKSR_15-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CKSR_15-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_CKSR'], 'footprint':'Sensor_Current:LEM_CKSR', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/cksr_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCKSR_15-NP\n\ncurrent transducer', 'pins':[
            Pin(num='11',name='Vref',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2063', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2063'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2063.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2063\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2092', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2092'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7S'], 'footprint':'Sensor_Current:AKM_CQ_7S', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2092.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2092\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3200'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3200.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3200\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CSLW6B1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CSLW6B1'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Honeywell_CSLW'], 'footprint':'Sensor_Current:Honeywell_CSLW', 'keywords':'hall current sensor', 'description':'', 'datasheet':'https://sensing.honeywell.com/honeywell-sensing-cslw-series-product-sheet-005861-1-en.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCSLW6B1\n\nhall current sensor', 'pins':[
            Pin(num='1',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Iout',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Iin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CZ-3813', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CZ-3813'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm'], 'footprint':'Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CZ-3813.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCZ-3813\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO40-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO40-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO40-NP'], 'footprint':'Sensor_Current:LEM_HO40-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_0100__1100_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO40-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO8-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO8-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NP'], 'footprint':'Sensor_Current:LEM_HO8-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np-0000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO8-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO8-NPxSP33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO8-NPxSP33'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NP'], 'footprint':'Sensor_Current:LEM_HO8-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_sp33-1000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO8-NPxSP33\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO8-NSM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO8-NSM'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NSM'], 'footprint':'Sensor_Current:LEM_HO8-NSM', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-nsm-0000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO8-NSM\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HTFS200-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HTFS200-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HTFS'], 'footprint':'Sensor_Current:LEM_HTFS', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/htfs_200_800-p.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHTFS200-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Vc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX02-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX02-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX02-P'], 'footprint':'Sensor_Current:LEM_HX02-P', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%202_6-p_e%20v5.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX02-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX03-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX03-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX03-P-SP2'], 'footprint':'Sensor_Current:LEM_HX03-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX03-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX04-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX04-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX04-P'], 'footprint':'Sensor_Current:LEM_HX04-P', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%202_6-p_e%20v5.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX04-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX05-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX05-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX05-NP'], 'footprint':'Sensor_Current:LEM_HX05-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%205_15-np_e%20v10.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX05-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN2+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX05-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX05-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX05-P-SP2'], 'footprint':'Sensor_Current:LEM_HX05-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX05-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX06-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX06-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX06-P'], 'footprint':'Sensor_Current:LEM_HX06-P', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%202_6-p_e%20v5.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX06-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX10-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX10-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX10-NP'], 'footprint':'Sensor_Current:LEM_HX10-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%205_15-np_e%20v10.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX10-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN2+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX10-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX10-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX10-P-SP2'], 'footprint':'Sensor_Current:LEM_HX10-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX10-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX15-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX15-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX15-NP'], 'footprint':'Sensor_Current:LEM_HX15-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%205_15-np_e%20v10.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX15-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN2+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX15-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX15-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX15-P-SP2'], 'footprint':'Sensor_Current:LEM_HX15-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX15-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX20-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX20-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX20-P-SP2'], 'footprint':'Sensor_Current:LEM_HX20-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX20-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX25-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX25-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX25-P-SP2'], 'footprint':'Sensor_Current:LEM_HX25-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX25-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX50-P-SP2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX50-P-SP2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HX50-P-SP2'], 'footprint':'Sensor_Current:LEM_HX50-P-SP2', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/hx%203_50-p_sp2_e%20v07.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHX50-P-SP2\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR2175', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR2175'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'half bridge current sense', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir2175.pdf?fileId=5546d462533600a4015355c9161216c6', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nIR2175\n\nhalf bridge current sense', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{OC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VB',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VIN+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR21771S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR21771S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'half bridge current sense', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir21771s.pdf?fileId=5546d462533600a4015355c9222c16c8', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nIR21771S\n\nhalf bridge current sense', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='PO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR2177S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR2177S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'half bridge current sense', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir2177s.pdf?fileId=5546d462533600a4015355c92e7416cb', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nIR2177S\n\nhalf bridge current sense', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='PO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR25750L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR25750L'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'single current sense', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir25750lpbf.pdf?fileId=5546d462533600a4015355ca1d0e16f7', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nIR25750L\n\nsingle current sense', 'pins':[
            Pin(num='1',name='CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GATE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LA25-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LA25-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LA25-NP'], 'footprint':'Sensor_Current:LEM_LA25-NP', 'keywords':'Current Transducer LEM ', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/la%2025-np.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLA25-NP\n\nCurrent Transducer LEM ', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='+',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='M',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OUT',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='OUT',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LA25-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LA25-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LA25-P'], 'footprint':'Sensor_Current:LEM_LA25-P', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/la_25-p.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLA25-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='M',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTSR6-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTSR6-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LTSR-NP'], 'footprint':'Sensor_Current:LEM_LTSR-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ltsr_6-np.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLTSR6-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Ref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Out',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='0V',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-65-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-65-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1102-01%20RevG_MCA1101_Fix%20Gain%205V_10112021.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-65-5\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1363xKTTN-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1363xKTTN-10'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1363-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1363xKTTN-10\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1363xKTTN-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1363xKTTN-2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1363-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1363xKTTN-2\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1363xKTTN-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1363xKTTN-5'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1363-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1363xKTTN-5\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1365xKTTN-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1365xKTTN-10'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1365-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1365xKTTN-10\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1365xKTTN-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1365xKTTN-2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1365-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1365xKTTN-2\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1365xKTTN-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1365xKTTN-5'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1365-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1365xKTTN-5\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1366xKTTN-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1366xKTTN-1'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1366-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1366xKTTN-1\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1366xKTTN-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1366xKTTN-10'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1366-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1366xKTTN-10\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1366xKTTN-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1366xKTTN-2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1366-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1366xKTTN-2\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1366xKTTN-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1366xKTTN-5'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1366-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1366xKTTN-5\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1367xKTTN-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1367xKTTN-1'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1367-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1367xKTTN-1\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1367xKTTN-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1367xKTTN-10'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1367-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1367xKTTN-10\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1367xKTTN-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1367xKTTN-2'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1367-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1367xKTTN-2\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1367xKTTN-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1367xKTTN-5'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4', 'Sensor_Current:Allegro_SIP-4'], 'footprint':'Sensor_Current:Allegro_SIP-4', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1367-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1367xKTTN-5\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A1369xUA-24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A1369xUA-24'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-3', 'Sensor_Current:Allegro_SIP-3'], 'footprint':'Sensor_Current:Allegro_SIP-3', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A1369-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nA1369xUA-24\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS709xLFTR-10BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS709xLFTR-10BB'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS709-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS709xLFTR-10BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS709xLFTR-20BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS709xLFTR-20BB'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS709-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS709xLFTR-20BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS709xLFTR-35BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS709xLFTR-35BB'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS709-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS709xLFTR-35BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-10BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-10BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-10BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-10BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-10BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-10BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-12BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-12BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-12BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-12BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-12BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-12BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-25BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-25BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-25BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-25BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-25BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-25BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS710xLATR-6BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS710xLATR-6BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS710-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS710xLATR-6BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS711xEXLT-31AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS711xEXLT-31AB'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QFN-12-10-1EP_3x3mm_P0.5mm', 'Sensor_Current:Allegro_QFN-12-10-1EP_3x3mm_P0.5mm'], 'footprint':'Sensor_Current:Allegro_QFN-12-10-1EP_3x3mm_P0.5mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/Media/Files/Datasheets/ACS711-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS711xEXLT-31AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VIOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS711xLCTR-25AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS711xLCTR-25AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/Media/Files/Datasheets/ACS711-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS711xLCTR-25AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS712xLCTR-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS712xLCTR-20A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS712-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS712xLCTR-20A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS712xLCTR-30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS712xLCTR-30A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS712-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS712xLCTR-30A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS713xLCTR-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS713xLCTR-20A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS713-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS713xLCTR-20A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS713xLCTR-30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS713xLCTR-30A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS713-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS713xLCTR-30A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS714xLCTR-05B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS714xLCTR-05B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS714-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS714xLCTR-05B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS714xLCTR-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS714xLCTR-20A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS714-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS714xLCTR-20A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS714xLCTR-30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS714xLCTR-30A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS714-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS714xLCTR-30A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS714xLCTR-50A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS714xLCTR-50A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS714-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS714xLCTR-50A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS715xLCTR-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS715xLCTR-20A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS715-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS715xLCTR-20A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS715xLCTR-30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS715xLCTR-30A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS715-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS715xLCTR-30A\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS716xLATR-12BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS716xLATR-12BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS716-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS716xLATR-12BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS716xLATR-12BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS716xLATR-12BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS716-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS716xLATR-12BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS716xLATR-25BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS716xLATR-25BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS716-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS716xLATR-25BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS716xLATR-25BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS716xLATR-25BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS716-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS716xLATR-25BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS716xLATR-6BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS716xLATR-6BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS716-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS716xLATR-6BB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS716xLATR-6BB-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS716xLATR-6BB-NL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS716-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS716xLATR-6BB-NL\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='FAULT_EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS717xMATR-20B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS717xMATR-20B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS717-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS717xMATR-20B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS718xMATR-10B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS718xMATR-10B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS718-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS718xMATR-10B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS718xMATR-20B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS718xMATR-20B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS718-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS718xMATR-20B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS720xMATR-35B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS720xMATR-35B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS720-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS720xMATR-35B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~{FAULT_S}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT_F}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC_F',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VOC_S',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS720xMATR-65B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS720xMATR-65B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS720-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS720xMATR-65B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~{FAULT_S}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT_F}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOC_F',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VOC_S',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-10AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-10AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-10AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-10AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-10AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-10AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-20AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-20AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-20AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xLCTR-40AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xLCTR-40AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xLCTR-40AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xMATR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xMATR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xMATR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS722xMATR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS722xMATR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS722KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS722xMATR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-05AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-05AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-05AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-10AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-10AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-10AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-10AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-10AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-10AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-20AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-20AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-20AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xLCTR-40AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xLCTR-40AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xLCTR-40AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xMATR-10AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xMATR-10AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xMATR-10AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xMATR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xMATR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xMATR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS723xMATR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS723xMATR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS723KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS723xMATR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BW_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-05AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-05AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-05AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-10AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-10AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-10AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-10AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-10AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-10AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-20AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-20AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-20AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-30AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-30AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-30AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-30AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-30AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-30AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xLCTR-50AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xLCTR-50AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xLCTR-50AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xMATR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xMATR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xMATR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xMATR-30AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xMATR-30AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xMATR-30AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xMATR-30AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xMATR-30AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xMATR-30AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS724xMATR-65AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS724xMATR-65AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS724KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS724xMATR-65AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-10AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-10AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-10AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-20AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-20AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-20AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-30AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-30AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-30AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-30AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-30AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-30AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xLCTR-50AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xLCTR-50AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xLCTR-50AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xMATR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xMATR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xMATR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xMATR-30AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xMATR-30AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xMATR-30AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS725xMATR-30AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS725xMATR-30AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS725KMA-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS725xMATR-30AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS726xLFTR-40B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS726xLFTR-40B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Sensor_Current:Allegro_QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS726-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS726xLFTR-40B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VOUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VOUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VINGP',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VINGN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VOUTGN',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VOUTGP',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS730xLCTR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS730xLCTR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS730-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS730xLCTR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS730xLCTR-40AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS730xLCTR-40AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS730-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS730xLCTR-40AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS730xLCTR-50AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS730xLCTR-50AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS730-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS730xLCTR-50AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS730xLCTR-80AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS730xLCTR-80AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS730-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS730xLCTR-80AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VZCR',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS73369xUAA-010B5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS73369xUAA-010B5'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_SIP-3', 'Sensor_Current:Allegro_SIP-3', 'Sensor_Current:Allegro_SIP-3'], 'footprint':'Sensor_Current:Allegro_SIP-3', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS73369-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS73369xUAA-010B5\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS733xLATR-20AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS733xLATR-20AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS732-ACS733-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS733xLATR-20AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PROGRAM',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS733xLATR-40AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS733xLATR-40AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS732-ACS733-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS733xLATR-40AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PROGRAM',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS733xLATR-40AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS733xLATR-40AU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS732-ACS733-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS733xLATR-40AU\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PROGRAM',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS733xLATR-65AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS733xLATR-65AB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS732-ACS733-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS733xLATR-65AB\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PROGRAM',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS756xCB-100B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS756xCB-100B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS756-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS756xCB-100B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-050B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-050B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-050B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-050U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-050U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-050U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-100B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-100B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-100B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-100U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-100U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-100U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-150B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-150B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-150B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-150U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-150U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-150U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-150U-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-150U-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-150U-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-200B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-200B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-200B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-200B-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-200B-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-200B-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-200B-PSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-200B-PSS'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSS', 'Sensor_Current:Allegro_CB_PSS'], 'footprint':'Sensor_Current:Allegro_CB_PSS', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-200B-PSS\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-200U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-200U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-200U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS758xCB-200U-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS758xCB-200U-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS758xCB-200U-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS759xCB-050B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS759xCB-050B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS759-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS759xCB-050B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS759xCB-100B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS759xCB-100B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS759-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS759xCB-100B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS759xCB-150B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS759xCB-150B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS759-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS759xCB-150B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS759xCB-150B-PSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS759xCB-150B-PSS'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSS', 'Sensor_Current:Allegro_CB_PSS', 'Sensor_Current:Allegro_CB_PSS'], 'footprint':'Sensor_Current:Allegro_CB_PSS', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS759-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS759xCB-150B-PSS\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS759xCB-200B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS759xCB-200B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS759-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS759xCB-200B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS759xCB-200B-PSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS759xCB-200B-PSS'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSS', 'Sensor_Current:Allegro_CB_PSS', 'Sensor_Current:Allegro_CB_PSS', 'Sensor_Current:Allegro_CB_PSS'], 'footprint':'Sensor_Current:Allegro_CB_PSS', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS759-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS759xCB-200B-PSS\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-050B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-050B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-050B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-050U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-050U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-050U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-100B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-100B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-100B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-100U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-100U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-100U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-100U-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-100U-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-100U-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-150B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-150B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-150B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-150B-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-150B-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-150B-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-150U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-150U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-150U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-150U-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-150U-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-150U-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-200B-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-200B-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-200B-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-200B-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-200B-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-200B-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-200U-PFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-200U-PFF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF', 'Sensor_Current:Allegro_CB_PFF'], 'footprint':'Sensor_Current:Allegro_CB_PFF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-200U-PFF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS770xCB-200U-PSF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS770xCB-200U-PSF'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF', 'Sensor_Current:Allegro_CB_PSF'], 'footprint':'Sensor_Current:Allegro_CB_PSF', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS758-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS770xCB-200U-PSF\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS780xLRTR-050U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS780xLRTR-050U'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS780xLRTR-050U\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS780xLRTR-100B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS780xLRTR-100B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS780xLRTR-100B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS780xLRTR-100U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS780xLRTR-100U'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS780xLRTR-100U\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS780xLRTR-150B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS780xLRTR-150B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS780xLRTR-150B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS780xLRTR-150U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS780xLRTR-150U'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS780xLRTR-150U\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS781xLRTR-050B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS781xLRTR-050B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS781xLRTR-050B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS781xLRTR-050U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS781xLRTR-050U'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS781xLRTR-050U\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS781xLRTR-100B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS781xLRTR-100B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS780-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS781xLRTR-100B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS781xLRTR-100U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS781xLRTR-100U'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS781-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS781xLRTR-100U\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS781xLRTR-150B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS781xLRTR-150B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS781-Datsaheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS781xLRTR-150B\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ACS781xLRTR-150U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ACS781xLRTR-150U'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm'], 'footprint':'Sensor_Current:Allegro_PSOF-7_4.8x6.4mm_P1.60mm', 'keywords':'hall effect current monitor sensor isolated', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/ACS781-Datsaheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nACS781xLRTR-150U\n\nhall effect current monitor sensor isolated', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CKSR_25-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CKSR_25-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_CKSR', 'Sensor_Current:LEM_CKSR'], 'footprint':'Sensor_Current:LEM_CKSR', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/cksr_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCKSR_25-NP\n\ncurrent transducer', 'pins':[
            Pin(num='11',name='Vref',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CKSR_50-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CKSR_50-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_CKSR', 'Sensor_Current:LEM_CKSR', 'Sensor_Current:LEM_CKSR'], 'footprint':'Sensor_Current:LEM_CKSR', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/cksr_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCKSR_50-NP\n\ncurrent transducer', 'pins':[
            Pin(num='11',name='Vref',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CKSR_6-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CKSR_6-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_CKSR', 'Sensor_Current:LEM_CKSR', 'Sensor_Current:LEM_CKSR', 'Sensor_Current:LEM_CKSR'], 'footprint':'Sensor_Current:LEM_CKSR', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/cksr_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCKSR_6-NP\n\ncurrent transducer', 'pins':[
            Pin(num='11',name='Vref',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2064', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2064'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2064.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2064\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2065', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2065'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2065.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2065\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-206A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-206A'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-206A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-206A\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-206B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-206B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-206B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-206B\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2093', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2093'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S'], 'footprint':'Sensor_Current:AKM_CQ_7S', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2093.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2093\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-209A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-209A'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S'], 'footprint':'Sensor_Current:AKM_CQ_7S', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-209A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-209A\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-209B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-209B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S'], 'footprint':'Sensor_Current:AKM_CQ_7S', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-209B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-209B\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-209D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-209D'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S', 'Sensor_Current:AKM_CQ_7S'], 'footprint':'Sensor_Current:AKM_CQ_7S', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-209D.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-209D\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2232', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2232'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2232.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2232\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2233', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2233'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2233.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2233\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2234', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2234'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2234.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2234\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2235', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2235'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2235.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2235\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2332', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2332'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2332.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2332\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2333', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2333'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2333.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2333\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2334', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2334'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2334.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2334\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2335', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2335'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2335.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2335\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-2336', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-2336'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-2335.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-2336\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-236B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-236B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7', 'Sensor_Current:AKM_CQ_7'], 'footprint':'Sensor_Current:AKM_CQ_7', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-236B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-236B\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='DATA_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCLK',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3201'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3201.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3201\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3202'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3202.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3202\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3203'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3203.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3203\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3204'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3204.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3204\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-320A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-320A'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-320A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-320A\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-320B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-320B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-320B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-320B\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3300', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3300'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3300.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3300\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3301'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3301.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3301\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3302'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3302.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3302\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-3303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-3303'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-3303.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-3303\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330A'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330A\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330B'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330B\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330E'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330E.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330E\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330F'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330F.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330F\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330G'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330G.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330G\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330H'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330H.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330H\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CQ-330J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CQ-330J'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm'], 'footprint':'Sensor_Current:AKM_CQ_VSOP-24_5.6x7.9mm_P0.65mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CQ-330J.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCQ-330J\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='TAB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TEST1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TEST2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='TEST3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TAB',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CSLW6B200M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CSLW6B200M'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Honeywell_CSLW', 'Sensor_Current:Honeywell_CSLW'], 'footprint':'Sensor_Current:Honeywell_CSLW', 'keywords':'hall current sensor', 'description':'', 'datasheet':'https://sensing.honeywell.com/honeywell-sensing-cslw-series-product-sheet-005861-1-en.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCSLW6B200M\n\nhall current sensor', 'pins':[
            Pin(num='1',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Iout',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Iin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CSLW6B40M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CSLW6B40M'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Honeywell_CSLW', 'Sensor_Current:Honeywell_CSLW', 'Sensor_Current:Honeywell_CSLW'], 'footprint':'Sensor_Current:Honeywell_CSLW', 'keywords':'hall current sensor', 'description':'', 'datasheet':'https://sensing.honeywell.com/honeywell-sensing-cslw-series-product-sheet-005861-1-en.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCSLW6B40M\n\nhall current sensor', 'pins':[
            Pin(num='1',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Iout',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Iin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CSLW6B5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CSLW6B5'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:Honeywell_CSLW', 'Sensor_Current:Honeywell_CSLW', 'Sensor_Current:Honeywell_CSLW', 'Sensor_Current:Honeywell_CSLW'], 'footprint':'Sensor_Current:Honeywell_CSLW', 'keywords':'hall current sensor', 'description':'', 'datasheet':'https://sensing.honeywell.com/honeywell-sensing-cslw-series-product-sheet-005861-1-en.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCSLW6B5\n\nhall current sensor', 'pins':[
            Pin(num='1',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Iout',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Iin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CZ-3814', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CZ-3814'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm', 'Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm'], 'footprint':'Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CZ-3814.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCZ-3814\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CZ-3815', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CZ-3815'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm', 'Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm', 'Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm'], 'footprint':'Sensor_Current:AKM_CZ_SSOP-10_6.5x8.1mm_P0.95mm', 'keywords':'hall effect current sensor', 'description':'', 'datasheet':'http://www.akm.com/akm/en/file/datasheet/CZ-3815.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nCZ-3815\n\nhall effect current sensor', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO120-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO120-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO40-NP', 'Sensor_Current:LEM_HO40-NP'], 'footprint':'Sensor_Current:LEM_HO40-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_0100__1100_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO120-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO15-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO15-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NP', 'Sensor_Current:LEM_HO8-NP'], 'footprint':'Sensor_Current:LEM_HO8-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np-0000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO15-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO15-NPxSP33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO15-NPxSP33'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NP', 'Sensor_Current:LEM_HO8-NP'], 'footprint':'Sensor_Current:LEM_HO8-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_sp33-1000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO15-NPxSP33\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO15-NSM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO15-NSM'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NSM', 'Sensor_Current:LEM_HO8-NSM'], 'footprint':'Sensor_Current:LEM_HO8-NSM', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-nsm-0000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO15-NSM\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO150-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO150-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO40-NP', 'Sensor_Current:LEM_HO40-NP', 'Sensor_Current:LEM_HO40-NP'], 'footprint':'Sensor_Current:LEM_HO40-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_0100__1100_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO150-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO25-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO25-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NP', 'Sensor_Current:LEM_HO8-NP', 'Sensor_Current:LEM_HO8-NP'], 'footprint':'Sensor_Current:LEM_HO8-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np-0000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO25-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO25-NPxSP33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO25-NPxSP33'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NP', 'Sensor_Current:LEM_HO8-NP', 'Sensor_Current:LEM_HO8-NP'], 'footprint':'Sensor_Current:LEM_HO8-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_sp33-1000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO25-NPxSP33\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO25-NSM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO25-NSM'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO8-NSM', 'Sensor_Current:LEM_HO8-NSM', 'Sensor_Current:LEM_HO8-NSM'], 'footprint':'Sensor_Current:LEM_HO8-NSM', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-nsm-0000_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO25-NSM\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='0V',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Standby',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HO60-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HO60-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HO40-NP', 'Sensor_Current:LEM_HO40-NP', 'Sensor_Current:LEM_HO40-NP', 'Sensor_Current:LEM_HO40-NP'], 'footprint':'Sensor_Current:LEM_HO40-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ho-np_0100__1100_series.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHO60-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Uc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OCD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HTFS400-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HTFS400-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HTFS', 'Sensor_Current:LEM_HTFS'], 'footprint':'Sensor_Current:LEM_HTFS', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/htfs_200_800-p.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHTFS400-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Vc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HTFS600-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HTFS600-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HTFS', 'Sensor_Current:LEM_HTFS', 'Sensor_Current:LEM_HTFS'], 'footprint':'Sensor_Current:LEM_HTFS', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/htfs_200_800-p.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHTFS600-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Vc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HTFS800-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HTFS800-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_HTFS', 'Sensor_Current:LEM_HTFS', 'Sensor_Current:LEM_HTFS', 'Sensor_Current:LEM_HTFS'], 'footprint':'Sensor_Current:LEM_HTFS', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/htfs_200_800-p.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nHTFS800-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='+Vc',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vref',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR22771S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR22771S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'half bridge current sense', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir21771s.pdf?fileId=5546d462533600a4015355c9222c16c8', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nIR22771S\n\nhalf bridge current sense', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='PO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR2277S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR2277S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'half bridge current sense', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir2177s.pdf?fileId=5546d462533600a4015355c92e7416cb', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nIR2277S\n\nhalf bridge current sense', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='PO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LA100-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LA100-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LA25-P', 'Sensor_Current:LEM_LA25-P'], 'footprint':'Sensor_Current:LEM_LA25-P', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/la_100-p_e_.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLA100-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='M',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LA55-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LA55-P'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LA25-P', 'Sensor_Current:LEM_LA25-P', 'Sensor_Current:LEM_LA25-P'], 'footprint':'Sensor_Current:LEM_LA25-P', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/la_55-p_e.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLA55-P\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='M',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTSR15-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTSR15-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LTSR-NP', 'Sensor_Current:LEM_LTSR-NP'], 'footprint':'Sensor_Current:LEM_LTSR-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ltsr_15-np.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLTSR15-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Ref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Out',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='0V',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTSR25-NP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTSR25-NP'}), 'ref_prefix':'U', 'fplist':['Sensor_Current:LEM_LTSR-NP', 'Sensor_Current:LEM_LTSR-NP', 'Sensor_Current:LEM_LTSR-NP'], 'footprint':'Sensor_Current:LEM_LTSR-NP', 'keywords':'current transducer', 'description':'', 'datasheet':'https://www.lem.com/sites/default/files/products_datasheets/ltsr_25-np.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nLTSR25-NP\n\ncurrent transducer', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Ref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Out',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='0V',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-20-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-20-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1104-01_C%20Datasheet%2C%20Current%20Sensor%20Fix%20Gain%203.3V_20210408.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-20-3\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-20-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-20-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1102-01%20RevG_MCA1101_Fix%20Gain%205V_10112021.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-20-5\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-5-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-5-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1104-01_C%20Datasheet%2C%20Current%20Sensor%20Fix%20Gain%203.3V_20210408.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-5-3\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-5-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-5-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1102-01%20RevG_MCA1101_Fix%20Gain%205V_10112021.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-5-5\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-50-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-50-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1104-01_C%20Datasheet%2C%20Current%20Sensor%20Fix%20Gain%203.3V_20210408.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-50-3\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCA1101-50-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCA1101-50-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'amr-sensor isolated-current-sensor', 'description':'', 'datasheet':'https://navview.blob.core.windows.net/web-resources/6020-1102-01%20RevG_MCA1101_Fix%20Gain%205V_10112021.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Current.kicad_sym\nMCA1101-50-5\n\namr-sensor isolated-current-sensor', 'pins':[
            Pin(num='1',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VOC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IP-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{FAULTB}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] })])